/* Generated by Cython 0.28.3 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [],
        "extra_compile_args": [
            "-O2"
        ],
        "name": "uvloop.loop",
        "sources": [
            "uvloop/loop.pyx"
        ]
    },
    "module_name": "uvloop.loop"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_28_3"
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (0 && PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0; // PyThread_create_key reports success always
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif // TSS (Thread Specific Storage) API
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
  #define PyObject_Unicode             PyObject_Str
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : (Py_INCREF(func), func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__uvloop__loop
#define __PYX_HAVE_API__uvloop__loop
/* Early includes */
#include <stdint.h>
#include <sys/types.h>
#include "arpa/inet.h"
#include "sys/socket.h"
#include "unistd.h"
#include "pthread.h"
#include "includes/compat.h"
#include "uv.h"
#include "includes/debug.h"
#include <string.h>
#include <errno.h>
#include <stdio.h>
#include "pythread.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "uvloop/sslproto.pyx",
  "uvloop/errors.pyx",
  "uvloop/loop.pyx",
  "uvloop/cbhandles.pyx",
  "uvloop/handles/handle.pyx",
  "uvloop/handles/tcp.pyx",
  "uvloop/handles/process.pyx",
  "uvloop/dns.pyx",
  "uvloop/loop.pxd",
  "stringsource",
  "uvloop/pseudosock.pyx",
  "uvloop/handles/async_.pyx",
  "uvloop/handles/idle.pyx",
  "uvloop/handles/check.pyx",
  "uvloop/handles/timer.pyx",
  "uvloop/handles/poll.pyx",
  "uvloop/handles/basetransport.pyx",
  "uvloop/handles/basetransport.pxd",
  "uvloop/handles/stream.pyx",
  "uvloop/handles/streamserver.pyx",
  "uvloop/handles/pipe.pyx",
  "uvloop/request.pyx",
  "uvloop/handles/udp.pyx",
  "uvloop/server.pyx",
  "type.pxd",
  "bool.pxd",
  "complex.pxd",
  "uvloop/includes/stdlib.pxi",
};
/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif


/*--- Type declarations ---*/
struct __pyx_obj_6uvloop_4loop_Loop;
struct __pyx_obj_6uvloop_4loop_Handle;
struct __pyx_obj_6uvloop_4loop_TimerHandle;
struct __pyx_obj_6uvloop_4loop_UVHandle;
struct __pyx_obj_6uvloop_4loop_UVSocketHandle;
struct __pyx_obj_6uvloop_4loop_UVAsync;
struct __pyx_obj_6uvloop_4loop_UVIdle;
struct __pyx_obj_6uvloop_4loop_UVCheck;
struct __pyx_obj_6uvloop_4loop_UVTimer;
struct __pyx_obj_6uvloop_4loop_UVPoll;
struct __pyx_obj_6uvloop_4loop_UVBaseTransport;
struct __pyx_obj_6uvloop_4loop_UVStream;
struct __pyx_obj_6uvloop_4loop_UVStreamServer;
struct __pyx_obj_6uvloop_4loop_TCPServer;
struct __pyx_obj_6uvloop_4loop_TCPTransport;
struct __pyx_obj_6uvloop_4loop_UnixServer;
struct __pyx_obj_6uvloop_4loop_UnixTransport;
struct __pyx_obj_6uvloop_4loop_ReadUnixTransport;
struct __pyx_obj_6uvloop_4loop_WriteUnixTransport;
struct __pyx_obj_6uvloop_4loop_UVProcess;
struct __pyx_obj_6uvloop_4loop_UVProcessTransport;
struct __pyx_obj_6uvloop_4loop_UVRequest;
struct __pyx_obj_6uvloop_4loop_UDPTransport;
struct __pyx_obj_6uvloop_4loop_Server;
struct __pyx_obj_6uvloop_4loop_PseudoSocket;
struct __pyx_obj_6uvloop_4loop__StreamWriteContext;
struct __pyx_obj_6uvloop_4loop__TCPConnectRequest;
struct __pyx_obj_6uvloop_4loop__PipeConnectRequest;
struct __pyx_obj_6uvloop_4loop_AddrInfo;
struct __pyx_obj_6uvloop_4loop_AddrInfoRequest;
struct __pyx_obj_6uvloop_4loop_NameInfoRequest;
struct __pyx_obj_6uvloop_4loop__SSLPipe;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed;
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1;
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py;
struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error;
struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits;
struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__fatal_error;
struct __pyx_opt_args_6uvloop_4loop_9TCPServer_bind;
struct __pyx_opt_args_6uvloop_4loop_12TCPTransport_bind;
struct __pyx_opt_args_6uvloop_4loop_6UVPoll__fatal_error;
struct __pyx_opt_args_6uvloop_4loop_14UVStreamServer__fatal_error;
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_do_handshake;
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_shutdown;
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_ssldata;
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_appdata;

/* "uvloop/loop.pxd":26
 * cdef class UVBaseTransport(UVSocketHandle)
 * 
 * ctypedef object (*method_t)(object)             # <<<<<<<<<<<<<<
 * ctypedef object (*method1_t)(object, object)
 * ctypedef object (*method2_t)(object, object, object)
 */
typedef PyObject *(*__pyx_t_6uvloop_4loop_method_t)(PyObject *);

/* "uvloop/loop.pxd":27
 * 
 * ctypedef object (*method_t)(object)
 * ctypedef object (*method1_t)(object, object)             # <<<<<<<<<<<<<<
 * ctypedef object (*method2_t)(object, object, object)
 * ctypedef object (*method3_t)(object, object, object, object)
 */
typedef PyObject *(*__pyx_t_6uvloop_4loop_method1_t)(PyObject *, PyObject *);

/* "uvloop/loop.pxd":28
 * ctypedef object (*method_t)(object)
 * ctypedef object (*method1_t)(object, object)
 * ctypedef object (*method2_t)(object, object, object)             # <<<<<<<<<<<<<<
 * ctypedef object (*method3_t)(object, object, object, object)
 * 
 */
typedef PyObject *(*__pyx_t_6uvloop_4loop_method2_t)(PyObject *, PyObject *, PyObject *);

/* "uvloop/loop.pxd":29
 * ctypedef object (*method1_t)(object, object)
 * ctypedef object (*method2_t)(object, object, object)
 * ctypedef object (*method3_t)(object, object, object, object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
typedef PyObject *(*__pyx_t_6uvloop_4loop_method3_t)(PyObject *, PyObject *, PyObject *, PyObject *);

/* "uvloop/handles/handle.pxd":23
 * 
 *     cdef _error(self, exc, throw)
 *     cdef _fatal_error(self, exc, throw, reason=?)             # <<<<<<<<<<<<<<
 * 
 *     cdef _warn_unclosed(self)
 */
struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error {
  int __pyx_n;
  PyObject *reason;
};

/* "uvloop/handles/basetransport.pxd":24
 *     # All "inline" methods are final
 * 
 *     cdef inline _set_write_buffer_limits(self, int high=*, int low=*)             # <<<<<<<<<<<<<<
 *     cdef inline _maybe_pause_protocol(self)
 *     cdef inline _maybe_resume_protocol(self)
 */
struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits {
  int __pyx_n;
  int high;
  int low;
};

/* "uvloop/handles/basetransport.pxd":36
 * 
 *     # Overloads of UVHandle methods:
 *     cdef _fatal_error(self, exc, throw, reason=?)             # <<<<<<<<<<<<<<
 *     cdef _close(self)
 * 
 */
struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__fatal_error {
  int __pyx_n;
  PyObject *reason;
};

/* "uvloop/handles/tcp.pxd":2
 * cdef class TCPServer(UVStreamServer):
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=*)             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
struct __pyx_opt_args_6uvloop_4loop_9TCPServer_bind {
  int __pyx_n;
  unsigned int flags;
};

/* "uvloop/handles/tcp.pxd":17
 *         system.sockaddr_storage __sockname
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=*)             # <<<<<<<<<<<<<<
 *     cdef connect(self, system.sockaddr* addr)
 *     cdef _set_nodelay(self)
 */
struct __pyx_opt_args_6uvloop_4loop_12TCPTransport_bind {
  int __pyx_n;
  unsigned int flags;
};

/* "uvloop/handles/poll.pyx":174
 *         UVHandle._close(<UVHandle>self)
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         try:
 *             if self.reading_handle is not None:
 */
struct __pyx_opt_args_6uvloop_4loop_6UVPoll__fatal_error {
  int __pyx_n;
  PyObject *reason;
};

/* "uvloop/handles/streamserver.pyx":79
 *         client._accept(<UVStream>self)
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         # Overload UVHandle._fatal_error
 * 
 */
struct __pyx_opt_args_6uvloop_4loop_14UVStreamServer__fatal_error {
  int __pyx_n;
  PyObject *reason;
};

/* "uvloop/sslproto.pyx":83
 *         self._shutdown_cb = None
 * 
 *     cdef do_handshake(self, callback=None):             # <<<<<<<<<<<<<<
 *         """Start the SSL handshake.
 * 
 */
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_do_handshake {
  int __pyx_n;
  PyObject *callback;
};

/* "uvloop/sslproto.pyx":104
 *         return ssldata
 * 
 *     cdef shutdown(self, callback=None):             # <<<<<<<<<<<<<<
 *         """Start the SSL shutdown sequence.
 * 
 */
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_shutdown {
  int __pyx_n;
  PyObject *callback;
};

/* "uvloop/sslproto.pyx":134
 *         assert appdata == [] or appdata == [b'']
 * 
 *     cdef feed_ssldata(self, data, bint only_handshake=False):             # <<<<<<<<<<<<<<
 *         """Feed SSL record level data into the pipe.
 * 
 */
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_ssldata {
  int __pyx_n;
  int only_handshake;
};

/* "uvloop/sslproto.pyx":213
 *         return (ssldata, appdata)
 * 
 *     cdef feed_appdata(self, data, int offset=0):             # <<<<<<<<<<<<<<
 *         """Feed plaintext data into the pipe.
 * 
 */
struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_appdata {
  int __pyx_n;
  int offset;
};

/* "uvloop/loop.pxd":33
 * 
 * 
 * cdef class Loop:             # <<<<<<<<<<<<<<
 *     cdef:
 *         uv.uv_loop_t *uvloop
 */
struct __pyx_obj_6uvloop_4loop_Loop {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_Loop *__pyx_vtab;
  uv_loop_t *uvloop;
  int _coroutine_debug_set;
  int _coroutine_origin_tracking_saved_depth;
  PyObject *slow_callback_duration;
  int _closed;
  int _debug;
  int _running;
  int _stopping;
  uint64_t _thread_id;
  int _thread_is_main;
  PyObject *_task_factory;
  PyObject *_exception_handler;
  PyObject *_default_executor;
  PyObject *_ready;
  PyObject *_queued_streams;
  Py_ssize_t _ready_len;
  PyObject *_servers;
  PyObject *_transports;
  PyObject *_processes;
  PyObject *_fd_to_reader_fileobj;
  PyObject *_fd_to_writer_fileobj;
  PyObject *_signals;
  PyObject *_signal_handlers;
  PyObject *_ssock;
  PyObject *_csock;
  int _listening_signals;
  PyObject *_timers;
  PyObject *_polls;
  struct __pyx_obj_6uvloop_4loop_UVProcess *active_process_handler;
  struct __pyx_obj_6uvloop_4loop_UVAsync *handler_async;
  struct __pyx_obj_6uvloop_4loop_UVIdle *handler_idle;
  struct __pyx_obj_6uvloop_4loop_UVCheck *handler_check__exec_writes;
  PyObject *_last_error;
  PyObject *__weakref__;
  PyObject *_asyncgens;
  int _asyncgens_shutdown_called;
  char _recv_buffer[0x3E800];
  int _recv_buffer_in_use;
  int _debug_cc;
  PyObject *_debug_handles_total;
  PyObject *_debug_handles_closed;
  PyObject *_debug_handles_current;
  uint64_t _debug_uv_handles_total;
  uint64_t _debug_uv_handles_freed;
  uint64_t _debug_cb_handles_total;
  uint64_t _debug_cb_handles_count;
  uint64_t _debug_cb_timer_handles_total;
  uint64_t _debug_cb_timer_handles_count;
  uint64_t _debug_stream_shutdown_errors_total;
  uint64_t _debug_stream_listen_errors_total;
  uint64_t _debug_stream_read_cb_total;
  uint64_t _debug_stream_read_cb_errors_total;
  uint64_t _debug_stream_read_eof_total;
  uint64_t _debug_stream_read_eof_cb_errors_total;
  uint64_t _debug_stream_read_errors_total;
  uint64_t _debug_stream_write_tries;
  uint64_t _debug_stream_write_errors_total;
  uint64_t _debug_stream_write_ctx_total;
  uint64_t _debug_stream_write_ctx_cnt;
  uint64_t _debug_stream_write_cb_errors_total;
  uint64_t _poll_read_events_total;
  uint64_t _poll_read_cb_errors_total;
  uint64_t _poll_write_events_total;
  uint64_t _poll_write_cb_errors_total;
  uint64_t _sock_try_write_total;
  uint64_t _debug_exception_handler_cnt;
};


/* "uvloop/cbhandles.pxd":1
 * cdef class Handle:             # <<<<<<<<<<<<<<
 *     cdef:
 *         Loop loop
 */
struct __pyx_obj_6uvloop_4loop_Handle {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_Handle *__pyx_vtab;
  struct __pyx_obj_6uvloop_4loop_Loop *loop;
  PyObject *context;
  int _cancelled;
  PyObject *meth_name;
  int cb_type;
  void *callback;
  PyObject *arg1;
  PyObject *arg2;
  PyObject *arg3;
  PyObject *arg4;
  PyObject *__weakref__;
  PyObject *_source_traceback;
};


/* "uvloop/cbhandles.pxd":25
 * 
 * 
 * cdef class TimerHandle:             # <<<<<<<<<<<<<<
 *     cdef:
 *         object callback, args
 */
struct __pyx_obj_6uvloop_4loop_TimerHandle {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_TimerHandle *__pyx_vtab;
  PyObject *callback;
  PyObject *args;
  int _cancelled;
  struct __pyx_obj_6uvloop_4loop_UVTimer *timer;
  struct __pyx_obj_6uvloop_4loop_Loop *loop;
  PyObject *context;
  PyObject *__weakref__;
  PyObject *_source_traceback;
};


/* "uvloop/loop.pxd":17
 * 
 * 
 * cdef class UVHandle             # <<<<<<<<<<<<<<
 * cdef class UVSocketHandle(UVHandle)
 * 
 */
struct __pyx_obj_6uvloop_4loop_UVHandle {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *__pyx_vtab;
  uv_handle_t *_handle;
  struct __pyx_obj_6uvloop_4loop_Loop *_loop;
  PyObject *_source_traceback;
  int _closed;
  int _inited;
  int _has_handle;
};


/* "uvloop/loop.pxd":18
 * 
 * cdef class UVHandle
 * cdef class UVSocketHandle(UVHandle)             # <<<<<<<<<<<<<<
 * 
 * cdef class UVAsync(UVHandle)
 */
struct __pyx_obj_6uvloop_4loop_UVSocketHandle {
  struct __pyx_obj_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *_fileobj;
  PyObject *__pyx___cached_socket;
};


/* "uvloop/loop.pxd":20
 * cdef class UVSocketHandle(UVHandle)
 * 
 * cdef class UVAsync(UVHandle)             # <<<<<<<<<<<<<<
 * cdef class UVTimer(UVHandle)
 * cdef class UVIdle(UVHandle)
 */
struct __pyx_obj_6uvloop_4loop_UVAsync {
  struct __pyx_obj_6uvloop_4loop_UVHandle __pyx_base;
  __pyx_t_6uvloop_4loop_method_t callback;
  PyObject *ctx;
};


/* "uvloop/loop.pxd":22
 * cdef class UVAsync(UVHandle)
 * cdef class UVTimer(UVHandle)
 * cdef class UVIdle(UVHandle)             # <<<<<<<<<<<<<<
 * 
 * cdef class UVBaseTransport(UVSocketHandle)
 */
struct __pyx_obj_6uvloop_4loop_UVIdle {
  struct __pyx_obj_6uvloop_4loop_UVHandle __pyx_base;
  struct __pyx_obj_6uvloop_4loop_Handle *h;
  int running;
};


/* "uvloop/handles/check.pxd":1
 * cdef class UVCheck(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Handle h
 */
struct __pyx_obj_6uvloop_4loop_UVCheck {
  struct __pyx_obj_6uvloop_4loop_UVHandle __pyx_base;
  struct __pyx_obj_6uvloop_4loop_Handle *h;
  int running;
};


/* "uvloop/loop.pxd":21
 * 
 * cdef class UVAsync(UVHandle)
 * cdef class UVTimer(UVHandle)             # <<<<<<<<<<<<<<
 * cdef class UVIdle(UVHandle)
 * 
 */
struct __pyx_obj_6uvloop_4loop_UVTimer {
  struct __pyx_obj_6uvloop_4loop_UVHandle __pyx_base;
  __pyx_t_6uvloop_4loop_method_t callback;
  PyObject *ctx;
  int running;
  uint64_t timeout;
};


/* "uvloop/handles/poll.pxd":1
 * cdef class UVPoll(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int fd
 */
struct __pyx_obj_6uvloop_4loop_UVPoll {
  struct __pyx_obj_6uvloop_4loop_UVHandle __pyx_base;
  int fd;
  struct __pyx_obj_6uvloop_4loop_Handle *reading_handle;
  struct __pyx_obj_6uvloop_4loop_Handle *writing_handle;
};


/* "uvloop/loop.pxd":24
 * cdef class UVIdle(UVHandle)
 * 
 * cdef class UVBaseTransport(UVSocketHandle)             # <<<<<<<<<<<<<<
 * 
 * ctypedef object (*method_t)(object)
 */
struct __pyx_obj_6uvloop_4loop_UVBaseTransport {
  struct __pyx_obj_6uvloop_4loop_UVSocketHandle __pyx_base;
  int _closing;
  int _protocol_connected;
  int _protocol_paused;
  PyObject *_protocol_data_received;
  size_t _high_water;
  size_t _low_water;
  PyObject *_protocol;
  struct __pyx_obj_6uvloop_4loop_Server *_server;
  PyObject *_waiter;
  PyObject *_extra_info;
  uint32_t _conn_lost;
  PyObject *__weakref__;
};


/* "uvloop/handles/stream.pxd":1
 * cdef class UVStream(UVBaseTransport):             # <<<<<<<<<<<<<<
 *     cdef:
 *         uv.uv_shutdown_t _shutdown_req
 */
struct __pyx_obj_6uvloop_4loop_UVStream {
  struct __pyx_obj_6uvloop_4loop_UVBaseTransport __pyx_base;
  uv_shutdown_t _shutdown_req;
  int __pyx___shutting_down;
  int __pyx___reading;
  int __pyx___read_error_close;
  int __pyx___buffered;
  PyObject *_protocol_get_buffer;
  PyObject *_protocol_buffer_updated;
  int _eof;
  PyObject *_buffer;
  size_t _buffer_size;
  Py_buffer _read_pybuf;
  int _read_pybuf_acquired;
};


/* "uvloop/handles/streamserver.pxd":1
 * cdef class UVStreamServer(UVSocketHandle):             # <<<<<<<<<<<<<<
 *     cdef:
 *         object ssl
 */
struct __pyx_obj_6uvloop_4loop_UVStreamServer {
  struct __pyx_obj_6uvloop_4loop_UVSocketHandle __pyx_base;
  PyObject *ssl;
  PyObject *ssl_handshake_timeout;
  PyObject *protocol_factory;
  int opened;
  struct __pyx_obj_6uvloop_4loop_Server *_server;
};


/* "uvloop/handles/tcp.pxd":1
 * cdef class TCPServer(UVStreamServer):             # <<<<<<<<<<<<<<
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=*)
 * 
 */
struct __pyx_obj_6uvloop_4loop_TCPServer {
  struct __pyx_obj_6uvloop_4loop_UVStreamServer __pyx_base;
};


/* "uvloop/handles/tcp.pxd":10
 * 
 * 
 * cdef class TCPTransport(UVStream):             # <<<<<<<<<<<<<<
 *     cdef:
 *         bint __peername_set
 */
struct __pyx_obj_6uvloop_4loop_TCPTransport {
  struct __pyx_obj_6uvloop_4loop_UVStream __pyx_base;
  int __pyx___peername_set;
  int __pyx___sockname_set;
  struct sockaddr_storage __pyx___peername;
  struct sockaddr_storage __pyx___sockname;
};


/* "uvloop/handles/pipe.pxd":1
 * cdef class UnixServer(UVStreamServer):             # <<<<<<<<<<<<<<
 * 
 *     cdef bind(self, str path)
 */
struct __pyx_obj_6uvloop_4loop_UnixServer {
  struct __pyx_obj_6uvloop_4loop_UVStreamServer __pyx_base;
};


/* "uvloop/handles/pipe.pxd":10
 * 
 * 
 * cdef class UnixTransport(UVStream):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
struct __pyx_obj_6uvloop_4loop_UnixTransport {
  struct __pyx_obj_6uvloop_4loop_UVStream __pyx_base;
};


/* "uvloop/handles/pipe.pxd":19
 * 
 * 
 * cdef class ReadUnixTransport(UVStream):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
struct __pyx_obj_6uvloop_4loop_ReadUnixTransport {
  struct __pyx_obj_6uvloop_4loop_UVStream __pyx_base;
};


/* "uvloop/handles/pipe.pxd":26
 * 
 * 
 * cdef class WriteUnixTransport(UVStream):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
struct __pyx_obj_6uvloop_4loop_WriteUnixTransport {
  struct __pyx_obj_6uvloop_4loop_UVStream __pyx_base;
};


/* "uvloop/handles/process.pxd":1
 * cdef class UVProcess(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef:
 *         object _returncode
 */
struct __pyx_obj_6uvloop_4loop_UVProcess {
  struct __pyx_obj_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *_returncode;
  PyObject *_pid;
  PyObject *_errpipe_read;
  PyObject *_errpipe_write;
  PyObject *_preexec_fn;
  int _restore_signals;
  PyObject *_fds_to_close;
  uv_process_options_t options;
  uv_stdio_container_t iocnt[3];
  PyObject *__pyx___env;
  char **uv_opt_env;
  PyObject *__pyx___args;
  char **uv_opt_args;
  char *uv_opt_file;
  PyObject *__pyx___cwd;
};


/* "uvloop/handles/process.pxd":43
 * 
 * 
 * cdef class UVProcessTransport(UVProcess):             # <<<<<<<<<<<<<<
 *     cdef:
 *         list _exit_waiters
 */
struct __pyx_obj_6uvloop_4loop_UVProcessTransport {
  struct __pyx_obj_6uvloop_4loop_UVProcess __pyx_base;
  PyObject *_exit_waiters;
  PyObject *_init_futs;
  int _stdio_ready;
  PyObject *_pending_calls;
  PyObject *_protocol;
  int _finished;
  struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *_stdin;
  struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *_stdout;
  struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *_stderr;
  PyObject *stdin_proto;
  PyObject *stdout_proto;
  PyObject *stderr_proto;
};


/* "uvloop/request.pxd":1
 * cdef class UVRequest:             # <<<<<<<<<<<<<<
 *     cdef:
 *         uv.uv_req_t *request
 */
struct __pyx_obj_6uvloop_4loop_UVRequest {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_UVRequest *__pyx_vtab;
  uv_req_t *request;
  int done;
  struct __pyx_obj_6uvloop_4loop_Loop *loop;
};


/* "uvloop/handles/udp.pxd":1
 * cdef class UDPTransport(UVBaseTransport):             # <<<<<<<<<<<<<<
 *     cdef:
 *         object sock
 */
struct __pyx_obj_6uvloop_4loop_UDPTransport {
  struct __pyx_obj_6uvloop_4loop_UVBaseTransport __pyx_base;
  PyObject *sock;
  struct __pyx_obj_6uvloop_4loop_UVPoll *poll;
  PyObject *address;
  PyObject *buffer;
};


/* "uvloop/server.pxd":1
 * cdef class Server:             # <<<<<<<<<<<<<<
 *     cdef:
 *         list _servers
 */
struct __pyx_obj_6uvloop_4loop_Server {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_Server *__pyx_vtab;
  PyObject *_servers;
  PyObject *_waiters;
  int _active_count;
  struct __pyx_obj_6uvloop_4loop_Loop *_loop;
  PyObject *__weakref__;
};


/* "uvloop/pseudosock.pyx":1
 * cdef class PseudoSocket:             # <<<<<<<<<<<<<<
 *     cdef:
 *         int _family
 */
struct __pyx_obj_6uvloop_4loop_PseudoSocket {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *__pyx_vtab;
  int _family;
  int _type;
  int _proto;
  int _fd;
  PyObject *_peername;
  PyObject *_sockname;
};


/* "uvloop/handles/stream.pyx":5
 * @cython.no_gc_clear
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class _StreamWriteContext:             # <<<<<<<<<<<<<<
 *     # used to hold additional write request information for uv_write
 * 
 */
struct __pyx_obj_6uvloop_4loop__StreamWriteContext {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *__pyx_vtab;
  uv_write_t req;
  PyObject *buffers;
  uv_buf_t uv_bufs_sml[4];
  Py_buffer py_bufs_sml[4];
  int py_bufs_sml_inuse;
  uv_buf_t *uv_bufs;
  Py_buffer *py_bufs;
  size_t py_bufs_len;
  uv_buf_t *uv_bufs_start;
  size_t uv_bufs_len;
  struct __pyx_obj_6uvloop_4loop_UVStream *stream;
  int closed;
};


/* "uvloop/handles/tcp.pyx":181
 * 
 * 
 * cdef class _TCPConnectRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         TCPTransport transport
 */
struct __pyx_obj_6uvloop_4loop__TCPConnectRequest {
  struct __pyx_obj_6uvloop_4loop_UVRequest __pyx_base;
  struct __pyx_obj_6uvloop_4loop_TCPTransport *transport;
  uv_connect_t _req_data;
};


/* "uvloop/handles/pipe.pyx":177
 * 
 * 
 * cdef class _PipeConnectRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         UnixTransport transport
 */
struct __pyx_obj_6uvloop_4loop__PipeConnectRequest {
  struct __pyx_obj_6uvloop_4loop_UVRequest __pyx_base;
  struct __pyx_obj_6uvloop_4loop_UnixTransport *transport;
  uv_connect_t _req_data;
};


/* "uvloop/dns.pyx":204
 * 
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class AddrInfo:             # <<<<<<<<<<<<<<
 *     cdef:
 *         system.addrinfo *data
 */
struct __pyx_obj_6uvloop_4loop_AddrInfo {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop_AddrInfo *__pyx_vtab;
  struct addrinfo *data;
};


/* "uvloop/dns.pyx":248
 * 
 * 
 * cdef class AddrInfoRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         system.addrinfo hints
 */
struct __pyx_obj_6uvloop_4loop_AddrInfoRequest {
  struct __pyx_obj_6uvloop_4loop_UVRequest __pyx_base;
  struct addrinfo hints;
  PyObject *callback;
  uv_getaddrinfo_t _req_data;
};


/* "uvloop/dns.pyx":303
 * 
 * 
 * cdef class NameInfoRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         object callback
 */
struct __pyx_obj_6uvloop_4loop_NameInfoRequest {
  struct __pyx_obj_6uvloop_4loop_UVRequest __pyx_base;
  PyObject *callback;
  uv_getnameinfo_t _req_data;
};


/* "uvloop/sslproto.pyx":30
 * 
 * @cython.no_gc_clear
 * cdef class _SSLPipe:             # <<<<<<<<<<<<<<
 *     """An SSL "Pipe".
 * 
 */
struct __pyx_obj_6uvloop_4loop__SSLPipe {
  PyObject_HEAD
  struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *__pyx_vtab;
  PyObject *_context;
  PyObject *_server_side;
  PyObject *_server_hostname;
  PyObject *_state;
  PyObject *_incoming;
  PyObject *_outgoing;
  PyObject *_sslobj;
  int _need_ssldata;
  PyObject *_handshake_cb;
  PyObject *_shutdown_cb;
};


/* "uvloop/loop.pyx":822
 *         return poll.is_writing()
 * 
 *     cdef _getaddrinfo(self, object host, object port,             # <<<<<<<<<<<<<<
 *                       int family, int type,
 *                       int proto, int flags,
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo {
  PyObject_HEAD
  PyObject *__pyx_v_fut;
  int __pyx_v_unpack;
};


/* "uvloop/loop.pyx":862
 *         return fut
 * 
 *     cdef _getnameinfo(self, system.sockaddr *addr, int flags):             # <<<<<<<<<<<<<<
 *         cdef NameInfoRequest nr
 *         fut = self._new_future()
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo {
  PyObject_HEAD
  PyObject *__pyx_v_fut;
};


/* "uvloop/loop.pyx":986
 *             self._remove_reader(sock)
 * 
 *     cdef _sock_connect(self, sock, address):             # <<<<<<<<<<<<<<
 *         cdef:
 *             Handle handle
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect {
  PyObject_HEAD
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
};


/* "uvloop/loop.pyx":1221
 * 
 *     property print_debug_info:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 return lambda: self._print_debug_info()
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ {
  PyObject_HEAD
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
};


/* "uvloop/loop.pyx":1411
 *         return self._task_factory
 * 
 *     def run_until_complete(self, future):             # <<<<<<<<<<<<<<
 *         """Run until the Future is done.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete {
  PyObject_HEAD
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
};


/* "uvloop/loop.pyx":1451
 * 
 *     @cython.iterable_coroutine
 *     async def getaddrinfo(self, object host, object port, *,             # <<<<<<<<<<<<<<
 *                           int family=0, int type=0, int proto=0, int flags=0):
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo {
  PyObject_HEAD
  PyObject *__pyx_v_addr;
  int __pyx_v_family;
  int __pyx_v_flags;
  PyObject *__pyx_v_fut;
  PyObject *__pyx_v_host;
  PyObject *__pyx_v_port;
  int __pyx_v_proto;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  int __pyx_v_type;
};


/* "uvloop/loop.pyx":1465
 * 
 *     @cython.iterable_coroutine
 *     async def getnameinfo(self, sockaddr, int flags=0):             # <<<<<<<<<<<<<<
 *         cdef:
 *             AddrInfo ai_cnt
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo {
  PyObject_HEAD
  struct addrinfo *__pyx_v_ai;
  struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_ai_cnt;
  int __pyx_v_flags;
  PyObject *__pyx_v_flowinfo;
  PyObject *__pyx_v_msg;
  PyObject *__pyx_v_scope_id;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  struct sockaddr_in6 *__pyx_v_sin6;
  Py_ssize_t __pyx_v_sl;
  PyObject *__pyx_v_sockaddr;
};


/* "uvloop/loop.pyx":1523
 * 
 *     @cython.iterable_coroutine
 *     async def start_tls(self, transport, protocol, sslcontext, *,             # <<<<<<<<<<<<<<
 *                         server_side=False,
 *                         server_hostname=None,
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls {
  PyObject_HEAD
  PyObject *__pyx_v_conmade_cb;
  PyObject *__pyx_v_protocol;
  PyObject *__pyx_v_resume_cb;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_server_hostname;
  PyObject *__pyx_v_server_side;
  PyObject *__pyx_v_ssl_handshake_timeout;
  PyObject *__pyx_v_ssl_protocol;
  PyObject *__pyx_v_sslcontext;
  PyObject *__pyx_v_transport;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "uvloop/loop.pyx":1567
 * 
 *     @cython.iterable_coroutine
 *     async def create_server(self, protocol_factory, host=None, port=None,             # <<<<<<<<<<<<<<
 *                             *,
 *                             int family=uv.AF_UNSPEC,
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server {
  PyObject_HEAD
  struct addrinfo *__pyx_v_addrinfo;
  PyObject *__pyx_v_backlog;
  int __pyx_v_completed;
  int __pyx_v_family;
  int __pyx_v_flags;
  PyObject *__pyx_v_fs;
  PyObject *__pyx_7genexpr__pyx_v_host;
  PyObject *__pyx_v_host;
  PyObject *__pyx_v_hosts;
  PyObject *__pyx_v_info;
  PyObject *__pyx_v_infos;
  PyObject *__pyx_v_port;
  PyObject *__pyx_v_protocol_factory;
  PyObject *__pyx_v_reuse_address;
  PyObject *__pyx_v_reuse_port;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server;
  PyObject *__pyx_v_sock;
  PyObject *__pyx_v_ssl;
  PyObject *__pyx_v_ssl_handshake_timeout;
  struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_tcp;
};


/* "uvloop/loop.pyx":1709
 * 
 *     @cython.iterable_coroutine
 *     async def create_connection(self, protocol_factory, host=None, port=None, *,             # <<<<<<<<<<<<<<
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,
 *                                 local_addr=None, server_hostname=None,
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection {
  PyObject_HEAD
  PyObject *__pyx_v_addr;
  struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_ai_local;
  struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_ai_remote;
  PyObject *__pyx_v_app_protocol;
  PyObject *__pyx_v_exc;
  PyObject *__pyx_v_exceptions;
  PyObject *__pyx_v_f1;
  PyObject *__pyx_v_f2;
  PyObject *__pyx_v_family;
  PyObject *__pyx_v_flags;
  PyObject *__pyx_v_fs;
  PyObject *__pyx_v_genexpr;
  PyObject *__pyx_v_host;
  struct addrinfo *__pyx_v_lai;
  struct sockaddr_storage __pyx_v_lai_addr_static;
  struct addrinfo *__pyx_v_lai_iter;
  struct addrinfo __pyx_v_lai_static;
  PyObject *__pyx_v_local_addr;
  PyObject *__pyx_v_model;
  PyObject *__pyx_v_port;
  PyObject *__pyx_v_proto;
  PyObject *__pyx_v_protocol;
  PyObject *__pyx_v_protocol_factory;
  struct addrinfo *__pyx_v_rai;
  struct sockaddr_storage __pyx_v_rai_addr_static;
  struct addrinfo *__pyx_v_rai_iter;
  struct addrinfo __pyx_v_rai_static;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_server_hostname;
  PyObject *__pyx_v_sock;
  PyObject *__pyx_v_ssl;
  PyObject *__pyx_v_ssl_handshake_timeout;
  PyObject *__pyx_v_ssl_waiter;
  PyObject *__pyx_v_sslcontext;
  struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_tr;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "uvloop/loop.pyx":1880
 *                 # If they all have the same str(), raise one.
 *                 model = str(exceptions[0])
 *                 if all(str(exc) == model for exc in exceptions):             # <<<<<<<<<<<<<<
 *                     raise exceptions[0]
 *                 # Raise a combined exception so the user can see all
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *__pyx_outer_scope;
  PyObject *__pyx_v_exc;
};


/* "uvloop/loop.pyx":1885
 *                 # the various error messages.
 *                 raise OSError('Multiple exceptions: {}'.format(
 *                     ', '.join(str(exc) for exc in exceptions)))             # <<<<<<<<<<<<<<
 *         else:
 *             if sock is None:
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *__pyx_outer_scope;
  PyObject *__pyx_v_exc;
};


/* "uvloop/loop.pyx":1927
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_server(self, protocol_factory, path=None,             # <<<<<<<<<<<<<<
 *                                  *, backlog=100, sock=None, ssl=None,
 *                                  ssl_handshake_timeout=None):
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server {
  PyObject_HEAD
  PyObject *__pyx_v_backlog;
  PyObject *__pyx_v_err;
  PyObject *__pyx_v_exc;
  PyObject *__pyx_v_fspath;
  PyObject *__pyx_v_msg;
  PyObject *__pyx_v_orig_path;
  PyObject *__pyx_v_path;
  struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_pipe;
  PyObject *__pyx_v_protocol_factory;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server;
  PyObject *__pyx_v_sock;
  PyObject *__pyx_v_ssl;
  PyObject *__pyx_v_ssl_handshake_timeout;
};


/* "uvloop/loop.pyx":2050
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_connection(self, protocol_factory, path=None, *,             # <<<<<<<<<<<<<<
 *                                      ssl=None, sock=None,
 *                                      server_hostname=None,
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection {
  PyObject_HEAD
  PyObject *__pyx_v_app_protocol;
  PyObject *__pyx_v_fspath;
  PyObject *__pyx_v_path;
  PyObject *__pyx_v_protocol;
  PyObject *__pyx_v_protocol_factory;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_server_hostname;
  PyObject *__pyx_v_sock;
  PyObject *__pyx_v_ssl;
  PyObject *__pyx_v_ssl_handshake_timeout;
  PyObject *__pyx_v_ssl_waiter;
  PyObject *__pyx_v_sslcontext;
  struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_tr;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "uvloop/loop.pyx":2275
 * 
 *     @cython.iterable_coroutine
 *     async def sock_recv(self, sock, n):             # <<<<<<<<<<<<<<
 *         """Receive data from the socket.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv {
  PyObject_HEAD
  PyObject *__pyx_v_fut;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle;
  PyObject *__pyx_v_n;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
};


/* "uvloop/loop.pyx":2302
 * 
 *     @cython.iterable_coroutine
 *     async def sock_recv_into(self, sock, buf):             # <<<<<<<<<<<<<<
 *         """Receive data from the socket.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into {
  PyObject_HEAD
  PyObject *__pyx_v_buf;
  PyObject *__pyx_v_fut;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
};


/* "uvloop/loop.pyx":2328
 * 
 *     @cython.iterable_coroutine
 *     async def sock_sendall(self, sock, data):             # <<<<<<<<<<<<<<
 *         """Send data to the socket.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall {
  PyObject_HEAD
  PyObject *__pyx_v_data;
  PyObject *__pyx_v_fut;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle;
  Py_ssize_t __pyx_v_n;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
};


/* "uvloop/loop.pyx":2381
 * 
 *     @cython.iterable_coroutine
 *     async def sock_accept(self, sock):             # <<<<<<<<<<<<<<
 *         """Accept a connection.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept {
  PyObject_HEAD
  PyObject *__pyx_v_fut;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
};


/* "uvloop/loop.pyx":2409
 * 
 *     @cython.iterable_coroutine
 *     async def sock_connect(self, sock, address):             # <<<<<<<<<<<<<<
 *         """Connect to a remote socket at address.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect {
  PyObject_HEAD
  PyObject *__pyx_v__;
  PyObject *__pyx_v_address;
  PyObject *__pyx_v_addrs;
  PyObject *__pyx_v_fut;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
};


/* "uvloop/loop.pyx":2433
 * 
 *     @cython.iterable_coroutine
 *     async def connect_accepted_socket(self, protocol_factory, sock, *,             # <<<<<<<<<<<<<<
 *                                       ssl=None, ssl_handshake_timeout=None):
 *         """Handle an accepted connection.
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket {
  PyObject_HEAD
  PyObject *__pyx_v_app_protocol;
  PyObject *__pyx_v_protocol;
  PyObject *__pyx_v_protocol_factory;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
  PyObject *__pyx_v_ssl;
  PyObject *__pyx_v_ssl_handshake_timeout;
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_transport;
  PyObject *__pyx_v_transport_waiter;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "uvloop/loop.pyx":2518
 * 
 *     @cython.iterable_coroutine
 *     async def __subprocess_run(self, protocol_factory, args,             # <<<<<<<<<<<<<<
 *                                stdin=subprocess_PIPE,
 *                                stdout=subprocess_PIPE,
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run {
  PyObject_HEAD
  PyObject *__pyx_v___uvloop_sleep_after_fork;
  PyObject *__pyx_v_args;
  PyObject *__pyx_v_bufsize;
  PyObject *__pyx_v_close_fds;
  PyObject *__pyx_v_creationflags;
  PyObject *__pyx_v_cwd;
  int __pyx_v_debug_flags;
  PyObject *__pyx_v_env;
  PyObject *__pyx_v_executable;
  PyObject *__pyx_v_pass_fds;
  PyObject *__pyx_v_preexec_fn;
  struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_proc;
  PyObject *__pyx_v_protocol;
  PyObject *__pyx_v_protocol_factory;
  PyObject *__pyx_v_restore_signals;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_shell;
  PyObject *__pyx_v_start_new_session;
  PyObject *__pyx_v_startupinfo;
  PyObject *__pyx_v_stderr;
  PyObject *__pyx_v_stdin;
  PyObject *__pyx_v_stdout;
  PyObject *__pyx_v_universal_newlines;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "uvloop/loop.pyx":2580
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_shell(self, protocol_factory, cmd, *,             # <<<<<<<<<<<<<<
 *                                shell=True,
 *                                **kwargs):
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell {
  PyObject_HEAD
  PyObject *__pyx_v_args;
  PyObject *__pyx_v_cmd;
  PyObject *__pyx_v_kwargs;
  PyObject *__pyx_v_protocol_factory;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_shell;
};


/* "uvloop/loop.pyx":2595
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_exec(self,  protocol_factory, program, *args,             # <<<<<<<<<<<<<<
 *                               shell=False, **kwargs):
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec {
  PyObject_HEAD
  PyObject *__pyx_v_args;
  PyObject *__pyx_v_kwargs;
  PyObject *__pyx_v_program;
  PyObject *__pyx_v_protocol_factory;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_shell;
};


/* "uvloop/loop.pyx":2607
 * 
 *     @cython.iterable_coroutine
 *     async def connect_read_pipe(self, proto_factory, pipe):             # <<<<<<<<<<<<<<
 *         """Register read pipe in event loop. Set the pipe to non-blocking mode.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe {
  PyObject_HEAD
  PyObject *__pyx_v_pipe;
  PyObject *__pyx_v_proto;
  PyObject *__pyx_v_proto_factory;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_transp;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "uvloop/loop.pyx":2632
 * 
 *     @cython.iterable_coroutine
 *     async def connect_write_pipe(self, proto_factory, pipe):             # <<<<<<<<<<<<<<
 *         """Register write pipe in event loop.
 * 
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe {
  PyObject_HEAD
  PyObject *__pyx_v_pipe;
  PyObject *__pyx_v_proto;
  PyObject *__pyx_v_proto_factory;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_transp;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "uvloop/loop.pyx":2766
 * 
 *     @cython.iterable_coroutine
 *     async def create_datagram_endpoint(self, protocol_factory,             # <<<<<<<<<<<<<<
 *                                        local_addr=None, remote_addr=None, *,
 *                                        family=0, proto=0, flags=0,
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint {
  PyObject_HEAD
  PyObject *__pyx_v__;
  PyObject *__pyx_v_addr;
  PyObject *__pyx_v_addr_infos;
  PyObject *__pyx_8genexpr4__pyx_v_addr_pair;
  PyObject *__pyx_v_addr_pairs_info;
  PyObject *__pyx_v_address;
  PyObject *__pyx_v_allow_broadcast;
  PyObject *__pyx_v_exc;
  PyObject *__pyx_v_exceptions;
  PyObject *__pyx_v_fam;
  PyObject *__pyx_v_family;
  PyObject *__pyx_v_flags;
  PyObject *__pyx_v_genexpr;
  PyObject *__pyx_v_idx;
  PyObject *__pyx_v_infos;
  PyObject *__pyx_8genexpr4__pyx_v_key;
  PyObject *__pyx_v_key;
  PyObject *__pyx_v_local_addr;
  PyObject *__pyx_v_local_address;
  PyObject *__pyx_v_opts;
  PyObject *__pyx_v_pro;
  PyObject *__pyx_v_problems;
  PyObject *__pyx_v_proto;
  PyObject *__pyx_v_protocol;
  PyObject *__pyx_v_protocol_factory;
  PyObject *__pyx_v_r_addr;
  struct sockaddr_storage __pyx_v_rai;
  PyObject *__pyx_v_remote_addr;
  PyObject *__pyx_v_remote_address;
  PyObject *__pyx_v_reuse_address;
  PyObject *__pyx_v_reuse_port;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_sock;
  struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_udp;
  PyObject *__pyx_v_waiter;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
  PyObject *__pyx_t_3;
  PyObject *__pyx_t_4;
  PyObject *__pyx_t_5;
};


/* "uvloop/loop.pyx":2816
 *                             allow_broadcast=allow_broadcast)
 *                 problems = ', '.join(
 *                     '{}={}'.format(k, v) for k, v in opts.items() if v)             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'socket modifier keyword arguments can not be used '
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr {
  PyObject_HEAD
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *__pyx_outer_scope;
  PyObject *__pyx_v_k;
  PyObject *__pyx_v_v;
};


/* "uvloop/loop.pyx":2932
 * 
 *     @cython.iterable_coroutine
 *     async def shutdown_asyncgens(self):             # <<<<<<<<<<<<<<
 *         """Shutdown all active asynchronous generators."""
 *         self._asyncgens_shutdown_called = True
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens {
  PyObject_HEAD
  PyObject *__pyx_8genexpr5__pyx_v_ag;
  PyObject *__pyx_v_agen;
  PyObject *__pyx_v_closing_agens;
  PyObject *__pyx_v_result;
  PyObject *__pyx_v_results;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self;
  PyObject *__pyx_v_shutdown_coro;
};


/* "uvloop/server.pyx":46
 * 
 *     @cython.iterable_coroutine
 *     async def wait_closed(self):             # <<<<<<<<<<<<<<
 *         if self._waiters is None:
 *             return
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed {
  PyObject_HEAD
  struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self;
  PyObject *__pyx_v_waiter;
};


/* "uvloop/loop.pyx":3103
 * 
 * @cython.iterable_coroutine
 * async def _test_coroutine_1():             # <<<<<<<<<<<<<<
 *     return 42
 */
struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 {
  PyObject_HEAD
};


/* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):             # <<<<<<<<<<<<<<
 *     def wrap(Loop self, bint enabled):
 *         """wrap(self: 'Loop', enabled: bool)"""
 */
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py {
  PyObject_HEAD
  PyObject *(*__pyx_v_f)(struct __pyx_obj_6uvloop_4loop_Loop *, int);
};



/* "uvloop/handles/handle.pyx":2
 * @cython.no_gc_clear
 * cdef class UVHandle:             # <<<<<<<<<<<<<<
 *     """A base class for all libuv handles.
 * 
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVHandle {
  PyObject *(*_start_init)(struct __pyx_obj_6uvloop_4loop_UVHandle *, struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_abort_init)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
  PyObject *(*_finish_init)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
  int (*_is_alive)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
  PyObject *(*_ensure_alive)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
  PyObject *(*_error)(struct __pyx_obj_6uvloop_4loop_UVHandle *, PyObject *, PyObject *);
  PyObject *(*_fatal_error)(struct __pyx_obj_6uvloop_4loop_UVHandle *, PyObject *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error *__pyx_optional_args);
  PyObject *(*_warn_unclosed)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
  PyObject *(*_dealloc_impl)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
  PyObject *(*_free)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
  PyObject *(*_close)(struct __pyx_obj_6uvloop_4loop_UVHandle *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *__pyx_vtabptr_6uvloop_4loop_UVHandle;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__start_init(struct __pyx_obj_6uvloop_4loop_UVHandle *, struct __pyx_obj_6uvloop_4loop_Loop *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__abort_init(struct __pyx_obj_6uvloop_4loop_UVHandle *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__finish_init(struct __pyx_obj_6uvloop_4loop_UVHandle *);
static CYTHON_INLINE int __pyx_f_6uvloop_4loop_8UVHandle__is_alive(struct __pyx_obj_6uvloop_4loop_UVHandle *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__ensure_alive(struct __pyx_obj_6uvloop_4loop_UVHandle *);


/* "uvloop/handles/handle.pyx":228
 * 
 * @cython.no_gc_clear
 * cdef class UVSocketHandle(UVHandle):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self):
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle {
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *(*_fileno)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *);
  PyObject *(*_new_socket)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *);
  PyObject *(*_get_socket)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *);
  PyObject *(*_attach_fileobj)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, PyObject *);
  PyObject *(*_open)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle *__pyx_vtabptr_6uvloop_4loop_UVSocketHandle;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__get_socket(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__attach_fileobj(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, PyObject *);


/* "uvloop/handles/async_.pyx":2
 * @cython.no_gc_clear
 * cdef class UVAsync(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef _init(self, Loop loop, method_t callback, object ctx):
 *         cdef int err
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVAsync {
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVAsync *, struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *);
  PyObject *(*send)(struct __pyx_obj_6uvloop_4loop_UVAsync *);
  struct __pyx_obj_6uvloop_4loop_UVAsync *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *__pyx_vtabptr_6uvloop_4loop_UVAsync;


/* "uvloop/handles/timer.pyx":2
 * @cython.no_gc_clear
 * cdef class UVTimer(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef _init(self, Loop loop, method_t callback, object ctx,
 *                uint64_t timeout):
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVTimer {
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVTimer *, struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *, uint64_t);
  PyObject *(*stop)(struct __pyx_obj_6uvloop_4loop_UVTimer *);
  PyObject *(*start)(struct __pyx_obj_6uvloop_4loop_UVTimer *);
  struct __pyx_obj_6uvloop_4loop_UVTimer *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *, uint64_t);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *__pyx_vtabptr_6uvloop_4loop_UVTimer;


/* "uvloop/handles/idle.pyx":2
 * @cython.no_gc_clear
 * cdef class UVIdle(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef _init(self, Loop loop, Handle h):
 *         cdef int err
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVIdle {
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVIdle *, struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*stop)(struct __pyx_obj_6uvloop_4loop_UVIdle *);
  PyObject *(*start)(struct __pyx_obj_6uvloop_4loop_UVIdle *);
  struct __pyx_obj_6uvloop_4loop_UVIdle *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *__pyx_vtabptr_6uvloop_4loop_UVIdle;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVIdle_stop(struct __pyx_obj_6uvloop_4loop_UVIdle *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVIdle_start(struct __pyx_obj_6uvloop_4loop_UVIdle *);


/* "uvloop/handles/basetransport.pyx":2
 * @cython.no_gc_clear
 * cdef class UVBaseTransport(UVSocketHandle):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self):
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport {
  struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle __pyx_base;
  PyObject *(*_set_write_buffer_limits)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits *__pyx_optional_args);
  PyObject *(*_maybe_pause_protocol)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_maybe_resume_protocol)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_schedule_call_connection_made)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_schedule_call_connection_lost)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *);
  PyObject *(*_wakeup_waiter)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_call_connection_made)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_call_connection_lost)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *);
  PyObject *(*_set_server)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, struct __pyx_obj_6uvloop_4loop_Server *);
  PyObject *(*_set_waiter)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *);
  PyObject *(*_set_protocol)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *);
  PyObject *(*_clear_protocol)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_init_protocol)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_add_extra_info)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *, PyObject *);
  size_t (*_get_write_buffer_size)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  int (*_is_reading)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_start_reading)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_stop_reading)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *__pyx_vtabptr_6uvloop_4loop_UVBaseTransport;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits *__pyx_optional_args);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_pause_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_resume_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_made(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_lost(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_server(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, struct __pyx_obj_6uvloop_4loop_Server *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_waiter(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__init_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__add_extra_info(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *, PyObject *);


/* "uvloop/loop.pyx":86
 * 
 * @cython.no_gc_clear
 * cdef class Loop:             # <<<<<<<<<<<<<<
 *     def __cinit__(self):
 *         cdef int err
 */

struct __pyx_vtabstruct_6uvloop_4loop_Loop {
  PyObject *(*_init_debug_fields)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_on_wake)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_on_idle)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*__pyx___run)(struct __pyx_obj_6uvloop_4loop_Loop *, uv_run_mode);
  PyObject *(*_run)(struct __pyx_obj_6uvloop_4loop_Loop *, uv_run_mode);
  PyObject *(*_close)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_stop)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  uint64_t (*_time)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_queue_write)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_exec_queued_writes)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_call_soon)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_call_soon_handle)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*_call_later)(struct __pyx_obj_6uvloop_4loop_Loop *, uint64_t, PyObject *, PyObject *, PyObject *);
  void (*_handle_exception)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_new_future)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_check_signal)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_check_closed)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_check_thread)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_getaddrinfo)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, int, int, int, int, int);
  PyObject *(*_getnameinfo)(struct __pyx_obj_6uvloop_4loop_Loop *, struct sockaddr *, int);
  PyObject *(*_create_server)(struct __pyx_obj_6uvloop_4loop_Loop *, struct sockaddr *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, int, PyObject *, PyObject *);
  PyObject *(*_track_transport)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVBaseTransport *);
  PyObject *(*_fileobj_to_fd)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_ensure_fd_no_transport)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_track_process)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVProcess *);
  PyObject *(*_untrack_process)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVProcess *);
  PyObject *(*_add_reader)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*_has_reader)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_remove_reader)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_add_writer)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*_has_writer)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_remove_writer)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_sock_recv)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_sock_recv_into)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_sock_sendall)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_sock_accept)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *);
  PyObject *(*_sock_connect)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *);
  PyObject *(*_sock_connect_cb)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_sock_set_reuseport)(struct __pyx_obj_6uvloop_4loop_Loop *, int);
  PyObject *(*_setup_signals)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_shutdown_signals)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_recv_signals_start)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_recv_signals_stop)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_handle_signal)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_read_from_self)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_ceval_process_signals)(struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_invoke_signals)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
  PyObject *(*_set_coroutine_debug)(struct __pyx_obj_6uvloop_4loop_Loop *, int);
  PyObject *(*_print_debug_info)(struct __pyx_obj_6uvloop_4loop_Loop *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_Loop *__pyx_vtabptr_6uvloop_4loop_Loop;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__queue_write(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__call_soon(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__call_soon_handle(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__new_future(struct __pyx_obj_6uvloop_4loop_Loop *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_signal(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_closed(struct __pyx_obj_6uvloop_4loop_Loop *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_thread(struct __pyx_obj_6uvloop_4loop_Loop *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__ceval_process_signals(struct __pyx_obj_6uvloop_4loop_Loop *);


/* "uvloop/cbhandles.pyx":3
 * @cython.no_gc_clear
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class Handle:             # <<<<<<<<<<<<<<
 *     def __cinit__(self):
 *         self._cancelled = 0
 */

struct __pyx_vtabstruct_6uvloop_4loop_Handle {
  PyObject *(*_set_loop)(struct __pyx_obj_6uvloop_4loop_Handle *, struct __pyx_obj_6uvloop_4loop_Loop *);
  PyObject *(*_set_context)(struct __pyx_obj_6uvloop_4loop_Handle *, PyObject *);
  PyObject *(*_run)(struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*_cancel)(struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*_format_handle)(struct __pyx_obj_6uvloop_4loop_Handle *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_Handle *__pyx_vtabptr_6uvloop_4loop_Handle;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__set_loop(struct __pyx_obj_6uvloop_4loop_Handle *, struct __pyx_obj_6uvloop_4loop_Loop *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__set_context(struct __pyx_obj_6uvloop_4loop_Handle *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__run(struct __pyx_obj_6uvloop_4loop_Handle *);


/* "uvloop/cbhandles.pyx":167
 * @cython.no_gc_clear
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class TimerHandle:             # <<<<<<<<<<<<<<
 *     def __cinit__(self, Loop loop, object callback, object args,
 *                   uint64_t delay, object context):
 */

struct __pyx_vtabstruct_6uvloop_4loop_TimerHandle {
  PyObject *(*_run)(struct __pyx_obj_6uvloop_4loop_TimerHandle *);
  PyObject *(*_cancel)(struct __pyx_obj_6uvloop_4loop_TimerHandle *);
  PyObject *(*_clear)(struct __pyx_obj_6uvloop_4loop_TimerHandle *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_TimerHandle *__pyx_vtabptr_6uvloop_4loop_TimerHandle;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_11TimerHandle__clear(struct __pyx_obj_6uvloop_4loop_TimerHandle *);


/* "uvloop/handles/check.pyx":2
 * @cython.no_gc_clear
 * cdef class UVCheck(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef _init(self, Loop loop, Handle h):
 *         cdef int err
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVCheck {
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVCheck *, struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*stop)(struct __pyx_obj_6uvloop_4loop_UVCheck *);
  PyObject *(*start)(struct __pyx_obj_6uvloop_4loop_UVCheck *);
  struct __pyx_obj_6uvloop_4loop_UVCheck *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *__pyx_vtabptr_6uvloop_4loop_UVCheck;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_7UVCheck_stop(struct __pyx_obj_6uvloop_4loop_UVCheck *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_7UVCheck_start(struct __pyx_obj_6uvloop_4loop_UVCheck *);


/* "uvloop/handles/poll.pyx":2
 * @cython.no_gc_clear
 * cdef class UVPoll(UVHandle):             # <<<<<<<<<<<<<<
 *     cdef _init(self, Loop loop, int fd):
 *         cdef int err
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVPoll {
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVPoll *, struct __pyx_obj_6uvloop_4loop_Loop *, int);
  PyObject *(*_poll_start)(struct __pyx_obj_6uvloop_4loop_UVPoll *, int);
  PyObject *(*_poll_stop)(struct __pyx_obj_6uvloop_4loop_UVPoll *);
  int (*is_active)(struct __pyx_obj_6uvloop_4loop_UVPoll *);
  PyObject *(*is_reading)(struct __pyx_obj_6uvloop_4loop_UVPoll *);
  PyObject *(*is_writing)(struct __pyx_obj_6uvloop_4loop_UVPoll *);
  PyObject *(*start_reading)(struct __pyx_obj_6uvloop_4loop_UVPoll *, struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*start_writing)(struct __pyx_obj_6uvloop_4loop_UVPoll *, struct __pyx_obj_6uvloop_4loop_Handle *);
  PyObject *(*stop_reading)(struct __pyx_obj_6uvloop_4loop_UVPoll *);
  PyObject *(*stop_writing)(struct __pyx_obj_6uvloop_4loop_UVPoll *);
  PyObject *(*stop)(struct __pyx_obj_6uvloop_4loop_UVPoll *);
  struct __pyx_obj_6uvloop_4loop_UVPoll *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, int);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *__pyx_vtabptr_6uvloop_4loop_UVPoll;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVPoll__poll_start(struct __pyx_obj_6uvloop_4loop_UVPoll *, int);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVPoll__poll_stop(struct __pyx_obj_6uvloop_4loop_UVPoll *);


/* "uvloop/handles/stream.pyx":208
 * 
 * @cython.no_gc_clear
 * cdef class UVStream(UVBaseTransport):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self):
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVStream {
  struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *);
  PyObject *(*_exec_write)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_shutdown)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_accept)(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_close_on_read_error)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*__pyx___reading_started)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*__pyx___reading_stopped)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_write)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *);
  PyObject *(*_try_write)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *);
  PyObject *(*_on_accept)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_on_eof)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_on_write)(struct __pyx_obj_6uvloop_4loop_UVStream *);
  PyObject *(*_on_connect)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVStream *__pyx_vtabptr_6uvloop_4loop_UVStream;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__init(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__exec_write(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__shutdown(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__accept(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__close_on_read_error(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream___reading_started(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream___reading_stopped(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__write(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__try_write(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_accept(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_eof(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_write(struct __pyx_obj_6uvloop_4loop_UVStream *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_connect(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *);


/* "uvloop/handles/streamserver.pyx":2
 * @cython.no_gc_clear
 * cdef class UVStreamServer(UVSocketHandle):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self):
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer {
  struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, PyObject *);
  PyObject *(*_mark_as_open)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *);
  PyObject *(*listen)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, PyObject *);
  PyObject *(*_on_listen)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *);
  struct __pyx_obj_6uvloop_4loop_UVStream *(*_make_new_transport)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *__pyx_vtabptr_6uvloop_4loop_UVStreamServer;
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__init(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__mark_as_open(struct __pyx_obj_6uvloop_4loop_UVStreamServer *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer_listen(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, PyObject *);
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__on_listen(struct __pyx_obj_6uvloop_4loop_UVStreamServer *);


/* "uvloop/handles/tcp.pyx":57
 * 
 * @cython.no_gc_clear
 * cdef class TCPServer(UVStreamServer):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */

struct __pyx_vtabstruct_6uvloop_4loop_TCPServer {
  struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer __pyx_base;
  PyObject *(*bind)(struct __pyx_obj_6uvloop_4loop_TCPServer *, struct sockaddr *, struct __pyx_opt_args_6uvloop_4loop_9TCPServer_bind *__pyx_optional_args);
  struct __pyx_obj_6uvloop_4loop_TCPServer *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, unsigned int, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *__pyx_vtabptr_6uvloop_4loop_TCPServer;


/* "uvloop/handles/tcp.pyx":99
 * 
 * @cython.no_gc_clear
 * cdef class TCPTransport(UVStream):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */

struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport {
  struct __pyx_vtabstruct_6uvloop_4loop_UVStream __pyx_base;
  PyObject *(*bind)(struct __pyx_obj_6uvloop_4loop_TCPTransport *, struct sockaddr *, struct __pyx_opt_args_6uvloop_4loop_12TCPTransport_bind *__pyx_optional_args);
  PyObject *(*connect)(struct __pyx_obj_6uvloop_4loop_TCPTransport *, struct sockaddr *);
  PyObject *(*_set_nodelay)(struct __pyx_obj_6uvloop_4loop_TCPTransport *);
  struct __pyx_obj_6uvloop_4loop_TCPTransport *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *__pyx_vtabptr_6uvloop_4loop_TCPTransport;


/* "uvloop/handles/pipe.pyx":38
 * 
 * @cython.no_gc_clear
 * cdef class UnixServer(UVStreamServer):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */

struct __pyx_vtabstruct_6uvloop_4loop_UnixServer {
  struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer __pyx_base;
  PyObject *(*bind)(struct __pyx_obj_6uvloop_4loop_UnixServer *, PyObject *);
  struct __pyx_obj_6uvloop_4loop_UnixServer *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *__pyx_vtabptr_6uvloop_4loop_UnixServer;


/* "uvloop/handles/pipe.pyx":78
 * 
 * @cython.no_gc_clear
 * cdef class UnixTransport(UVStream):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */

struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport {
  struct __pyx_vtabstruct_6uvloop_4loop_UVStream __pyx_base;
  struct __pyx_obj_6uvloop_4loop_UnixTransport *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *);
  PyObject *(*connect)(struct __pyx_obj_6uvloop_4loop_UnixTransport *, char *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *__pyx_vtabptr_6uvloop_4loop_UnixTransport;


/* "uvloop/handles/pipe.pyx":103
 * 
 * @cython.no_gc_clear
 * cdef class ReadUnixTransport(UVStream):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */

struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport {
  struct __pyx_vtabstruct_6uvloop_4loop_UVStream __pyx_base;
  struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *__pyx_vtabptr_6uvloop_4loop_ReadUnixTransport;


/* "uvloop/handles/pipe.pyx":146
 * 
 * @cython.no_gc_clear
 * cdef class WriteUnixTransport(UVStream):             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */

struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport {
  struct __pyx_vtabstruct_6uvloop_4loop_UVStream __pyx_base;
  struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *__pyx_vtabptr_6uvloop_4loop_WriteUnixTransport;


/* "uvloop/handles/process.pyx":2
 * @cython.no_gc_clear
 * cdef class UVProcess(UVHandle):             # <<<<<<<<<<<<<<
 *     """Abstract class; wrapper over uv_process_t handle."""
 * 
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVProcess {
  struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UVProcess *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_after_fork)(struct __pyx_obj_6uvloop_4loop_UVProcess *);
  char **(*__pyx___to_cstring_array)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *);
  PyObject *(*_init_args)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *);
  PyObject *(*_init_env)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *);
  PyObject *(*_init_files)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_init_options)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *);
  PyObject *(*_close_after_spawn)(struct __pyx_obj_6uvloop_4loop_UVProcess *, int);
  PyObject *(*_on_exit)(struct __pyx_obj_6uvloop_4loop_UVProcess *, int64_t, int);
  PyObject *(*_kill)(struct __pyx_obj_6uvloop_4loop_UVProcess *, int);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *__pyx_vtabptr_6uvloop_4loop_UVProcess;


/* "uvloop/handles/process.pyx":346
 * 
 * @cython.no_gc_clear
 * cdef class UVProcessTransport(UVProcess):             # <<<<<<<<<<<<<<
 *     def __cinit__(self):
 *         self._exit_waiters = []
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport {
  struct __pyx_vtabstruct_6uvloop_4loop_UVProcess __pyx_base;
  PyObject *(*_file_redirect_stdio)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, int);
  PyObject *(*_file_devnull)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *);
  PyObject *(*_file_inpipe)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *);
  PyObject *(*_file_outpipe)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *);
  PyObject *(*_check_proc)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *);
  PyObject *(*_pipe_connection_lost)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, int, PyObject *);
  PyObject *(*_pipe_data_received)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, int, PyObject *);
  PyObject *(*_call_connection_made)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, PyObject *);
  PyObject *(*_try_finish)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *);
  struct __pyx_obj_6uvloop_4loop_UVProcessTransport *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *__pyx_vtabptr_6uvloop_4loop_UVProcessTransport;


/* "uvloop/request.pyx":1
 * cdef class UVRequest:             # <<<<<<<<<<<<<<
 *     """A base class for all libuv requests (uv_getaddrinfo_t, etc).
 * 
 */

struct __pyx_vtabstruct_6uvloop_4loop_UVRequest {
  PyObject *(*on_done)(struct __pyx_obj_6uvloop_4loop_UVRequest *);
  PyObject *(*cancel)(struct __pyx_obj_6uvloop_4loop_UVRequest *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVRequest *__pyx_vtabptr_6uvloop_4loop_UVRequest;


/* "uvloop/handles/udp.pyx":2
 * @cython.no_gc_clear
 * cdef class UDPTransport(UVBaseTransport):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self):
 */

struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport {
  struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport __pyx_base;
  PyObject *(*_init)(struct __pyx_obj_6uvloop_4loop_UDPTransport *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *);
  PyObject *(*_on_read_ready)(struct __pyx_obj_6uvloop_4loop_UDPTransport *);
  PyObject *(*_on_write_ready)(struct __pyx_obj_6uvloop_4loop_UDPTransport *);
  struct __pyx_obj_6uvloop_4loop_UDPTransport *(*new)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *__pyx_vtabptr_6uvloop_4loop_UDPTransport;


/* "uvloop/server.pyx":1
 * cdef class Server:             # <<<<<<<<<<<<<<
 *     def __cinit__(self, Loop loop):
 *         self._loop = loop
 */

struct __pyx_vtabstruct_6uvloop_4loop_Server {
  PyObject *(*_add_server)(struct __pyx_obj_6uvloop_4loop_Server *, struct __pyx_obj_6uvloop_4loop_UVStreamServer *);
  PyObject *(*_wakeup)(struct __pyx_obj_6uvloop_4loop_Server *);
  PyObject *(*_attach)(struct __pyx_obj_6uvloop_4loop_Server *);
  PyObject *(*_detach)(struct __pyx_obj_6uvloop_4loop_Server *);
  PyObject *(*_ref)(struct __pyx_obj_6uvloop_4loop_Server *);
  PyObject *(*_unref)(struct __pyx_obj_6uvloop_4loop_Server *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_Server *__pyx_vtabptr_6uvloop_4loop_Server;


/* "uvloop/pseudosock.pyx":1
 * cdef class PseudoSocket:             # <<<<<<<<<<<<<<
 *     cdef:
 *         int _family
 */

struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket {
  PyObject *(*_na)(struct __pyx_obj_6uvloop_4loop_PseudoSocket *, PyObject *);
  PyObject *(*_make_sock)(struct __pyx_obj_6uvloop_4loop_PseudoSocket *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *__pyx_vtabptr_6uvloop_4loop_PseudoSocket;


/* "uvloop/handles/stream.pyx":5
 * @cython.no_gc_clear
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class _StreamWriteContext:             # <<<<<<<<<<<<<<
 *     # used to hold additional write request information for uv_write
 * 
 */

struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext {
  PyObject *(*free_bufs)(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *);
  PyObject *(*close)(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *);
  PyObject *(*advance_uv_buf)(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *, size_t);
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *(*new)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *__pyx_vtabptr_6uvloop_4loop__StreamWriteContext;


/* "uvloop/handles/tcp.pyx":181
 * 
 * 
 * cdef class _TCPConnectRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         TCPTransport transport
 */

struct __pyx_vtabstruct_6uvloop_4loop__TCPConnectRequest {
  struct __pyx_vtabstruct_6uvloop_4loop_UVRequest __pyx_base;
  PyObject *(*connect)(struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *, struct sockaddr *);
};
static struct __pyx_vtabstruct_6uvloop_4loop__TCPConnectRequest *__pyx_vtabptr_6uvloop_4loop__TCPConnectRequest;


/* "uvloop/handles/pipe.pyx":177
 * 
 * 
 * cdef class _PipeConnectRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         UnixTransport transport
 */

struct __pyx_vtabstruct_6uvloop_4loop__PipeConnectRequest {
  struct __pyx_vtabstruct_6uvloop_4loop_UVRequest __pyx_base;
  PyObject *(*connect)(struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *, char *);
};
static struct __pyx_vtabstruct_6uvloop_4loop__PipeConnectRequest *__pyx_vtabptr_6uvloop_4loop__PipeConnectRequest;


/* "uvloop/dns.pyx":204
 * 
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class AddrInfo:             # <<<<<<<<<<<<<<
 *     cdef:
 *         system.addrinfo *data
 */

struct __pyx_vtabstruct_6uvloop_4loop_AddrInfo {
  void (*set_data)(struct __pyx_obj_6uvloop_4loop_AddrInfo *, struct addrinfo *);
  PyObject *(*unpack)(struct __pyx_obj_6uvloop_4loop_AddrInfo *);
  int (*isinstance)(PyObject *);
};
static struct __pyx_vtabstruct_6uvloop_4loop_AddrInfo *__pyx_vtabptr_6uvloop_4loop_AddrInfo;


/* "uvloop/dns.pyx":248
 * 
 * 
 * cdef class AddrInfoRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         system.addrinfo hints
 */

struct __pyx_vtabstruct_6uvloop_4loop_AddrInfoRequest {
  struct __pyx_vtabstruct_6uvloop_4loop_UVRequest __pyx_base;
};
static struct __pyx_vtabstruct_6uvloop_4loop_AddrInfoRequest *__pyx_vtabptr_6uvloop_4loop_AddrInfoRequest;


/* "uvloop/dns.pyx":303
 * 
 * 
 * cdef class NameInfoRequest(UVRequest):             # <<<<<<<<<<<<<<
 *     cdef:
 *         object callback
 */

struct __pyx_vtabstruct_6uvloop_4loop_NameInfoRequest {
  struct __pyx_vtabstruct_6uvloop_4loop_UVRequest __pyx_base;
  PyObject *(*query)(struct __pyx_obj_6uvloop_4loop_NameInfoRequest *, struct sockaddr *, int);
};
static struct __pyx_vtabstruct_6uvloop_4loop_NameInfoRequest *__pyx_vtabptr_6uvloop_4loop_NameInfoRequest;


/* "uvloop/sslproto.pyx":30
 * 
 * @cython.no_gc_clear
 * cdef class _SSLPipe:             # <<<<<<<<<<<<<<
 *     """An SSL "Pipe".
 * 
 */

struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe {
  PyObject *(*do_handshake)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_do_handshake *__pyx_optional_args);
  PyObject *(*shutdown)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_shutdown *__pyx_optional_args);
  PyObject *(*feed_eof)(struct __pyx_obj_6uvloop_4loop__SSLPipe *);
  PyObject *(*feed_ssldata)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_ssldata *__pyx_optional_args);
  PyObject *(*feed_appdata)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_appdata *__pyx_optional_args);
};
static struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *__pyx_vtabptr_6uvloop_4loop__SSLPipe;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* IncludeStringH.proto */
#include <string.h>

/* decode_c_string_utf16.proto */
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 0;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16LE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = -1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16BE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* GetModuleGlobalName.proto */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AndObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_AndObjC(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceAnd(op1, op2) : PyNumber_And(op1, op2))
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* pyfrozenset_new.proto */
static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it);

/* py_set_discard.proto */
static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key);

/* set_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set);
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* py_dict_clear.proto */
#define __Pyx_PyDict_Clear(d) (PyDict_Clear(d), 0)

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* py_dict_pop.proto */
static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunction.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code)\
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* CallableCheck.proto */
#if CYTHON_USE_TYPE_SLOTS && PY_MAJOR_VERSION >= 3
#define __Pyx_PyCallable_Check(obj)   ((obj)->ob_type->tp_call != NULL)
#else
#define __Pyx_PyCallable_Check(obj)   PyCallable_Check(obj)
#endif

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->exc_type, &(self)->exc_value, &(self)->exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(self);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->exc_type, (self)->exc_value, (self)->exc_traceback);\
    (self)->exc_type = (self)->exc_value = (self)->exc_traceback = NULL;\
    }
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__pyx_CoroutineObject *self);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Coroutine.proto */
#define __Pyx_Coroutine_USED
static PyTypeObject *__pyx_CoroutineType = 0;
static PyTypeObject *__pyx_CoroutineAwaitType = 0;
#define __Pyx_Coroutine_CheckExact(obj) (Py_TYPE(obj) == __pyx_CoroutineType)
#define __Pyx_Coroutine_Check(obj) __Pyx_Coroutine_CheckExact(obj)
#define __Pyx_CoroutineAwait_CheckExact(obj) (Py_TYPE(obj) == __pyx_CoroutineAwaitType)
#define __Pyx_Coroutine_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_CoroutineType, body, code, closure, name, qualname, module_name)
static int __pyx_Coroutine_init(void);
static PyObject *__Pyx__Coroutine_await(PyObject *coroutine);
typedef struct {
    PyObject_HEAD
    PyObject *coroutine;
} __pyx_CoroutineAwaitObject;
static PyObject *__Pyx_CoroutineAwait_Close(__pyx_CoroutineAwaitObject *self);
static PyObject *__Pyx_CoroutineAwait_Throw(__pyx_CoroutineAwaitObject *self, PyObject *args);

/* GetAwaitIter.proto */
static CYTHON_INLINE PyObject *__Pyx_Coroutine_GetAwaitableIter(PyObject *o);
static PyObject *__Pyx__Coroutine_GetAwaitableIter(PyObject *o);

/* CoroutineYieldFrom.proto */
static CYTHON_INLINE PyObject* __Pyx_Coroutine_Yield_From(__pyx_CoroutineObject *gen, PyObject *source);

/* ReturnWithStopIteration.proto */
#define __Pyx_ReturnWithStopIteration(value)\
    if (value == Py_None) PyErr_SetNone(PyExc_StopIteration); else __Pyx__ReturnWithStopIteration(value)
static void __Pyx__ReturnWithStopIteration(PyObject* value);

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* MergeKeywords.proto */
static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_EqObjC(op1, op2, intval, inplace)\
    PyObject_RichCompare(op1, op2, Py_EQ)
    #endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* py_set_remove.proto */
static CYTHON_INLINE int __Pyx_PySet_Remove(PyObject *set, PyObject *key);

/* None.proto */
static CYTHON_INLINE long __Pyx_div_long(long, long);

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return __Pyx_PyObject_GetAttrStr(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#else
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* decode_c_bytes.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_bytes(
         const char* cstring, Py_ssize_t length, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* decode_bytes.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_bytes(
         PyObject* string, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    return __Pyx_decode_c_bytes(
        PyBytes_AS_STRING(string), PyBytes_GET_SIZE(string),
        start, stop, encoding, errors, decode_func);
}

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_str(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_str(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* DelItemInt.proto */
#define __Pyx_DelItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_DelItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_DelItem_Generic(o, to_py_func(i))))
static int __Pyx_DelItem_Generic(PyObject *o, PyObject *j);
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               int is_list, int wraparound);

/* SliceObject.proto */
#define __Pyx_PyObject_DelSlice(obj, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)\
    __Pyx_PyObject_SetSlice(obj, (PyObject*)NULL, cstart, cstop, py_start, py_stop, py_slice, has_cstart, has_cstop, wraparound)
static CYTHON_INLINE int __Pyx_PyObject_SetSlice(
        PyObject* obj, PyObject* value, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* PatchInspect.proto */
static PyObject* __Pyx_patch_inspect(PyObject* module);

/* PatchAsyncIO.proto */
static PyObject* __Pyx_patch_asyncio(PyObject* module);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint64_t(uint64_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint32_t(uint32_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_short(unsigned short value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_volatile__int(volatile int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int64_t(int64_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_long(unsigned long value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int64_t __Pyx_PyInt_As_int64_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE uint64_t __Pyx_PyInt_As_uint64_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE unsigned long __Pyx_PyInt_As_unsigned_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *);

/* IterableCoroutine.proto */
#define __Pyx_IterableCoroutine_USED
static PyTypeObject *__pyx_IterableCoroutineType = 0;
#undef __Pyx_Coroutine_Check
#define __Pyx_Coroutine_Check(obj) (__Pyx_Coroutine_CheckExact(obj) || (Py_TYPE(obj) == __pyx_IterableCoroutineType))
#define __Pyx_IterableCoroutine_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_IterableCoroutineType, body, code, closure, name, qualname, module_name)
static int __pyx_IterableCoroutine_init(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* PyIdentifierFromString.proto */
#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

/* ModuleImport.proto */
static PyObject *__Pyx_ImportModule(const char *name);

/* TypeImport.proto */
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_6uvloop_4loop_4Loop__init_debug_fields(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__setup_signals(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__recv_signals_start(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__recv_signals_stop(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__shutdown_signals(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__ceval_process_signals(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__read_from_self(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__invoke_signals(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_data); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__handle_signal(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__on_wake(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__on_idle(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__stop(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_exc); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop___run(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, uv_run_mode __pyx_v_mode); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__run(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, uv_run_mode __pyx_v_mode); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__close(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static uint64_t __pyx_f_6uvloop_4loop_4Loop__time(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__queue_write(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_stream); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__exec_queued_writes(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__call_soon(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_args, PyObject *__pyx_v_context); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__call_soon_handle(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__call_later(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, uint64_t __pyx_v_delay, PyObject *__pyx_v_callback, PyObject *__pyx_v_args, PyObject *__pyx_v_context); /* proto*/
static void __pyx_f_6uvloop_4loop_4Loop__handle_exception(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_ex); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_signal(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_closed(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_thread(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__new_future(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__track_transport(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_transport); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__track_process(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_proc); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__untrack_process(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_proc); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__fileobj_to_fd(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__ensure_fd_no_transport(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__add_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__remove_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__has_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__add_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__remove_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__has_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__getaddrinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags, int __pyx_v_unpack); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__getnameinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct sockaddr *__pyx_v_addr, int __pyx_v_flags); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_recv(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_n); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_recv_into(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_buf); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_sendall(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_data); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_accept(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_connect(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_address); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_connect_cb(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_address); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_set_reuseport(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, int __pyx_v_fd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__set_coroutine_debug(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, int __pyx_v_enabled); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__create_server(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct sockaddr *__pyx_v_addr, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, int __pyx_v_reuse_port, PyObject *__pyx_v_backlog, PyObject *__pyx_v_ssl_handshake_timeout); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_4Loop__print_debug_info(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__set_loop(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__set_context(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self, PyObject *__pyx_v_context); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__run(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Handle__cancel(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Handle__format_handle(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_11TimerHandle__cancel(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_11TimerHandle__clear(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_11TimerHandle__run(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12PseudoSocket__na(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_what); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12PseudoSocket__make_sock(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__dealloc_impl(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__free(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__warn_unclosed(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__abort_init(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__finish_init(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__start_init(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop); /* proto*/
static CYTHON_INLINE int __pyx_f_6uvloop_4loop_8UVHandle__is_alive(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__ensure_alive(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__fatal_error(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__error(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__close(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__fileno(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__new_socket(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__get_socket(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__attach_fileobj(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self, PyObject *__pyx_v_file); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__close(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__open(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self, CYTHON_UNUSED int __pyx_v_sockfd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_7UVAsync__init(struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_7UVAsync_send(struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_f_6uvloop_4loop_7UVAsync_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVIdle__init(struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVIdle_stop(struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVIdle_start(struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_f_6uvloop_4loop_6UVIdle_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_7UVCheck__init(struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_7UVCheck_stop(struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_7UVCheck_start(struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_f_6uvloop_4loop_7UVCheck_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_7UVTimer__init(struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx, uint64_t __pyx_v_timeout); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_7UVTimer_stop(struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_7UVTimer_start(struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_f_6uvloop_4loop_7UVTimer_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx, uint64_t __pyx_v_timeout); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll__init(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, int __pyx_v_fd); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_f_6uvloop_4loop_6UVPoll_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, int __pyx_v_fd); /* proto*/
static int __pyx_f_6uvloop_4loop_6UVPoll_is_active(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVPoll__poll_start(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, int __pyx_v_flags); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVPoll__poll_stop(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_is_reading(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_is_writing(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_start_reading(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_callback); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_start_writing(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_callback); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_stop_reading(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_stop_writing(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_stop(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll__close(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6UVPoll__fatal_error(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_exc, CYTHON_UNUSED PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_6UVPoll__fatal_error *__pyx_optional_args); /* proto*/
static size_t __pyx_f_6uvloop_4loop_15UVBaseTransport__get_write_buffer_size(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_made(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_lost(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__fatal_error(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__fatal_error *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_pause_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_resume_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__wakeup_waiter(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__call_connection_made(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__call_connection_lost(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_server(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_waiter(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_waiter); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_protocol); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__clear_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__init_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__add_extra_info(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_obj); /* proto*/
static int __pyx_f_6uvloop_4loop_15UVBaseTransport__is_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__start_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__stop_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_19_StreamWriteContext_free_bufs(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_19_StreamWriteContext_close(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_19_StreamWriteContext_advance_uv_buf(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self, size_t __pyx_v_sent); /* proto*/
static struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_f_6uvloop_4loop_19_StreamWriteContext_new(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_stream, PyObject *__pyx_v_buffers); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVStream__set_protocol(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_protocol); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVStream__clear_protocol(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__shutdown(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__accept(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_server); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__close_on_read_error(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static int __pyx_f_6uvloop_4loop_8UVStream__is_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVStream__start_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream___reading_started(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream___reading_stopped(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVStream__stop_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__try_write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_data); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_data); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__exec_write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static size_t __pyx_f_6uvloop_4loop_8UVStream__get_write_buffer_size(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8UVStream__close(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_accept(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_eof(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__init(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_connect(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_exc); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__init(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer_listen(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, PyObject *__pyx_v_backlog); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__on_listen(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__fatal_error(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_14UVStreamServer__fatal_error *__pyx_optional_args); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__mark_as_open(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_f_6uvloop_4loop_14UVStreamServer__make_new_transport(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_protocol, CYTHON_UNUSED PyObject *__pyx_v_waiter); /* proto*/
static struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_f_6uvloop_4loop_9TCPServer_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, unsigned int __pyx_v_flags, PyObject *__pyx_v_ssl_handshake_timeout); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9TCPServer__new_socket(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9TCPServer__open(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, int __pyx_v_sockfd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9TCPServer_bind(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, struct sockaddr *__pyx_v_addr, struct __pyx_opt_args_6uvloop_4loop_9TCPServer_bind *__pyx_optional_args); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_f_6uvloop_4loop_9TCPServer__make_new_transport(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, PyObject *__pyx_v_protocol, PyObject *__pyx_v_waiter); /* proto*/
static struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_f_6uvloop_4loop_12TCPTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__set_nodelay(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__call_connection_made(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__new_socket(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport_bind(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, struct sockaddr *__pyx_v_addr, struct __pyx_opt_args_6uvloop_4loop_12TCPTransport_bind *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__open(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, int __pyx_v_sockfd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport_connect(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, struct sockaddr *__pyx_v_addr); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18_TCPConnectRequest_connect(struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self, struct sockaddr *__pyx_v_addr); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_f_6uvloop_4loop_10UnixServer_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_10UnixServer__new_socket(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_10UnixServer__open(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, int __pyx_v_sockfd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_10UnixServer_bind(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, PyObject *__pyx_v_path); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_f_6uvloop_4loop_10UnixServer__make_new_transport(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, PyObject *__pyx_v_protocol, PyObject *__pyx_v_waiter); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_f_6uvloop_4loop_13UnixTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_13UnixTransport__new_socket(struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_13UnixTransport__open(struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self, int __pyx_v_sockfd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_13UnixTransport_connect(struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self, char *__pyx_v_addr); /* proto*/
static struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_f_6uvloop_4loop_17ReadUnixTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_17ReadUnixTransport__new_socket(struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_17ReadUnixTransport__open(struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, int __pyx_v_sockfd); /* proto*/
static struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_f_6uvloop_4loop_18WriteUnixTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18WriteUnixTransport__new_socket(struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18WriteUnixTransport__open(struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self, int __pyx_v_sockfd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_19_PipeConnectRequest_connect(struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self, char *__pyx_v_addr); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_args, PyObject *__pyx_v_env, PyObject *__pyx_v_cwd, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr, PyObject *__pyx_v_pass_fds, PyObject *__pyx_v_debug_flags, PyObject *__pyx_v_preexec_fn, PyObject *__pyx_v_restore_signals); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__after_fork(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__close_after_spawn(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, int __pyx_v_fd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__dealloc_impl(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self); /* proto*/
static char **__pyx_f_6uvloop_4loop_9UVProcess___to_cstring_array(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_arr); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_options(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_env, PyObject *__pyx_v_cwd, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_args(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_args); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_env(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_env); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_files(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__stdin, CYTHON_UNUSED PyObject *__pyx_v__stdout, CYTHON_UNUSED PyObject *__pyx_v__stderr); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__kill(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, int __pyx_v_signum); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__on_exit(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, int64_t __pyx_v_exit_status, int __pyx_v_term_signal); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__close(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__on_exit(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int64_t __pyx_v_exit_status, int __pyx_v_term_signal); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__check_proc(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__pipe_connection_lost(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_fd, PyObject *__pyx_v_exc); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__pipe_data_received(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_fd, PyObject *__pyx_v_data); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_redirect_stdio(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_fd); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_devnull(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_outpipe(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_inpipe(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__init_files(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__call_connection_made(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_waiter); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__try_finish(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_f_6uvloop_4loop_18UVProcessTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, PyObject *__pyx_v_args, PyObject *__pyx_v_env, PyObject *__pyx_v_cwd, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr, PyObject *__pyx_v_pass_fds, PyObject *__pyx_v_waiter, PyObject *__pyx_v_debug_flags, PyObject *__pyx_v_preexec_fn, PyObject *__pyx_v_restore_signals); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVRequest_on_done(struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_9UVRequest_cancel(struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self); /* proto*/
static void __pyx_f_6uvloop_4loop_8AddrInfo_set_data(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self, struct addrinfo *__pyx_v_data); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8AddrInfo_unpack(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self); /* proto*/
static int __pyx_f_6uvloop_4loop_8AddrInfo_isinstance(PyObject *__pyx_v_other); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_15NameInfoRequest_query(struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self, struct sockaddr *__pyx_v_addr, int __pyx_v_flags); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_do_handshake(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_do_handshake *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_shutdown(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_shutdown *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_feed_eof(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_feed_ssldata(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v_data, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_ssldata *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_feed_appdata(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v_data, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_appdata *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__init(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_sock, PyObject *__pyx_v_r_addr); /* proto*/
static size_t __pyx_f_6uvloop_4loop_12UDPTransport__get_write_buffer_size(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__fileno(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static int __pyx_f_6uvloop_4loop_12UDPTransport__is_reading(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__start_reading(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__stop_reading(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__on_read_ready(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__on_write_ready(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__new_socket(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_f_6uvloop_4loop_12UDPTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_sock, PyObject *__pyx_v_r_addr); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__dealloc_impl(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__free(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__close(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Server__add_server(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_srv); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Server__wakeup(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Server__attach(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Server__detach(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Server__ref(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6uvloop_4loop_6Server__unref(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto*/

/* Module declarations from 'uvloop.includes' */

/* Module declarations from 'libc.stdint' */

/* Module declarations from 'posix.types' */

/* Module declarations from 'uvloop.includes.system' */

/* Module declarations from 'uvloop.includes.uv' */

/* Module declarations from 'cython' */

/* Module declarations from 'uvloop.includes.debug' */

/* Module declarations from 'uvloop.includes.python' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc' */

/* Module declarations from 'libc.errno' */

/* Module declarations from 'cpython.version' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.exc' */

/* Module declarations from 'cpython.module' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'cpython.tuple' */

/* Module declarations from 'cpython.list' */

/* Module declarations from 'cpython.sequence' */

/* Module declarations from 'cpython.mapping' */

/* Module declarations from 'cpython.iterator' */

/* Module declarations from 'cpython.number' */

/* Module declarations from 'cpython.int' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.bool' */
static PyTypeObject *__pyx_ptype_7cpython_4bool_bool = 0;

/* Module declarations from 'cpython.long' */

/* Module declarations from 'cpython.float' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.complex' */
static PyTypeObject *__pyx_ptype_7cpython_7complex_complex = 0;

/* Module declarations from 'cpython.string' */

/* Module declarations from 'cpython.unicode' */

/* Module declarations from 'cpython.dict' */

/* Module declarations from 'cpython.instance' */

/* Module declarations from 'cpython.function' */

/* Module declarations from 'cpython.method' */

/* Module declarations from 'cpython.weakref' */

/* Module declarations from 'cpython.getargs' */

/* Module declarations from 'cpython.pythread' */

/* Module declarations from 'cpython.pystate' */

/* Module declarations from 'cpython.cobject' */

/* Module declarations from 'cpython.oldbuffer' */

/* Module declarations from 'cpython.set' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'cpython.bytes' */

/* Module declarations from 'cpython.pycapsule' */

/* Module declarations from 'cpython' */

/* Module declarations from 'uvloop.loop' */
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVHandle = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVSocketHandle = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVAsync = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVTimer = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVIdle = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVBaseTransport = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_Loop = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_Handle = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_TimerHandle = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVCheck = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVPoll = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVStream = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVStreamServer = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_TCPServer = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_TCPTransport = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UnixServer = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UnixTransport = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_ReadUnixTransport = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_WriteUnixTransport = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVProcess = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVProcessTransport = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UVRequest = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_UDPTransport = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_Server = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_PseudoSocket = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop__StreamWriteContext = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop__TCPConnectRequest = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop__PipeConnectRequest = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_AddrInfo = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_AddrInfoRequest = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop_NameInfoRequest = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop__SSLPipe = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct___getaddrinfo = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_1__getnameinfo = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_2__sock_connect = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_3___get__ = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_4_run_until_complete = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_6_getnameinfo = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_7_start_tls = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_8_create_server = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_9_create_connection = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_10_genexpr = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_11_genexpr = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_12_create_unix_server = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_14_sock_recv = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_16_sock_sendall = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_17_sock_accept = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_18_sock_connect = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_20___subprocess_run = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_26_genexpr = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_28_wait_closed = 0;
static PyTypeObject *__pyx_ptype_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 = 0;
static PyTypeObject *__pyx_ptype___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_get_event_loop = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_CancelledError = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_InvalidStateError = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_TimeoutError = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_Future = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_Task = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_ensure_future = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_gather = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_wait = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_wrap_future = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_logger = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_iscoroutine = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_iscoroutinefunction = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_BaseProtocol = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_Protocol = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_isfuture = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_get_running_loop = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_set_running_loop = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_debug_wrapper = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_AbstractChildWatcher = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_Transport = 0;
static PyObject *__pyx_v_6uvloop_4loop_aio_FlowControlMixin = 0;
static PyObject *__pyx_v_6uvloop_4loop_col_deque = 0;
static PyObject *__pyx_v_6uvloop_4loop_col_Iterable = 0;
static PyObject *__pyx_v_6uvloop_4loop_col_Counter = 0;
static PyObject *__pyx_v_6uvloop_4loop_col_OrderedDict = 0;
static PyObject *__pyx_v_6uvloop_4loop_cc_ThreadPoolExecutor = 0;
static PyObject *__pyx_v_6uvloop_4loop_cc_Future = 0;
static PyObject *__pyx_v_6uvloop_4loop_errno_EBADF = 0;
static PyObject *__pyx_v_6uvloop_4loop_errno_EINVAL = 0;
static PyObject *__pyx_v_6uvloop_4loop_ft_partial = 0;
static PyObject *__pyx_v_6uvloop_4loop_gc_disable = 0;
static PyObject *__pyx_v_6uvloop_4loop_iter_chain = 0;
static PyObject *__pyx_v_6uvloop_4loop_inspect_isgenerator = 0;
static int __pyx_v_6uvloop_4loop_has_SO_REUSEPORT;
static int __pyx_v_6uvloop_4loop_SO_REUSEPORT;
static int __pyx_v_6uvloop_4loop_SO_BROADCAST;
static int __pyx_v_6uvloop_4loop_SOCK_NONBLOCK;
static PyObject *__pyx_v_6uvloop_4loop_socket_gaierror = 0;
static PyObject *__pyx_v_6uvloop_4loop_socket_error = 0;
static PyObject *__pyx_v_6uvloop_4loop_socket_timeout = 0;
static PyObject *__pyx_v_6uvloop_4loop_socket_socket = 0;
static PyObject *__pyx_v_6uvloop_4loop_socket_socketpair = 0;
static PyObject *__pyx_v_6uvloop_4loop_socket_getservbyname = 0;
static PyObject *__pyx_v_6uvloop_4loop_socket_AddressFamily = 0;
static PyObject *__pyx_v_6uvloop_4loop_socket_SocketKind = 0;
static int __pyx_v_6uvloop_4loop_socket_EAI_ADDRFAMILY;
static int __pyx_v_6uvloop_4loop_socket_EAI_AGAIN;
static int __pyx_v_6uvloop_4loop_socket_EAI_BADFLAGS;
static int __pyx_v_6uvloop_4loop_socket_EAI_BADHINTS;
static int __pyx_v_6uvloop_4loop_socket_EAI_CANCELED;
static int __pyx_v_6uvloop_4loop_socket_EAI_FAIL;
static int __pyx_v_6uvloop_4loop_socket_EAI_FAMILY;
static int __pyx_v_6uvloop_4loop_socket_EAI_MEMORY;
static int __pyx_v_6uvloop_4loop_socket_EAI_NODATA;
static int __pyx_v_6uvloop_4loop_socket_EAI_NONAME;
static int __pyx_v_6uvloop_4loop_socket_EAI_OVERFLOW;
static int __pyx_v_6uvloop_4loop_socket_EAI_PROTOCOL;
static int __pyx_v_6uvloop_4loop_socket_EAI_SERVICE;
static int __pyx_v_6uvloop_4loop_socket_EAI_SOCKTYPE;
static PyObject *__pyx_v_6uvloop_4loop_os_name = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_environ = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_dup = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_set_inheritable = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_get_inheritable = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_close = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_open = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_devnull = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_O_RDWR = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_pipe = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_read = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_remove = 0;
static PyObject *__pyx_v_6uvloop_4loop_os_stat = 0;
static PyObject *__pyx_v_6uvloop_4loop_stat_S_ISSOCK = 0;
static PyObject *__pyx_v_6uvloop_4loop_sys_ignore_environment = 0;
static PyObject *__pyx_v_6uvloop_4loop_sys_exc_info = 0;
static PyObject *__pyx_v_6uvloop_4loop_sys_set_coroutine_wrapper = 0;
static PyObject *__pyx_v_6uvloop_4loop_sys_get_coroutine_wrapper = 0;
static PyObject *__pyx_v_6uvloop_4loop_sys_getframe = 0;
static PyObject *__pyx_v_6uvloop_4loop_sys_version_info = 0;
static PyObject *__pyx_v_6uvloop_4loop_ssl_SSLContext = 0;
static PyObject *__pyx_v_6uvloop_4loop_ssl_MemoryBIO = 0;
static PyObject *__pyx_v_6uvloop_4loop_ssl_create_default_context = 0;
static PyObject *__pyx_v_6uvloop_4loop_ssl_SSLError = 0;
static PyObject *__pyx_v_6uvloop_4loop_ssl_CertificateError = 0;
static int __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ;
static int __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_WRITE;
static int __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_SYSCALL;
static uint64_t __pyx_v_6uvloop_4loop_MAIN_THREAD_ID;
static int __pyx_v_6uvloop_4loop_subprocess_PIPE;
static int __pyx_v_6uvloop_4loop_subprocess_STDOUT;
static int __pyx_v_6uvloop_4loop_subprocess_DEVNULL;
static PyObject *__pyx_v_6uvloop_4loop_subprocess_SubprocessError = 0;
static int __pyx_v_6uvloop_4loop_signal_NSIG;
static PyObject *__pyx_v_6uvloop_4loop_signal_signal = 0;
static PyObject *__pyx_v_6uvloop_4loop_signal_siginterrupt = 0;
static PyObject *__pyx_v_6uvloop_4loop_signal_set_wakeup_fd = 0;
static PyObject *__pyx_v_6uvloop_4loop_signal_default_int_handler = 0;
static PyObject *__pyx_v_6uvloop_4loop_signal_SIG_DFL = 0;
static PyObject *__pyx_v_6uvloop_4loop_time_sleep = 0;
static PyObject *__pyx_v_6uvloop_4loop_time_monotonic = 0;
static PyObject *__pyx_v_6uvloop_4loop_tb_StackSummary = 0;
static PyObject *__pyx_v_6uvloop_4loop_tb_walk_stack = 0;
static PyObject *__pyx_v_6uvloop_4loop_tb_format_list = 0;
static PyObject *__pyx_v_6uvloop_4loop_warnings_warn = 0;
static PyObject *__pyx_v_6uvloop_4loop_weakref_WeakValueDictionary = 0;
static PyObject *__pyx_v_6uvloop_4loop_weakref_WeakSet = 0;
static PyObject *__pyx_v_6uvloop_4loop_py_inf = 0;
static int __pyx_v_6uvloop_4loop_PY37;
static int __pyx_v_6uvloop_4loop_PY36;
static PyObject *__pyx_v_6uvloop_4loop__UNWRAPPED = 0;
static PyObject *__pyx_v_6uvloop_4loop__DO_HANDSHAKE = 0;
static PyObject *__pyx_v_6uvloop_4loop__WRAPPED = 0;
static PyObject *__pyx_v_6uvloop_4loop__SHUTDOWN = 0;
static Py_ssize_t __pyx_v_6uvloop_4loop_READ_MAX_SIZE;
static volatile int __pyx_v_6uvloop_4loop___atfork_installed;
static volatile int __pyx_v_6uvloop_4loop___forking;
static struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_6uvloop_4loop___forking_loop = 0;
static volatile int __pyx_v_6uvloop_4loop___mem_installed;
static PyObject *__pyx_f_6uvloop_4loop___strerr(int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___convert_python_error(int); /*proto*/
static int __pyx_f_6uvloop_4loop___convert_socket_error(int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_convert_error(int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop__is_sock_stream(PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop__is_sock_dgram(PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_isfuture(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_socket_inc_io_ref(PyObject *); /*proto*/
static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_socket_dec_io_ref(PyObject *); /*proto*/
static void __pyx_f_6uvloop_4loop___loop_alloc_buffer(uv_handle_t *, size_t, uv_buf_t *); /*proto*/
static CYTHON_INLINE void __pyx_f_6uvloop_4loop___loop_free_buffer(struct __pyx_obj_6uvloop_4loop_Loop *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_new_Handle(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, __pyx_t_6uvloop_4loop_method_t, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle1(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, __pyx_t_6uvloop_4loop_method1_t, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle2(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, __pyx_t_6uvloop_4loop_method2_t, PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle3(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, __pyx_t_6uvloop_4loop_method3_t, PyObject *, PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop_extract_stack(void); /*proto*/
static CYTHON_INLINE int __pyx_f_6uvloop_4loop___ensure_handle_data(uv_handle_t *, char const *); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_close_handle_cb(uv_handle_t *); /*proto*/
static void __pyx_f_6uvloop_4loop___close_all_handles(struct __pyx_obj_6uvloop_4loop_Loop *); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_walk_close_all_handles_cb(uv_handle_t *, void *); /*proto*/
static void __pyx_f_6uvloop_4loop___uvasync_callback(uv_async_t *); /*proto*/
static void __pyx_f_6uvloop_4loop_cb_idle_callback(uv_idle_t *); /*proto*/
static void __pyx_f_6uvloop_4loop_cb_check_callback(uv_check_t *); /*proto*/
static void __pyx_f_6uvloop_4loop___uvtimer_callback(uv_timer_t *); /*proto*/
static void __pyx_f_6uvloop_4loop___on_uvpoll_event(uv_poll_t *, int, int); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_stream_on_shutdown(uv_shutdown_t *, int); /*proto*/
static CYTHON_INLINE int __pyx_f_6uvloop_4loop___uv_stream_on_read_common(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_Loop *, Py_ssize_t); /*proto*/
static CYTHON_INLINE void __pyx_f_6uvloop_4loop___uv_stream_on_read_impl(uv_stream_t *, Py_ssize_t, uv_buf_t const *); /*proto*/
static CYTHON_INLINE void __pyx_f_6uvloop_4loop___uv_stream_on_write_impl(uv_write_t *, int); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_stream_on_read(uv_stream_t *, Py_ssize_t, uv_buf_t const *); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_stream_on_write(uv_write_t *, int); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_stream_buffered_alloc(uv_handle_t *, size_t, uv_buf_t *); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_stream_buffered_on_read(uv_stream_t *, Py_ssize_t, uv_buf_t const *); /*proto*/
static void __pyx_f_6uvloop_4loop___uv_streamserver_on_listen(uv_stream_t *, int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___tcp_init_uv_handle(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_Loop *, unsigned int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___tcp_bind(struct __pyx_obj_6uvloop_4loop_UVStream *, struct sockaddr *, unsigned int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___tcp_open(struct __pyx_obj_6uvloop_4loop_UVStream *, int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___tcp_get_socket(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *); /*proto*/
static void __pyx_f_6uvloop_4loop___tcp_connect_callback(uv_connect_t *, int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___pipe_init_uv_handle(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_Loop *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___pipe_open(struct __pyx_obj_6uvloop_4loop_UVStream *, int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___pipe_get_socket(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *); /*proto*/
static void __pyx_f_6uvloop_4loop___pipe_connect_callback(uv_connect_t *, int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___process_convert_fileno(PyObject *); /*proto*/
static void __pyx_f_6uvloop_4loop___uvprocess_on_exit_callback(uv_process_t *, int64_t, int); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___socketpair(void); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___port_to_int(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___convert_sockaddr_to_pyaddr(struct sockaddr const *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___convert_pyaddr_to_sockaddr(int, PyObject *, struct sockaddr *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___static_getaddrinfo(PyObject *, PyObject *, int, int, int, struct sockaddr *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___static_getaddrinfo_pyaddr(PyObject *, PyObject *, int, int, int, int); /*proto*/
static void __pyx_f_6uvloop_4loop___on_addrinfo_resolved(uv_getaddrinfo_t *, int, struct addrinfo *); /*proto*/
static void __pyx_f_6uvloop_4loop___on_nameinfo_resolved(uv_getnameinfo_t *, int, char const *, char const *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop__create_transport_context(PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop__feed_data_to_bufferred_proto(PyObject *, PyObject *); /*proto*/
static void __pyx_f_6uvloop_4loop___atfork_child(void); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___install_atfork(void); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___install_pymem(void); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop__set_signal_wakeup_fd(PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop__warn_with_source(PyObject *, PyObject *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___pyx_unpickle_PseudoSocket__set_state(struct __pyx_obj_6uvloop_4loop_PseudoSocket *, PyObject *); /*proto*/
static PyObject *__pyx_f_6uvloop_4loop___pyx_unpickle__SSLPipe__set_state(struct __pyx_obj_6uvloop_4loop__SSLPipe *, PyObject *); /*proto*/
static PyObject *__Pyx_CFunc_object____Loop____bint___to_py(PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, int)); /*proto*/
#define __Pyx_MODULE_NAME "uvloop.loop"
extern int __pyx_module_is_main_uvloop__loop;
int __pyx_module_is_main_uvloop__loop = 0;

/* Implementation of 'uvloop.loop' */
static PyObject *__pyx_builtin_property;
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_OSError;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_BaseException;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_RuntimeWarning;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_OverflowError;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_NotImplementedError;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_super;
static PyObject *__pyx_builtin_open;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_UnicodeEncodeError;
static const char __pyx_k_b[] = "b";
static const char __pyx_k_c[] = "-c";
static const char __pyx_k_e[] = "e";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_n[] = "n";
static const char __pyx_k__7[] = "";
static const char __pyx_k_dt[] = "dt";
static const char __pyx_k_ex[] = "ex";
static const char __pyx_k_fd[] = "fd";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_tr[] = "tr";
static const char __pyx_k_wb[] = "wb";
static const char __pyx_k__33[] = ": ";
static const char __pyx_k__40[] = "-------------------------------+---------+---------";
static const char __pyx_k__71[] = ", ";
static const char __pyx_k__87[] = "{}: {}";
static const char __pyx_k__88[] = "\n";
static const char __pyx_k_abc[] = "abc";
static const char __pyx_k_add[] = "add";
static const char __pyx_k_buf[] = "buf";
static const char __pyx_k_cmd[] = "cmd";
static const char __pyx_k_cwd[] = "cwd";
static const char __pyx_k_del[] = "__del__";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_dup[] = "dup";
static const char __pyx_k_env[] = "env";
static const char __pyx_k_exc[] = "exc";
static const char __pyx_k_fut[] = "fut";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_inf[] = "inf";
static const char __pyx_k_log[] = "log";
static const char __pyx_k_low[] = "low";
static const char __pyx_k_msg[] = "msg";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_r_s[] = "%r: %s";
static const char __pyx_k_sig[] = "sig";
static const char __pyx_k_ssl[] = "ssl";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_tcp[] = "tcp";
static const char __pyx_k_udp[] = "udp";
static const char __pyx_k_zip[] = "zip";
static const char __pyx_k_NSIG[] = "NSIG";
static const char __pyx_k_PIPE[] = "PIPE";
static const char __pyx_k_Task[] = "Task";
static const char __pyx_k__114[] = "{}={}";
static const char __pyx_k__128[] = "<";
static const char __pyx_k__129[] = " ";
static const char __pyx_k__130[] = ">";
static const char __pyx_k__159[] = "{} ({})";
static const char __pyx_k__209[] = ":";
static const char __pyx_k__220[] = "=";
static const char __pyx_k_addr[] = "addr";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_bind[] = "bind";
static const char __pyx_k_cast[] = "cast";
static const char __pyx_k_copy[] = "copy";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_done[] = "done";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_fd_2[] = " fd=";
static const char __pyx_k_func[] = "func";
static const char __pyx_k_high[] = "high (";
static const char __pyx_k_host[] = "host";
static const char __pyx_k_idna[] = "idna";
static const char __pyx_k_info[] = "info";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_loop[] = "loop";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_noop[] = "_noop";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_pipe[] = "pipe";
static const char __pyx_k_port[] = "port";
static const char __pyx_k_proc[] = "proc";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_recv[] = "recv";
static const char __pyx_k_repr[] = "__repr__";
static const char __pyx_k_self[] = "__self__";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_sock[] = "sock";
static const char __pyx_k_stat[] = "stat";
static const char __pyx_k_stop[] = "stop";
static const char __pyx_k_task[] = "task";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_wait[] = "wait";
static const char __pyx_k_warn[] = "warn";
static const char __pyx_k_when[] = "when";
static const char __pyx_k_wrap[] = "wrap";
static const char __pyx_k_abort[] = "_abort";
static const char __pyx_k_ascii[] = "ascii";
static const char __pyx_k_await[] = "__await__";
static const char __pyx_k_cause[] = "__cause__";
static const char __pyx_k_chain[] = "chain";
static const char __pyx_k_chunk[] = "chunk";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_clear[] = "clear";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_delay[] = "delay";
static const char __pyx_k_deque[] = "deque";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_errno[] = "errno";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_extra[] = "_extra";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_flush[] = "flush";
static const char __pyx_k_frame[] = "frame";
static const char __pyx_k_ident[] = "ident";
static const char __pyx_k_items[] = "items";
static const char __pyx_k_limit[] = "limit";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_proto[] = "proto";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_share[] = "share";
static const char __pyx_k_shell[] = "shell";
static const char __pyx_k_sleep[] = "sleep";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_stdin[] = "stdin";
static const char __pyx_k_super[] = "super";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_Future[] = "Future";
static const char __pyx_k_O_RDWR[] = "O_RDWR";
static const char __pyx_k_STDOUT[] = "STDOUT";
static const char __pyx_k_accept[] = "accept";
static const char __pyx_k_aclose[] = "aclose";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_bin_sh[] = "/bin/sh";
static const char __pyx_k_cancel[] = "cancel";
static const char __pyx_k_cipher[] = "cipher";
static const char __pyx_k_closed[] = "_closed";
static const char __pyx_k_decode[] = "decode";
static const char __pyx_k_detach[] = "detach";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_family[] = "family";
static const char __pyx_k_fileno[] = "fileno";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_fspath[] = "__fspath__";
static const char __pyx_k_gather[] = "gather";
static const char __pyx_k_handle[] = "handle";
static const char __pyx_k_high_2[] = "high";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_logger[] = "logger";
static const char __pyx_k_loop_2[] = "_loop";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "name";
static const char __pyx_k_noop_2[] = "noop";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_offset[] = "offset";
static const char __pyx_k_paused[] = "_paused";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_pipe_2[] = " pipe=";
static const char __pyx_k_reason[] = "reason";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_remove[] = "remove";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_rstrip[] = "rstrip";
static const char __pyx_k_self_2[] = "self";
static const char __pyx_k_sendto[] = "sendto";
static const char __pyx_k_signal[] = "signal";
static const char __pyx_k_signum[] = "signum";
static const char __pyx_k_socket[] = "socket ";
static const char __pyx_k_source[] = "source";
static const char __pyx_k_sslobj[] = "sslobj";
static const char __pyx_k_stderr[] = "stderr";
static const char __pyx_k_stdout[] = "stdout";
static const char __pyx_k_submit[] = "submit";
static const char __pyx_k_unwrap[] = "unwrap";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_waiter[] = "waiter";
static const char __pyx_k_Counter[] = "Counter";
static const char __pyx_k_DEVNULL[] = "DEVNULL";
static const char __pyx_k_OSError[] = "OSError";
static const char __pyx_k_SIG_DFL[] = "SIG_DFL";
static const char __pyx_k_WRAPPED[] = "WRAPPED";
static const char __pyx_k_WeakSet[] = "WeakSet";
static const char __pyx_k_abort_2[] = "abort";
static const char __pyx_k_address[] = "address";
static const char __pyx_k_appdata[] = "appdata";
static const char __pyx_k_asyncio[] = "asyncio";
static const char __pyx_k_backlog[] = "backlog";
static const char __pyx_k_bufsize[] = "bufsize";
static const char __pyx_k_connect[] = "connect";
static const char __pyx_k_context[] = "context";
static const char __pyx_k_default[] = "default";
static const char __pyx_k_devnull[] = "devnull";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_discard[] = "discard";
static const char __pyx_k_enabled[] = "enabled";
static const char __pyx_k_environ[] = "environ";
static const char __pyx_k_extract[] = "extract";
static const char __pyx_k_fileobj[] = "fileobj";
static const char __pyx_k_futures[] = "futures";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_inspect[] = "inspect";
static const char __pyx_k_io_refs[] = "_io_refs";
static const char __pyx_k_laddr_s[] = ", laddr=%s";
static const char __pyx_k_message[] = "message";
static const char __pyx_k_missing[] = "missing";
static const char __pyx_k_partial[] = "partial";
static const char __pyx_k_pending[] = "pending";
static const char __pyx_k_popleft[] = "popleft";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_program[] = "program";
static const char __pyx_k_raddr_s[] = ", raddr=%s";
static const char __pyx_k_reverse[] = "reverse";
static const char __pyx_k_sockets[] = " sockets=";
static const char __pyx_k_ssldata[] = "ssldata";
static const char __pyx_k_sslpipe[] = "_sslpipe";
static const char __pyx_k_st_mode[] = "st_mode";
static const char __pyx_k_timeout[] = "timeout";
static const char __pyx_k_warning[] = "warning";
static const char __pyx_k_weakref[] = "weakref";
static const char __pyx_k_18_7_7_7[] = "    {: <18} {: >7} | {: >7} | {: >7}";
static const char __pyx_k_EAI_FAIL[] = "EAI_FAIL";
static const char __pyx_k_Iterable[] = "Iterable";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_Protocol[] = "Protocol";
static const char __pyx_k_SHUTDOWN[] = "SHUTDOWN";
static const char __pyx_k_SSLError[] = "SSLError";
static const char __pyx_k_S_ISSOCK[] = "S_ISSOCK";
static const char __pyx_k_asyncgen[] = "asyncgen";
static const char __pyx_k_builtins[] = "__builtins__";
static const char __pyx_k_callback[] = "callback";
static const char __pyx_k_closed_x[] = "<{} closed={} {:#x}>";
static const char __pyx_k_exc_info[] = "exc_info";
static const char __pyx_k_executor[] = "executor";
static const char __pyx_k_finalize[] = "_finalize";
static const char __pyx_k_gaierror[] = "gaierror";
static const char __pyx_k_getframe[] = "_getframe";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_isfuture[] = "isfuture";
static const char __pyx_k_pass_fds[] = "pass_fds";
static const char __pyx_k_peercert[] = "peercert";
static const char __pyx_k_peername[] = "peername";
static const char __pyx_k_property[] = "property";
static const char __pyx_k_protocol[] = "protocol";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_reason_2[] = " reason: ";
static const char __pyx_k_recvfrom[] = "recvfrom";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_shutdown[] = "shutdown";
static const char __pyx_k_sockaddr[] = "sockaddr";
static const char __pyx_k_socket_2[] = "socket";
static const char __pyx_k_sockname[] = "sockname";
static const char __pyx_k_strerror[] = "strerror";
static const char __pyx_k_subtract[] = "subtract";
static const char __pyx_k_waiter_2[] = "_waiter";
static const char __pyx_k_warnings[] = "warnings";
static const char __pyx_k_wrap_bio[] = "wrap_bio";
static const char __pyx_k_EAI_AGAIN[] = "EAI_AGAIN";
static const char __pyx_k_Loop_time[] = "Loop time:                 {}";
static const char __pyx_k_MemoryBIO[] = "MemoryBIO";
static const char __pyx_k_Read_EOFs[] = "Read EOFs:                 {}";
static const char __pyx_k_Transport[] = "Transport";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_UNWRAPPED[] = "UNWRAPPED";
static const char __pyx_k_address_2[] = "_address";
static const char __pyx_k_call_soon[] = "call_soon";
static const char __pyx_k_cancelled[] = "cancelled";
static const char __pyx_k_close_fds[] = "close_fds";
static const char __pyx_k_exception[] = "exception";
static const char __pyx_k_finalizer[] = "finalizer";
static const char __pyx_k_firstiter[] = "firstiter";
static const char __pyx_k_functools[] = "functools";
static const char __pyx_k_get_debug[] = "get_debug";
static const char __pyx_k_is_closed[] = "is_closed";
static const char __pyx_k_itertools[] = "itertools";
static const char __pyx_k_keep_open[] = "keep_open";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_monotonic[] = "monotonic";
static const char __pyx_k_must_be_0[] = ") must be >= 0";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_recv_into[] = "recv_into";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_set_debug[] = "set_debug";
static const char __pyx_k_sock_recv[] = "sock_recv";
static const char __pyx_k_sockets_2[] = "sockets";
static const char __pyx_k_sslpipe_2[] = "sslpipe";
static const char __pyx_k_start_tls[] = "start_tls";
static const char __pyx_k_stdio_fut[] = "stdio_fut";
static const char __pyx_k_threading[] = "threading";
static const char __pyx_k_traceback[] = "__traceback__";
static const char __pyx_k_transport[] = "transport";
static const char __pyx_k_write_eof[] = "write_eof";
static const char __pyx_k_EAI_FAMILY[] = "EAI_FAMILY";
static const char __pyx_k_EAI_MEMORY[] = "EAI_MEMORY";
static const char __pyx_k_EAI_NODATA[] = "EAI_NODATA";
static const char __pyx_k_EAI_NONAME[] = "EAI_NONAME";
static const char __pyx_k_Loop__stop[] = "Loop._stop";
static const char __pyx_k_SSLContext[] = "SSLContext";
static const char __pyx_k_SocketKind[] = "SocketKind";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_appendleft[] = "appendleft";
static const char __pyx_k_call_later[] = "call_later";
static const char __pyx_k_concurrent[] = "concurrent";
static const char __pyx_k_coroutines[] = "coroutines";
static const char __pyx_k_created_at[] = "created at {}:{}";
static const char __pyx_k_executable[] = "executable";
static const char __pyx_k_get_buffer[] = "get_buffer";
static const char __pyx_k_getsockopt[] = "getsockopt";
static const char __pyx_k_gettimeout[] = "gettimeout";
static const char __pyx_k_is_closing[] = "is_closing";
static const char __pyx_k_is_reading[] = "is_reading";
static const char __pyx_k_is_running[] = "is_running";
static const char __pyx_k_local_addr[] = "local_addr";
static const char __pyx_k_memoryview[] = "memoryview";
static const char __pyx_k_preexec_fn[] = "preexec_fn";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_reuse_port[] = "reuse_port";
static const char __pyx_k_set_result[] = "set_result";
static const char __pyx_k_setsockopt[] = "setsockopt";
static const char __pyx_k_settimeout[] = "settimeout";
static const char __pyx_k_sighandler[] = "__sighandler";
static const char __pyx_k_socketpair[] = "socketpair";
static const char __pyx_k_ssl_object[] = "ssl_object";
static const char __pyx_k_sslcontext[] = "sslcontext";
static const char __pyx_k_subprocess[] = "subprocess";
static const char __pyx_k_transports[] = "transports";
static const char __pyx_k_walk_stack[] = "walk_stack";
static const char __pyx_k_writelines[] = "writelines";
static const char __pyx_k_EAI_SERVICE[] = "EAI_SERVICE";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_OrderedDict[] = "OrderedDict";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_Read_errors[] = "Read errors:               {}";
static const char __pyx_k_Read_events[] = "Read events:               {}";
static const char __pyx_k_SSLProtocol[] = "SSLProtocol";
static const char __pyx_k_asyncio_log[] = "asyncio.log";
static const char __pyx_k_bind_method[] = "bind() method";
static const char __pyx_k_cfunc_to_py[] = "cfunc.to_py";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_compression[] = "compression";
static const char __pyx_k_create_task[] = "create_task";
static const char __pyx_k_fatal_error[] = "_fatal_error";
static const char __pyx_k_force_close[] = "_force_close";
static const char __pyx_k_format_list[] = "format_list";
static const char __pyx_k_getaddrinfo[] = "getaddrinfo";
static const char __pyx_k_getnameinfo[] = "getnameinfo";
static const char __pyx_k_getpeercert[] = "getpeercert";
static const char __pyx_k_getpeername[] = "getpeername";
static const char __pyx_k_getsockname[] = "getsockname";
static const char __pyx_k_in_shutdown[] = "_in_shutdown";
static const char __pyx_k_iscoroutine[] = "iscoroutine";
static const char __pyx_k_isgenerator[] = "isgenerator";
static const char __pyx_k_main_thread[] = "main_thread";
static const char __pyx_k_mark_closed[] = "_mark_closed";
static const char __pyx_k_must_be_low[] = ") must be >= low (";
static const char __pyx_k_recv_method[] = "recv() method";
static const char __pyx_k_remote_addr[] = "remote_addr";
static const char __pyx_k_run_forever[] = "run_forever";
static const char __pyx_k_send_method[] = "send() method";
static const char __pyx_k_server_side[] = "server_side";
static const char __pyx_k_setblocking[] = "setblocking";
static const char __pyx_k_sock_accept[] = "sock_accept";
static const char __pyx_k_startupinfo[] = "startupinfo";
static const char __pyx_k_traceback_2[] = "traceback";
static const char __pyx_k_transport_2[] = "transport ";
static const char __pyx_k_transport_3[] = "_transport";
static const char __pyx_k_uvloop_loop[] = "uvloop.loop";
static const char __pyx_k_wait_closed[] = "wait_closed";
static const char __pyx_k_wrap_future[] = "wrap_future";
static const char __pyx_k_BaseProtocol[] = "BaseProtocol";
static const char __pyx_k_DO_HANDSHAKE[] = "DO_HANDSHAKE";
static const char __pyx_k_EAI_BADFLAGS[] = "EAI_BADFLAGS";
static const char __pyx_k_EAI_BADHINTS[] = "EAI_BADHINTS";
static const char __pyx_k_EAI_CANCELED[] = "EAI_CANCELED";
static const char __pyx_k_EAI_OVERFLOW[] = "EAI_OVERFLOW";
static const char __pyx_k_EAI_PROTOCOL[] = "EAI_PROTOCOL";
static const char __pyx_k_EAI_SOCKTYPE[] = "EAI_SOCKTYPE";
static const char __pyx_k_Process_info[] = "---- Process info: -----";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_SO_BROADCAST[] = "SO_BROADCAST";
static const char __pyx_k_SO_REUSEPORT[] = "SO_REUSEPORT";
static const char __pyx_k_StackSummary[] = "StackSummary";
static const char __pyx_k_TimeoutError[] = "TimeoutError";
static const char __pyx_k_Write_errors[] = "Write errors:              {}";
static const char __pyx_k_Write_events[] = "Write events:              {}";
static const char __pyx_k_alive_closed[] = "                        alive  | closed  |";
static const char __pyx_k_app_protocol[] = "_app_protocol";
static const char __pyx_k_close_method[] = "close() method";
static const char __pyx_k_disconnected[] = "disconnected";
static const char __pyx_k_do_handshake[] = "do_handshake";
static const char __pyx_k_eof_received[] = "eof_received";
static const char __pyx_k_get_protocol[] = "get_protocol";
static const char __pyx_k_in_handshake[] = "_in_handshake";
static const char __pyx_k_lookup_lines[] = "lookup_lines";
static const char __pyx_k_objs_handles[] = "                        objs   | handles |";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_set_protocol[] = "set_protocol";
static const char __pyx_k_siginterrupt[] = "siginterrupt";
static const char __pyx_k_sock_connect[] = "sock_connect";
static const char __pyx_k_sock_sendall[] = "sock_sendall";
static const char __pyx_k_ssl_protocol[] = "ssl_protocol";
static const char __pyx_k_sslcontext_2[] = "_sslcontext";
static const char __pyx_k_stdio_inited[] = "__stdio_inited";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_AddressFamily[] = "AddressFamily";
static const char __pyx_k_BaseException[] = "BaseException";
static const char __pyx_k_Errors_logged[] = "Errors logged:             {}";
static const char __pyx_k_Listen_errors[] = "Listen errors:             {}";
static const char __pyx_k_OverflowError[] = "OverflowError";
static const char __pyx_k_SOCK_NONBLOCK[] = "SOCK_NONBLOCK";
static const char __pyx_k_accept_method[] = "accept() method";
static const char __pyx_k_app_transport[] = "_app_transport";
static const char __pyx_k_asyncio_tasks[] = "asyncio.tasks";
static const char __pyx_k_can_write_eof[] = "can_write_eof";
static const char __pyx_k_create_server[] = "create_server";
static const char __pyx_k_creationflags[] = "creationflags";
static const char __pyx_k_data_received[] = "data_received";
static const char __pyx_k_debug_wrapper[] = "debug_wrapper";
static const char __pyx_k_detach_method[] = "detach() method";
static const char __pyx_k_ensure_future[] = "ensure_future";
static const char __pyx_k_getservbyname[] = "getservbyname";
static const char __pyx_k_handshake_exc[] = "handshake_exc";
static const char __pyx_k_listen_method[] = "listen() method";
static const char __pyx_k_loop__on_idle[] = "loop._on_idle";
static const char __pyx_k_pause_reading[] = "pause_reading";
static const char __pyx_k_pause_writing[] = "pause_writing";
static const char __pyx_k_proto_factory[] = "proto_factory";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_remove_reader[] = "remove_reader";
static const char __pyx_k_remove_writer[] = "remove_writer";
static const char __pyx_k_reuse_address[] = "reuse_address";
static const char __pyx_k_sendto_method[] = "sendto() method";
static const char __pyx_k_server_side_2[] = "_server_side";
static const char __pyx_k_set_exception[] = "set_exception";
static const char __pyx_k_set_wakeup_fd[] = "set_wakeup_fd";
static const char __pyx_k_wakeup_waiter[] = "_wakeup_waiter";
static const char __pyx_k_write_appdata[] = "_write_appdata";
static const char __pyx_k_write_backlog[] = "_write_backlog";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_CancelledError[] = "CancelledError";
static const char __pyx_k_EAI_ADDRFAMILY[] = "EAI_ADDRFAMILY";
static const char __pyx_k_Loop_sock_recv[] = "Loop.sock_recv";
static const char __pyx_k_Loop_start_tls[] = "Loop.start_tls";
static const char __pyx_k_Process_memory[] = "Process memory:            {}";
static const char __pyx_k_Read_callbacks[] = "Read callbacks:            {}";
static const char __pyx_k_RuntimeWarning[] = "RuntimeWarning";
static const char __pyx_k_app_protocol_2[] = "app_protocol";
static const char __pyx_k_buffer_updated[] = "buffer_updated";
static const char __pyx_k_check_hostname[] = "check_hostname";
static const char __pyx_k_connect_failed[] = "connect failed";
static const char __pyx_k_connect_method[] = "connect() method";
static const char __pyx_k_error_received[] = "error_received";
static const char __pyx_k_get_event_loop[] = "get_event_loop";
static const char __pyx_k_get_extra_info[] = "get_extra_info";
static const char __pyx_k_process_exited[] = "process_exited";
static const char __pyx_k_r_received_EOF[] = "%r received EOF";
static const char __pyx_k_recvmsg_method[] = "recvmsg() method";
static const char __pyx_k_resume_reading[] = "resume_reading";
static const char __pyx_k_resume_writing[] = "resume_writing";
static const char __pyx_k_sendall_method[] = "sendall() method";
static const char __pyx_k_sendmsg_method[] = "sendmsg() method";
static const char __pyx_k_sock_recv_into[] = "sock_recv_into";
static const char __pyx_k_ssl_protocol_2[] = "_ssl_protocol";
static const char __pyx_k_start_shutdown[] = "_start_shutdown";
static const char __pyx_k_subprocess_run[] = "__subprocess_run";
static const char __pyx_k_BlockingIOError[] = "BlockingIOError";
static const char __pyx_k_BrokenPipeError[] = "BrokenPipeError";
static const char __pyx_k_FileExistsError[] = "FileExistsError";
static const char __pyx_k_Loop__sock_recv[] = "Loop._sock_recv";
static const char __pyx_k_Loop_debug_info[] = "--- Loop debug info: ---";
static const char __pyx_k_PermissionError[] = "PermissionError";
static const char __pyx_k_ResourceWarning[] = "ResourceWarning";
static const char __pyx_k_SSL_error_errno[] = "SSL error errno:";
static const char __pyx_k_Shutdown_errors[] = "Shutdown errors            {}";
static const char __pyx_k_SubprocessError[] = "SubprocessError";
static const char __pyx_k_Timer_handles_8[] = "Timer handles:             {: <8} | {}";
static const char __pyx_k_allow_broadcast[] = "allow_broadcast";
static const char __pyx_k_asyncio_futures[] = "asyncio.futures";
static const char __pyx_k_collections_abc[] = "collections.abc";
static const char __pyx_k_connection_lost[] = "connection_lost";
static const char __pyx_k_connection_made[] = "connection_made";
static const char __pyx_k_get_inheritable[] = "get_inheritable";
static const char __pyx_k_makefile_method[] = "makefile() method";
static const char __pyx_k_protocol_paused[] = "_protocol_paused";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_recvfrom_method[] = "recvfrom() method";
static const char __pyx_k_restore_signals[] = "restore_signals";
static const char __pyx_k_sendfile_method[] = "sendfile() method";
static const char __pyx_k_server_hostname[] = "server_hostname";
static const char __pyx_k_set_inheritable[] = "set_inheritable";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_shutdown_method[] = "shutdown() method";
static const char __pyx_k_start_handshake[] = "_start_handshake";
static const char __pyx_k_subprocess_exec[] = "subprocess_exec";
static const char __pyx_k_uvloop_loop_pyx[] = "uvloop/loop.pyx";
static const char __pyx_k_CertificateError[] = "CertificateError";
static const char __pyx_k_FlowControlMixin[] = "_FlowControlMixin";
static const char __pyx_k_InterruptedError[] = "InterruptedError";
static const char __pyx_k_Loop_getaddrinfo[] = "Loop.getaddrinfo";
static const char __pyx_k_Loop_getnameinfo[] = "Loop.getnameinfo";
static const char __pyx_k_Loop_sock_accept[] = "Loop.sock_accept";
static const char __pyx_k_Polls_debug_info[] = "--- Polls debug info: ---";
static const char __pyx_k_Write_contexts_8[] = "Write contexts:            {: <8} | {}";
static const char __pyx_k_asyncio_sslproto[] = "asyncio.sslproto";
static const char __pyx_k_closed_reading_x[] = "<{} closed={} reading={} {:#x}>";
static const char __pyx_k_decref_socketios[] = "_decref_socketios";
static const char __pyx_k_get_extra_info_2[] = "_get_extra_info";
static const char __pyx_k_get_running_loop[] = "_get_running_loop";
static const char __pyx_k_on_ssl_connected[] = "__on_ssl_connected";
static const char __pyx_k_print_debug_info[] = "print_debug_info";
static const char __pyx_k_protocol_factory[] = "protocol_factory";
static const char __pyx_k_recv_into_method[] = "recv_into() method";
static const char __pyx_k_set_app_protocol[] = "_set_app_protocol";
static const char __pyx_k_set_running_loop[] = "_set_running_loop";
static const char __pyx_k_source_traceback[] = "source_traceback";
static const char __pyx_k_subprocess_shell[] = "subprocess_shell";
static const char __pyx_k_test_coroutine_1[] = "_test_coroutine_1";
static const char __pyx_k_FileNotFoundError[] = "FileNotFoundError";
static const char __pyx_k_InvalidStateError[] = "InvalidStateError";
static const char __pyx_k_IsADirectoryError[] = "IsADirectoryError";
static const char __pyx_k_Loop__sock_accept[] = "Loop._sock_accept";
static const char __pyx_k_Loop_sock_connect[] = "Loop.sock_connect";
static const char __pyx_k_Loop_sock_sendall[] = "Loop.sock_sendall";
static const char __pyx_k_Number_of_signals[] = "Number of signals:         {}";
static const char __pyx_k_SSL_ERROR_SYSCALL[] = "SSL_ERROR_SYSCALL";
static const char __pyx_k_Socket_try_writes[] = "Socket try-writes:         {}";
static const char __pyx_k_add_done_callback[] = "add_done_callback";
static const char __pyx_k_bufsize_must_be_0[] = "bufsize must be 0";
static const char __pyx_k_connect_ex_method[] = "connect_ex() method";
static const char __pyx_k_connect_read_pipe[] = "connect_read_pipe";
static const char __pyx_k_create_connection[] = "create_connection";
static const char __pyx_k_datagram_received[] = "datagram_received";
static const char __pyx_k_return_exceptions[] = "return_exceptions";
static const char __pyx_k_server_hostname_2[] = "_server_hostname";
static const char __pyx_k_start_new_session[] = "start_new_session";
static const char __pyx_k_write_buffer_size[] = "_write_buffer_size";
static const char __pyx_k_Callback_handles_8[] = "Callback handles:          {: <8} | {}";
static const char __pyx_k_Loop__sock_connect[] = "Loop._sock_connect";
static const char __pyx_k_Loop__sock_sendall[] = "Loop._sock_sendall";
static const char __pyx_k_Loop_create_server[] = "Loop.create_server";
static const char __pyx_k_PYTHONASYNCIODEBUG[] = "PYTHONASYNCIODEBUG";
static const char __pyx_k_ProcessLookupError[] = "ProcessLookupError";
static const char __pyx_k_SSLProtocol___init[] = "SSLProtocol.__init__";
static const char __pyx_k_SSLProtocol__abort[] = "SSLProtocol._abort";
static const char __pyx_k_Server_wait_closed[] = "Server.wait_closed";
static const char __pyx_k_Streams_debug_info[] = "--- Streams debug info: ---";
static const char __pyx_k_ThreadPoolExecutor[] = "ThreadPoolExecutor";
static const char __pyx_k_UnicodeEncodeError[] = "UnicodeEncodeError";
static const char __pyx_k_Write_without_poll[] = "Write without poll:        {}";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_asyncio_transports[] = "asyncio.transports";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_concurrent_futures[] = "concurrent.futures";
static const char __pyx_k_connect_write_pipe[] = "connect_write_pipe";
static const char __pyx_k_create_unix_server[] = "create_unix_server";
static const char __pyx_k_get_asyncgen_hooks[] = "get_asyncgen_hooks";
static const char __pyx_k_ignore_environment[] = "ignore_environment";
static const char __pyx_k_pipe_data_received[] = "pipe_data_received";
static const char __pyx_k_set_asyncgen_hooks[] = "set_asyncgen_hooks";
static const char __pyx_k_shell_must_be_True[] = "shell must be True";
static const char __pyx_k_shutdown_asyncgens[] = "shutdown_asyncgens";
static const char __pyx_k_sig_out_of_range_1[] = "sig {} out of range(1, {})";
static const char __pyx_k_string_is_expected[] = "string is expected";
static const char __pyx_k_universal_newlines[] = "universal_newlines";
static const char __pyx_k_unopened_TCPServer[] = "unopened TCPServer";
static const char __pyx_k_2_tuple_is_expected[] = "2-tuple is expected";
static const char __pyx_k_Connect_call_failed[] = "Connect call failed ";
static const char __pyx_k_Loop_sock_recv_into[] = "Loop.sock_recv_into";
static const char __pyx_k_Multiple_exceptions[] = "Multiple exceptions: {}";
static const char __pyx_k_NotImplementedError[] = "NotImplementedError";
static const char __pyx_k_SSL_ERROR_WANT_READ[] = "SSL_ERROR_WANT_READ";
static const char __pyx_k_WeakValueDictionary[] = "WeakValueDictionary";
static const char __pyx_k_asyncio_base_events[] = "asyncio.base_events";
static const char __pyx_k_default_int_handler[] = "default_int_handler";
static const char __pyx_k_iscoroutinefunction[] = "iscoroutinefunction";
static const char __pyx_k_log_destroy_pending[] = "_log_destroy_pending";
static const char __pyx_k_recvmsg_into_method[] = "recvmsg_into() method";
static const char __pyx_k_session_established[] = "_session_established";
static const char __pyx_k_shell_must_be_False[] = "shell must be False";
static const char __pyx_k_unclosed_resource_r[] = "unclosed resource {!r}; {}";
static const char __pyx_k_uvloop_sslproto_pyx[] = "uvloop/sslproto.pyx";
static const char __pyx_k_warn_on_full_buffer[] = "warn_on_full_buffer";
static const char __pyx_k_AbstractChildWatcher[] = "AbstractChildWatcher";
static const char __pyx_k_ConnectionResetError[] = "ConnectionResetError";
static const char __pyx_k_Event_loop_is_closed[] = "Event loop is closed";
static const char __pyx_k_Loop__read_from_self[] = "Loop._read_from_self";
static const char __pyx_k_Loop__sock_recv_into[] = "Loop._sock_recv_into";
static const char __pyx_k_Loop_subprocess_exec[] = "Loop.subprocess_exec";
static const char __pyx_k_PROTOCOL_IS_SHUTDOWN[] = "PROTOCOL_IS_SHUTDOWN";
static const char __pyx_k_SSLProtocolTransport[] = "_SSLProtocolTransport";
static const char __pyx_k_SSL_ERROR_WANT_WRITE[] = "SSL_ERROR_WANT_WRITE";
static const char __pyx_k_SSL_handshake_failed[] = "SSL handshake failed";
static const char __pyx_k_call_connection_made[] = "call_connection_made";
static const char __pyx_k_call_soon_threadsafe[] = "call_soon_threadsafe";
static const char __pyx_k_handshake_start_time[] = "_handshake_start_time";
static const char __pyx_k_pipe_connection_lost[] = "pipe_connection_lost";
static const char __pyx_k_protocol_is_required[] = "protocol is required";
static const char __pyx_k_recvfrom_into_method[] = "recvfrom_into() method";
static const char __pyx_k_remove_done_callback[] = "remove_done_callback";
static const char __pyx_k_running_closed_debug[] = "<{}.{} running={} closed={} debug={}>";
static const char __pyx_k_sendmsg_afalg_method[] = "sendmsg_afalg() method";
static const char __pyx_k_shutdown_in_progress[] = "shutdown in progress";
static const char __pyx_k_sig_cannot_be_caught[] = "sig {} cannot be caught";
static const char __pyx_k_unclosed_transport_r[] = "unclosed transport {!r}";
static const char __pyx_k_AddrInfo_data_is_NULL[] = "AddrInfo.data is NULL";
static const char __pyx_k_Exception_in_callback[] = "Exception in callback {}";
static const char __pyx_k_Fatal_error_on_server[] = "Fatal error on server {}";
static const char __pyx_k_Invalid_file_object_r[] = "Invalid file object: {!r}";
static const char __pyx_k_Loop___subprocess_run[] = "Loop.__subprocess_run";
static const char __pyx_k_Loop_subprocess_shell[] = "Loop.subprocess_shell";
static const char __pyx_k_Read_callbacks_failed[] = "Read callbacks failed:     {}";
static const char __pyx_k_Read_failed_callbacks[] = "Read failed callbacks:     {}";
static const char __pyx_k_SSLProtocol__finalize[] = "SSLProtocol._finalize";
static const char __pyx_k_get_coroutine_wrapper[] = "get_coroutine_wrapper";
static const char __pyx_k_get_write_buffer_size[] = "get_write_buffer_size";
static const char __pyx_k_on_handshake_complete[] = "_on_handshake_complete";
static const char __pyx_k_process_write_backlog[] = "_process_write_backlog";
static const char __pyx_k_pyx_unpickle__SSLPipe[] = "__pyx_unpickle__SSLPipe";
static const char __pyx_k_remove_signal_handler[] = "remove_signal_handler";
static const char __pyx_k_set_coroutine_wrapper[] = "set_coroutine_wrapper";
static const char __pyx_k_ssl_handshake_timeout[] = "ssl_handshake_timeout";
static const char __pyx_k_unclosed_resource_r_2[] = "unclosed resource {!r}";
static const char __pyx_k_ConnectionAbortedError[] = "ConnectionAbortedError";
static const char __pyx_k_ConnectionRefusedError[] = "ConnectionRefusedError";
static const char __pyx_k_Loop_connect_read_pipe[] = "Loop.connect_read_pipe";
static const char __pyx_k_Loop_create_connection[] = "Loop.create_connection";
static const char __pyx_k_SyncSocketReaderFuture[] = "_SyncSocketReaderFuture";
static const char __pyx_k_SyncSocketWriterFuture[] = "_SyncSocketWriterFuture";
static const char __pyx_k_Write_callbacks_failed[] = "Write callbacks failed:    {}";
static const char __pyx_k_Write_failed_callbacks[] = "Write failed callbacks:    {}";
static const char __pyx_k_app_protocol_is_buffer[] = "_app_protocol_is_buffer";
static const char __pyx_k_call_connection_made_2[] = "_call_connection_made";
static const char __pyx_k_call_exception_handler[] = "call_exception_handler";
static const char __pyx_k_cancel_request_is_NULL[] = "{}.cancel: .request is NULL";
static const char __pyx_k_concurrent_allocations[] = "concurrent allocations";
static const char __pyx_k_create_default_context[] = "create_default_context";
static const char __pyx_k_create_unix_connection[] = "create_unix_connection";
static const char __pyx_k_invalid_Handle_cb_type[] = "invalid Handle.cb_type: {}";
static const char __pyx_k_r_starts_SSL_handshake[] = "%r starts SSL handshake";
static const char __pyx_k_Invalid_file_descriptor[] = "Invalid file descriptor: {}";
static const char __pyx_k_Loop_connect_write_pipe[] = "Loop.connect_write_pipe";
static const char __pyx_k_Loop_create_unix_server[] = "Loop.create_unix_server";
static const char __pyx_k_Loop_shutdown_asyncgens[] = "Loop.shutdown_asyncgens";
static const char __pyx_k_ReadSubprocessPipeProto[] = "ReadSubprocessPipeProto";
static const char __pyx_k_asyncgen_finalizer_hook[] = "_asyncgen_finalizer_hook";
static const char __pyx_k_asyncgen_firstiter_hook[] = "_asyncgen_firstiter_hook";
static const char __pyx_k_check_handshake_timeout[] = "_check_handshake_timeout";
static const char __pyx_k_connect_accepted_socket[] = "connect_accepted_socket";
static const char __pyx_k_service_proto_not_found[] = "service/proto not found";
static const char __pyx_k_set_write_buffer_limits[] = "set_write_buffer_limits";
static const char __pyx_k_ssl_handshake_timeout_2[] = "_ssl_handshake_timeout";
static const char __pyx_k_uvloop_sleep_after_fork[] = "__uvloop_sleep_after_fork";
static const char __pyx_k_AF_UNSPEC_in_DNS_results[] = "AF_UNSPEC in DNS results";
static const char __pyx_k_Fatal_error_on_transport[] = "Fatal error on transport {}";
static const char __pyx_k_SSLProtocol__fatal_error[] = "SSLProtocol._fatal_error";
static const char __pyx_k_SSLProtocol__mark_closed[] = "SSLProtocol._mark_closed";
static const char __pyx_k_SSLProtocol_eof_received[] = "SSLProtocol.eof_received";
static const char __pyx_k_WriteSubprocessPipeProto[] = "WriteSubprocessPipeProto";
static const char __pyx_k_context_manager_protocol[] = "context manager protocol";
static const char __pyx_k_create_datagram_endpoint[] = "create_datagram_endpoint";
static const char __pyx_k_exception_in_Task___repr[] = "exception in Task.__repr__";
static const char __pyx_k_handshake_timeout_handle[] = "_handshake_timeout_handle";
static const char __pyx_k_loop__exec_queued_writes[] = "loop._exec_queued_writes";
static const char __pyx_k_set_wakeup_fd_1_failed_s[] = "set_wakeup_fd(-1) failed: %s";
static const char __pyx_k_sig_must_be_an_int_not_r[] = "sig must be an int, not {!r}";
static const char __pyx_k_Read_EOF_failed_callbacks[] = "Read EOF failed callbacks: {}";
static const char __pyx_k_SSLProtocol_data_received[] = "SSLProtocol.data_received";
static const char __pyx_k_SSLProtocol_pause_writing[] = "SSLProtocol.pause_writing";
static const char __pyx_k_abort_init__closed_is_set[] = "_abort_init: {}._closed is set";
static const char __pyx_k_abort_init__inited_is_set[] = "_abort_init: {}._inited is set";
static const char __pyx_k_default_exception_handler[] = "default_exception_handler";
static const char __pyx_k_no_security_layer_present[] = "no security layer present";
static const char __pyx_k_pyx_unpickle_PseudoSocket[] = "__pyx_unpickle_PseudoSocket";
static const char __pyx_k_unexpected_address_family[] = "unexpected address family";
static const char __pyx_k_Fatal_error_on_transport_2[] = "Fatal error on transport";
static const char __pyx_k_Loop___get___locals_lambda[] = "Loop.__get__.<locals>.<lambda>";
static const char __pyx_k_SSLProtocolTransport___del[] = "_SSLProtocolTransport.__del__";
static const char __pyx_k_SSLProtocolTransport_abort[] = "_SSLProtocolTransport.abort";
static const char __pyx_k_SSLProtocolTransport_close[] = "_SSLProtocolTransport.close";
static const char __pyx_k_SSLProtocolTransport_write[] = "_SSLProtocolTransport.write";
static const char __pyx_k_SSLProtocol__wakeup_waiter[] = "SSLProtocol._wakeup_waiter";
static const char __pyx_k_SSLProtocol__write_appdata[] = "SSLProtocol._write_appdata";
static const char __pyx_k_SSLProtocol_resume_writing[] = "SSLProtocol.resume_writing";
static const char __pyx_k_close__handle_data_is_NULL[] = "{}._close: _handle.data is NULL";
static const char __pyx_k_is_alive_but__loop_is_None[] = "{} is alive, but _loop is None";
static const char __pyx_k_r_SSL_handshake_took_1f_ms[] = "%r: SSL handshake took %.1f ms";
static const char __pyx_k_uvloop_handles_process_pyx[] = "uvloop/handles/process.pyx";
static const char __pyx_k_Address_r_is_already_in_use[] = "Address {!r} is already in use";
static const char __pyx_k_Executing_r_took_3f_seconds[] = "Executing %r took %.3f seconds";
static const char __pyx_k_Executing_s_took_3f_seconds[] = "Executing %s took %.3f seconds";
static const char __pyx_k_Loop_create_unix_connection[] = "Loop.create_unix_connection";
static const char __pyx_k_SSLProtocolTransport___init[] = "_SSLProtocolTransport.__init__";
static const char __pyx_k_SSLProtocol__get_extra_info[] = "SSLProtocol._get_extra_info";
static const char __pyx_k_SSLProtocol__start_shutdown[] = "SSLProtocol._start_shutdown";
static const char __pyx_k_SSLProtocol_connection_lost[] = "SSLProtocol.connection_lost";
static const char __pyx_k_SSLProtocol_connection_made[] = "SSLProtocol.connection_made";
static const char __pyx_k_UDPTransport__on_read_ready[] = "UDPTransport._on_read_ready";
static const char __pyx_k_cancel_request_data_is_NULL[] = "{}.cancel: .request.data is NULL";
static const char __pyx_k_close_uv_is_closing_is_true[] = "{}._close: uv_is_closing() is true";
static const char __pyx_k_host_must_be_a_str_or_bytes[] = "host must be a str or bytes";
static const char __pyx_k_invalid__init_protocol_call[] = "invalid _init_protocol call";
static const char __pyx_k_not_holding_the_import_lock[] = "not holding the import lock";
static const char __pyx_k_Fatal_error_on_SSL_transport[] = "Fatal error on SSL transport";
static const char __pyx_k_Loop_connect_accepted_socket[] = "Loop.connect_accepted_socket";
static const char __pyx_k_SSLProtocol__start_handshake[] = "SSLProtocol._start_handshake";
static const char __pyx_k_SyncSocketReaderFuture__loop[] = "_SyncSocketReaderFuture__loop";
static const char __pyx_k_SyncSocketReaderFuture__sock[] = "_SyncSocketReaderFuture__sock";
static const char __pyx_k_SyncSocketWriterFuture__loop[] = "_SyncSocketWriterFuture__loop";
static const char __pyx_k_SyncSocketWriterFuture__sock[] = "_SyncSocketWriterFuture__sock";
static const char __pyx_k_UDPTransport__on_write_ready[] = "UDPTransport._on_write_ready";
static const char __pyx_k_UVHandles_python_libuv_total[] = "UVHandles               python | libuv   | total";
static const char __pyx_k_called_with_handle_data_NULL[] = "{} called with handle.data == NULL";
static const char __pyx_k_is_alive_but__handle_is_NULL[] = "{} is alive, but _handle is NULL";
static const char __pyx_k_socket_send_raised_exception[] = "socket.send() raised exception.";
static const char __pyx_k_startupinfo_is_not_supported[] = "startupinfo is not supported";
static const char __pyx_k_AF_INET_address_must_be_tuple[] = "AF_INET address must be tuple";
static const char __pyx_k_Handle_loop_is_None_in_Handle[] = "Handle.loop is None in Handle.__dealloc__";
static const char __pyx_k_IPv4_sockaddr_must_be_2_tuple[] = "IPv4 sockaddr must be 2 tuple";
static const char __pyx_k_Loop_create_datagram_endpoint[] = "Loop.create_datagram_endpoint";
static const char __pyx_k_SSLProtocol__set_app_protocol[] = "SSLProtocol._set_app_protocol";
static const char __pyx_k_SyncSocketReaderFuture___init[] = "_SyncSocketReaderFuture.__init__";
static const char __pyx_k_SyncSocketReaderFuture_cancel[] = "_SyncSocketReaderFuture.cancel";
static const char __pyx_k_SyncSocketWriterFuture___init[] = "_SyncSocketWriterFuture.__init__";
static const char __pyx_k_SyncSocketWriterFuture_cancel[] = "_SyncSocketWriterFuture.cancel";
static const char __pyx_k_all_args_must_be_str_or_bytes[] = "all args must be str or bytes";
static const char __pyx_k_dealloc____handle_is_NULL__cl[] = "{}.__dealloc__: _handle is NULL, _closed == 1";
static const char __pyx_k_does_not_have_a_reader_in_the[] = " does not have a reader in the _sock_recv callback";
static const char __pyx_k_does_not_have_a_writer_in_the[] = " does not have a writer in the _sock_sendall callback";
static const char __pyx_k_integer_argument_expected_got[] = "integer argument expected, got {}";
static const char __pyx_k_is_not_supported_by_start_tls[] = " is not supported by start_tls()";
static const char __pyx_k_protocol_pause_writing_failed[] = "protocol.pause_writing() failed";
static const char __pyx_k_r_fileno_returned_non_integer[] = "{!r}.fileno() returned non-integer";
static const char __pyx_k_start_init_can_only_be_called[] = "{}._start_init can only be called once";
static const char __pyx_k_AF_INET6_address_must_be_tuple[] = "AF_INET6 address must be tuple";
static const char __pyx_k_Cannot_serialize_socket_object[] = "Cannot serialize socket object";
static const char __pyx_k_Pyx_CFunc_object____Loop____bi[] = "__Pyx_CFunc_object____Loop____bint___to_py.<locals>.wrap";
static const char __pyx_k_SSLProtocolTransport__protocol[] = "_SSLProtocolTransport._protocol_paused";
static const char __pyx_k_SSLProtocolTransport_can_write[] = "_SSLProtocolTransport.can_write_eof";
static const char __pyx_k_SSLProtocolTransport_get_extra[] = "_SSLProtocolTransport.get_extra_info";
static const char __pyx_k_SSLProtocolTransport_get_write[] = "_SSLProtocolTransport.get_write_buffer_size";
static const char __pyx_k_SSLProtocolTransport_set_write[] = "_SSLProtocolTransport.set_write_buffer_limits";
static const char __pyx_k_Sock_ops_successful_on_1st_try[] = "--- Sock ops successful on 1st try: ---";
static const char __pyx_k_cannot_apply_subprocess_STDOUT[] = "cannot apply subprocess.STDOUT";
static const char __pyx_k_close__handle_data_is_not_UVHa[] = "{}._close: _handle.data is not UVHandle/self";
static const char __pyx_k_creationflags_is_not_supported[] = "creationflags is not supported";
static const char __pyx_k_fatal_sent_0_in_advance_uv_buf[] = "fatal: sent < 0 in advance_uv_buf";
static const char __pyx_k_protocol_resume_writing_failed[] = "protocol.resume_writing() failed";
static const char __pyx_k_uv_close_handle_cb_handle_loop[] = "__uv_close_handle_cb: handle.loop is invalid";
static const char __pyx_k_AF_INET6_must_be_a_tuple_of_2_4[] = "AF_INET6 must be a tuple of 2-4 parameters: (host, port, flowinfo?, scope_id?)";
static const char __pyx_k_A_UDP_Socket_was_expected_got_r[] = "A UDP Socket was expected, got {!r}";
static const char __pyx_k_A_UNIX_Domain_Stream_Socket_was[] = "A UNIX Domain Stream Socket was expected, got {!r}";
static const char __pyx_k_AddrInfoRequest_callback_called[] = "AddrInfoRequest callback called with NULL resolver.data";
static const char __pyx_k_Bad_exception_data_from_child_r[] = "Bad exception data from child: {!r}";
static const char __pyx_k_Cannot_run_the_event_loop_while[] = "Cannot run the event loop while another loop is running";
static const char __pyx_k_Invalid_address_must_be_None_or[] = "Invalid address: must be None or {}";
static const char __pyx_k_Neither_host_port_nor_sock_were[] = "Neither host/port nor sock were specified";
static const char __pyx_k_SSLProtocolTransport_get_protoc[] = "_SSLProtocolTransport.get_protocol";
static const char __pyx_k_SSLProtocolTransport_is_closing[] = "_SSLProtocolTransport.is_closing";
static const char __pyx_k_SSLProtocolTransport_is_reading[] = "_SSLProtocolTransport.is_reading";
static const char __pyx_k_SSLProtocolTransport_pause_read[] = "_SSLProtocolTransport.pause_reading";
static const char __pyx_k_SSLProtocolTransport_resume_rea[] = "_SSLProtocolTransport.resume_reading";
static const char __pyx_k_SSLProtocolTransport_set_protoc[] = "_SSLProtocolTransport.set_protocol";
static const char __pyx_k_StreamWriteContext_close_py_buf[] = "_StreamWriteContext.close: py_bufs != NULL and py_bufs_sml_inuse is True";
static const char __pyx_k_StreamWriteContext_close_uv_buf[] = "_StreamWriteContext.close: uv_bufs != NULL and py_bufs_sml_inuse is True";
static const char __pyx_k_UDP_sendto_address_r_requires_a[] = "UDP.sendto(): address {!r} requires a DNS lookup";
static const char __pyx_k_UVStream__try_write_called_with[] = "UVStream._try_write called with data in uv buffers";
static const char __pyx_k_Unable_to_check_or_remove_stale[] = "Unable to check or remove stale UNIX socket %r: %r";
static const char __pyx_k_WriteSubprocessPipeProto___init[] = "WriteSubprocessPipeProto.__init__";
static const char __pyx_k_WriteSubprocessPipeProto___repr[] = "WriteSubprocessPipeProto.__repr__";
static const char __pyx_k_WriteSubprocessPipeProto_resume[] = "WriteSubprocessPipeProto.resume_writing";
static const char __pyx_k_asyncio_is_trying_to_install_it[] = "!!! asyncio is trying to install its ChildWatcher for SIGCHLD signal !!!\n\nThis is probably because a uvloop instance is used with asyncio.set_event_loop(). The correct way to use uvloop is to install its policy: `asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())`\n\n";
static const char __pyx_k_buffer_size_is_not_0_after_a_su[] = "_buffer_size is not 0 after a successful _exec_write";
static const char __pyx_k_called_after_destroying_the_UVH[] = "{} called after destroying the UVHandle";
static const char __pyx_k_can_not_get_address_information[] = "can not get address information";
static const char __pyx_k_cancel_request_data_is_not_UVRe[] = "{}.cancel: .request.data is not UVRequest";
static const char __pyx_k_cannot_add_a_signal_handler_for[] = "cannot add a signal handler for SIGCHLD: it is used by the event loop to track subprocesses";
static const char __pyx_k_cannot_spawn_a_process_args_are[] = "cannot spawn a process: args are empty";
static const char __pyx_k_context_argument_requires_Pytho[] = "\"context\" argument requires Python 3.7";
static const char __pyx_k_create_datagram_endpoint_locals[] = "create_datagram_endpoint.<locals>.genexpr";
static const char __pyx_k_deallocating_an_open_event_loop[] = "deallocating an open event loop";
static const char __pyx_k_does_not_have_a_reader_in_the_2[] = " does not have a reader in the _sock_recv_into callback";
static const char __pyx_k_getaddrinfo_returned_empty_list[] = "getaddrinfo() returned empty list";
static const char __pyx_k_getsockaddrarg_flowinfo_must_be[] = "getsockaddrarg: flowinfo must be 0-1048575.";
static const char __pyx_k_getsockaddrarg_scope_id_must_be[] = "getsockaddrarg: scope_id must be unsigned 32 bit integer";
static const char __pyx_k_handle_loop_is_NULL_in___ensure[] = "handle.loop is NULL in __ensure_handle_data";
static const char __pyx_k_host_and_port_was_not_specified[] = "host and port was not specified and no sock specified";
static const char __pyx_k_is_alive_but__handle_data_is_no[] = "{} is alive, but _handle.data is not initialized";
static const char __pyx_k_is_alive_but__handle_loop_is_no[] = "{} is alive, but _handle.loop is not initialized";
static const char __pyx_k_is_not_supposed_to_be_instantia[] = "{} is not supposed to be instantiated from Python";
static const char __pyx_k_is_open_in___dealloc___with_loo[] = "{} is open in __dealloc__ with loop set to NULL";
static const char __pyx_k_no_path_and_sock_were_specified[] = "no path and sock were specified";
static const char __pyx_k_port_must_be_a_str_bytes_or_int[] = "port must be a str, bytes or int";
static const char __pyx_k_protocol_is_not_set_cannot_call[] = "protocol is not set, cannot call connection_made()";
static const char __pyx_k_seconds_aborting_the_connection[] = " seconds: aborting the connection";
static const char __pyx_k_sock_recv_into_is_called_on_a_c[] = "_sock_recv_into is called on a cancelled Future";
static const char __pyx_k_sock_recv_is_called_on_a_cancel[] = "_sock_recv is called on a cancelled Future";
static const char __pyx_k_sock_sendall_is_called_on_a_can[] = "_sock_sendall is called on a cancelled Future";
static const char __pyx_k_sockaddr_must_be_a_tuple_of_2_3[] = "sockaddr must be a tuple of 2, 3 or 4 values";
static const char __pyx_k_ssl_handshake_timeout_should_be[] = "ssl_handshake_timeout should be a positive number, got ";
static const char __pyx_k_sslcontext_is_expected_to_be_an[] = "sslcontext is expected to be an instance of ssl.SSLContext, got ";
static const char __pyx_k_task_factory_must_be_a_callable[] = "task factory must be a callable or None";
static const char __pyx_k_the_socket_must_be_non_blocking[] = "the socket must be non-blocking";
static const char __pyx_k_try_write_sent_all_data_and_ret[] = "_try_write sent all data and returned non-zero";
static const char __pyx_k_unable_to_start_the_loop_it_was[] = "unable to start the loop; it was closed";
static const char __pyx_k_uv_handle_t_current_freed_total[] = "uv_handle_t (current: {}; freed: {}; total: {})";
static const char __pyx_k_uvloop_PseudoSocket_fd_family_s[] = "<uvloop.PseudoSocket fd={}, family={!s}, type={!s}, proto={}";
static const char __pyx_k_without_no_gc_clear_loop_was_se[] = "{} without @no_gc_clear; loop was set to None by GC";
static const char __pyx_k_AF_INET_address_must_be_tuple_of[] = "AF_INET address must be tuple of (host, port)";
static const char __pyx_k_A_Stream_Socket_was_expected_got[] = "A Stream Socket was expected, got {!r}";
static const char __pyx_k_A_callable_object_or_None_is_exp[] = "A callable object or None is expected, got {!r}";
static const char __pyx_k_Cannot_call_write_after_write_eo[] = "Cannot call write() after write_eof()";
static const char __pyx_k_Cannot_call_writelines_after_wri[] = "Cannot call writelines() after write_eof()";
static const char __pyx_k_Cannot_close_a_running_event_loo[] = "Cannot close a running event loop";
static const char __pyx_k_Event_loop_stopped_before_Future[] = "Event loop stopped before Future completed.";
static const char __pyx_k_Exception_in___repr___r_value_ty[] = "Exception in __repr__ {!r}; value type: {!r}";
static const char __pyx_k_Exception_in_default_exception_h[] = "Exception in default exception handler";
static const char __pyx_k_Exception_occurred_in_preexec_fn[] = "Exception occurred in preexec_fn.";
static const char __pyx_k_Fatal_read_error_on_datagram_tra[] = "Fatal read error on datagram transport";
static const char __pyx_k_Fatal_write_error_on_datagram_tr[] = "Fatal write error on datagram transport";
static const char __pyx_k_File_descriptor_r_is_used_by_tra[] = "File descriptor {!r} is used by transport {!r}";
static const char __pyx_k_Incompatible_checksums_s_vs_0x38[] = "Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))";
static const char __pyx_k_Incompatible_checksums_s_vs_0x88[] = "Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))";
static const char __pyx_k_Loop__getaddrinfo_locals_callbac[] = "Loop._getaddrinfo.<locals>.callback";
static const char __pyx_k_Loop__getnameinfo_locals_callbac[] = "Loop._getnameinfo.<locals>.callback";
static const char __pyx_k_Loop__sock_connect_locals_lambda[] = "Loop._sock_connect.<locals>.<lambda>";
static const char __pyx_k_Non_thread_safe_operation_invoke[] = "Non-thread-safe operation invoked on an event loop other than the current one";
static const char __pyx_k_Object_created_at_most_recent_ca[] = "Object created at (most recent call last):\n";
static const char __pyx_k_Racing_with_another_loop_to_spaw[] = "Racing with another loop to spawn a process.";
static const char __pyx_k_ReadSubprocessPipeProto_data_rec[] = "ReadSubprocessPipeProto.data_received";
static const char __pyx_k_SSLProtocol__check_handshake_tim[] = "SSLProtocol._check_handshake_timeout";
static const char __pyx_k_SSLProtocol__on_handshake_comple[] = "SSLProtocol._on_handshake_complete";
static const char __pyx_k_SSLProtocol__process_write_backl[] = "SSLProtocol._process_write_backlog";
static const char __pyx_k_SSL_handshake_failed_on_verifyin[] = "SSL handshake failed on verifying the certificate";
static const char __pyx_k_SSL_handshake_is_taking_longer_t[] = "SSL handshake is taking longer than ";
static const char __pyx_k_SSL_protocol_Implementation_of_S[] = "SSL protocol.\n\n    Implementation of SSL on top of a socket using incoming and outgoing\n    buffers which are ssl.MemoryBIO objects.\n    ";
static const char __pyx_k_SSL_transport_has_not_been_initi[] = "SSL transport has not been initialized yet";
static const char __pyx_k_Server_side_SSL_needs_a_valid_SS[] = "Server side SSL needs a valid SSLContext";
static const char __pyx_k_UDP_sendto_r_socket_family_misma[] = "UDP.sendto(): {!r} socket family mismatch";
static const char __pyx_k_UVProcessTransport__call_connect[] = "UVProcessTransport._call_connection_made";
static const char __pyx_k_UVProcess__close_after_spawn_cal[] = "UVProcess._close_after_spawn called after uv_spawn";
static const char __pyx_k_UVStream_shutdown_callback_calle[] = "UVStream.shutdown callback called with NULL req.data, status=%r";
static const char __pyx_k_UVStream_write_callback_called_w[] = "UVStream.write callback called with NULL req.data, status=%r";
static const char __pyx_k_UVTransport__call_connection_los[] = "UVTransport._call_connection_lost";
static const char __pyx_k_UVTransport__call_connection_mad[] = "UVTransport._call_connection_made";
static const char __pyx_k_Unhandled_error_in_exception_han[] = "Unhandled error in exception handler";
static const char __pyx_k_Unhandled_exception_in_event_loo[] = "Unhandled exception in event loop";
static const char __pyx_k_WriteSubprocessPipeProto_connect[] = "WriteSubprocessPipeProto.connection_made";
static const char __pyx_k_WriteSubprocessPipeProto_pause_w[] = "WriteSubprocessPipeProto.pause_writing";
static const char __pyx_k_XXX_an_allocated_buffer_in_trans[] = "XXX: an allocated buffer in transport._close()";
static const char __pyx_k_You_must_set_server_hostname_whe[] = "You must set server_hostname when using ssl without a host";
static const char __pyx_k_active_TimerHandle_is_deallacati[] = "active TimerHandle is deallacating";
static const char __pyx_k_all_environment_values_must_be_b[] = "all environment values must be bytes or str";
static const char __pyx_k_all_environment_vars_must_be_byt[] = "all environment vars must be bytes or str";
static const char __pyx_k_an_error_occurred_during_closing[] = "an error occurred during closing of asynchronous generator {!r}";
static const char __pyx_k_application_protocol_failed_to_r[] = "application protocol failed to receive SSL data";
static const char __pyx_k_asynchronous_generator_r_was_sch[] = "asynchronous generator {!r} was scheduled after loop.shutdown_asyncgens() call";
static const char __pyx_k_cannot_convert_sockaddr_into_Pyt[] = "cannot convert sockaddr into Python object";
static const char __pyx_k_closed_Transport_handle_and_unse[] = "closed Transport handle and unset waiter";
static const char __pyx_k_coroutines_cannot_be_used_with_a[] = "coroutines cannot be used with add_signal_handler()";
static const char __pyx_k_coroutines_cannot_be_used_with_r[] = "coroutines cannot be used with run_in_executor()";
static const char __pyx_k_could_not_close_attached_file_ob[] = "could not close attached file object {!r}";
static const char __pyx_k_create_connection_locals_genexpr[] = "create_connection.<locals>.genexpr";
static const char __pyx_k_cwd_must_be_a_str_or_bytes_objec[] = "cwd must be a str or bytes object";
static const char __pyx_k_data_argument_must_be_a_bytes_li[] = "data argument must be a bytes-like object, not {!r}";
static const char __pyx_k_data_expecting_a_bytes_like_inst[] = "data: expecting a bytes-like instance, got ";
static const char __pyx_k_deallocating_a_running_event_loo[] = "deallocating a running event loop!";
static const char __pyx_k_epected_AF_INET_or_AF_INET6_fami[] = "epected AF_INET or AF_INET6 family, got {}";
static const char __pyx_k_error_status_in_uv_stream_t_list[] = "error status in uv_stream_t.listen callback";
static const char __pyx_k_error_status_in_uv_stream_t_read[] = "error status in uv_stream_t.read callback";
static const char __pyx_k_error_status_in_uv_stream_t_shut[] = "error status in uv_stream_t.shutdown callback";
static const char __pyx_k_error_status_in_uv_stream_t_writ[] = "error status in uv_stream_t.write callback";
static const char __pyx_k_error_while_attempting_to_bind_o[] = "error while attempting to bind on address ";
static const char __pyx_k_fatal_Could_not_advance__StreamW[] = "fatal: Could not advance _StreamWriteContext";
static const char __pyx_k_get_buffer_returned_an_empty_buf[] = "get_buffer() returned an empty buffer";
static const char __pyx_k_get_coroutine_origin_tracking_de[] = "get_coroutine_origin_tracking_depth";
static const char __pyx_k_getnameinfo_argument_1_must_be_a[] = "getnameinfo() argument 1 must be a tuple";
static const char __pyx_k_getnameinfo_flowinfo_must_be_0_1[] = "getnameinfo(): flowinfo must be 0-1048575.";
static const char __pyx_k_handle_data_is_NULL_in___close_a[] = "handle.data is NULL in __close_all_handles_cb";
static const char __pyx_k_handle_loop_data_is_NULL_in___en[] = "handle.loop.data is NULL in __ensure_handle_data";
static const char __pyx_k_handshake_in_progress_or_complet[] = "handshake in progress or completed";
static const char __pyx_k_has_handle_0_in___uv_close_handl[] = "has_handle=0 in __uv_close_handle_cb";
static const char __pyx_k_host_must_be_a_string_or_bytes_o[] = "host must be a string or bytes object";
static const char __pyx_k_host_port_and_sock_can_not_be_sp[] = "host/port and sock can not be specified at the same time";
static const char __pyx_k_invalid_data_in_writebuf_an_inst[] = "invalid data in writebuf: an instance of bytes, bytearray or memoryview was expected, got {}";
static const char __pyx_k_invalid_socket_family_expected_A[] = "invalid socket family, expected AF_UNIX, AF_INET or AF_INET6";
static const char __pyx_k_invalid_waiter_object_r_expected[] = "invalid waiter object {!r}, expected asyncio.Future";
static const char __pyx_k_local_addr_must_be_a_tuple_of_ho[] = "local_addr must be a tuple of host and port";
static const char __pyx_k_loop__queued_streams_are_not_emp[] = "loop._queued_streams are not empty after _exec_queued_writes";
static const char __pyx_k_loop_set_debug_False_cannot_unse[] = "loop.set_debug(False): cannot unset debug coroutine wrapper; another wrapper was set %r";
static const char __pyx_k_loop_set_debug_True_cannot_set_d[] = "loop.set_debug(True): cannot set debug coroutine wrapper; another wrapper is already set %r";
static const char __pyx_k_new_callbacks_were_queued_during[] = "new callbacks were queued during loop closing: {}";
static const char __pyx_k_new_poll_handles_were_queued_dur[] = "new poll handles were queued during loop closing: {}";
static const char __pyx_k_new_timers_were_queued_during_lo[] = "new timers were queued during loop closing: {}";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_no_python_buffer_is_allocated_in[] = "no python buffer is allocated in on_read; nread=";
static const char __pyx_k_object_created_at_most_recent_ca[] = "object created at (most recent call last):\n{}";
static const char __pyx_k_open__StreamWriteContext_is_bein[] = "open _StreamWriteContext is being deallocated";
static const char __pyx_k_path_and_sock_can_not_be_specifi[] = "path and sock can not be specified at the same time";
static const char __pyx_k_path_was_not_specified_and_no_so[] = "path was not specified, and no sock specified";
static const char __pyx_k_returning_true_from_eof_received[] = "returning true from eof_received() has no effect when using ssl";
static const char __pyx_k_reuse_port_not_supported_by_sock[] = "reuse_port not supported by socket module";
static const char __pyx_k_run_until_complete_locals_lambda[] = "run_until_complete.<locals>.<lambda>";
static const char __pyx_k_self_py_bufs_self_py_bufs_sml_se[] = "self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling";
static const char __pyx_k_server_hostname_is_only_meaningf[] = "server_hostname is only meaningful with ssl";
static const char __pyx_k_set_coroutine_origin_tracking_de[] = "set_coroutine_origin_tracking_depth";
static const char __pyx_k_set_wakeup_fd_only_works_in_main[] = "set_wakeup_fd only works in main thread";
static const char __pyx_k_setblocking_transport_sockets_ca[] = "setblocking(): transport sockets cannot be blocking";
static const char __pyx_k_settimeout_only_0_timeout_is_all[] = "settimeout(): only 0 timeout is allowed on transport sockets";
static const char __pyx_k_sockaddr_resolved_to_multiple_ad[] = "sockaddr resolved to multiple addresses";
static const char __pyx_k_socket_modifier_keyword_argument[] = "socket modifier keyword arguments can not be used when sock is specified. ({})";
static const char __pyx_k_ssl_argument_must_be_an_SSLConte[] = "ssl argument must be an SSLContext or None";
static const char __pyx_k_ssl_handshake_timeout_is_only_me[] = "ssl_handshake_timeout is only meaningful with ssl";
static const char __pyx_k_ssl_is_expected_to_be_None_or_an[] = "ssl is expected to be None or an instance of ssl.SSLContext, got {!r}";
static const char __pyx_k_stream_is_open_after_UVStream__t[] = "stream is open after UVStream._try_write returned None";
static const char __pyx_k_subprocess_STDOUT_is_supported_o[] = "subprocess.STDOUT is supported only by stderr parameter";
static const char __pyx_k_this_event_loop_is_already_runni[] = "this event loop is already running.";
static const char __pyx_k_transport_sockets_do_not_support[] = "transport sockets do not support {}";
static const char __pyx_k_unable_to_listen_no_protocol_fac[] = "unable to listen(); no protocol_factory";
static const char __pyx_k_unable_to_perform_operation_on_r[] = "unable to perform operation on {!r}; the handler is closed";
static const char __pyx_k_unclosed_resource_r_could_not_se[] = "unclosed resource {!r}; could not serialize debug traceback: {}: {}";
static const char __pyx_k_unhandled_error_or_an_empty_buff[] = "unhandled error (or an empty buffer) in get_buffer()";
static const char __pyx_k_universal_newlines_must_be_False[] = "universal_newlines must be False";
static const char __pyx_k_waiter_is_not_None_in__call_conn[] = "waiter is not None in {}._call_connection_lost";
static const char __pyx_k_getaddrinfo_returned_empty_list_2[] = "getaddrinfo() returned empty list for local_addr";
static const char __pyx_k_Exception_in_default_exception_h_2[] = "Exception in default exception handler while handling an unexpected error in custom exception handler";
static const char __pyx_k_WriteSubprocessPipeProto_connect_2[] = "WriteSubprocessPipeProto.connection_lost";
static PyObject *__pyx_kp_u_18_7_7_7;
static PyObject *__pyx_kp_u_2_tuple_is_expected;
static PyObject *__pyx_kp_u_AF_INET6_address_must_be_tuple;
static PyObject *__pyx_kp_u_AF_INET6_must_be_a_tuple_of_2_4;
static PyObject *__pyx_kp_u_AF_INET_address_must_be_tuple;
static PyObject *__pyx_kp_u_AF_INET_address_must_be_tuple_of;
static PyObject *__pyx_kp_u_AF_UNSPEC_in_DNS_results;
static PyObject *__pyx_kp_u_A_Stream_Socket_was_expected_got;
static PyObject *__pyx_kp_u_A_UDP_Socket_was_expected_got_r;
static PyObject *__pyx_kp_u_A_UNIX_Domain_Stream_Socket_was;
static PyObject *__pyx_kp_u_A_callable_object_or_None_is_exp;
static PyObject *__pyx_n_s_AbstractChildWatcher;
static PyObject *__pyx_kp_u_AddrInfoRequest_callback_called;
static PyObject *__pyx_kp_u_AddrInfo_data_is_NULL;
static PyObject *__pyx_n_s_AddressFamily;
static PyObject *__pyx_kp_u_Address_r_is_already_in_use;
static PyObject *__pyx_n_s_AttributeError;
static PyObject *__pyx_kp_u_Bad_exception_data_from_child_r;
static PyObject *__pyx_n_s_BaseException;
static PyObject *__pyx_n_s_BaseProtocol;
static PyObject *__pyx_n_s_BlockingIOError;
static PyObject *__pyx_n_s_BrokenPipeError;
static PyObject *__pyx_kp_u_Callback_handles_8;
static PyObject *__pyx_n_s_CancelledError;
static PyObject *__pyx_kp_u_Cannot_call_write_after_write_eo;
static PyObject *__pyx_kp_u_Cannot_call_writelines_after_wri;
static PyObject *__pyx_kp_u_Cannot_close_a_running_event_loo;
static PyObject *__pyx_kp_u_Cannot_run_the_event_loop_while;
static PyObject *__pyx_kp_u_Cannot_serialize_socket_object;
static PyObject *__pyx_n_s_CertificateError;
static PyObject *__pyx_kp_u_Connect_call_failed;
static PyObject *__pyx_n_s_ConnectionAbortedError;
static PyObject *__pyx_n_s_ConnectionRefusedError;
static PyObject *__pyx_n_s_ConnectionResetError;
static PyObject *__pyx_n_s_Counter;
static PyObject *__pyx_n_s_DEVNULL;
static PyObject *__pyx_n_u_DO_HANDSHAKE;
static PyObject *__pyx_n_u_EAI_ADDRFAMILY;
static PyObject *__pyx_n_u_EAI_AGAIN;
static PyObject *__pyx_n_u_EAI_BADFLAGS;
static PyObject *__pyx_n_u_EAI_BADHINTS;
static PyObject *__pyx_n_u_EAI_CANCELED;
static PyObject *__pyx_n_u_EAI_FAIL;
static PyObject *__pyx_n_u_EAI_FAMILY;
static PyObject *__pyx_n_u_EAI_MEMORY;
static PyObject *__pyx_n_u_EAI_NODATA;
static PyObject *__pyx_n_u_EAI_NONAME;
static PyObject *__pyx_n_u_EAI_OVERFLOW;
static PyObject *__pyx_n_u_EAI_PROTOCOL;
static PyObject *__pyx_n_u_EAI_SERVICE;
static PyObject *__pyx_n_u_EAI_SOCKTYPE;
static PyObject *__pyx_kp_u_Errors_logged;
static PyObject *__pyx_kp_u_Event_loop_is_closed;
static PyObject *__pyx_kp_u_Event_loop_stopped_before_Future;
static PyObject *__pyx_kp_u_Exception_in___repr___r_value_ty;
static PyObject *__pyx_kp_u_Exception_in_callback;
static PyObject *__pyx_kp_u_Exception_in_default_exception_h;
static PyObject *__pyx_kp_u_Exception_in_default_exception_h_2;
static PyObject *__pyx_kp_u_Exception_occurred_in_preexec_fn;
static PyObject *__pyx_kp_u_Executing_r_took_3f_seconds;
static PyObject *__pyx_kp_u_Executing_s_took_3f_seconds;
static PyObject *__pyx_kp_u_Fatal_error_on_SSL_transport;
static PyObject *__pyx_kp_u_Fatal_error_on_server;
static PyObject *__pyx_kp_u_Fatal_error_on_transport;
static PyObject *__pyx_kp_u_Fatal_error_on_transport_2;
static PyObject *__pyx_kp_u_Fatal_read_error_on_datagram_tra;
static PyObject *__pyx_kp_u_Fatal_write_error_on_datagram_tr;
static PyObject *__pyx_n_s_FileExistsError;
static PyObject *__pyx_n_s_FileNotFoundError;
static PyObject *__pyx_kp_u_File_descriptor_r_is_used_by_tra;
static PyObject *__pyx_n_s_FlowControlMixin;
static PyObject *__pyx_n_s_Future;
static PyObject *__pyx_kp_u_Handle_loop_is_None_in_Handle;
static PyObject *__pyx_kp_u_IPv4_sockaddr_must_be_2_tuple;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x38;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0x88;
static PyObject *__pyx_n_s_InterruptedError;
static PyObject *__pyx_n_s_InvalidStateError;
static PyObject *__pyx_kp_u_Invalid_address_must_be_None_or;
static PyObject *__pyx_kp_u_Invalid_file_descriptor;
static PyObject *__pyx_kp_u_Invalid_file_object_r;
static PyObject *__pyx_n_s_IsADirectoryError;
static PyObject *__pyx_n_s_Iterable;
static PyObject *__pyx_n_s_KeyError;
static PyObject *__pyx_kp_u_Listen_errors;
static PyObject *__pyx_n_s_Loop___get___locals_lambda;
static PyObject *__pyx_n_s_Loop___subprocess_run;
static PyObject *__pyx_n_s_Loop__getaddrinfo_locals_callbac;
static PyObject *__pyx_n_s_Loop__getnameinfo_locals_callbac;
static PyObject *__pyx_kp_u_Loop__read_from_self;
static PyObject *__pyx_kp_u_Loop__sock_accept;
static PyObject *__pyx_kp_u_Loop__sock_connect;
static PyObject *__pyx_n_s_Loop__sock_connect_locals_lambda;
static PyObject *__pyx_kp_u_Loop__sock_recv;
static PyObject *__pyx_kp_u_Loop__sock_recv_into;
static PyObject *__pyx_kp_u_Loop__sock_sendall;
static PyObject *__pyx_kp_u_Loop__stop;
static PyObject *__pyx_n_s_Loop_connect_accepted_socket;
static PyObject *__pyx_n_s_Loop_connect_read_pipe;
static PyObject *__pyx_n_s_Loop_connect_write_pipe;
static PyObject *__pyx_n_s_Loop_create_connection;
static PyObject *__pyx_n_s_Loop_create_datagram_endpoint;
static PyObject *__pyx_n_s_Loop_create_server;
static PyObject *__pyx_n_s_Loop_create_unix_connection;
static PyObject *__pyx_n_s_Loop_create_unix_server;
static PyObject *__pyx_kp_u_Loop_debug_info;
static PyObject *__pyx_n_s_Loop_getaddrinfo;
static PyObject *__pyx_n_s_Loop_getnameinfo;
static PyObject *__pyx_n_s_Loop_shutdown_asyncgens;
static PyObject *__pyx_n_s_Loop_sock_accept;
static PyObject *__pyx_n_s_Loop_sock_connect;
static PyObject *__pyx_n_s_Loop_sock_recv;
static PyObject *__pyx_n_s_Loop_sock_recv_into;
static PyObject *__pyx_n_s_Loop_sock_sendall;
static PyObject *__pyx_n_s_Loop_start_tls;
static PyObject *__pyx_n_s_Loop_subprocess_exec;
static PyObject *__pyx_n_s_Loop_subprocess_shell;
static PyObject *__pyx_kp_u_Loop_time;
static PyObject *__pyx_n_s_MemoryBIO;
static PyObject *__pyx_n_s_MemoryError;
static PyObject *__pyx_kp_u_Multiple_exceptions;
static PyObject *__pyx_n_s_NSIG;
static PyObject *__pyx_kp_u_Neither_host_port_nor_sock_were;
static PyObject *__pyx_kp_u_Non_thread_safe_operation_invoke;
static PyObject *__pyx_n_s_NotImplementedError;
static PyObject *__pyx_kp_u_Number_of_signals;
static PyObject *__pyx_n_s_OSError;
static PyObject *__pyx_n_s_O_RDWR;
static PyObject *__pyx_kp_u_Object_created_at_most_recent_ca;
static PyObject *__pyx_n_s_OrderedDict;
static PyObject *__pyx_n_s_OverflowError;
static PyObject *__pyx_n_s_PIPE;
static PyObject *__pyx_n_u_PROTOCOL_IS_SHUTDOWN;
static PyObject *__pyx_n_u_PYTHONASYNCIODEBUG;
static PyObject *__pyx_n_s_PermissionError;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_kp_u_Polls_debug_info;
static PyObject *__pyx_n_s_ProcessLookupError;
static PyObject *__pyx_kp_u_Process_info;
static PyObject *__pyx_kp_u_Process_memory;
static PyObject *__pyx_n_s_Protocol;
static PyObject *__pyx_n_s_Pyx_CFunc_object____Loop____bi;
static PyObject *__pyx_kp_u_Racing_with_another_loop_to_spaw;
static PyObject *__pyx_n_s_ReadSubprocessPipeProto;
static PyObject *__pyx_n_s_ReadSubprocessPipeProto_data_rec;
static PyObject *__pyx_kp_u_Read_EOF_failed_callbacks;
static PyObject *__pyx_kp_u_Read_EOFs;
static PyObject *__pyx_kp_u_Read_callbacks;
static PyObject *__pyx_kp_u_Read_callbacks_failed;
static PyObject *__pyx_kp_u_Read_errors;
static PyObject *__pyx_kp_u_Read_events;
static PyObject *__pyx_kp_u_Read_failed_callbacks;
static PyObject *__pyx_n_s_ResourceWarning;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_n_s_RuntimeWarning;
static PyObject *__pyx_n_u_SHUTDOWN;
static PyObject *__pyx_n_s_SIG_DFL;
static PyObject *__pyx_n_u_SOCK_NONBLOCK;
static PyObject *__pyx_n_u_SO_BROADCAST;
static PyObject *__pyx_n_u_SO_REUSEPORT;
static PyObject *__pyx_n_s_SSLContext;
static PyObject *__pyx_n_s_SSLError;
static PyObject *__pyx_n_s_SSLProtocol;
static PyObject *__pyx_n_s_SSLProtocolTransport;
static PyObject *__pyx_n_s_SSLProtocolTransport___del;
static PyObject *__pyx_n_s_SSLProtocolTransport___init;
static PyObject *__pyx_n_s_SSLProtocolTransport__protocol;
static PyObject *__pyx_n_s_SSLProtocolTransport_abort;
static PyObject *__pyx_n_s_SSLProtocolTransport_can_write;
static PyObject *__pyx_n_s_SSLProtocolTransport_close;
static PyObject *__pyx_n_s_SSLProtocolTransport_get_extra;
static PyObject *__pyx_n_s_SSLProtocolTransport_get_protoc;
static PyObject *__pyx_n_s_SSLProtocolTransport_get_write;
static PyObject *__pyx_n_s_SSLProtocolTransport_is_closing;
static PyObject *__pyx_n_s_SSLProtocolTransport_is_reading;
static PyObject *__pyx_n_s_SSLProtocolTransport_pause_read;
static PyObject *__pyx_n_s_SSLProtocolTransport_resume_rea;
static PyObject *__pyx_n_s_SSLProtocolTransport_set_protoc;
static PyObject *__pyx_n_s_SSLProtocolTransport_set_write;
static PyObject *__pyx_n_s_SSLProtocolTransport_write;
static PyObject *__pyx_n_s_SSLProtocol___init;
static PyObject *__pyx_n_s_SSLProtocol__abort;
static PyObject *__pyx_n_s_SSLProtocol__check_handshake_tim;
static PyObject *__pyx_n_s_SSLProtocol__fatal_error;
static PyObject *__pyx_n_s_SSLProtocol__finalize;
static PyObject *__pyx_n_s_SSLProtocol__get_extra_info;
static PyObject *__pyx_n_s_SSLProtocol__mark_closed;
static PyObject *__pyx_n_s_SSLProtocol__on_handshake_comple;
static PyObject *__pyx_n_s_SSLProtocol__process_write_backl;
static PyObject *__pyx_n_s_SSLProtocol__set_app_protocol;
static PyObject *__pyx_n_s_SSLProtocol__start_handshake;
static PyObject *__pyx_n_s_SSLProtocol__start_shutdown;
static PyObject *__pyx_n_s_SSLProtocol__wakeup_waiter;
static PyObject *__pyx_n_s_SSLProtocol__write_appdata;
static PyObject *__pyx_n_s_SSLProtocol_connection_lost;
static PyObject *__pyx_n_s_SSLProtocol_connection_made;
static PyObject *__pyx_n_s_SSLProtocol_data_received;
static PyObject *__pyx_n_s_SSLProtocol_eof_received;
static PyObject *__pyx_n_s_SSLProtocol_pause_writing;
static PyObject *__pyx_n_s_SSLProtocol_resume_writing;
static PyObject *__pyx_n_s_SSL_ERROR_SYSCALL;
static PyObject *__pyx_n_s_SSL_ERROR_WANT_READ;
static PyObject *__pyx_n_s_SSL_ERROR_WANT_WRITE;
static PyObject *__pyx_kp_u_SSL_error_errno;
static PyObject *__pyx_kp_u_SSL_handshake_failed;
static PyObject *__pyx_kp_u_SSL_handshake_failed_on_verifyin;
static PyObject *__pyx_kp_u_SSL_handshake_is_taking_longer_t;
static PyObject *__pyx_kp_s_SSL_protocol_Implementation_of_S;
static PyObject *__pyx_kp_u_SSL_transport_has_not_been_initi;
static PyObject *__pyx_n_s_STDOUT;
static PyObject *__pyx_n_s_S_ISSOCK;
static PyObject *__pyx_kp_u_Server_side_SSL_needs_a_valid_SS;
static PyObject *__pyx_n_s_Server_wait_closed;
static PyObject *__pyx_kp_u_Shutdown_errors;
static PyObject *__pyx_kp_u_Sock_ops_successful_on_1st_try;
static PyObject *__pyx_n_s_SocketKind;
static PyObject *__pyx_kp_u_Socket_try_writes;
static PyObject *__pyx_n_s_StackSummary;
static PyObject *__pyx_kp_u_StreamWriteContext_close_py_buf;
static PyObject *__pyx_kp_u_StreamWriteContext_close_uv_buf;
static PyObject *__pyx_kp_u_Streams_debug_info;
static PyObject *__pyx_n_s_SubprocessError;
static PyObject *__pyx_n_s_SyncSocketReaderFuture;
static PyObject *__pyx_n_s_SyncSocketReaderFuture___init;
static PyObject *__pyx_n_s_SyncSocketReaderFuture__loop;
static PyObject *__pyx_n_s_SyncSocketReaderFuture__sock;
static PyObject *__pyx_n_s_SyncSocketReaderFuture_cancel;
static PyObject *__pyx_n_s_SyncSocketWriterFuture;
static PyObject *__pyx_n_s_SyncSocketWriterFuture___init;
static PyObject *__pyx_n_s_SyncSocketWriterFuture__loop;
static PyObject *__pyx_n_s_SyncSocketWriterFuture__sock;
static PyObject *__pyx_n_s_SyncSocketWriterFuture_cancel;
static PyObject *__pyx_n_s_Task;
static PyObject *__pyx_n_s_ThreadPoolExecutor;
static PyObject *__pyx_n_s_TimeoutError;
static PyObject *__pyx_kp_u_Timer_handles_8;
static PyObject *__pyx_n_s_Transport;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_kp_u_UDPTransport__on_read_ready;
static PyObject *__pyx_kp_u_UDPTransport__on_write_ready;
static PyObject *__pyx_kp_u_UDP_sendto_address_r_requires_a;
static PyObject *__pyx_kp_u_UDP_sendto_r_socket_family_misma;
static PyObject *__pyx_n_u_UNWRAPPED;
static PyObject *__pyx_kp_u_UVHandles_python_libuv_total;
static PyObject *__pyx_kp_u_UVProcessTransport__call_connect;
static PyObject *__pyx_kp_u_UVProcess__close_after_spawn_cal;
static PyObject *__pyx_kp_u_UVStream__try_write_called_with;
static PyObject *__pyx_kp_u_UVStream_shutdown_callback_calle;
static PyObject *__pyx_kp_u_UVStream_write_callback_called_w;
static PyObject *__pyx_kp_u_UVTransport__call_connection_los;
static PyObject *__pyx_kp_u_UVTransport__call_connection_mad;
static PyObject *__pyx_kp_u_Unable_to_check_or_remove_stale;
static PyObject *__pyx_kp_u_Unhandled_error_in_exception_han;
static PyObject *__pyx_kp_u_Unhandled_exception_in_event_loo;
static PyObject *__pyx_n_s_UnicodeEncodeError;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_u_WRAPPED;
static PyObject *__pyx_n_s_WeakSet;
static PyObject *__pyx_n_s_WeakValueDictionary;
static PyObject *__pyx_n_s_WriteSubprocessPipeProto;
static PyObject *__pyx_n_s_WriteSubprocessPipeProto___init;
static PyObject *__pyx_n_s_WriteSubprocessPipeProto___repr;
static PyObject *__pyx_n_s_WriteSubprocessPipeProto_connect;
static PyObject *__pyx_n_s_WriteSubprocessPipeProto_connect_2;
static PyObject *__pyx_n_s_WriteSubprocessPipeProto_pause_w;
static PyObject *__pyx_n_s_WriteSubprocessPipeProto_resume;
static PyObject *__pyx_kp_u_Write_callbacks_failed;
static PyObject *__pyx_kp_u_Write_contexts_8;
static PyObject *__pyx_kp_u_Write_errors;
static PyObject *__pyx_kp_u_Write_events;
static PyObject *__pyx_kp_u_Write_failed_callbacks;
static PyObject *__pyx_kp_u_Write_without_poll;
static PyObject *__pyx_kp_u_XXX_an_allocated_buffer_in_trans;
static PyObject *__pyx_kp_u_You_must_set_server_hostname_whe;
static PyObject *__pyx_kp_u__114;
static PyObject *__pyx_kp_u__128;
static PyObject *__pyx_kp_u__129;
static PyObject *__pyx_kp_u__130;
static PyObject *__pyx_kp_u__159;
static PyObject *__pyx_kp_b__209;
static PyObject *__pyx_kp_b__220;
static PyObject *__pyx_kp_u__33;
static PyObject *__pyx_kp_u__40;
static PyObject *__pyx_n_s__7;
static PyObject *__pyx_kp_b__7;
static PyObject *__pyx_kp_u__7;
static PyObject *__pyx_kp_u__71;
static PyObject *__pyx_kp_u__87;
static PyObject *__pyx_kp_u__88;
static PyObject *__pyx_n_s_abc;
static PyObject *__pyx_n_s_abort;
static PyObject *__pyx_n_s_abort_2;
static PyObject *__pyx_kp_u_abort_init__closed_is_set;
static PyObject *__pyx_kp_u_abort_init__inited_is_set;
static PyObject *__pyx_n_s_accept;
static PyObject *__pyx_kp_u_accept_method;
static PyObject *__pyx_n_s_aclose;
static PyObject *__pyx_kp_u_active_TimerHandle_is_deallacati;
static PyObject *__pyx_n_s_add;
static PyObject *__pyx_n_s_add_done_callback;
static PyObject *__pyx_n_s_addr;
static PyObject *__pyx_n_s_address;
static PyObject *__pyx_n_s_address_2;
static PyObject *__pyx_kp_u_alive_closed;
static PyObject *__pyx_kp_u_all_args_must_be_str_or_bytes;
static PyObject *__pyx_kp_u_all_environment_values_must_be_b;
static PyObject *__pyx_kp_u_all_environment_vars_must_be_byt;
static PyObject *__pyx_n_s_allow_broadcast;
static PyObject *__pyx_kp_u_an_error_occurred_during_closing;
static PyObject *__pyx_n_s_app_protocol;
static PyObject *__pyx_n_s_app_protocol_2;
static PyObject *__pyx_n_s_app_protocol_is_buffer;
static PyObject *__pyx_n_s_app_transport;
static PyObject *__pyx_n_s_appdata;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_appendleft;
static PyObject *__pyx_kp_u_application_protocol_failed_to_r;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_u_ascii;
static PyObject *__pyx_n_u_asyncgen;
static PyObject *__pyx_n_s_asyncgen_finalizer_hook;
static PyObject *__pyx_n_s_asyncgen_firstiter_hook;
static PyObject *__pyx_kp_u_asynchronous_generator_r_was_sch;
static PyObject *__pyx_n_s_asyncio;
static PyObject *__pyx_n_s_asyncio_base_events;
static PyObject *__pyx_n_s_asyncio_coroutines;
static PyObject *__pyx_n_s_asyncio_futures;
static PyObject *__pyx_kp_u_asyncio_is_trying_to_install_it;
static PyObject *__pyx_n_s_asyncio_log;
static PyObject *__pyx_n_s_asyncio_sslproto;
static PyObject *__pyx_n_s_asyncio_tasks;
static PyObject *__pyx_n_s_asyncio_transports;
static PyObject *__pyx_n_s_await;
static PyObject *__pyx_n_u_b;
static PyObject *__pyx_n_s_backlog;
static PyObject *__pyx_kp_b_bin_sh;
static PyObject *__pyx_n_s_bind;
static PyObject *__pyx_kp_u_bind_method;
static PyObject *__pyx_n_s_buf;
static PyObject *__pyx_kp_u_buffer_size_is_not_0_after_a_su;
static PyObject *__pyx_n_s_buffer_updated;
static PyObject *__pyx_n_s_bufsize;
static PyObject *__pyx_kp_u_bufsize_must_be_0;
static PyObject *__pyx_n_s_builtins;
static PyObject *__pyx_kp_b_c;
static PyObject *__pyx_n_s_call_connection_made;
static PyObject *__pyx_n_s_call_connection_made_2;
static PyObject *__pyx_n_s_call_exception_handler;
static PyObject *__pyx_n_s_call_later;
static PyObject *__pyx_n_s_call_soon;
static PyObject *__pyx_n_s_call_soon_threadsafe;
static PyObject *__pyx_n_s_callback;
static PyObject *__pyx_kp_u_called_after_destroying_the_UVH;
static PyObject *__pyx_kp_u_called_with_handle_data_NULL;
static PyObject *__pyx_kp_u_can_not_get_address_information;
static PyObject *__pyx_n_s_can_write_eof;
static PyObject *__pyx_n_s_cancel;
static PyObject *__pyx_kp_u_cancel_request_data_is_NULL;
static PyObject *__pyx_kp_u_cancel_request_data_is_not_UVRe;
static PyObject *__pyx_kp_u_cancel_request_is_NULL;
static PyObject *__pyx_n_s_cancelled;
static PyObject *__pyx_n_u_cancelled;
static PyObject *__pyx_kp_u_cannot_add_a_signal_handler_for;
static PyObject *__pyx_kp_u_cannot_apply_subprocess_STDOUT;
static PyObject *__pyx_kp_u_cannot_convert_sockaddr_into_Pyt;
static PyObject *__pyx_kp_u_cannot_spawn_a_process_args_are;
static PyObject *__pyx_n_s_cast;
static PyObject *__pyx_n_s_cause;
static PyObject *__pyx_n_s_cfunc_to_py;
static PyObject *__pyx_n_s_chain;
static PyObject *__pyx_n_s_check_handshake_timeout;
static PyObject *__pyx_n_s_check_hostname;
static PyObject *__pyx_n_s_chunk;
static PyObject *__pyx_n_s_cipher;
static PyObject *__pyx_n_s_class;
static PyObject *__pyx_n_s_clear;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_kp_u_close__handle_data_is_NULL;
static PyObject *__pyx_kp_u_close__handle_data_is_not_UVHa;
static PyObject *__pyx_n_s_close_fds;
static PyObject *__pyx_kp_u_close_method;
static PyObject *__pyx_kp_u_close_uv_is_closing_is_true;
static PyObject *__pyx_n_s_closed;
static PyObject *__pyx_kp_u_closed_Transport_handle_and_unse;
static PyObject *__pyx_kp_u_closed_reading_x;
static PyObject *__pyx_kp_u_closed_x;
static PyObject *__pyx_n_s_cmd;
static PyObject *__pyx_n_s_collections;
static PyObject *__pyx_n_s_collections_abc;
static PyObject *__pyx_n_s_compression;
static PyObject *__pyx_n_s_concurrent;
static PyObject *__pyx_kp_u_concurrent_allocations;
static PyObject *__pyx_n_s_concurrent_futures;
static PyObject *__pyx_n_s_connect;
static PyObject *__pyx_n_s_connect_accepted_socket;
static PyObject *__pyx_kp_u_connect_ex_method;
static PyObject *__pyx_kp_u_connect_failed;
static PyObject *__pyx_kp_u_connect_method;
static PyObject *__pyx_n_s_connect_read_pipe;
static PyObject *__pyx_n_s_connect_write_pipe;
static PyObject *__pyx_n_s_connection_lost;
static PyObject *__pyx_n_s_connection_made;
static PyObject *__pyx_n_s_context;
static PyObject *__pyx_n_u_context;
static PyObject *__pyx_kp_u_context_argument_requires_Pytho;
static PyObject *__pyx_kp_u_context_manager_protocol;
static PyObject *__pyx_n_s_copy;
static PyObject *__pyx_n_s_coroutines;
static PyObject *__pyx_kp_u_coroutines_cannot_be_used_with_a;
static PyObject *__pyx_kp_u_coroutines_cannot_be_used_with_r;
static PyObject *__pyx_kp_u_could_not_close_attached_file_ob;
static PyObject *__pyx_n_s_create_connection;
static PyObject *__pyx_n_s_create_connection_locals_genexpr;
static PyObject *__pyx_n_s_create_datagram_endpoint;
static PyObject *__pyx_n_s_create_datagram_endpoint_locals;
static PyObject *__pyx_n_s_create_default_context;
static PyObject *__pyx_n_s_create_server;
static PyObject *__pyx_n_s_create_task;
static PyObject *__pyx_n_s_create_unix_connection;
static PyObject *__pyx_n_s_create_unix_server;
static PyObject *__pyx_kp_u_created_at;
static PyObject *__pyx_n_s_creationflags;
static PyObject *__pyx_kp_u_creationflags_is_not_supported;
static PyObject *__pyx_n_s_cwd;
static PyObject *__pyx_kp_u_cwd_must_be_a_str_or_bytes_objec;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_kp_u_data_argument_must_be_a_bytes_li;
static PyObject *__pyx_kp_u_data_expecting_a_bytes_like_inst;
static PyObject *__pyx_n_s_data_received;
static PyObject *__pyx_n_u_data_received;
static PyObject *__pyx_n_s_datagram_received;
static PyObject *__pyx_kp_u_dealloc____handle_is_NULL__cl;
static PyObject *__pyx_kp_u_deallocating_a_running_event_loo;
static PyObject *__pyx_kp_u_deallocating_an_open_event_loop;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_u_debug_wrapper;
static PyObject *__pyx_n_s_decode;
static PyObject *__pyx_n_s_decref_socketios;
static PyObject *__pyx_n_s_default;
static PyObject *__pyx_n_s_default_exception_handler;
static PyObject *__pyx_n_s_default_int_handler;
static PyObject *__pyx_n_s_del;
static PyObject *__pyx_n_s_delay;
static PyObject *__pyx_n_s_deque;
static PyObject *__pyx_n_s_detach;
static PyObject *__pyx_kp_u_detach_method;
static PyObject *__pyx_n_s_devnull;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_n_s_disable;
static PyObject *__pyx_n_s_discard;
static PyObject *__pyx_n_s_disconnected;
static PyObject *__pyx_n_s_do_handshake;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_kp_u_does_not_have_a_reader_in_the;
static PyObject *__pyx_kp_u_does_not_have_a_reader_in_the_2;
static PyObject *__pyx_kp_u_does_not_have_a_writer_in_the;
static PyObject *__pyx_n_s_done;
static PyObject *__pyx_n_s_dt;
static PyObject *__pyx_n_s_dup;
static PyObject *__pyx_n_s_e;
static PyObject *__pyx_n_s_enabled;
static PyObject *__pyx_n_s_encode;
static PyObject *__pyx_n_s_ensure_future;
static PyObject *__pyx_n_s_enter;
static PyObject *__pyx_n_s_env;
static PyObject *__pyx_n_s_environ;
static PyObject *__pyx_n_s_eof_received;
static PyObject *__pyx_kp_u_epected_AF_INET_or_AF_INET6_fami;
static PyObject *__pyx_n_s_errno;
static PyObject *__pyx_n_u_errno;
static PyObject *__pyx_n_s_error;
static PyObject *__pyx_n_s_error_received;
static PyObject *__pyx_kp_u_error_status_in_uv_stream_t_list;
static PyObject *__pyx_kp_u_error_status_in_uv_stream_t_read;
static PyObject *__pyx_kp_u_error_status_in_uv_stream_t_shut;
static PyObject *__pyx_kp_u_error_status_in_uv_stream_t_writ;
static PyObject *__pyx_kp_u_error_while_attempting_to_bind_o;
static PyObject *__pyx_n_s_ex;
static PyObject *__pyx_n_s_exc;
static PyObject *__pyx_n_s_exc_info;
static PyObject *__pyx_n_s_exception;
static PyObject *__pyx_n_u_exception;
static PyObject *__pyx_kp_u_exception_in_Task___repr;
static PyObject *__pyx_n_s_executable;
static PyObject *__pyx_n_s_executor;
static PyObject *__pyx_n_s_exit;
static PyObject *__pyx_n_s_extra;
static PyObject *__pyx_n_s_extract;
static PyObject *__pyx_n_s_family;
static PyObject *__pyx_kp_u_fatal_Could_not_advance__StreamW;
static PyObject *__pyx_n_s_fatal_error;
static PyObject *__pyx_kp_u_fatal_sent_0_in_advance_uv_buf;
static PyObject *__pyx_n_s_fd;
static PyObject *__pyx_kp_u_fd_2;
static PyObject *__pyx_n_s_fileno;
static PyObject *__pyx_n_s_fileobj;
static PyObject *__pyx_n_s_finalize;
static PyObject *__pyx_n_s_finalizer;
static PyObject *__pyx_n_s_firstiter;
static PyObject *__pyx_n_s_flags;
static PyObject *__pyx_n_s_flush;
static PyObject *__pyx_n_s_force_close;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_format_list;
static PyObject *__pyx_n_s_frame;
static PyObject *__pyx_n_s_fspath;
static PyObject *__pyx_n_s_func;
static PyObject *__pyx_n_s_functools;
static PyObject *__pyx_n_s_fut;
static PyObject *__pyx_n_s_futures;
static PyObject *__pyx_n_s_gaierror;
static PyObject *__pyx_n_s_gather;
static PyObject *__pyx_n_s_gc;
static PyObject *__pyx_n_s_genexpr;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_get_asyncgen_hooks;
static PyObject *__pyx_n_u_get_asyncgen_hooks;
static PyObject *__pyx_n_s_get_buffer;
static PyObject *__pyx_n_u_get_buffer;
static PyObject *__pyx_kp_u_get_buffer_returned_an_empty_buf;
static PyObject *__pyx_n_s_get_coroutine_origin_tracking_de;
static PyObject *__pyx_n_s_get_coroutine_wrapper;
static PyObject *__pyx_n_s_get_debug;
static PyObject *__pyx_n_s_get_event_loop;
static PyObject *__pyx_n_s_get_extra_info;
static PyObject *__pyx_n_s_get_extra_info_2;
static PyObject *__pyx_n_s_get_inheritable;
static PyObject *__pyx_n_s_get_protocol;
static PyObject *__pyx_n_u_get_running_loop;
static PyObject *__pyx_n_s_get_write_buffer_size;
static PyObject *__pyx_n_s_getaddrinfo;
static PyObject *__pyx_kp_u_getaddrinfo_returned_empty_list;
static PyObject *__pyx_kp_u_getaddrinfo_returned_empty_list_2;
static PyObject *__pyx_n_s_getframe;
static PyObject *__pyx_n_s_getnameinfo;
static PyObject *__pyx_kp_u_getnameinfo_argument_1_must_be_a;
static PyObject *__pyx_kp_u_getnameinfo_flowinfo_must_be_0_1;
static PyObject *__pyx_n_s_getpeercert;
static PyObject *__pyx_n_s_getpeername;
static PyObject *__pyx_n_s_getservbyname;
static PyObject *__pyx_kp_u_getsockaddrarg_flowinfo_must_be;
static PyObject *__pyx_kp_u_getsockaddrarg_scope_id_must_be;
static PyObject *__pyx_n_s_getsockname;
static PyObject *__pyx_n_s_getsockopt;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_gettimeout;
static PyObject *__pyx_n_u_handle;
static PyObject *__pyx_kp_u_handle_data_is_NULL_in___close_a;
static PyObject *__pyx_kp_u_handle_loop_data_is_NULL_in___en;
static PyObject *__pyx_kp_u_handle_loop_is_NULL_in___ensure;
static PyObject *__pyx_n_s_handshake_exc;
static PyObject *__pyx_kp_u_handshake_in_progress_or_complet;
static PyObject *__pyx_n_s_handshake_start_time;
static PyObject *__pyx_n_s_handshake_timeout_handle;
static PyObject *__pyx_kp_u_has_handle_0_in___uv_close_handl;
static PyObject *__pyx_kp_u_high;
static PyObject *__pyx_n_s_high_2;
static PyObject *__pyx_n_s_host;
static PyObject *__pyx_kp_u_host_and_port_was_not_specified;
static PyObject *__pyx_kp_u_host_must_be_a_str_or_bytes;
static PyObject *__pyx_kp_u_host_must_be_a_string_or_bytes_o;
static PyObject *__pyx_kp_u_host_port_and_sock_can_not_be_sp;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_id;
static PyObject *__pyx_n_s_ident;
static PyObject *__pyx_n_u_idna;
static PyObject *__pyx_n_s_ignore_environment;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_in_handshake;
static PyObject *__pyx_n_s_in_shutdown;
static PyObject *__pyx_n_u_inf;
static PyObject *__pyx_n_s_info;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_inspect;
static PyObject *__pyx_kp_u_integer_argument_expected_got;
static PyObject *__pyx_kp_u_invalid_Handle_cb_type;
static PyObject *__pyx_kp_u_invalid__init_protocol_call;
static PyObject *__pyx_kp_u_invalid_data_in_writebuf_an_inst;
static PyObject *__pyx_kp_u_invalid_socket_family_expected_A;
static PyObject *__pyx_kp_u_invalid_waiter_object_r_expected;
static PyObject *__pyx_n_s_io_refs;
static PyObject *__pyx_kp_u_is_alive_but__handle_data_is_no;
static PyObject *__pyx_kp_u_is_alive_but__handle_is_NULL;
static PyObject *__pyx_kp_u_is_alive_but__handle_loop_is_no;
static PyObject *__pyx_kp_u_is_alive_but__loop_is_None;
static PyObject *__pyx_n_s_is_closed;
static PyObject *__pyx_n_s_is_closing;
static PyObject *__pyx_kp_u_is_not_supported_by_start_tls;
static PyObject *__pyx_kp_u_is_not_supposed_to_be_instantia;
static PyObject *__pyx_kp_u_is_open_in___dealloc___with_loo;
static PyObject *__pyx_n_s_is_reading;
static PyObject *__pyx_n_s_is_running;
static PyObject *__pyx_n_s_iscoroutine;
static PyObject *__pyx_n_s_iscoroutinefunction;
static PyObject *__pyx_n_u_isfuture;
static PyObject *__pyx_n_s_isgenerator;
static PyObject *__pyx_n_s_items;
static PyObject *__pyx_n_s_itertools;
static PyObject *__pyx_n_s_keep_open;
static PyObject *__pyx_kp_u_laddr_s;
static PyObject *__pyx_n_s_limit;
static PyObject *__pyx_kp_u_listen_method;
static PyObject *__pyx_n_s_local_addr;
static PyObject *__pyx_kp_u_local_addr_must_be_a_tuple_of_ho;
static PyObject *__pyx_n_s_log;
static PyObject *__pyx_n_s_log_destroy_pending;
static PyObject *__pyx_n_s_logger;
static PyObject *__pyx_n_s_lookup_lines;
static PyObject *__pyx_n_s_loop;
static PyObject *__pyx_n_s_loop_2;
static PyObject *__pyx_kp_u_loop__exec_queued_writes;
static PyObject *__pyx_kp_u_loop__on_idle;
static PyObject *__pyx_kp_u_loop__queued_streams_are_not_emp;
static PyObject *__pyx_kp_u_loop_set_debug_False_cannot_unse;
static PyObject *__pyx_kp_u_loop_set_debug_True_cannot_set_d;
static PyObject *__pyx_n_s_low;
static PyObject *__pyx_n_s_lower;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_main_thread;
static PyObject *__pyx_kp_u_makefile_method;
static PyObject *__pyx_n_s_mark_closed;
static PyObject *__pyx_n_s_memoryview;
static PyObject *__pyx_n_s_message;
static PyObject *__pyx_n_u_message;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_u_missing;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_monotonic;
static PyObject *__pyx_n_s_msg;
static PyObject *__pyx_kp_u_must_be_0;
static PyObject *__pyx_kp_u_must_be_low;
static PyObject *__pyx_n_s_n;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_u_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_kp_u_new_callbacks_were_queued_during;
static PyObject *__pyx_kp_u_new_poll_handles_were_queued_dur;
static PyObject *__pyx_kp_u_new_timers_were_queued_during_lo;
static PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
static PyObject *__pyx_kp_u_no_path_and_sock_were_specified;
static PyObject *__pyx_kp_u_no_python_buffer_is_allocated_in;
static PyObject *__pyx_kp_u_no_security_layer_present;
static PyObject *__pyx_n_s_noop;
static PyObject *__pyx_n_s_noop_2;
static PyObject *__pyx_kp_u_not_holding_the_import_lock;
static PyObject *__pyx_n_s_object;
static PyObject *__pyx_kp_u_object_created_at_most_recent_ca;
static PyObject *__pyx_kp_u_objs_handles;
static PyObject *__pyx_n_s_offset;
static PyObject *__pyx_n_s_on_handshake_complete;
static PyObject *__pyx_n_s_on_ssl_connected;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_kp_u_open__StreamWriteContext_is_bein;
static PyObject *__pyx_n_s_os;
static PyObject *__pyx_n_s_partial;
static PyObject *__pyx_n_s_pass_fds;
static PyObject *__pyx_n_s_path;
static PyObject *__pyx_kp_u_path_and_sock_can_not_be_specifi;
static PyObject *__pyx_kp_u_path_was_not_specified_and_no_so;
static PyObject *__pyx_n_s_pause_reading;
static PyObject *__pyx_n_s_pause_writing;
static PyObject *__pyx_n_s_paused;
static PyObject *__pyx_n_s_peercert;
static PyObject *__pyx_n_u_peername;
static PyObject *__pyx_n_s_pending;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pipe;
static PyObject *__pyx_n_u_pipe;
static PyObject *__pyx_kp_u_pipe_2;
static PyObject *__pyx_n_s_pipe_connection_lost;
static PyObject *__pyx_n_s_pipe_data_received;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_popleft;
static PyObject *__pyx_n_s_port;
static PyObject *__pyx_kp_u_port_must_be_a_str_bytes_or_int;
static PyObject *__pyx_n_s_preexec_fn;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_u_print_debug_info;
static PyObject *__pyx_n_s_proc;
static PyObject *__pyx_n_s_process_exited;
static PyObject *__pyx_n_s_process_write_backlog;
static PyObject *__pyx_n_s_program;
static PyObject *__pyx_n_s_property;
static PyObject *__pyx_n_s_proto;
static PyObject *__pyx_n_s_proto_factory;
static PyObject *__pyx_n_s_protocol;
static PyObject *__pyx_n_u_protocol;
static PyObject *__pyx_n_s_protocol_factory;
static PyObject *__pyx_kp_u_protocol_is_not_set_cannot_call;
static PyObject *__pyx_kp_u_protocol_is_required;
static PyObject *__pyx_kp_u_protocol_pause_writing_failed;
static PyObject *__pyx_n_s_protocol_paused;
static PyObject *__pyx_kp_u_protocol_resume_writing_failed;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_PseudoSocket;
static PyObject *__pyx_n_s_pyx_unpickle__SSLPipe;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_u_qualname;
static PyObject *__pyx_kp_u_r_SSL_handshake_took_1f_ms;
static PyObject *__pyx_kp_u_r_fileno_returned_non_integer;
static PyObject *__pyx_kp_u_r_received_EOF;
static PyObject *__pyx_kp_u_r_s;
static PyObject *__pyx_kp_u_r_starts_SSL_handshake;
static PyObject *__pyx_kp_u_raddr_s;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_read;
static PyObject *__pyx_n_s_reason;
static PyObject *__pyx_n_u_reason;
static PyObject *__pyx_kp_u_reason_2;
static PyObject *__pyx_n_s_recv;
static PyObject *__pyx_n_s_recv_into;
static PyObject *__pyx_kp_u_recv_into_method;
static PyObject *__pyx_kp_u_recv_method;
static PyObject *__pyx_n_s_recvfrom;
static PyObject *__pyx_kp_u_recvfrom_into_method;
static PyObject *__pyx_kp_u_recvfrom_method;
static PyObject *__pyx_kp_u_recvmsg_into_method;
static PyObject *__pyx_kp_u_recvmsg_method;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_remote_addr;
static PyObject *__pyx_n_s_remove;
static PyObject *__pyx_n_s_remove_done_callback;
static PyObject *__pyx_n_s_remove_reader;
static PyObject *__pyx_n_s_remove_signal_handler;
static PyObject *__pyx_n_s_remove_writer;
static PyObject *__pyx_n_s_repr;
static PyObject *__pyx_n_s_restore_signals;
static PyObject *__pyx_n_s_result;
static PyObject *__pyx_n_s_resume_reading;
static PyObject *__pyx_n_s_resume_writing;
static PyObject *__pyx_n_s_return_exceptions;
static PyObject *__pyx_kp_u_returning_true_from_eof_received;
static PyObject *__pyx_n_s_reuse_address;
static PyObject *__pyx_n_s_reuse_port;
static PyObject *__pyx_kp_u_reuse_port_not_supported_by_sock;
static PyObject *__pyx_n_s_reverse;
static PyObject *__pyx_n_s_rstrip;
static PyObject *__pyx_n_s_run_forever;
static PyObject *__pyx_n_s_run_until_complete_locals_lambda;
static PyObject *__pyx_kp_u_running_closed_debug;
static PyObject *__pyx_kp_u_seconds_aborting_the_connection;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_u_self;
static PyObject *__pyx_n_s_self_2;
static PyObject *__pyx_kp_s_self_py_bufs_self_py_bufs_sml_se;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_kp_u_send_method;
static PyObject *__pyx_kp_u_sendall_method;
static PyObject *__pyx_kp_u_sendfile_method;
static PyObject *__pyx_kp_u_sendmsg_afalg_method;
static PyObject *__pyx_kp_u_sendmsg_method;
static PyObject *__pyx_n_s_sendto;
static PyObject *__pyx_kp_u_sendto_method;
static PyObject *__pyx_n_s_server_hostname;
static PyObject *__pyx_n_s_server_hostname_2;
static PyObject *__pyx_kp_u_server_hostname_is_only_meaningf;
static PyObject *__pyx_n_s_server_side;
static PyObject *__pyx_n_s_server_side_2;
static PyObject *__pyx_kp_u_service_proto_not_found;
static PyObject *__pyx_n_s_session_established;
static PyObject *__pyx_n_s_set_app_protocol;
static PyObject *__pyx_n_s_set_asyncgen_hooks;
static PyObject *__pyx_n_s_set_coroutine_origin_tracking_de;
static PyObject *__pyx_n_s_set_coroutine_wrapper;
static PyObject *__pyx_n_s_set_debug;
static PyObject *__pyx_n_s_set_exception;
static PyObject *__pyx_n_s_set_inheritable;
static PyObject *__pyx_n_s_set_protocol;
static PyObject *__pyx_n_s_set_result;
static PyObject *__pyx_n_u_set_running_loop;
static PyObject *__pyx_n_s_set_wakeup_fd;
static PyObject *__pyx_kp_u_set_wakeup_fd_1_failed_s;
static PyObject *__pyx_kp_u_set_wakeup_fd_only_works_in_main;
static PyObject *__pyx_n_s_set_write_buffer_limits;
static PyObject *__pyx_n_s_setblocking;
static PyObject *__pyx_kp_u_setblocking_transport_sockets_ca;
static PyObject *__pyx_n_s_setsockopt;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_settimeout;
static PyObject *__pyx_kp_u_settimeout_only_0_timeout_is_all;
static PyObject *__pyx_n_s_share;
static PyObject *__pyx_n_s_shell;
static PyObject *__pyx_kp_u_shell_must_be_False;
static PyObject *__pyx_kp_u_shell_must_be_True;
static PyObject *__pyx_n_s_shutdown;
static PyObject *__pyx_n_s_shutdown_asyncgens;
static PyObject *__pyx_kp_u_shutdown_in_progress;
static PyObject *__pyx_kp_u_shutdown_method;
static PyObject *__pyx_n_s_sig;
static PyObject *__pyx_kp_u_sig_cannot_be_caught;
static PyObject *__pyx_kp_u_sig_must_be_an_int_not_r;
static PyObject *__pyx_kp_u_sig_out_of_range_1;
static PyObject *__pyx_n_s_sighandler;
static PyObject *__pyx_n_s_siginterrupt;
static PyObject *__pyx_n_s_signal;
static PyObject *__pyx_n_s_signum;
static PyObject *__pyx_n_s_sleep;
static PyObject *__pyx_n_s_sock;
static PyObject *__pyx_n_s_sock_accept;
static PyObject *__pyx_n_s_sock_connect;
static PyObject *__pyx_n_s_sock_recv;
static PyObject *__pyx_n_s_sock_recv_into;
static PyObject *__pyx_kp_u_sock_recv_into_is_called_on_a_c;
static PyObject *__pyx_kp_u_sock_recv_is_called_on_a_cancel;
static PyObject *__pyx_n_s_sock_sendall;
static PyObject *__pyx_kp_u_sock_sendall_is_called_on_a_can;
static PyObject *__pyx_n_s_sockaddr;
static PyObject *__pyx_kp_u_sockaddr_must_be_a_tuple_of_2_3;
static PyObject *__pyx_kp_u_sockaddr_resolved_to_multiple_ad;
static PyObject *__pyx_kp_u_socket;
static PyObject *__pyx_n_s_socket_2;
static PyObject *__pyx_n_u_socket_2;
static PyObject *__pyx_kp_u_socket_modifier_keyword_argument;
static PyObject *__pyx_kp_u_socket_send_raised_exception;
static PyObject *__pyx_n_s_socketpair;
static PyObject *__pyx_kp_u_sockets;
static PyObject *__pyx_n_s_sockets_2;
static PyObject *__pyx_n_u_sockname;
static PyObject *__pyx_n_s_source;
static PyObject *__pyx_n_u_source_traceback;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_ssl;
static PyObject *__pyx_kp_u_ssl_argument_must_be_an_SSLConte;
static PyObject *__pyx_n_s_ssl_handshake_timeout;
static PyObject *__pyx_n_s_ssl_handshake_timeout_2;
static PyObject *__pyx_kp_u_ssl_handshake_timeout_is_only_me;
static PyObject *__pyx_kp_u_ssl_handshake_timeout_should_be;
static PyObject *__pyx_kp_u_ssl_is_expected_to_be_None_or_an;
static PyObject *__pyx_n_s_ssl_object;
static PyObject *__pyx_n_s_ssl_protocol;
static PyObject *__pyx_n_s_ssl_protocol_2;
static PyObject *__pyx_n_s_sslcontext;
static PyObject *__pyx_n_s_sslcontext_2;
static PyObject *__pyx_kp_u_sslcontext_is_expected_to_be_an;
static PyObject *__pyx_n_s_ssldata;
static PyObject *__pyx_n_s_sslobj;
static PyObject *__pyx_n_s_sslpipe;
static PyObject *__pyx_n_s_sslpipe_2;
static PyObject *__pyx_n_s_st_mode;
static PyObject *__pyx_n_s_start_handshake;
static PyObject *__pyx_kp_u_start_init_can_only_be_called;
static PyObject *__pyx_n_s_start_new_session;
static PyObject *__pyx_n_s_start_shutdown;
static PyObject *__pyx_n_s_start_tls;
static PyObject *__pyx_n_s_startupinfo;
static PyObject *__pyx_kp_u_startupinfo_is_not_supported;
static PyObject *__pyx_n_s_stat;
static PyObject *__pyx_n_s_stderr;
static PyObject *__pyx_n_s_stdin;
static PyObject *__pyx_n_s_stdio_fut;
static PyObject *__pyx_n_s_stdio_inited;
static PyObject *__pyx_n_s_stdout;
static PyObject *__pyx_n_s_stop;
static PyObject *__pyx_kp_u_stream_is_open_after_UVStream__t;
static PyObject *__pyx_n_s_strerror;
static PyObject *__pyx_kp_u_string_is_expected;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_submit;
static PyObject *__pyx_n_s_subprocess;
static PyObject *__pyx_kp_u_subprocess_STDOUT_is_supported_o;
static PyObject *__pyx_n_s_subprocess_exec;
static PyObject *__pyx_n_s_subprocess_run;
static PyObject *__pyx_n_s_subprocess_shell;
static PyObject *__pyx_n_s_subtract;
static PyObject *__pyx_n_s_super;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_u_task;
static PyObject *__pyx_kp_u_task_factory_must_be_a_callable;
static PyObject *__pyx_n_u_tcp;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_test_coroutine_1;
static PyObject *__pyx_kp_u_the_socket_must_be_non_blocking;
static PyObject *__pyx_kp_u_this_event_loop_is_already_runni;
static PyObject *__pyx_n_s_threading;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_time;
static PyObject *__pyx_n_s_timeout;
static PyObject *__pyx_n_s_tr;
static PyObject *__pyx_n_s_traceback;
static PyObject *__pyx_n_s_traceback_2;
static PyObject *__pyx_n_s_transport;
static PyObject *__pyx_n_u_transport;
static PyObject *__pyx_kp_u_transport_2;
static PyObject *__pyx_n_s_transport_3;
static PyObject *__pyx_kp_u_transport_sockets_do_not_support;
static PyObject *__pyx_n_s_transports;
static PyObject *__pyx_kp_u_try_write_sent_all_data_and_ret;
static PyObject *__pyx_n_s_type;
static PyObject *__pyx_n_u_udp;
static PyObject *__pyx_kp_u_unable_to_listen_no_protocol_fac;
static PyObject *__pyx_kp_u_unable_to_perform_operation_on_r;
static PyObject *__pyx_kp_u_unable_to_start_the_loop_it_was;
static PyObject *__pyx_kp_u_unclosed_resource_r;
static PyObject *__pyx_kp_u_unclosed_resource_r_2;
static PyObject *__pyx_kp_u_unclosed_resource_r_could_not_se;
static PyObject *__pyx_kp_u_unclosed_transport_r;
static PyObject *__pyx_kp_u_unexpected_address_family;
static PyObject *__pyx_kp_u_unhandled_error_or_an_empty_buff;
static PyObject *__pyx_n_s_universal_newlines;
static PyObject *__pyx_kp_u_universal_newlines_must_be_False;
static PyObject *__pyx_kp_u_unopened_TCPServer;
static PyObject *__pyx_n_s_unwrap;
static PyObject *__pyx_n_s_update;
static PyObject *__pyx_kp_u_uv_close_handle_cb_handle_loop;
static PyObject *__pyx_kp_u_uv_handle_t_current_freed_total;
static PyObject *__pyx_kp_u_uvloop_PseudoSocket_fd_family_s;
static PyObject *__pyx_kp_s_uvloop_handles_process_pyx;
static PyObject *__pyx_n_s_uvloop_loop;
static PyObject *__pyx_kp_s_uvloop_loop_pyx;
static PyObject *__pyx_n_s_uvloop_sleep_after_fork;
static PyObject *__pyx_kp_s_uvloop_sslproto_pyx;
static PyObject *__pyx_n_s_values;
static PyObject *__pyx_n_s_version_info;
static PyObject *__pyx_n_s_wait;
static PyObject *__pyx_n_s_wait_closed;
static PyObject *__pyx_n_s_waiter;
static PyObject *__pyx_n_s_waiter_2;
static PyObject *__pyx_kp_u_waiter_is_not_None_in__call_conn;
static PyObject *__pyx_n_s_wakeup_waiter;
static PyObject *__pyx_n_s_walk_stack;
static PyObject *__pyx_n_s_warn;
static PyObject *__pyx_n_s_warn_on_full_buffer;
static PyObject *__pyx_n_s_warning;
static PyObject *__pyx_n_s_warnings;
static PyObject *__pyx_n_u_wb;
static PyObject *__pyx_n_s_weakref;
static PyObject *__pyx_n_s_when;
static PyObject *__pyx_kp_u_without_no_gc_clear_loop_was_se;
static PyObject *__pyx_n_s_wrap;
static PyObject *__pyx_n_s_wrap_bio;
static PyObject *__pyx_n_s_wrap_future;
static PyObject *__pyx_n_s_write;
static PyObject *__pyx_n_s_write_appdata;
static PyObject *__pyx_n_s_write_backlog;
static PyObject *__pyx_n_s_write_buffer_size;
static PyObject *__pyx_n_s_write_eof;
static PyObject *__pyx_n_s_writelines;
static PyObject *__pyx_n_s_zip;
static int __pyx_pf_6uvloop_4loop_4Loop___cinit__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static int __pyx_pf_6uvloop_4loop_4Loop_2__init__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static void __pyx_pf_6uvloop_4loop_4Loop_4__dealloc__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_6__sighandler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_signum, CYTHON_UNUSED PyObject *__pyx_v_frame); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_12_getaddrinfo_callback(PyObject *__pyx_self, PyObject *__pyx_v_result); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_12_getnameinfo_callback(PyObject *__pyx_self, PyObject *__pyx_v_result); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_fut); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_8_get_backend_id(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda1(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_16print_debug_info___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_10__repr__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_12call_soon(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_14call_soon_threadsafe(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_16call_later(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_delay, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_18call_at(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_when, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_20time(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_22stop(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_24run_forever(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_26close(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_28get_debug(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_30set_debug(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_enabled); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_32is_running(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_34is_closed(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_36create_future(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_38create_task(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_coro); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_40set_task_factory(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_factory); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_42get_task_factory(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda2(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_fut); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_44run_until_complete(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_future); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_46getaddrinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_49getnameinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sockaddr, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_52start_tls(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_transport, PyObject *__pyx_v_protocol, PyObject *__pyx_v_sslcontext, PyObject *__pyx_v_server_side, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_ssl_handshake_timeout); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_55create_server(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_flags, PyObject *__pyx_v_sock, PyObject *__pyx_v_backlog, PyObject *__pyx_v_ssl, CYTHON_UNUSED PyObject *__pyx_v_reuse_address, PyObject *__pyx_v_reuse_port, PyObject *__pyx_v_ssl_handshake_timeout); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_17create_connection_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_17create_connection_3genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_58create_connection(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_host, PyObject *__pyx_v_port, PyObject *__pyx_v_ssl, PyObject *__pyx_v_family, PyObject *__pyx_v_proto, PyObject *__pyx_v_flags, PyObject *__pyx_v_sock, PyObject *__pyx_v_local_addr, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_ssl_handshake_timeout); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_61create_unix_server(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_path, PyObject *__pyx_v_backlog, PyObject *__pyx_v_sock, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_64create_unix_connection(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_path, PyObject *__pyx_v_ssl, PyObject *__pyx_v_sock, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_ssl_handshake_timeout); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_67default_exception_handler(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_69get_exception_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_71set_exception_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_handler); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_73call_exception_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_75add_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, PyObject *__pyx_v_callback, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_77remove_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_79add_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, PyObject *__pyx_v_callback, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_81remove_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_83sock_recv(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_n); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_86sock_recv_into(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_buf); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_89sock_sendall(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_92sock_accept(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_95sock_connect(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_address); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_98connect_accepted_socket(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_sock, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_101run_in_executor(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_executor, PyObject *__pyx_v_func, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_103set_default_executor(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_executor); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_105__subprocess_run(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_args, PyObject *__pyx_v_stdin, PyObject *__pyx_v_stdout, PyObject *__pyx_v_stderr, PyObject *__pyx_v_universal_newlines, CYTHON_UNUSED PyObject *__pyx_v_shell, PyObject *__pyx_v_bufsize, PyObject *__pyx_v_preexec_fn, CYTHON_UNUSED PyObject *__pyx_v_close_fds, PyObject *__pyx_v_cwd, PyObject *__pyx_v_env, PyObject *__pyx_v_startupinfo, PyObject *__pyx_v_creationflags, PyObject *__pyx_v_restore_signals, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v_executable, PyObject *__pyx_v_pass_fds, PyObject *__pyx_v___uvloop_sleep_after_fork); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_108subprocess_shell(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_cmd, PyObject *__pyx_v_shell, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_111subprocess_exec(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_program, PyObject *__pyx_v_shell, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_114connect_read_pipe(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_proto_factory, PyObject *__pyx_v_pipe); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_117connect_write_pipe(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_proto_factory, PyObject *__pyx_v_pipe); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_120add_signal_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig, PyObject *__pyx_v_callback, PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_122remove_signal_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_24create_datagram_endpoint_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_124create_datagram_endpoint(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_local_addr, PyObject *__pyx_v_remote_addr, PyObject *__pyx_v_family, PyObject *__pyx_v_proto, PyObject *__pyx_v_flags, PyObject *__pyx_v_reuse_address, PyObject *__pyx_v_reuse_port, PyObject *__pyx_v_allow_broadcast, PyObject *__pyx_v_sock); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_127_asyncgen_finalizer_hook(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_agen); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_129_asyncgen_firstiter_hook(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_agen); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_131shutdown_asyncgens(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static int __pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration_2__set__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration_4__del__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_7_closed___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_9_debug_cc___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_20_debug_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_21_debug_handles_closed___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_22_debug_handles_current___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_uv_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_uv_handles_freed___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_cb_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_cb_handles_count___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_count___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_35_debug_stream_shutdown_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_33_debug_stream_listen_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_27_debug_stream_read_cb_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_34_debug_stream_read_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_28_debug_stream_read_eof_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_38_debug_stream_read_eof_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_31_debug_stream_read_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_25_debug_stream_write_tries___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_32_debug_stream_write_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_29_debug_stream_write_ctx_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_27_debug_stream_write_ctx_cnt___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_35_debug_stream_write_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_poll_read_events_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_26_poll_read_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_24_poll_write_events_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_27_poll_write_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_21_sock_try_write_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_28_debug_exception_handler_cnt___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_134__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_4Loop_136__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketReaderFuture___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_loop); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketReaderFuture_2cancel(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketWriterFuture___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_loop); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketWriterFuture_2cancel(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static int __pyx_pf_6uvloop_4loop_6Handle___cinit__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static void __pyx_pf_6uvloop_4loop_6Handle_2__dealloc__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static int __pyx_pf_6uvloop_4loop_6Handle_4__init__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Handle_6__repr__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Handle_8cancel(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Handle_10cancelled(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Handle_17_source_traceback___get__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Handle_12__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Handle_14__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_11TimerHandle___cinit__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_callback, PyObject *__pyx_v_args, uint64_t __pyx_v_delay, PyObject *__pyx_v_context); /* proto */
static void __pyx_pf_6uvloop_4loop_11TimerHandle_2__dealloc__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_4__repr__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_6cancelled(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_8cancel(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_17_source_traceback___get__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_10__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_12__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_12PseudoSocket___init__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_fd); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_6family___get__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_4type___get__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_5proto___get__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_2__repr__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_4__getstate__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_6fileno(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_8dup(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_10get_inheritable(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_12set_inheritable(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_14ioctl(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_16getsockopt(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_18setsockopt(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_20getpeername(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_22getsockname(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_24share(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_process_id); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_26accept(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_28connect(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_30connect_ex(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_32bind(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_34listen(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_36makefile(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_38sendfile(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_40close(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_42detach(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_44shutdown(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_46sendmsg_afalg(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_48sendmsg(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_50sendto(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_52send(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_54sendall(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_56recv_into(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_58recvfrom_into(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_60recvmsg_into(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_62recvmsg(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_64recvfrom(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_66recv(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_68settimeout(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_70gettimeout(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_72setblocking(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_flag); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_74__enter__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_76__exit__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_err); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_78__reduce_cython__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_80__setstate_cython__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_8UVHandle___cinit__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto */
static int __pyx_pf_6uvloop_4loop_8UVHandle_2__init__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto */
static void __pyx_pf_6uvloop_4loop_8UVHandle_4__dealloc__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_6__repr__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_17_source_traceback___get__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_14UVSocketHandle___cinit__(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_14UVSocketHandle_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_14UVSocketHandle_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_7UVAsync___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_7UVAsync_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6UVIdle___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6UVIdle_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_7UVCheck___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_7UVCheck_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_7UVTimer___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_7UVTimer_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6UVPoll___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6UVPoll_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_15UVBaseTransport___cinit__(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_7_paused___get__(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_2get_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_4set_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_protocol); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_6_force_close(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_8abort(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_10close(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_12is_closing(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_14get_write_buffer_size(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_16set_write_buffer_limits(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_high, PyObject *__pyx_v_low); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_18get_write_buffer_limits(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_20get_extra_info(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_8_closing___get__(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static void __pyx_pf_6uvloop_4loop_19_StreamWriteContext___dealloc__(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_19_StreamWriteContext_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_19_StreamWriteContext_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_8UVStream___cinit__(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_2__repr__(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_4write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_buf); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_6writelines(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_bufs); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_8write_eof(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_10can_write_eof(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_12is_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_14pause_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_16resume_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_18__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_20__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_14UVStreamServer___cinit__(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_14UVStreamServer_2__on_ssl_connected(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, PyObject *__pyx_v_transport, PyObject *__pyx_v_fut); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_14UVStreamServer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_14UVStreamServer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_9TCPServer___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_9TCPServer_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12TCPTransport_get_extra_info(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12TCPTransport_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12TCPTransport_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_18_TCPConnectRequest___cinit__(struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_loop, PyObject *__pyx_v_transport); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18_TCPConnectRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18_TCPConnectRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_10UnixServer___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_10UnixServer_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_13UnixTransport___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_13UnixTransport_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_get_write_buffer_limits(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_2set_write_buffer_limits(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_high, CYTHON_UNUSED PyObject *__pyx_v_low); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_4get_write_buffer_size(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_6write(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_8writelines(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_list_of_data); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_10write_eof(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_12can_write_eof(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_14abort(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_pause_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_2resume_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_19_PipeConnectRequest___cinit__(struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_loop, PyObject *__pyx_v_transport); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_19_PipeConnectRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_19_PipeConnectRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_9UVProcess___cinit__(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_9UVProcess_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_9UVProcess_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_18UVProcessTransport___cinit__(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_2__stdio_inited(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_waiter, PyObject *__pyx_v_stdio_fut); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_4get_protocol(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_6set_protocol(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_protocol); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_8get_pid(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_10get_returncode(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_12get_pipe_transport(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_fd); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_14terminate(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_16kill(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_18send_signal(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_signal); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_20is_closing(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_22close(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_24get_extra_info(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_26_wait(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_proc, PyObject *__pyx_v_fd); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_2connection_made(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_transport); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_6connection_lost(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_8pause_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_10resume_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_23ReadSubprocessPipeProto_data_received(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static int __pyx_pf_6uvloop_4loop_9UVRequest___cinit__(struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, CYTHON_UNUSED PyObject *__pyx_v__); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_9UVRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_9UVRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_8AddrInfo___cinit__(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self); /* proto */
static void __pyx_pf_6uvloop_4loop_8AddrInfo_2__dealloc__(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8AddrInfo_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8AddrInfo_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_15AddrInfoRequest___cinit__(struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags, PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15AddrInfoRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15AddrInfoRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_15NameInfoRequest___cinit__(struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self, CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_callback); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15NameInfoRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_15NameInfoRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_8_SSLPipe___init__(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v_context, PyObject *__pyx_v_server_side, PyObject *__pyx_v_server_hostname); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8_SSLPipe_2__reduce_cython__(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_8_SSLPipe_4__setstate_cython__(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_loop, PyObject *__pyx_v_ssl_protocol); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_2get_extra_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_4set_protocol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_protocol); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_6get_protocol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_8is_closing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_10close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_12__del__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_14is_reading(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_16pause_reading(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_18resume_reading(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_20set_write_buffer_limits(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_high, PyObject *__pyx_v_low); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_22get_write_buffer_size(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_24_protocol_paused(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_26write(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_28can_write_eof(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_30abort(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_loop, PyObject *__pyx_v_app_protocol, PyObject *__pyx_v_sslcontext, PyObject *__pyx_v_waiter, PyObject *__pyx_v_server_side, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_call_connection_made, PyObject *__pyx_v_ssl_handshake_timeout); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_2_set_app_protocol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_app_protocol); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_4_wakeup_waiter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_6connection_made(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_transport); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_8connection_lost(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_10pause_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_12resume_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_14data_received(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_16eof_received(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_18_get_extra_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_20_mark_closed(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_22_start_shutdown(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_24_write_appdata(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_26_start_handshake(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_28_check_handshake_timeout(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_30_on_handshake_complete(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_handshake_exc); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_32_process_write_backlog(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_34_fatal_error(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_message); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_36_finalize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_38_abort(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static int __pyx_pf_6uvloop_4loop_12UDPTransport___cinit__(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12UDPTransport_2sendto(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self, PyObject *__pyx_v_data, PyObject *__pyx_v_addr); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12UDPTransport_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_12UDPTransport_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6uvloop_4loop_6Server___cinit__(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Server_2__repr__(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Server_4get_loop(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Server_6wait_closed(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Server_9close(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Server_7sockets___get__(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Server_11__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_6Server_13__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop__test_coroutine_1(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_3__pyx_unpickle_PseudoSocket(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6uvloop_4loop_5__pyx_unpickle__SSLPipe(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_wrap(PyObject *__pyx_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, int __pyx_v_enabled); /* proto */
static PyObject *__pyx_tp_new_6uvloop_4loop_UVHandle(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVSocketHandle(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVAsync(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVTimer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVIdle(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVBaseTransport(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_Loop(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_Handle(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_TimerHandle(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVCheck(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVPoll(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVStream(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVStreamServer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_TCPServer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_TCPTransport(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UnixServer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UnixTransport(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_ReadUnixTransport(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_WriteUnixTransport(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVProcess(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVProcessTransport(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UVRequest(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_UDPTransport(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_Server(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_PseudoSocket(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop__StreamWriteContext(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop__TCPConnectRequest(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop__PipeConnectRequest(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_AddrInfo(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_AddrInfoRequest(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop_NameInfoRequest(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop__SSLPipe(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct___getaddrinfo(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_1__getnameinfo(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_2__sock_connect(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_3___get__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_4_run_until_complete(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_6_getnameinfo(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_7_start_tls(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_8_create_server(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_9_create_connection(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_10_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_11_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_12_create_unix_server(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_14_sock_recv(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_16_sock_sendall(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_17_sock_accept(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_18_sock_connect(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_20___subprocess_run(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_26_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_28_wait_closed(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop = {0, &__pyx_n_s_pop, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyList_Type_copy = {0, &__pyx_n_s_copy, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyUnicode_Type_rstrip = {0, &__pyx_n_s_rstrip, 0, 0, 0};
static PyObject *__pyx_float_0_1;
static PyObject *__pyx_float_1e3;
static PyObject *__pyx_float_60_0;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_15;
static PyObject *__pyx_int_42;
static PyObject *__pyx_int_100;
static PyObject *__pyx_int_1000;
static PyObject *__pyx_int_50000;
static PyObject *__pyx_int_65536;
static PyObject *__pyx_int_256000;
static PyObject *__pyx_int_1048575;
static PyObject *__pyx_int_59579947;
static PyObject *__pyx_int_143395587;
static PyObject *__pyx_int_3153600000;
static PyObject *__pyx_int_4294967296;
static PyObject *__pyx_int_neg_1;
static int __pyx_k__53;
static int __pyx_k__54;
static PyObject *__pyx_k__101;
static PyObject *__pyx_k__102;
static PyObject *__pyx_k__103;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_slice__96;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__63;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__82;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__85;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__90;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__92;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__94;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__97;
static PyObject *__pyx_tuple__98;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_slice__119;
static PyObject *__pyx_tuple__100;
static PyObject *__pyx_tuple__104;
static PyObject *__pyx_tuple__105;
static PyObject *__pyx_tuple__106;
static PyObject *__pyx_tuple__107;
static PyObject *__pyx_tuple__108;
static PyObject *__pyx_tuple__109;
static PyObject *__pyx_tuple__110;
static PyObject *__pyx_tuple__111;
static PyObject *__pyx_tuple__112;
static PyObject *__pyx_tuple__113;
static PyObject *__pyx_tuple__115;
static PyObject *__pyx_tuple__116;
static PyObject *__pyx_tuple__117;
static PyObject *__pyx_tuple__118;
static PyObject *__pyx_tuple__120;
static PyObject *__pyx_tuple__121;
static PyObject *__pyx_tuple__122;
static PyObject *__pyx_tuple__123;
static PyObject *__pyx_tuple__124;
static PyObject *__pyx_tuple__125;
static PyObject *__pyx_tuple__126;
static PyObject *__pyx_tuple__127;
static PyObject *__pyx_tuple__131;
static PyObject *__pyx_tuple__132;
static PyObject *__pyx_tuple__133;
static PyObject *__pyx_tuple__134;
static PyObject *__pyx_tuple__135;
static PyObject *__pyx_tuple__136;
static PyObject *__pyx_tuple__137;
static PyObject *__pyx_tuple__138;
static PyObject *__pyx_tuple__139;
static PyObject *__pyx_tuple__140;
static PyObject *__pyx_tuple__141;
static PyObject *__pyx_tuple__142;
static PyObject *__pyx_tuple__143;
static PyObject *__pyx_tuple__144;
static PyObject *__pyx_tuple__145;
static PyObject *__pyx_tuple__146;
static PyObject *__pyx_tuple__147;
static PyObject *__pyx_tuple__148;
static PyObject *__pyx_tuple__149;
static PyObject *__pyx_tuple__150;
static PyObject *__pyx_tuple__151;
static PyObject *__pyx_tuple__152;
static PyObject *__pyx_tuple__153;
static PyObject *__pyx_tuple__154;
static PyObject *__pyx_tuple__155;
static PyObject *__pyx_tuple__156;
static PyObject *__pyx_tuple__157;
static PyObject *__pyx_tuple__158;
static PyObject *__pyx_tuple__160;
static PyObject *__pyx_tuple__161;
static PyObject *__pyx_tuple__162;
static PyObject *__pyx_tuple__163;
static PyObject *__pyx_tuple__164;
static PyObject *__pyx_tuple__165;
static PyObject *__pyx_tuple__166;
static PyObject *__pyx_tuple__167;
static PyObject *__pyx_tuple__168;
static PyObject *__pyx_tuple__169;
static PyObject *__pyx_tuple__170;
static PyObject *__pyx_tuple__171;
static PyObject *__pyx_tuple__172;
static PyObject *__pyx_tuple__173;
static PyObject *__pyx_tuple__174;
static PyObject *__pyx_tuple__175;
static PyObject *__pyx_tuple__176;
static PyObject *__pyx_tuple__177;
static PyObject *__pyx_tuple__178;
static PyObject *__pyx_tuple__179;
static PyObject *__pyx_tuple__180;
static PyObject *__pyx_tuple__181;
static PyObject *__pyx_tuple__182;
static PyObject *__pyx_tuple__183;
static PyObject *__pyx_tuple__184;
static PyObject *__pyx_tuple__185;
static PyObject *__pyx_tuple__186;
static PyObject *__pyx_tuple__187;
static PyObject *__pyx_tuple__188;
static PyObject *__pyx_tuple__189;
static PyObject *__pyx_tuple__190;
static PyObject *__pyx_tuple__191;
static PyObject *__pyx_tuple__192;
static PyObject *__pyx_tuple__193;
static PyObject *__pyx_tuple__194;
static PyObject *__pyx_tuple__195;
static PyObject *__pyx_tuple__196;
static PyObject *__pyx_tuple__197;
static PyObject *__pyx_tuple__198;
static PyObject *__pyx_tuple__199;
static PyObject *__pyx_tuple__200;
static PyObject *__pyx_tuple__201;
static PyObject *__pyx_tuple__202;
static PyObject *__pyx_tuple__203;
static PyObject *__pyx_tuple__204;
static PyObject *__pyx_tuple__205;
static PyObject *__pyx_tuple__206;
static PyObject *__pyx_tuple__207;
static PyObject *__pyx_tuple__208;
static PyObject *__pyx_tuple__210;
static PyObject *__pyx_tuple__211;
static PyObject *__pyx_tuple__212;
static PyObject *__pyx_tuple__213;
static PyObject *__pyx_tuple__214;
static PyObject *__pyx_tuple__215;
static PyObject *__pyx_tuple__216;
static PyObject *__pyx_tuple__217;
static PyObject *__pyx_tuple__218;
static PyObject *__pyx_tuple__219;
static PyObject *__pyx_tuple__221;
static PyObject *__pyx_tuple__222;
static PyObject *__pyx_tuple__223;
static PyObject *__pyx_tuple__224;
static PyObject *__pyx_tuple__225;
static PyObject *__pyx_tuple__226;
static PyObject *__pyx_tuple__227;
static PyObject *__pyx_tuple__228;
static PyObject *__pyx_tuple__229;
static PyObject *__pyx_tuple__230;
static PyObject *__pyx_tuple__231;
static PyObject *__pyx_tuple__232;
static PyObject *__pyx_tuple__233;
static PyObject *__pyx_tuple__234;
static PyObject *__pyx_tuple__235;
static PyObject *__pyx_tuple__236;
static PyObject *__pyx_tuple__237;
static PyObject *__pyx_tuple__238;
static PyObject *__pyx_tuple__239;
static PyObject *__pyx_tuple__240;
static PyObject *__pyx_tuple__241;
static PyObject *__pyx_tuple__242;
static PyObject *__pyx_tuple__243;
static PyObject *__pyx_tuple__244;
static PyObject *__pyx_tuple__245;
static PyObject *__pyx_tuple__246;
static PyObject *__pyx_tuple__247;
static PyObject *__pyx_tuple__248;
static PyObject *__pyx_tuple__249;
static PyObject *__pyx_tuple__250;
static PyObject *__pyx_tuple__251;
static PyObject *__pyx_tuple__252;
static PyObject *__pyx_tuple__253;
static PyObject *__pyx_tuple__254;
static PyObject *__pyx_tuple__255;
static PyObject *__pyx_tuple__256;
static PyObject *__pyx_tuple__257;
static PyObject *__pyx_tuple__258;
static PyObject *__pyx_tuple__259;
static PyObject *__pyx_tuple__260;
static PyObject *__pyx_tuple__261;
static PyObject *__pyx_tuple__262;
static PyObject *__pyx_tuple__263;
static PyObject *__pyx_tuple__264;
static PyObject *__pyx_tuple__265;
static PyObject *__pyx_tuple__266;
static PyObject *__pyx_tuple__267;
static PyObject *__pyx_tuple__268;
static PyObject *__pyx_tuple__269;
static PyObject *__pyx_tuple__271;
static PyObject *__pyx_tuple__273;
static PyObject *__pyx_tuple__275;
static PyObject *__pyx_tuple__277;
static PyObject *__pyx_tuple__279;
static PyObject *__pyx_tuple__281;
static PyObject *__pyx_tuple__283;
static PyObject *__pyx_tuple__285;
static PyObject *__pyx_tuple__287;
static PyObject *__pyx_tuple__289;
static PyObject *__pyx_tuple__291;
static PyObject *__pyx_tuple__293;
static PyObject *__pyx_tuple__295;
static PyObject *__pyx_tuple__297;
static PyObject *__pyx_tuple__299;
static PyObject *__pyx_tuple__300;
static PyObject *__pyx_tuple__302;
static PyObject *__pyx_tuple__304;
static PyObject *__pyx_tuple__306;
static PyObject *__pyx_tuple__308;
static PyObject *__pyx_tuple__310;
static PyObject *__pyx_tuple__312;
static PyObject *__pyx_tuple__314;
static PyObject *__pyx_tuple__316;
static PyObject *__pyx_tuple__318;
static PyObject *__pyx_tuple__319;
static PyObject *__pyx_tuple__321;
static PyObject *__pyx_tuple__323;
static PyObject *__pyx_tuple__325;
static PyObject *__pyx_tuple__327;
static PyObject *__pyx_tuple__329;
static PyObject *__pyx_tuple__330;
static PyObject *__pyx_tuple__332;
static PyObject *__pyx_tuple__333;
static PyObject *__pyx_tuple__335;
static PyObject *__pyx_tuple__337;
static PyObject *__pyx_tuple__338;
static PyObject *__pyx_tuple__340;
static PyObject *__pyx_tuple__342;
static PyObject *__pyx_tuple__344;
static PyObject *__pyx_tuple__346;
static PyObject *__pyx_tuple__348;
static PyObject *__pyx_tuple__350;
static PyObject *__pyx_tuple__352;
static PyObject *__pyx_tuple__353;
static PyObject *__pyx_tuple__355;
static PyObject *__pyx_tuple__357;
static PyObject *__pyx_tuple__359;
static PyObject *__pyx_tuple__361;
static PyObject *__pyx_tuple__363;
static PyObject *__pyx_tuple__365;
static PyObject *__pyx_tuple__367;
static PyObject *__pyx_tuple__369;
static PyObject *__pyx_tuple__370;
static PyObject *__pyx_tuple__372;
static PyObject *__pyx_tuple__374;
static PyObject *__pyx_tuple__376;
static PyObject *__pyx_codeobj__22;
static PyObject *__pyx_codeobj__24;
static PyObject *__pyx_codeobj__270;
static PyObject *__pyx_codeobj__272;
static PyObject *__pyx_codeobj__274;
static PyObject *__pyx_codeobj__276;
static PyObject *__pyx_codeobj__278;
static PyObject *__pyx_codeobj__280;
static PyObject *__pyx_codeobj__282;
static PyObject *__pyx_codeobj__284;
static PyObject *__pyx_codeobj__286;
static PyObject *__pyx_codeobj__288;
static PyObject *__pyx_codeobj__290;
static PyObject *__pyx_codeobj__292;
static PyObject *__pyx_codeobj__294;
static PyObject *__pyx_codeobj__296;
static PyObject *__pyx_codeobj__298;
static PyObject *__pyx_codeobj__301;
static PyObject *__pyx_codeobj__303;
static PyObject *__pyx_codeobj__305;
static PyObject *__pyx_codeobj__307;
static PyObject *__pyx_codeobj__309;
static PyObject *__pyx_codeobj__311;
static PyObject *__pyx_codeobj__313;
static PyObject *__pyx_codeobj__315;
static PyObject *__pyx_codeobj__317;
static PyObject *__pyx_codeobj__320;
static PyObject *__pyx_codeobj__322;
static PyObject *__pyx_codeobj__324;
static PyObject *__pyx_codeobj__326;
static PyObject *__pyx_codeobj__328;
static PyObject *__pyx_codeobj__331;
static PyObject *__pyx_codeobj__334;
static PyObject *__pyx_codeobj__336;
static PyObject *__pyx_codeobj__339;
static PyObject *__pyx_codeobj__341;
static PyObject *__pyx_codeobj__343;
static PyObject *__pyx_codeobj__345;
static PyObject *__pyx_codeobj__347;
static PyObject *__pyx_codeobj__349;
static PyObject *__pyx_codeobj__351;
static PyObject *__pyx_codeobj__354;
static PyObject *__pyx_codeobj__356;
static PyObject *__pyx_codeobj__358;
static PyObject *__pyx_codeobj__360;
static PyObject *__pyx_codeobj__362;
static PyObject *__pyx_codeobj__364;
static PyObject *__pyx_codeobj__366;
static PyObject *__pyx_codeobj__368;
static PyObject *__pyx_codeobj__371;
static PyObject *__pyx_codeobj__373;
static PyObject *__pyx_codeobj__375;
static PyObject *__pyx_codeobj__377;
/* Late includes */

/* "uvloop/errors.pyx":1
 * cdef str __strerr(int errno):             # <<<<<<<<<<<<<<
 *     return strerror(errno).decode()
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop___strerr(int __pyx_v_errno) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__strerr", 0);

  /* "uvloop/errors.pyx":2
 * cdef str __strerr(int errno):
 *     return strerror(errno).decode()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = strerror(__pyx_v_errno);
  __pyx_t_2 = __Pyx_decode_c_string(__pyx_t_1, 0, strlen(__pyx_t_1), NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_INCREF(__pyx_t_2);
  __pyx_r = ((PyObject*)__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/errors.pyx":1
 * cdef str __strerr(int errno):             # <<<<<<<<<<<<<<
 *     return strerror(errno).decode()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__strerr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/errors.pyx":5
 * 
 * 
 * cdef __convert_python_error(int uverr):             # <<<<<<<<<<<<<<
 *     # XXX Won't work for Windows:
 *     # From libuv docs:
 */

static PyObject *__pyx_f_6uvloop_4loop___convert_python_error(int __pyx_v_uverr) {
  int __pyx_v_oserr;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("__convert_python_error", 0);

  /* "uvloop/errors.pyx":11
 *     #      negated errno (or -errno), while on Windows they
 *     #      are defined by libuv to arbitrary negative numbers.
 *     cdef int oserr = -uverr             # <<<<<<<<<<<<<<
 * 
 *     exc = OSError
 */
  __pyx_v_oserr = (-__pyx_v_uverr);

  /* "uvloop/errors.pyx":13
 *     cdef int oserr = -uverr
 * 
 *     exc = OSError             # <<<<<<<<<<<<<<
 * 
 *     if uverr in (uv.UV_EACCES, uv.UV_EPERM):
 */
  __Pyx_INCREF(__pyx_builtin_OSError);
  __pyx_v_exc = __pyx_builtin_OSError;

  /* "uvloop/errors.pyx":15
 *     exc = OSError
 * 
 *     if uverr in (uv.UV_EACCES, uv.UV_EPERM):             # <<<<<<<<<<<<<<
 *         exc = PermissionError
 * 
 */
  __pyx_t_1 = __pyx_v_uverr;
  __pyx_t_3 = ((__pyx_t_1 == UV_EACCES) != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_t_1 == UV_EPERM) != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":16
 * 
 *     if uverr in (uv.UV_EACCES, uv.UV_EPERM):
 *         exc = PermissionError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr in (uv.UV_EAGAIN, uv.UV_EALREADY):
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_PermissionError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 16, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":15
 *     exc = OSError
 * 
 *     if uverr in (uv.UV_EACCES, uv.UV_EPERM):             # <<<<<<<<<<<<<<
 *         exc = PermissionError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":18
 *         exc = PermissionError
 * 
 *     elif uverr in (uv.UV_EAGAIN, uv.UV_EALREADY):             # <<<<<<<<<<<<<<
 *         exc = BlockingIOError
 * 
 */
  __pyx_t_1 = __pyx_v_uverr;
  __pyx_t_2 = ((__pyx_t_1 == UV_EAGAIN) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_3 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_t_1 == UV_EALREADY) != 0);
  __pyx_t_3 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "uvloop/errors.pyx":19
 * 
 *     elif uverr in (uv.UV_EAGAIN, uv.UV_EALREADY):
 *         exc = BlockingIOError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr in (uv.UV_EPIPE, uv.UV_ESHUTDOWN):
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 19, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":18
 *         exc = PermissionError
 * 
 *     elif uverr in (uv.UV_EAGAIN, uv.UV_EALREADY):             # <<<<<<<<<<<<<<
 *         exc = BlockingIOError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":21
 *         exc = BlockingIOError
 * 
 *     elif uverr in (uv.UV_EPIPE, uv.UV_ESHUTDOWN):             # <<<<<<<<<<<<<<
 *         exc = BrokenPipeError
 * 
 */
  __pyx_t_1 = __pyx_v_uverr;
  __pyx_t_3 = ((__pyx_t_1 == UV_EPIPE) != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_t_1 == UV_ESHUTDOWN) != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L8_bool_binop_done:;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":22
 * 
 *     elif uverr in (uv.UV_EPIPE, uv.UV_ESHUTDOWN):
 *         exc = BrokenPipeError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_ECONNABORTED:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_BrokenPipeError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 22, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":21
 *         exc = BlockingIOError
 * 
 *     elif uverr in (uv.UV_EPIPE, uv.UV_ESHUTDOWN):             # <<<<<<<<<<<<<<
 *         exc = BrokenPipeError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":24
 *         exc = BrokenPipeError
 * 
 *     elif uverr == uv.UV_ECONNABORTED:             # <<<<<<<<<<<<<<
 *         exc = ConnectionAbortedError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_ECONNABORTED) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":25
 * 
 *     elif uverr == uv.UV_ECONNABORTED:
 *         exc = ConnectionAbortedError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_ECONNREFUSED:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionAbortedError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 25, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":24
 *         exc = BrokenPipeError
 * 
 *     elif uverr == uv.UV_ECONNABORTED:             # <<<<<<<<<<<<<<
 *         exc = ConnectionAbortedError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":27
 *         exc = ConnectionAbortedError
 * 
 *     elif uverr == uv.UV_ECONNREFUSED:             # <<<<<<<<<<<<<<
 *         exc = ConnectionRefusedError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_ECONNREFUSED) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":28
 * 
 *     elif uverr == uv.UV_ECONNREFUSED:
 *         exc = ConnectionRefusedError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_ECONNRESET:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionRefusedError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 28, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":27
 *         exc = ConnectionAbortedError
 * 
 *     elif uverr == uv.UV_ECONNREFUSED:             # <<<<<<<<<<<<<<
 *         exc = ConnectionRefusedError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":30
 *         exc = ConnectionRefusedError
 * 
 *     elif uverr == uv.UV_ECONNRESET:             # <<<<<<<<<<<<<<
 *         exc = ConnectionResetError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_ECONNRESET) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":31
 * 
 *     elif uverr == uv.UV_ECONNRESET:
 *         exc = ConnectionResetError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EEXIST:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionResetError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 31, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":30
 *         exc = ConnectionRefusedError
 * 
 *     elif uverr == uv.UV_ECONNRESET:             # <<<<<<<<<<<<<<
 *         exc = ConnectionResetError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":33
 *         exc = ConnectionResetError
 * 
 *     elif uverr == uv.UV_EEXIST:             # <<<<<<<<<<<<<<
 *         exc = FileExistsError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_EEXIST) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":34
 * 
 *     elif uverr == uv.UV_EEXIST:
 *         exc = FileExistsError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_ENOENT:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_FileExistsError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":33
 *         exc = ConnectionResetError
 * 
 *     elif uverr == uv.UV_EEXIST:             # <<<<<<<<<<<<<<
 *         exc = FileExistsError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":36
 *         exc = FileExistsError
 * 
 *     elif uverr == uv.UV_ENOENT:             # <<<<<<<<<<<<<<
 *         exc = FileNotFoundError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_ENOENT) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":37
 * 
 *     elif uverr == uv.UV_ENOENT:
 *         exc = FileNotFoundError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EINTR:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_FileNotFoundError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":36
 *         exc = FileExistsError
 * 
 *     elif uverr == uv.UV_ENOENT:             # <<<<<<<<<<<<<<
 *         exc = FileNotFoundError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":39
 *         exc = FileNotFoundError
 * 
 *     elif uverr == uv.UV_EINTR:             # <<<<<<<<<<<<<<
 *         exc = InterruptedError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_EINTR) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":40
 * 
 *     elif uverr == uv.UV_EINTR:
 *         exc = InterruptedError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EISDIR:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 40, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":39
 *         exc = FileNotFoundError
 * 
 *     elif uverr == uv.UV_EINTR:             # <<<<<<<<<<<<<<
 *         exc = InterruptedError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":42
 *         exc = InterruptedError
 * 
 *     elif uverr == uv.UV_EISDIR:             # <<<<<<<<<<<<<<
 *         exc = IsADirectoryError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_EISDIR) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":43
 * 
 *     elif uverr == uv.UV_EISDIR:
 *         exc = IsADirectoryError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_ESRCH:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_IsADirectoryError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":42
 *         exc = InterruptedError
 * 
 *     elif uverr == uv.UV_EISDIR:             # <<<<<<<<<<<<<<
 *         exc = IsADirectoryError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":45
 *         exc = IsADirectoryError
 * 
 *     elif uverr == uv.UV_ESRCH:             # <<<<<<<<<<<<<<
 *         exc = ProcessLookupError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_ESRCH) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":46
 * 
 *     elif uverr == uv.UV_ESRCH:
 *         exc = ProcessLookupError             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_ETIMEDOUT:
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ProcessLookupError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":45
 *         exc = IsADirectoryError
 * 
 *     elif uverr == uv.UV_ESRCH:             # <<<<<<<<<<<<<<
 *         exc = ProcessLookupError
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":48
 *         exc = ProcessLookupError
 * 
 *     elif uverr == uv.UV_ETIMEDOUT:             # <<<<<<<<<<<<<<
 *         exc = TimeoutError
 * 
 */
  __pyx_t_3 = ((__pyx_v_uverr == UV_ETIMEDOUT) != 0);
  if (__pyx_t_3) {

    /* "uvloop/errors.pyx":49
 * 
 *     elif uverr == uv.UV_ETIMEDOUT:
 *         exc = TimeoutError             # <<<<<<<<<<<<<<
 * 
 *     return exc(oserr, __strerr(oserr))
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_TimeoutError); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_exc, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/errors.pyx":48
 *         exc = ProcessLookupError
 * 
 *     elif uverr == uv.UV_ETIMEDOUT:             # <<<<<<<<<<<<<<
 *         exc = TimeoutError
 * 
 */
  }
  __pyx_L3:;

  /* "uvloop/errors.pyx":51
 *         exc = TimeoutError
 * 
 *     return exc(oserr, __strerr(oserr))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_oserr); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __pyx_f_6uvloop_4loop___strerr(__pyx_v_oserr); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_exc);
  __pyx_t_7 = __pyx_v_exc; __pyx_t_8 = NULL;
  __pyx_t_1 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_1 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_5, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_1, 2+__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 51, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_5, __pyx_t_6};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_1, 2+__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 51, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_1, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_1, __pyx_t_6);
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "uvloop/errors.pyx":5
 * 
 * 
 * cdef __convert_python_error(int uverr):             # <<<<<<<<<<<<<<
 *     # XXX Won't work for Windows:
 *     # From libuv docs:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.__convert_python_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/errors.pyx":54
 * 
 * 
 * cdef int __convert_socket_error(int uverr):             # <<<<<<<<<<<<<<
 *     cdef int sock_err = 0
 * 
 */

static int __pyx_f_6uvloop_4loop___convert_socket_error(int __pyx_v_uverr) {
  int __pyx_v_sock_err;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__convert_socket_error", 0);

  /* "uvloop/errors.pyx":55
 * 
 * cdef int __convert_socket_error(int uverr):
 *     cdef int sock_err = 0             # <<<<<<<<<<<<<<
 * 
 *     if uverr == uv.UV_EAI_ADDRFAMILY:
 */
  __pyx_v_sock_err = 0;

  /* "uvloop/errors.pyx":57
 *     cdef int sock_err = 0
 * 
 *     if uverr == uv.UV_EAI_ADDRFAMILY:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_ADDRFAMILY
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_ADDRFAMILY) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":58
 * 
 *     if uverr == uv.UV_EAI_ADDRFAMILY:
 *         sock_err = socket_EAI_ADDRFAMILY             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_AGAIN:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_ADDRFAMILY;

    /* "uvloop/errors.pyx":57
 *     cdef int sock_err = 0
 * 
 *     if uverr == uv.UV_EAI_ADDRFAMILY:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_ADDRFAMILY
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":60
 *         sock_err = socket_EAI_ADDRFAMILY
 * 
 *     elif uverr == uv.UV_EAI_AGAIN:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_AGAIN
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_AGAIN) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":61
 * 
 *     elif uverr == uv.UV_EAI_AGAIN:
 *         sock_err = socket_EAI_AGAIN             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_BADFLAGS:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_AGAIN;

    /* "uvloop/errors.pyx":60
 *         sock_err = socket_EAI_ADDRFAMILY
 * 
 *     elif uverr == uv.UV_EAI_AGAIN:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_AGAIN
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":63
 *         sock_err = socket_EAI_AGAIN
 * 
 *     elif uverr == uv.UV_EAI_BADFLAGS:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_BADFLAGS
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_BADFLAGS) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":64
 * 
 *     elif uverr == uv.UV_EAI_BADFLAGS:
 *         sock_err = socket_EAI_BADFLAGS             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_BADHINTS:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_BADFLAGS;

    /* "uvloop/errors.pyx":63
 *         sock_err = socket_EAI_AGAIN
 * 
 *     elif uverr == uv.UV_EAI_BADFLAGS:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_BADFLAGS
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":66
 *         sock_err = socket_EAI_BADFLAGS
 * 
 *     elif uverr == uv.UV_EAI_BADHINTS:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_BADHINTS
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_BADHINTS) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":67
 * 
 *     elif uverr == uv.UV_EAI_BADHINTS:
 *         sock_err = socket_EAI_BADHINTS             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_CANCELED:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_BADHINTS;

    /* "uvloop/errors.pyx":66
 *         sock_err = socket_EAI_BADFLAGS
 * 
 *     elif uverr == uv.UV_EAI_BADHINTS:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_BADHINTS
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":69
 *         sock_err = socket_EAI_BADHINTS
 * 
 *     elif uverr == uv.UV_EAI_CANCELED:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_CANCELED
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_CANCELED) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":70
 * 
 *     elif uverr == uv.UV_EAI_CANCELED:
 *         sock_err = socket_EAI_CANCELED             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_FAIL:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_CANCELED;

    /* "uvloop/errors.pyx":69
 *         sock_err = socket_EAI_BADHINTS
 * 
 *     elif uverr == uv.UV_EAI_CANCELED:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_CANCELED
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":72
 *         sock_err = socket_EAI_CANCELED
 * 
 *     elif uverr == uv.UV_EAI_FAIL:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_FAIL
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_FAIL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":73
 * 
 *     elif uverr == uv.UV_EAI_FAIL:
 *         sock_err = socket_EAI_FAIL             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_FAMILY:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_FAIL;

    /* "uvloop/errors.pyx":72
 *         sock_err = socket_EAI_CANCELED
 * 
 *     elif uverr == uv.UV_EAI_FAIL:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_FAIL
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":75
 *         sock_err = socket_EAI_FAIL
 * 
 *     elif uverr == uv.UV_EAI_FAMILY:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_FAMILY
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_FAMILY) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":76
 * 
 *     elif uverr == uv.UV_EAI_FAMILY:
 *         sock_err = socket_EAI_FAMILY             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_MEMORY:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_FAMILY;

    /* "uvloop/errors.pyx":75
 *         sock_err = socket_EAI_FAIL
 * 
 *     elif uverr == uv.UV_EAI_FAMILY:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_FAMILY
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":78
 *         sock_err = socket_EAI_FAMILY
 * 
 *     elif uverr == uv.UV_EAI_MEMORY:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_MEMORY
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_MEMORY) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":79
 * 
 *     elif uverr == uv.UV_EAI_MEMORY:
 *         sock_err = socket_EAI_MEMORY             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_NODATA:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_MEMORY;

    /* "uvloop/errors.pyx":78
 *         sock_err = socket_EAI_FAMILY
 * 
 *     elif uverr == uv.UV_EAI_MEMORY:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_MEMORY
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":81
 *         sock_err = socket_EAI_MEMORY
 * 
 *     elif uverr == uv.UV_EAI_NODATA:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_NODATA
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_NODATA) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":82
 * 
 *     elif uverr == uv.UV_EAI_NODATA:
 *         sock_err = socket_EAI_NODATA             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_NONAME:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_NODATA;

    /* "uvloop/errors.pyx":81
 *         sock_err = socket_EAI_MEMORY
 * 
 *     elif uverr == uv.UV_EAI_NODATA:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_NODATA
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":84
 *         sock_err = socket_EAI_NODATA
 * 
 *     elif uverr == uv.UV_EAI_NONAME:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_NONAME
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_NONAME) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":85
 * 
 *     elif uverr == uv.UV_EAI_NONAME:
 *         sock_err = socket_EAI_NONAME             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_OVERFLOW:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_NONAME;

    /* "uvloop/errors.pyx":84
 *         sock_err = socket_EAI_NODATA
 * 
 *     elif uverr == uv.UV_EAI_NONAME:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_NONAME
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":87
 *         sock_err = socket_EAI_NONAME
 * 
 *     elif uverr == uv.UV_EAI_OVERFLOW:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_OVERFLOW
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_OVERFLOW) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":88
 * 
 *     elif uverr == uv.UV_EAI_OVERFLOW:
 *         sock_err = socket_EAI_OVERFLOW             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_PROTOCOL:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_OVERFLOW;

    /* "uvloop/errors.pyx":87
 *         sock_err = socket_EAI_NONAME
 * 
 *     elif uverr == uv.UV_EAI_OVERFLOW:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_OVERFLOW
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":90
 *         sock_err = socket_EAI_OVERFLOW
 * 
 *     elif uverr == uv.UV_EAI_PROTOCOL:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_PROTOCOL
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_PROTOCOL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":91
 * 
 *     elif uverr == uv.UV_EAI_PROTOCOL:
 *         sock_err = socket_EAI_PROTOCOL             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_SERVICE:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_PROTOCOL;

    /* "uvloop/errors.pyx":90
 *         sock_err = socket_EAI_OVERFLOW
 * 
 *     elif uverr == uv.UV_EAI_PROTOCOL:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_PROTOCOL
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":93
 *         sock_err = socket_EAI_PROTOCOL
 * 
 *     elif uverr == uv.UV_EAI_SERVICE:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_SERVICE
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_SERVICE) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":94
 * 
 *     elif uverr == uv.UV_EAI_SERVICE:
 *         sock_err = socket_EAI_SERVICE             # <<<<<<<<<<<<<<
 * 
 *     elif uverr == uv.UV_EAI_SOCKTYPE:
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_SERVICE;

    /* "uvloop/errors.pyx":93
 *         sock_err = socket_EAI_PROTOCOL
 * 
 *     elif uverr == uv.UV_EAI_SERVICE:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_SERVICE
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/errors.pyx":96
 *         sock_err = socket_EAI_SERVICE
 * 
 *     elif uverr == uv.UV_EAI_SOCKTYPE:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_SOCKTYPE
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_EAI_SOCKTYPE) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":97
 * 
 *     elif uverr == uv.UV_EAI_SOCKTYPE:
 *         sock_err = socket_EAI_SOCKTYPE             # <<<<<<<<<<<<<<
 * 
 *     return sock_err
 */
    __pyx_v_sock_err = __pyx_v_6uvloop_4loop_socket_EAI_SOCKTYPE;

    /* "uvloop/errors.pyx":96
 *         sock_err = socket_EAI_SERVICE
 * 
 *     elif uverr == uv.UV_EAI_SOCKTYPE:             # <<<<<<<<<<<<<<
 *         sock_err = socket_EAI_SOCKTYPE
 * 
 */
  }
  __pyx_L3:;

  /* "uvloop/errors.pyx":99
 *         sock_err = socket_EAI_SOCKTYPE
 * 
 *     return sock_err             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_sock_err;
  goto __pyx_L0;

  /* "uvloop/errors.pyx":54
 * 
 * 
 * cdef int __convert_socket_error(int uverr):             # <<<<<<<<<<<<<<
 *     cdef int sock_err = 0
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/errors.pyx":102
 * 
 * 
 * cdef convert_error(int uverr):             # <<<<<<<<<<<<<<
 *     cdef int sock_err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_convert_error(int __pyx_v_uverr) {
  int __pyx_v_sock_err;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char const *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("convert_error", 0);

  /* "uvloop/errors.pyx":105
 *     cdef int sock_err
 * 
 *     if uverr == uv.UV_ECANCELED:             # <<<<<<<<<<<<<<
 *         return aio_CancelledError()
 * 
 */
  __pyx_t_1 = ((__pyx_v_uverr == UV_ECANCELED) != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":106
 * 
 *     if uverr == uv.UV_ECANCELED:
 *         return aio_CancelledError()             # <<<<<<<<<<<<<<
 * 
 *     sock_err = __convert_socket_error(uverr)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_CancelledError);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_CancelledError; __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 106, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 106, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "uvloop/errors.pyx":105
 *     cdef int sock_err
 * 
 *     if uverr == uv.UV_ECANCELED:             # <<<<<<<<<<<<<<
 *         return aio_CancelledError()
 * 
 */
  }

  /* "uvloop/errors.pyx":108
 *         return aio_CancelledError()
 * 
 *     sock_err = __convert_socket_error(uverr)             # <<<<<<<<<<<<<<
 *     if sock_err:
 *         msg = system.gai_strerror(sock_err).decode('utf-8')
 */
  __pyx_v_sock_err = __pyx_f_6uvloop_4loop___convert_socket_error(__pyx_v_uverr);

  /* "uvloop/errors.pyx":109
 * 
 *     sock_err = __convert_socket_error(uverr)
 *     if sock_err:             # <<<<<<<<<<<<<<
 *         msg = system.gai_strerror(sock_err).decode('utf-8')
 *         return socket_gaierror(sock_err, msg)
 */
  __pyx_t_1 = (__pyx_v_sock_err != 0);
  if (__pyx_t_1) {

    /* "uvloop/errors.pyx":110
 *     sock_err = __convert_socket_error(uverr)
 *     if sock_err:
 *         msg = system.gai_strerror(sock_err).decode('utf-8')             # <<<<<<<<<<<<<<
 *         return socket_gaierror(sock_err, msg)
 * 
 */
    __pyx_t_5 = gai_strerror(__pyx_v_sock_err);
    __pyx_t_2 = __Pyx_decode_c_string(__pyx_t_5, 0, strlen(__pyx_t_5), NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_msg = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/errors.pyx":111
 *     if sock_err:
 *         msg = system.gai_strerror(sock_err).decode('utf-8')
 *         return socket_gaierror(sock_err, msg)             # <<<<<<<<<<<<<<
 * 
 *     return __convert_python_error(uverr)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_sock_err); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_gaierror);
    __pyx_t_4 = __pyx_v_6uvloop_4loop_socket_gaierror; __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_3, __pyx_v_msg};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 111, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_3, __pyx_v_msg};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 111, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_3);
      __Pyx_INCREF(__pyx_v_msg);
      __Pyx_GIVEREF(__pyx_v_msg);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_msg);
      __pyx_t_3 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 111, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "uvloop/errors.pyx":109
 * 
 *     sock_err = __convert_socket_error(uverr)
 *     if sock_err:             # <<<<<<<<<<<<<<
 *         msg = system.gai_strerror(sock_err).decode('utf-8')
 *         return socket_gaierror(sock_err, msg)
 */
  }

  /* "uvloop/errors.pyx":113
 *         return socket_gaierror(sock_err, msg)
 * 
 *     return __convert_python_error(uverr)             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_f_6uvloop_4loop___convert_python_error(__pyx_v_uverr); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/errors.pyx":102
 * 
 * 
 * cdef convert_error(int uverr):             # <<<<<<<<<<<<<<
 *     cdef int sock_err
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.convert_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":48
 * 
 * 
 * cdef _is_sock_stream(sock_type):             # <<<<<<<<<<<<<<
 *     if SOCK_NONBLOCK == -1:
 *         return sock_type == uv.SOCK_STREAM
 */

static PyObject *__pyx_f_6uvloop_4loop__is_sock_stream(PyObject *__pyx_v_sock_type) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_is_sock_stream", 0);

  /* "uvloop/loop.pyx":49
 * 
 * cdef _is_sock_stream(sock_type):
 *     if SOCK_NONBLOCK == -1:             # <<<<<<<<<<<<<<
 *         return sock_type == uv.SOCK_STREAM
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_6uvloop_4loop_SOCK_NONBLOCK == -1L) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":50
 * cdef _is_sock_stream(sock_type):
 *     if SOCK_NONBLOCK == -1:
 *         return sock_type == uv.SOCK_STREAM             # <<<<<<<<<<<<<<
 *     else:
 *         # Linux's socket.type is a bitmask that can include extra info
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_int(SOCK_STREAM); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_sock_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 50, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":49
 * 
 * cdef _is_sock_stream(sock_type):
 *     if SOCK_NONBLOCK == -1:             # <<<<<<<<<<<<<<
 *         return sock_type == uv.SOCK_STREAM
 *     else:
 */
  }

  /* "uvloop/loop.pyx":57
 *         # https://github.com/torvalds/linux/blob/v4.13/include/linux/net.h#L77
 *         # for more details.
 *         return (sock_type & 0xF) == uv.SOCK_STREAM             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_AndObjC(__pyx_v_sock_type, __pyx_int_15, 0xF, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyInt_From_int(SOCK_STREAM); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 57, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "uvloop/loop.pyx":48
 * 
 * 
 * cdef _is_sock_stream(sock_type):             # <<<<<<<<<<<<<<
 *     if SOCK_NONBLOCK == -1:
 *         return sock_type == uv.SOCK_STREAM
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop._is_sock_stream", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":60
 * 
 * 
 * cdef _is_sock_dgram(sock_type):             # <<<<<<<<<<<<<<
 *     if SOCK_NONBLOCK == -1:
 *         return sock_type == uv.SOCK_DGRAM
 */

static PyObject *__pyx_f_6uvloop_4loop__is_sock_dgram(PyObject *__pyx_v_sock_type) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_is_sock_dgram", 0);

  /* "uvloop/loop.pyx":61
 * 
 * cdef _is_sock_dgram(sock_type):
 *     if SOCK_NONBLOCK == -1:             # <<<<<<<<<<<<<<
 *         return sock_type == uv.SOCK_DGRAM
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_6uvloop_4loop_SOCK_NONBLOCK == -1L) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":62
 * cdef _is_sock_dgram(sock_type):
 *     if SOCK_NONBLOCK == -1:
 *         return sock_type == uv.SOCK_DGRAM             # <<<<<<<<<<<<<<
 *     else:
 *         # Read the comment in `_is_sock_stream`.
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyInt_From_int(SOCK_DGRAM); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_sock_type, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 62, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":61
 * 
 * cdef _is_sock_dgram(sock_type):
 *     if SOCK_NONBLOCK == -1:             # <<<<<<<<<<<<<<
 *         return sock_type == uv.SOCK_DGRAM
 *     else:
 */
  }

  /* "uvloop/loop.pyx":65
 *     else:
 *         # Read the comment in `_is_sock_stream`.
 *         return (sock_type & 0xF) == uv.SOCK_DGRAM             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyInt_AndObjC(__pyx_v_sock_type, __pyx_int_15, 0xF, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyInt_From_int(SOCK_DGRAM); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 65, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "uvloop/loop.pyx":60
 * 
 * 
 * cdef _is_sock_dgram(sock_type):             # <<<<<<<<<<<<<<
 *     if SOCK_NONBLOCK == -1:
 *         return sock_type == uv.SOCK_DGRAM
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop._is_sock_dgram", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":68
 * 
 * 
 * cdef isfuture(obj):             # <<<<<<<<<<<<<<
 *     if aio_isfuture is None:
 *         return isinstance(obj, aio_Future)
 */

static PyObject *__pyx_f_6uvloop_4loop_isfuture(PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("isfuture", 0);

  /* "uvloop/loop.pyx":69
 * 
 * cdef isfuture(obj):
 *     if aio_isfuture is None:             # <<<<<<<<<<<<<<
 *         return isinstance(obj, aio_Future)
 *     else:
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop_aio_isfuture == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":70
 * cdef isfuture(obj):
 *     if aio_isfuture is None:
 *         return isinstance(obj, aio_Future)             # <<<<<<<<<<<<<<
 *     else:
 *         return aio_isfuture(obj)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_Future;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 70, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":69
 * 
 * cdef isfuture(obj):
 *     if aio_isfuture is None:             # <<<<<<<<<<<<<<
 *         return isinstance(obj, aio_Future)
 *     else:
 */
  }

  /* "uvloop/loop.pyx":72
 *         return isinstance(obj, aio_Future)
 *     else:
 *         return aio_isfuture(obj)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_isfuture);
    __pyx_t_4 = __pyx_v_6uvloop_4loop_aio_isfuture; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 72, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_obj};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 72, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_obj};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 72, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 72, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_obj);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 72, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "uvloop/loop.pyx":68
 * 
 * 
 * cdef isfuture(obj):             # <<<<<<<<<<<<<<
 *     if aio_isfuture is None:
 *         return isinstance(obj, aio_Future)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.isfuture", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":75
 * 
 * 
 * cdef inline socket_inc_io_ref(sock):             # <<<<<<<<<<<<<<
 *     if isinstance(sock, socket_socket):
 *         sock._io_refs += 1
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_socket_inc_io_ref(PyObject *__pyx_v_sock) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("socket_inc_io_ref", 0);

  /* "uvloop/loop.pyx":76
 * 
 * cdef inline socket_inc_io_ref(sock):
 *     if isinstance(sock, socket_socket):             # <<<<<<<<<<<<<<
 *         sock._io_refs += 1
 * 
 */
  __pyx_t_1 = __pyx_v_6uvloop_4loop_socket_socket;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_sock, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":77
 * cdef inline socket_inc_io_ref(sock):
 *     if isinstance(sock, socket_socket):
 *         sock._io_refs += 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_io_refs); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_sock, __pyx_n_s_io_refs, __pyx_t_4) < 0) __PYX_ERR(2, 77, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":76
 * 
 * cdef inline socket_inc_io_ref(sock):
 *     if isinstance(sock, socket_socket):             # <<<<<<<<<<<<<<
 *         sock._io_refs += 1
 * 
 */
  }

  /* "uvloop/loop.pyx":75
 * 
 * 
 * cdef inline socket_inc_io_ref(sock):             # <<<<<<<<<<<<<<
 *     if isinstance(sock, socket_socket):
 *         sock._io_refs += 1
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.socket_inc_io_ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":80
 * 
 * 
 * cdef inline socket_dec_io_ref(sock):             # <<<<<<<<<<<<<<
 *     if isinstance(sock, socket_socket):
 *         sock._decref_socketios()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_socket_dec_io_ref(PyObject *__pyx_v_sock) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("socket_dec_io_ref", 0);

  /* "uvloop/loop.pyx":81
 * 
 * cdef inline socket_dec_io_ref(sock):
 *     if isinstance(sock, socket_socket):             # <<<<<<<<<<<<<<
 *         sock._decref_socketios()
 * 
 */
  __pyx_t_1 = __pyx_v_6uvloop_4loop_socket_socket;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_sock, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":82
 * cdef inline socket_dec_io_ref(sock):
 *     if isinstance(sock, socket_socket):
 *         sock._decref_socketios()             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_decref_socketios); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 82, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 82, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":81
 * 
 * cdef inline socket_dec_io_ref(sock):
 *     if isinstance(sock, socket_socket):             # <<<<<<<<<<<<<<
 *         sock._decref_socketios()
 * 
 */
  }

  /* "uvloop/loop.pyx":80
 * 
 * 
 * cdef inline socket_dec_io_ref(sock):             # <<<<<<<<<<<<<<
 *     if isinstance(sock, socket_socket):
 *         sock._decref_socketios()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.socket_dec_io_ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":87
 * @cython.no_gc_clear
 * cdef class Loop:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_4Loop_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_4Loop_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop___cinit__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_4Loop___cinit__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  int __pyx_v_err;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/loop.pyx":91
 * 
 *         # Install PyMem* memory allocators if they aren't installed yet.
 *         __install_pymem()             # <<<<<<<<<<<<<<
 * 
 *         # Install pthread_atfork handlers
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___install_pymem(); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":94
 * 
 *         # Install pthread_atfork handlers
 *         __install_atfork()             # <<<<<<<<<<<<<<
 * 
 *         self.uvloop = <uv.uv_loop_t*> \
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___install_atfork(); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":96
 *         __install_atfork()
 * 
 *         self.uvloop = <uv.uv_loop_t*> \             # <<<<<<<<<<<<<<
 *                             PyMem_RawMalloc(sizeof(uv.uv_loop_t))
 *         if self.uvloop is NULL:
 */
  __pyx_v_self->uvloop = ((uv_loop_t *)PyMem_RawMalloc((sizeof(uv_loop_t))));

  /* "uvloop/loop.pyx":98
 *         self.uvloop = <uv.uv_loop_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_loop_t))
 *         if self.uvloop is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->uvloop == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":99
 *                             PyMem_RawMalloc(sizeof(uv.uv_loop_t))
 *         if self.uvloop is NULL:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         self.slow_callback_duration = 0.1
 */
    PyErr_NoMemory(); __PYX_ERR(2, 99, __pyx_L1_error)

    /* "uvloop/loop.pyx":98
 *         self.uvloop = <uv.uv_loop_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_loop_t))
 *         if self.uvloop is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
  }

  /* "uvloop/loop.pyx":101
 *             raise MemoryError()
 * 
 *         self.slow_callback_duration = 0.1             # <<<<<<<<<<<<<<
 * 
 *         self._closed = 0
 */
  __Pyx_INCREF(__pyx_float_0_1);
  __Pyx_GIVEREF(__pyx_float_0_1);
  __Pyx_GOTREF(__pyx_v_self->slow_callback_duration);
  __Pyx_DECREF(__pyx_v_self->slow_callback_duration);
  __pyx_v_self->slow_callback_duration = __pyx_float_0_1;

  /* "uvloop/loop.pyx":103
 *         self.slow_callback_duration = 0.1
 * 
 *         self._closed = 0             # <<<<<<<<<<<<<<
 *         self._debug = 0
 *         self._thread_is_main = 0
 */
  __pyx_v_self->_closed = 0;

  /* "uvloop/loop.pyx":104
 * 
 *         self._closed = 0
 *         self._debug = 0             # <<<<<<<<<<<<<<
 *         self._thread_is_main = 0
 *         self._thread_id = 0
 */
  __pyx_v_self->_debug = 0;

  /* "uvloop/loop.pyx":105
 *         self._closed = 0
 *         self._debug = 0
 *         self._thread_is_main = 0             # <<<<<<<<<<<<<<
 *         self._thread_id = 0
 *         self._running = 0
 */
  __pyx_v_self->_thread_is_main = 0;

  /* "uvloop/loop.pyx":106
 *         self._debug = 0
 *         self._thread_is_main = 0
 *         self._thread_id = 0             # <<<<<<<<<<<<<<
 *         self._running = 0
 *         self._stopping = 0
 */
  __pyx_v_self->_thread_id = 0;

  /* "uvloop/loop.pyx":107
 *         self._thread_is_main = 0
 *         self._thread_id = 0
 *         self._running = 0             # <<<<<<<<<<<<<<
 *         self._stopping = 0
 * 
 */
  __pyx_v_self->_running = 0;

  /* "uvloop/loop.pyx":108
 *         self._thread_id = 0
 *         self._running = 0
 *         self._stopping = 0             # <<<<<<<<<<<<<<
 * 
 *         self._transports = weakref_WeakValueDictionary()
 */
  __pyx_v_self->_stopping = 0;

  /* "uvloop/loop.pyx":110
 *         self._stopping = 0
 * 
 *         self._transports = weakref_WeakValueDictionary()             # <<<<<<<<<<<<<<
 *         self._processes = set()
 * 
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_weakref_WeakValueDictionary);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_weakref_WeakValueDictionary; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 110, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 110, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_transports);
  __Pyx_DECREF(__pyx_v_self->_transports);
  __pyx_v_self->_transports = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":111
 * 
 *         self._transports = weakref_WeakValueDictionary()
 *         self._processes = set()             # <<<<<<<<<<<<<<
 * 
 *         # Used to keep a reference (and hence keep the fileobj alive)
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_processes);
  __Pyx_DECREF(__pyx_v_self->_processes);
  __pyx_v_self->_processes = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":116
 *         # for as long as its registered by add_reader or add_writer.
 *         # This is how the selector module and hence asyncio behaves.
 *         self._fd_to_reader_fileobj = {}             # <<<<<<<<<<<<<<
 *         self._fd_to_writer_fileobj = {}
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_fd_to_reader_fileobj);
  __Pyx_DECREF(__pyx_v_self->_fd_to_reader_fileobj);
  __pyx_v_self->_fd_to_reader_fileobj = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":117
 *         # This is how the selector module and hence asyncio behaves.
 *         self._fd_to_reader_fileobj = {}
 *         self._fd_to_writer_fileobj = {}             # <<<<<<<<<<<<<<
 * 
 *         self._timers = set()
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_fd_to_writer_fileobj);
  __Pyx_DECREF(__pyx_v_self->_fd_to_writer_fileobj);
  __pyx_v_self->_fd_to_writer_fileobj = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":119
 *         self._fd_to_writer_fileobj = {}
 * 
 *         self._timers = set()             # <<<<<<<<<<<<<<
 *         self._polls = {}
 * 
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_timers);
  __Pyx_DECREF(__pyx_v_self->_timers);
  __pyx_v_self->_timers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":120
 * 
 *         self._timers = set()
 *         self._polls = {}             # <<<<<<<<<<<<<<
 * 
 *         self._recv_buffer_in_use = 0
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_polls);
  __Pyx_DECREF(__pyx_v_self->_polls);
  __pyx_v_self->_polls = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":122
 *         self._polls = {}
 * 
 *         self._recv_buffer_in_use = 0             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_loop_init(self.uvloop)
 */
  __pyx_v_self->_recv_buffer_in_use = 0;

  /* "uvloop/loop.pyx":124
 *         self._recv_buffer_in_use = 0
 * 
 *         err = uv.uv_loop_init(self.uvloop)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
  __pyx_v_err = uv_loop_init(__pyx_v_self->uvloop);

  /* "uvloop/loop.pyx":125
 * 
 *         err = uv.uv_loop_init(self.uvloop)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 *         self.uvloop.data = <void*> self
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":126
 *         err = uv.uv_loop_init(self.uvloop)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 *         self.uvloop.data = <void*> self
 * 
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 126, __pyx_L1_error)

    /* "uvloop/loop.pyx":125
 * 
 *         err = uv.uv_loop_init(self.uvloop)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 *         self.uvloop.data = <void*> self
 */
  }

  /* "uvloop/loop.pyx":127
 *         if err < 0:
 *             raise convert_error(err)
 *         self.uvloop.data = <void*> self             # <<<<<<<<<<<<<<
 * 
 *         self._init_debug_fields()
 */
  __pyx_v_self->uvloop->data = ((void *)__pyx_v_self);

  /* "uvloop/loop.pyx":129
 *         self.uvloop.data = <void*> self
 * 
 *         self._init_debug_fields()             # <<<<<<<<<<<<<<
 * 
 *         self.active_process_handler = None
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_init_debug_fields(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":131
 *         self._init_debug_fields()
 * 
 *         self.active_process_handler = None             # <<<<<<<<<<<<<<
 * 
 *         self._last_error = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->active_process_handler);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->active_process_handler));
  __pyx_v_self->active_process_handler = ((struct __pyx_obj_6uvloop_4loop_UVProcess *)Py_None);

  /* "uvloop/loop.pyx":133
 *         self.active_process_handler = None
 * 
 *         self._last_error = None             # <<<<<<<<<<<<<<
 * 
 *         self._task_factory = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_last_error);
  __Pyx_DECREF(__pyx_v_self->_last_error);
  __pyx_v_self->_last_error = Py_None;

  /* "uvloop/loop.pyx":135
 *         self._last_error = None
 * 
 *         self._task_factory = None             # <<<<<<<<<<<<<<
 *         self._exception_handler = None
 *         self._default_executor = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_task_factory);
  __Pyx_DECREF(__pyx_v_self->_task_factory);
  __pyx_v_self->_task_factory = Py_None;

  /* "uvloop/loop.pyx":136
 * 
 *         self._task_factory = None
 *         self._exception_handler = None             # <<<<<<<<<<<<<<
 *         self._default_executor = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_exception_handler);
  __Pyx_DECREF(__pyx_v_self->_exception_handler);
  __pyx_v_self->_exception_handler = Py_None;

  /* "uvloop/loop.pyx":137
 *         self._task_factory = None
 *         self._exception_handler = None
 *         self._default_executor = None             # <<<<<<<<<<<<<<
 * 
 *         self._queued_streams = set()
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_default_executor);
  __Pyx_DECREF(__pyx_v_self->_default_executor);
  __pyx_v_self->_default_executor = Py_None;

  /* "uvloop/loop.pyx":139
 *         self._default_executor = None
 * 
 *         self._queued_streams = set()             # <<<<<<<<<<<<<<
 *         self._ready = col_deque()
 *         self._ready_len = 0
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_queued_streams);
  __Pyx_DECREF(__pyx_v_self->_queued_streams);
  __pyx_v_self->_queued_streams = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":140
 * 
 *         self._queued_streams = set()
 *         self._ready = col_deque()             # <<<<<<<<<<<<<<
 *         self._ready_len = 0
 * 
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_col_deque);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_col_deque; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 140, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 140, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_ready);
  __Pyx_DECREF(__pyx_v_self->_ready);
  __pyx_v_self->_ready = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":141
 *         self._queued_streams = set()
 *         self._ready = col_deque()
 *         self._ready_len = 0             # <<<<<<<<<<<<<<
 * 
 *         self.handler_async = UVAsync.new(
 */
  __pyx_v_self->_ready_len = 0;

  /* "uvloop/loop.pyx":143
 *         self._ready_len = 0
 * 
 *         self.handler_async = UVAsync.new(             # <<<<<<<<<<<<<<
 *             self, <method_t>self._on_wake, self)
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_6uvloop_4loop_7UVAsync_new(__pyx_v_self, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_on_wake), ((PyObject *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->handler_async);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->handler_async));
  __pyx_v_self->handler_async = ((struct __pyx_obj_6uvloop_4loop_UVAsync *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":148
 *         self.handler_idle = UVIdle.new(
 *             self,
 *             new_MethodHandle(             # <<<<<<<<<<<<<<
 *                 self, "loop._on_idle", <method_t>self._on_idle, self))
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_new_MethodHandle(__pyx_v_self, __pyx_kp_u_loop__on_idle, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_on_idle), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 148, __pyx_L1_error)

  /* "uvloop/loop.pyx":146
 *             self, <method_t>self._on_wake, self)
 * 
 *         self.handler_idle = UVIdle.new(             # <<<<<<<<<<<<<<
 *             self,
 *             new_MethodHandle(
 */
  __pyx_t_3 = ((PyObject *)__pyx_f_6uvloop_4loop_6UVIdle_new(__pyx_v_self, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1))); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->handler_idle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->handler_idle));
  __pyx_v_self->handler_idle = ((struct __pyx_obj_6uvloop_4loop_UVIdle *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":155
 *         self.handler_check__exec_writes = UVCheck.new(
 *             self,
 *             new_MethodHandle(             # <<<<<<<<<<<<<<
 *                 self, "loop._exec_queued_writes",
 *                 <method_t>self._exec_queued_writes, self))
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_new_MethodHandle(__pyx_v_self, __pyx_kp_u_loop__exec_queued_writes, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_exec_queued_writes), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 155, __pyx_L1_error)

  /* "uvloop/loop.pyx":153
 *         # Needed to call `UVStream._exec_write` for writes scheduled
 *         # during `Protocol.data_received`.
 *         self.handler_check__exec_writes = UVCheck.new(             # <<<<<<<<<<<<<<
 *             self,
 *             new_MethodHandle(
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_6uvloop_4loop_7UVCheck_new(__pyx_v_self, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_3))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->handler_check__exec_writes);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->handler_check__exec_writes));
  __pyx_v_self->handler_check__exec_writes = ((struct __pyx_obj_6uvloop_4loop_UVCheck *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":159
 *                 <method_t>self._exec_queued_writes, self))
 * 
 *         self._signals = set()             # <<<<<<<<<<<<<<
 *         self._ssock = self._csock = None
 *         self._signal_handlers = {}
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_signals);
  __Pyx_DECREF(__pyx_v_self->_signals);
  __pyx_v_self->_signals = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":160
 * 
 *         self._signals = set()
 *         self._ssock = self._csock = None             # <<<<<<<<<<<<<<
 *         self._signal_handlers = {}
 *         self._listening_signals = False
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_ssock);
  __Pyx_DECREF(__pyx_v_self->_ssock);
  __pyx_v_self->_ssock = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_csock);
  __Pyx_DECREF(__pyx_v_self->_csock);
  __pyx_v_self->_csock = Py_None;

  /* "uvloop/loop.pyx":161
 *         self._signals = set()
 *         self._ssock = self._csock = None
 *         self._signal_handlers = {}             # <<<<<<<<<<<<<<
 *         self._listening_signals = False
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_signal_handlers);
  __Pyx_DECREF(__pyx_v_self->_signal_handlers);
  __pyx_v_self->_signal_handlers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":162
 *         self._ssock = self._csock = None
 *         self._signal_handlers = {}
 *         self._listening_signals = False             # <<<<<<<<<<<<<<
 * 
 *         self._coroutine_debug_set = False
 */
  __pyx_v_self->_listening_signals = 0;

  /* "uvloop/loop.pyx":164
 *         self._listening_signals = False
 * 
 *         self._coroutine_debug_set = False             # <<<<<<<<<<<<<<
 * 
 *         if hasattr(sys, 'get_asyncgen_hooks'):
 */
  __pyx_v_self->_coroutine_debug_set = 0;

  /* "uvloop/loop.pyx":166
 *         self._coroutine_debug_set = False
 * 
 *         if hasattr(sys, 'get_asyncgen_hooks'):             # <<<<<<<<<<<<<<
 *             # Python >= 3.6
 *             # A weak set of all asynchronous generators that are
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_HasAttr(__pyx_t_1, __pyx_n_u_get_asyncgen_hooks); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_2 != 0);
  if (__pyx_t_5) {

    /* "uvloop/loop.pyx":170
 *             # A weak set of all asynchronous generators that are
 *             # being iterated by the loop.
 *             self._asyncgens = weakref_WeakSet()             # <<<<<<<<<<<<<<
 *         else:
 *             self._asyncgens = None
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_weakref_WeakSet);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_weakref_WeakSet; __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 170, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 170, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_asyncgens);
    __Pyx_DECREF(__pyx_v_self->_asyncgens);
    __pyx_v_self->_asyncgens = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":166
 *         self._coroutine_debug_set = False
 * 
 *         if hasattr(sys, 'get_asyncgen_hooks'):             # <<<<<<<<<<<<<<
 *             # Python >= 3.6
 *             # A weak set of all asynchronous generators that are
 */
    goto __pyx_L5;
  }

  /* "uvloop/loop.pyx":172
 *             self._asyncgens = weakref_WeakSet()
 *         else:
 *             self._asyncgens = None             # <<<<<<<<<<<<<<
 * 
 *         # Set to True when `loop.shutdown_asyncgens` is called.
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_asyncgens);
    __Pyx_DECREF(__pyx_v_self->_asyncgens);
    __pyx_v_self->_asyncgens = Py_None;
  }
  __pyx_L5:;

  /* "uvloop/loop.pyx":175
 * 
 *         # Set to True when `loop.shutdown_asyncgens` is called.
 *         self._asyncgens_shutdown_called = False             # <<<<<<<<<<<<<<
 * 
 *         self._servers = set()
 */
  __pyx_v_self->_asyncgens_shutdown_called = 0;

  /* "uvloop/loop.pyx":177
 *         self._asyncgens_shutdown_called = False
 * 
 *         self._servers = set()             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_servers);
  __Pyx_DECREF(__pyx_v_self->_servers);
  __pyx_v_self->_servers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":87
 * @cython.no_gc_clear
 * cdef class Loop:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":179
 *         self._servers = set()
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.set_debug((not sys_ignore_environment
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_4Loop_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_4Loop_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_2__init__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_4Loop_2__init__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/loop.pyx":180
 * 
 *     def __init__(self):
 *         self.set_debug((not sys_ignore_environment             # <<<<<<<<<<<<<<
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_debug); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/loop.pyx":181
 *     def __init__(self):
 *         self.set_debug((not sys_ignore_environment
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_6uvloop_4loop_sys_ignore_environment); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 180, __pyx_L1_error)

  /* "uvloop/loop.pyx":180
 * 
 *     def __init__(self):
 *         self.set_debug((not sys_ignore_environment             # <<<<<<<<<<<<<<
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))
 * 
 */
  __pyx_t_5 = (!__pyx_t_4);
  if (__pyx_t_5) {
  } else {
    __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L3_bool_binop_done;
  }

  /* "uvloop/loop.pyx":181
 *     def __init__(self):
 *         self.set_debug((not sys_ignore_environment
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_os_environ, __pyx_n_s_get); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(2, 181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyBool_FromLong((!(!__pyx_t_5))); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_t_7);
  __pyx_t_3 = __pyx_t_7;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 180, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 180, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 180, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":179
 *         self._servers = set()
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.set_debug((not sys_ignore_environment
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":183
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._running == 1:
 *             raise RuntimeError('deallocating a running event loop!')
 */

/* Python wrapper */
static void __pyx_pw_6uvloop_4loop_4Loop_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6uvloop_4loop_4Loop_5__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_6uvloop_4loop_4Loop_4__dealloc__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6uvloop_4loop_4Loop_4__dealloc__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "uvloop/loop.pyx":184
 * 
 *     def __dealloc__(self):
 *         if self._running == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('deallocating a running event loop!')
 *         if self._closed == 0:
 */
  __pyx_t_1 = ((__pyx_v_self->_running == 1) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":185
 *     def __dealloc__(self):
 *         if self._running == 1:
 *             raise RuntimeError('deallocating a running event loop!')             # <<<<<<<<<<<<<<
 *         if self._closed == 0:
 *             aio_logger.error("deallocating an open event loop")
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 185, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 185, __pyx_L1_error)

    /* "uvloop/loop.pyx":184
 * 
 *     def __dealloc__(self):
 *         if self._running == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('deallocating a running event loop!')
 *         if self._closed == 0:
 */
  }

  /* "uvloop/loop.pyx":186
 *         if self._running == 1:
 *             raise RuntimeError('deallocating a running event loop!')
 *         if self._closed == 0:             # <<<<<<<<<<<<<<
 *             aio_logger.error("deallocating an open event loop")
 *             return
 */
  __pyx_t_1 = ((__pyx_v_self->_closed == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":187
 *             raise RuntimeError('deallocating a running event loop!')
 *         if self._closed == 0:
 *             aio_logger.error("deallocating an open event loop")             # <<<<<<<<<<<<<<
 *             return
 *         PyMem_RawFree(self.uvloop)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":188
 *         if self._closed == 0:
 *             aio_logger.error("deallocating an open event loop")
 *             return             # <<<<<<<<<<<<<<
 *         PyMem_RawFree(self.uvloop)
 *         self.uvloop = NULL
 */
    goto __pyx_L0;

    /* "uvloop/loop.pyx":186
 *         if self._running == 1:
 *             raise RuntimeError('deallocating a running event loop!')
 *         if self._closed == 0:             # <<<<<<<<<<<<<<
 *             aio_logger.error("deallocating an open event loop")
 *             return
 */
  }

  /* "uvloop/loop.pyx":189
 *             aio_logger.error("deallocating an open event loop")
 *             return
 *         PyMem_RawFree(self.uvloop)             # <<<<<<<<<<<<<<
 *         self.uvloop = NULL
 * 
 */
  PyMem_RawFree(__pyx_v_self->uvloop);

  /* "uvloop/loop.pyx":190
 *             return
 *         PyMem_RawFree(self.uvloop)
 *         self.uvloop = NULL             # <<<<<<<<<<<<<<
 * 
 *     cdef _init_debug_fields(self):
 */
  __pyx_v_self->uvloop = NULL;

  /* "uvloop/loop.pyx":183
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._running == 1:
 *             raise RuntimeError('deallocating a running event loop!')
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_WriteUnraisable("uvloop.loop.Loop.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/loop.pyx":192
 *         self.uvloop = NULL
 * 
 *     cdef _init_debug_fields(self):             # <<<<<<<<<<<<<<
 *         self._debug_cc = bool(UVLOOP_DEBUG)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__init_debug_fields(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_init_debug_fields", 0);

  /* "uvloop/loop.pyx":193
 * 
 *     cdef _init_debug_fields(self):
 *         self._debug_cc = bool(UVLOOP_DEBUG)             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(UVLOOP_DEBUG); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->_debug_cc = (!(!__pyx_t_2));

  /* "uvloop/loop.pyx":195
 *         self._debug_cc = bool(UVLOOP_DEBUG)
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._debug_handles_current = col_Counter()
 *             self._debug_handles_closed = col_Counter()
 */
  __pyx_t_2 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":196
 * 
 *         if UVLOOP_DEBUG:
 *             self._debug_handles_current = col_Counter()             # <<<<<<<<<<<<<<
 *             self._debug_handles_closed = col_Counter()
 *             self._debug_handles_total = col_Counter()
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_col_Counter);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_col_Counter; __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 196, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 196, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_debug_handles_current);
    __Pyx_DECREF(__pyx_v_self->_debug_handles_current);
    __pyx_v_self->_debug_handles_current = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":197
 *         if UVLOOP_DEBUG:
 *             self._debug_handles_current = col_Counter()
 *             self._debug_handles_closed = col_Counter()             # <<<<<<<<<<<<<<
 *             self._debug_handles_total = col_Counter()
 *         else:
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_col_Counter);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_col_Counter; __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 197, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 197, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_debug_handles_closed);
    __Pyx_DECREF(__pyx_v_self->_debug_handles_closed);
    __pyx_v_self->_debug_handles_closed = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":198
 *             self._debug_handles_current = col_Counter()
 *             self._debug_handles_closed = col_Counter()
 *             self._debug_handles_total = col_Counter()             # <<<<<<<<<<<<<<
 *         else:
 *             self._debug_handles_current = None
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_col_Counter);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_col_Counter; __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 198, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 198, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_debug_handles_total);
    __Pyx_DECREF(__pyx_v_self->_debug_handles_total);
    __pyx_v_self->_debug_handles_total = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":195
 *         self._debug_cc = bool(UVLOOP_DEBUG)
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._debug_handles_current = col_Counter()
 *             self._debug_handles_closed = col_Counter()
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":200
 *             self._debug_handles_total = col_Counter()
 *         else:
 *             self._debug_handles_current = None             # <<<<<<<<<<<<<<
 *             self._debug_handles_closed = None
 *             self._debug_handles_total = None
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_debug_handles_current);
    __Pyx_DECREF(__pyx_v_self->_debug_handles_current);
    __pyx_v_self->_debug_handles_current = Py_None;

    /* "uvloop/loop.pyx":201
 *         else:
 *             self._debug_handles_current = None
 *             self._debug_handles_closed = None             # <<<<<<<<<<<<<<
 *             self._debug_handles_total = None
 * 
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_debug_handles_closed);
    __Pyx_DECREF(__pyx_v_self->_debug_handles_closed);
    __pyx_v_self->_debug_handles_closed = Py_None;

    /* "uvloop/loop.pyx":202
 *             self._debug_handles_current = None
 *             self._debug_handles_closed = None
 *             self._debug_handles_total = None             # <<<<<<<<<<<<<<
 * 
 *         self._debug_uv_handles_total = 0
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_debug_handles_total);
    __Pyx_DECREF(__pyx_v_self->_debug_handles_total);
    __pyx_v_self->_debug_handles_total = Py_None;
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":204
 *             self._debug_handles_total = None
 * 
 *         self._debug_uv_handles_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_uv_handles_freed = 0
 * 
 */
  __pyx_v_self->_debug_uv_handles_total = 0;

  /* "uvloop/loop.pyx":205
 * 
 *         self._debug_uv_handles_total = 0
 *         self._debug_uv_handles_freed = 0             # <<<<<<<<<<<<<<
 * 
 *         self._debug_stream_read_cb_total = 0
 */
  __pyx_v_self->_debug_uv_handles_freed = 0;

  /* "uvloop/loop.pyx":207
 *         self._debug_uv_handles_freed = 0
 * 
 *         self._debug_stream_read_cb_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_read_eof_total = 0
 *         self._debug_stream_read_errors_total = 0
 */
  __pyx_v_self->_debug_stream_read_cb_total = 0;

  /* "uvloop/loop.pyx":208
 * 
 *         self._debug_stream_read_cb_total = 0
 *         self._debug_stream_read_eof_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_read_errors_total = 0
 *         self._debug_stream_read_cb_errors_total = 0
 */
  __pyx_v_self->_debug_stream_read_eof_total = 0;

  /* "uvloop/loop.pyx":209
 *         self._debug_stream_read_cb_total = 0
 *         self._debug_stream_read_eof_total = 0
 *         self._debug_stream_read_errors_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_read_cb_errors_total = 0
 *         self._debug_stream_read_eof_cb_errors_total = 0
 */
  __pyx_v_self->_debug_stream_read_errors_total = 0;

  /* "uvloop/loop.pyx":210
 *         self._debug_stream_read_eof_total = 0
 *         self._debug_stream_read_errors_total = 0
 *         self._debug_stream_read_cb_errors_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_read_eof_cb_errors_total = 0
 * 
 */
  __pyx_v_self->_debug_stream_read_cb_errors_total = 0;

  /* "uvloop/loop.pyx":211
 *         self._debug_stream_read_errors_total = 0
 *         self._debug_stream_read_cb_errors_total = 0
 *         self._debug_stream_read_eof_cb_errors_total = 0             # <<<<<<<<<<<<<<
 * 
 *         self._debug_stream_shutdown_errors_total = 0
 */
  __pyx_v_self->_debug_stream_read_eof_cb_errors_total = 0;

  /* "uvloop/loop.pyx":213
 *         self._debug_stream_read_eof_cb_errors_total = 0
 * 
 *         self._debug_stream_shutdown_errors_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_listen_errors_total = 0
 * 
 */
  __pyx_v_self->_debug_stream_shutdown_errors_total = 0;

  /* "uvloop/loop.pyx":214
 * 
 *         self._debug_stream_shutdown_errors_total = 0
 *         self._debug_stream_listen_errors_total = 0             # <<<<<<<<<<<<<<
 * 
 *         self._debug_stream_write_tries = 0
 */
  __pyx_v_self->_debug_stream_listen_errors_total = 0;

  /* "uvloop/loop.pyx":216
 *         self._debug_stream_listen_errors_total = 0
 * 
 *         self._debug_stream_write_tries = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_write_errors_total = 0
 *         self._debug_stream_write_ctx_total = 0
 */
  __pyx_v_self->_debug_stream_write_tries = 0;

  /* "uvloop/loop.pyx":217
 * 
 *         self._debug_stream_write_tries = 0
 *         self._debug_stream_write_errors_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_write_ctx_total = 0
 *         self._debug_stream_write_ctx_cnt = 0
 */
  __pyx_v_self->_debug_stream_write_errors_total = 0;

  /* "uvloop/loop.pyx":218
 *         self._debug_stream_write_tries = 0
 *         self._debug_stream_write_errors_total = 0
 *         self._debug_stream_write_ctx_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_write_ctx_cnt = 0
 *         self._debug_stream_write_cb_errors_total = 0
 */
  __pyx_v_self->_debug_stream_write_ctx_total = 0;

  /* "uvloop/loop.pyx":219
 *         self._debug_stream_write_errors_total = 0
 *         self._debug_stream_write_ctx_total = 0
 *         self._debug_stream_write_ctx_cnt = 0             # <<<<<<<<<<<<<<
 *         self._debug_stream_write_cb_errors_total = 0
 * 
 */
  __pyx_v_self->_debug_stream_write_ctx_cnt = 0;

  /* "uvloop/loop.pyx":220
 *         self._debug_stream_write_ctx_total = 0
 *         self._debug_stream_write_ctx_cnt = 0
 *         self._debug_stream_write_cb_errors_total = 0             # <<<<<<<<<<<<<<
 * 
 *         self._debug_cb_handles_total = 0
 */
  __pyx_v_self->_debug_stream_write_cb_errors_total = 0;

  /* "uvloop/loop.pyx":222
 *         self._debug_stream_write_cb_errors_total = 0
 * 
 *         self._debug_cb_handles_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_cb_handles_count = 0
 * 
 */
  __pyx_v_self->_debug_cb_handles_total = 0;

  /* "uvloop/loop.pyx":223
 * 
 *         self._debug_cb_handles_total = 0
 *         self._debug_cb_handles_count = 0             # <<<<<<<<<<<<<<
 * 
 *         self._debug_cb_timer_handles_total = 0
 */
  __pyx_v_self->_debug_cb_handles_count = 0;

  /* "uvloop/loop.pyx":225
 *         self._debug_cb_handles_count = 0
 * 
 *         self._debug_cb_timer_handles_total = 0             # <<<<<<<<<<<<<<
 *         self._debug_cb_timer_handles_count = 0
 * 
 */
  __pyx_v_self->_debug_cb_timer_handles_total = 0;

  /* "uvloop/loop.pyx":226
 * 
 *         self._debug_cb_timer_handles_total = 0
 *         self._debug_cb_timer_handles_count = 0             # <<<<<<<<<<<<<<
 * 
 *         self._poll_read_events_total = 0
 */
  __pyx_v_self->_debug_cb_timer_handles_count = 0;

  /* "uvloop/loop.pyx":228
 *         self._debug_cb_timer_handles_count = 0
 * 
 *         self._poll_read_events_total = 0             # <<<<<<<<<<<<<<
 *         self._poll_read_cb_errors_total = 0
 *         self._poll_write_events_total = 0
 */
  __pyx_v_self->_poll_read_events_total = 0;

  /* "uvloop/loop.pyx":229
 * 
 *         self._poll_read_events_total = 0
 *         self._poll_read_cb_errors_total = 0             # <<<<<<<<<<<<<<
 *         self._poll_write_events_total = 0
 *         self._poll_write_cb_errors_total = 0
 */
  __pyx_v_self->_poll_read_cb_errors_total = 0;

  /* "uvloop/loop.pyx":230
 *         self._poll_read_events_total = 0
 *         self._poll_read_cb_errors_total = 0
 *         self._poll_write_events_total = 0             # <<<<<<<<<<<<<<
 *         self._poll_write_cb_errors_total = 0
 * 
 */
  __pyx_v_self->_poll_write_events_total = 0;

  /* "uvloop/loop.pyx":231
 *         self._poll_read_cb_errors_total = 0
 *         self._poll_write_events_total = 0
 *         self._poll_write_cb_errors_total = 0             # <<<<<<<<<<<<<<
 * 
 *         self._sock_try_write_total = 0
 */
  __pyx_v_self->_poll_write_cb_errors_total = 0;

  /* "uvloop/loop.pyx":233
 *         self._poll_write_cb_errors_total = 0
 * 
 *         self._sock_try_write_total = 0             # <<<<<<<<<<<<<<
 * 
 *         self._debug_exception_handler_cnt = 0
 */
  __pyx_v_self->_sock_try_write_total = 0;

  /* "uvloop/loop.pyx":235
 *         self._sock_try_write_total = 0
 * 
 *         self._debug_exception_handler_cnt = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef _setup_signals(self):
 */
  __pyx_v_self->_debug_exception_handler_cnt = 0;

  /* "uvloop/loop.pyx":192
 *         self.uvloop = NULL
 * 
 *     cdef _init_debug_fields(self):             # <<<<<<<<<<<<<<
 *         self._debug_cc = bool(UVLOOP_DEBUG)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop._init_debug_fields", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":237
 *         self._debug_exception_handler_cnt = 0
 * 
 *     cdef _setup_signals(self):             # <<<<<<<<<<<<<<
 *         if self._listening_signals:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__setup_signals(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("_setup_signals", 0);

  /* "uvloop/loop.pyx":238
 * 
 *     cdef _setup_signals(self):
 *         if self._listening_signals:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_listening_signals != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":239
 *     cdef _setup_signals(self):
 *         if self._listening_signals:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._ssock, self._csock = socket_socketpair()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":238
 * 
 *     cdef _setup_signals(self):
 *         if self._listening_signals:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/loop.pyx":241
 *             return
 * 
 *         self._ssock, self._csock = socket_socketpair()             # <<<<<<<<<<<<<<
 *         self._ssock.setblocking(False)
 *         self._csock.setblocking(False)
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_socketpair);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_socket_socketpair; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 241, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 241, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 241, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(2, 241, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 241, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->_ssock);
  __Pyx_DECREF(__pyx_v_self->_ssock);
  __pyx_v_self->_ssock = __pyx_t_3;
  __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->_csock);
  __Pyx_DECREF(__pyx_v_self->_csock);
  __pyx_v_self->_csock = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":242
 * 
 *         self._ssock, self._csock = socket_socketpair()
 *         self._ssock.setblocking(False)             # <<<<<<<<<<<<<<
 *         self._csock.setblocking(False)
 *         try:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_ssock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":243
 *         self._ssock, self._csock = socket_socketpair()
 *         self._ssock.setblocking(False)
 *         self._csock.setblocking(False)             # <<<<<<<<<<<<<<
 *         try:
 *             _set_signal_wakeup_fd(self._csock.fileno())
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_csock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":244
 *         self._ssock.setblocking(False)
 *         self._csock.setblocking(False)
 *         try:             # <<<<<<<<<<<<<<
 *             _set_signal_wakeup_fd(self._csock.fileno())
 *         except (OSError, ValueError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "uvloop/loop.pyx":245
 *         self._csock.setblocking(False)
 *         try:
 *             _set_signal_wakeup_fd(self._csock.fileno())             # <<<<<<<<<<<<<<
 *         except (OSError, ValueError):
 *             # Not the main thread
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_csock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 245, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_3) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 245, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 245, __pyx_L6_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __pyx_f_6uvloop_4loop__set_signal_wakeup_fd(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 245, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":244
 *         self._ssock.setblocking(False)
 *         self._csock.setblocking(False)
 *         try:             # <<<<<<<<<<<<<<
 *             _set_signal_wakeup_fd(self._csock.fileno())
 *         except (OSError, ValueError):
 */
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":246
 *         try:
 *             _set_signal_wakeup_fd(self._csock.fileno())
 *         except (OSError, ValueError):             # <<<<<<<<<<<<<<
 *             # Not the main thread
 *             self._ssock.close()
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.Loop._setup_signals", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(2, 246, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/loop.pyx":248
 *         except (OSError, ValueError):
 *             # Not the main thread
 *             self._ssock.close()             # <<<<<<<<<<<<<<
 *             self._csock.close()
 *             self._ssock = self._csock = None
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_ssock, __pyx_n_s_close); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 248, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      if (__pyx_t_12) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 248, __pyx_L8_except_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else {
        __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 248, __pyx_L8_except_error)
      }
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":249
 *             # Not the main thread
 *             self._ssock.close()
 *             self._csock.close()             # <<<<<<<<<<<<<<
 *             self._ssock = self._csock = None
 *             return
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_csock, __pyx_n_s_close); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 249, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      if (__pyx_t_12) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 249, __pyx_L8_except_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else {
        __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 249, __pyx_L8_except_error)
      }
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":250
 *             self._ssock.close()
 *             self._csock.close()
 *             self._ssock = self._csock = None             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->_ssock);
      __Pyx_DECREF(__pyx_v_self->_ssock);
      __pyx_v_self->_ssock = Py_None;
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->_csock);
      __Pyx_DECREF(__pyx_v_self->_csock);
      __pyx_v_self->_csock = Py_None;

      /* "uvloop/loop.pyx":251
 *             self._csock.close()
 *             self._ssock = self._csock = None
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._listening_signals = True
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L9_except_return;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/loop.pyx":244
 *         self._ssock.setblocking(False)
 *         self._csock.setblocking(False)
 *         try:             # <<<<<<<<<<<<<<
 *             _set_signal_wakeup_fd(self._csock.fileno())
 *         except (OSError, ValueError):
 */
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L9_except_return:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L0;
    __pyx_L11_try_end:;
  }

  /* "uvloop/loop.pyx":253
 *             return
 * 
 *         self._listening_signals = True             # <<<<<<<<<<<<<<
 * 
 *     cdef _recv_signals_start(self):
 */
  __pyx_v_self->_listening_signals = 1;

  /* "uvloop/loop.pyx":237
 *         self._debug_exception_handler_cnt = 0
 * 
 *     cdef _setup_signals(self):             # <<<<<<<<<<<<<<
 *         if self._listening_signals:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.Loop._setup_signals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":255
 *         self._listening_signals = True
 * 
 *     cdef _recv_signals_start(self):             # <<<<<<<<<<<<<<
 *         if self._ssock is None:
 *             self._setup_signals()
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__recv_signals_start(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_recv_signals_start", 0);

  /* "uvloop/loop.pyx":256
 * 
 *     cdef _recv_signals_start(self):
 *         if self._ssock is None:             # <<<<<<<<<<<<<<
 *             self._setup_signals()
 *             if self._ssock is None:
 */
  __pyx_t_1 = (__pyx_v_self->_ssock == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":257
 *     cdef _recv_signals_start(self):
 *         if self._ssock is None:
 *             self._setup_signals()             # <<<<<<<<<<<<<<
 *             if self._ssock is None:
 *                 # Not the main thread.
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_setup_signals(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":258
 *         if self._ssock is None:
 *             self._setup_signals()
 *             if self._ssock is None:             # <<<<<<<<<<<<<<
 *                 # Not the main thread.
 *                 return
 */
    __pyx_t_2 = (__pyx_v_self->_ssock == Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":260
 *             if self._ssock is None:
 *                 # Not the main thread.
 *                 return             # <<<<<<<<<<<<<<
 * 
 *         self._add_reader(
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/loop.pyx":258
 *         if self._ssock is None:
 *             self._setup_signals()
 *             if self._ssock is None:             # <<<<<<<<<<<<<<
 *                 # Not the main thread.
 *                 return
 */
    }

    /* "uvloop/loop.pyx":256
 * 
 *     cdef _recv_signals_start(self):
 *         if self._ssock is None:             # <<<<<<<<<<<<<<
 *             self._setup_signals()
 *             if self._ssock is None:
 */
  }

  /* "uvloop/loop.pyx":263
 * 
 *         self._add_reader(
 *             self._ssock,             # <<<<<<<<<<<<<<
 *             new_MethodHandle(
 *                 self,
 */
  __pyx_t_3 = __pyx_v_self->_ssock;
  __Pyx_INCREF(__pyx_t_3);

  /* "uvloop/loop.pyx":264
 *         self._add_reader(
 *             self._ssock,
 *             new_MethodHandle(             # <<<<<<<<<<<<<<
 *                 self,
 *                 "Loop._read_from_self",
 */
  __pyx_t_4 = __pyx_f_6uvloop_4loop_new_MethodHandle(__pyx_v_self, __pyx_kp_u_Loop__read_from_self, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_read_from_self), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 264, __pyx_L1_error)

  /* "uvloop/loop.pyx":262
 *                 return
 * 
 *         self._add_reader(             # <<<<<<<<<<<<<<
 *             self._ssock,
 *             new_MethodHandle(
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_add_reader(__pyx_v_self, __pyx_t_3, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":255
 *         self._listening_signals = True
 * 
 *     cdef _recv_signals_start(self):             # <<<<<<<<<<<<<<
 *         if self._ssock is None:
 *             self._setup_signals()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.Loop._recv_signals_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":270
 *                 self))
 * 
 *     cdef _recv_signals_stop(self):             # <<<<<<<<<<<<<<
 *         if self._ssock is None:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__recv_signals_stop(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_recv_signals_stop", 0);

  /* "uvloop/loop.pyx":271
 * 
 *     cdef _recv_signals_stop(self):
 *         if self._ssock is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_ssock == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":272
 *     cdef _recv_signals_stop(self):
 *         if self._ssock is None:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._remove_reader(self._ssock)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":271
 * 
 *     cdef _recv_signals_stop(self):
 *         if self._ssock is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/loop.pyx":274
 *             return
 * 
 *         self._remove_reader(self._ssock)             # <<<<<<<<<<<<<<
 * 
 *     cdef _shutdown_signals(self):
 */
  __pyx_t_3 = __pyx_v_self->_ssock;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":270
 *                 self))
 * 
 *     cdef _recv_signals_stop(self):             # <<<<<<<<<<<<<<
 *         if self._ssock is None:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop._recv_signals_stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":276
 *         self._remove_reader(self._ssock)
 * 
 *     cdef _shutdown_signals(self):             # <<<<<<<<<<<<<<
 *         if not self._listening_signals:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__shutdown_signals(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("_shutdown_signals", 0);

  /* "uvloop/loop.pyx":277
 * 
 *     cdef _shutdown_signals(self):
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(__pyx_v_self->_listening_signals != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":278
 *     cdef _shutdown_signals(self):
 *         if not self._listening_signals:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         for sig in list(self._signal_handlers):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":277
 * 
 *     cdef _shutdown_signals(self):
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/loop.pyx":280
 *             return
 * 
 *         for sig in list(self._signal_handlers):             # <<<<<<<<<<<<<<
 *             self.remove_signal_handler(sig)
 * 
 */
  __pyx_t_2 = PySequence_List(__pyx_v_self->_signal_handlers); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(2, 280, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_sig, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":281
 * 
 *         for sig in list(self._signal_handlers):
 *             self.remove_signal_handler(sig)             # <<<<<<<<<<<<<<
 * 
 *         if not self._listening_signals:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_remove_signal_handler); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_sig); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 281, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_sig};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 281, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_sig};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 281, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 281, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_sig);
        __Pyx_GIVEREF(__pyx_v_sig);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_sig);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 281, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":280
 *             return
 * 
 *         for sig in list(self._signal_handlers):             # <<<<<<<<<<<<<<
 *             self.remove_signal_handler(sig)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":283
 *             self.remove_signal_handler(sig)
 * 
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             # `remove_signal_handler` will call `_shutdown_signals` when
 *             # removing last signal handler.
 */
  __pyx_t_1 = ((!(__pyx_v_self->_listening_signals != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":286
 *             # `remove_signal_handler` will call `_shutdown_signals` when
 *             # removing last signal handler.
 *             return             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":283
 *             self.remove_signal_handler(sig)
 * 
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             # `remove_signal_handler` will call `_shutdown_signals` when
 *             # removing last signal handler.
 */
  }

  /* "uvloop/loop.pyx":288
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             signal_set_wakeup_fd(-1)
 *         except (ValueError, OSError) as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "uvloop/loop.pyx":289
 * 
 *         try:
 *             signal_set_wakeup_fd(-1)             # <<<<<<<<<<<<<<
 *         except (ValueError, OSError) as exc:
 *             aio_logger.info('set_wakeup_fd(-1) failed: %s', exc)
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_signal_set_wakeup_fd, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 289, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":288
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             signal_set_wakeup_fd(-1)
 *         except (ValueError, OSError) as exc:
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L12_try_end;
    __pyx_L7_error:;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":290
 *         try:
 *             signal_set_wakeup_fd(-1)
 *         except (ValueError, OSError) as exc:             # <<<<<<<<<<<<<<
 *             aio_logger.info('set_wakeup_fd(-1) failed: %s', exc)
 * 
 */
    __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
    if (__pyx_t_11) {
      __Pyx_AddTraceback("uvloop.loop.Loop._shutdown_signals", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_5) < 0) __PYX_ERR(2, 290, __pyx_L9_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      /*try:*/ {

        /* "uvloop/loop.pyx":291
 *             signal_set_wakeup_fd(-1)
 *         except (ValueError, OSError) as exc:
 *             aio_logger.info('set_wakeup_fd(-1) failed: %s', exc)             # <<<<<<<<<<<<<<
 * 
 *         self._remove_reader(self._ssock)
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_info); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 291, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_12 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_kp_u_set_wakeup_fd_1_failed_s, __pyx_v_exc};
          __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 291, __pyx_L18_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_kp_u_set_wakeup_fd_1_failed_s, __pyx_v_exc};
          __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 291, __pyx_L18_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 291, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_12) {
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
          }
          __Pyx_INCREF(__pyx_kp_u_set_wakeup_fd_1_failed_s);
          __Pyx_GIVEREF(__pyx_kp_u_set_wakeup_fd_1_failed_s);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_11, __pyx_kp_u_set_wakeup_fd_1_failed_s);
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_GIVEREF(__pyx_v_exc);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_11, __pyx_v_exc);
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_13, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 291, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }

      /* "uvloop/loop.pyx":290
 *         try:
 *             signal_set_wakeup_fd(-1)
 *         except (ValueError, OSError) as exc:             # <<<<<<<<<<<<<<
 *             aio_logger.info('set_wakeup_fd(-1) failed: %s', exc)
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L19;
        }
        __pyx_L18_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_11 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
          goto __pyx_L9_except_error;
        }
        __pyx_L19:;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L8_exception_handled;
    }
    goto __pyx_L9_except_error;
    __pyx_L9_except_error:;

    /* "uvloop/loop.pyx":288
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             signal_set_wakeup_fd(-1)
 *         except (ValueError, OSError) as exc:
 */
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L8_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    __pyx_L12_try_end:;
  }

  /* "uvloop/loop.pyx":293
 *             aio_logger.info('set_wakeup_fd(-1) failed: %s', exc)
 * 
 *         self._remove_reader(self._ssock)             # <<<<<<<<<<<<<<
 *         self._ssock.close()
 *         self._csock.close()
 */
  __pyx_t_5 = __pyx_v_self->_ssock;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":294
 * 
 *         self._remove_reader(self._ssock)
 *         self._ssock.close()             # <<<<<<<<<<<<<<
 *         self._csock.close()
 *         self._ssock = None
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_ssock, __pyx_n_s_close); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 294, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 294, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":295
 *         self._remove_reader(self._ssock)
 *         self._ssock.close()
 *         self._csock.close()             # <<<<<<<<<<<<<<
 *         self._ssock = None
 *         self._csock = None
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_csock, __pyx_n_s_close); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 295, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 295, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":296
 *         self._ssock.close()
 *         self._csock.close()
 *         self._ssock = None             # <<<<<<<<<<<<<<
 *         self._csock = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_ssock);
  __Pyx_DECREF(__pyx_v_self->_ssock);
  __pyx_v_self->_ssock = Py_None;

  /* "uvloop/loop.pyx":297
 *         self._csock.close()
 *         self._ssock = None
 *         self._csock = None             # <<<<<<<<<<<<<<
 * 
 *         self._listening_signals = False
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_csock);
  __Pyx_DECREF(__pyx_v_self->_csock);
  __pyx_v_self->_csock = Py_None;

  /* "uvloop/loop.pyx":299
 *         self._csock = None
 * 
 *         self._listening_signals = False             # <<<<<<<<<<<<<<
 * 
 *     def __sighandler(self, signum, frame):
 */
  __pyx_v_self->_listening_signals = 0;

  /* "uvloop/loop.pyx":276
 *         self._remove_reader(self._ssock)
 * 
 *     cdef _shutdown_signals(self):             # <<<<<<<<<<<<<<
 *         if not self._listening_signals:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.Loop._shutdown_signals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":301
 *         self._listening_signals = False
 * 
 *     def __sighandler(self, signum, frame):             # <<<<<<<<<<<<<<
 *         self._signals.add(signum)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_7__sighandler(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_6__sighandler[] = "Loop.__sighandler(self, signum, frame)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_7__sighandler(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_signum = 0;
  CYTHON_UNUSED PyObject *__pyx_v_frame = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__sighandler (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_signum,&__pyx_n_s_frame,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_signum)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_frame)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__sighandler", 1, 2, 2, 1); __PYX_ERR(2, 301, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__sighandler") < 0)) __PYX_ERR(2, 301, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_signum = values[0];
    __pyx_v_frame = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__sighandler", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 301, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.__sighandler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_6__sighandler(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_signum, __pyx_v_frame);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_6__sighandler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_signum, CYTHON_UNUSED PyObject *__pyx_v_frame) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__sighandler", 0);

  /* "uvloop/loop.pyx":302
 * 
 *     def __sighandler(self, signum, frame):
 *         self._signals.add(signum)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _ceval_process_signals(self):
 */
  if (unlikely(__pyx_v_self->_signals == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(2, 302, __pyx_L1_error)
  }
  __pyx_t_1 = PySet_Add(__pyx_v_self->_signals, __pyx_v_signum); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 302, __pyx_L1_error)

  /* "uvloop/loop.pyx":301
 *         self._listening_signals = False
 * 
 *     def __sighandler(self, signum, frame):             # <<<<<<<<<<<<<<
 *         self._signals.add(signum)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.__sighandler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":304
 *         self._signals.add(signum)
 * 
 *     cdef inline _ceval_process_signals(self):             # <<<<<<<<<<<<<<
 *         # Invoke CPython eval loop to let process signals.
 *         PyErr_CheckSignals()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__ceval_process_signals(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_ceval_process_signals", 0);

  /* "uvloop/loop.pyx":306
 *     cdef inline _ceval_process_signals(self):
 *         # Invoke CPython eval loop to let process signals.
 *         PyErr_CheckSignals()             # <<<<<<<<<<<<<<
 *         # Calling a pure-Python function will invoke
 *         # _PyEval_EvalFrameDefault which will process
 */
  __pyx_t_1 = PyErr_CheckSignals(); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 306, __pyx_L1_error)

  /* "uvloop/loop.pyx":310
 *         # _PyEval_EvalFrameDefault which will process
 *         # pending signal callbacks.
 *         _noop.noop()  # Might raise ^C             # <<<<<<<<<<<<<<
 * 
 *     cdef _read_from_self(self):
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_noop); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_noop_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 310, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 310, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":304
 *         self._signals.add(signum)
 * 
 *     cdef inline _ceval_process_signals(self):             # <<<<<<<<<<<<<<
 *         # Invoke CPython eval loop to let process signals.
 *         PyErr_CheckSignals()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop._ceval_process_signals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":312
 *         _noop.noop()  # Might raise ^C
 * 
 *     cdef _read_from_self(self):             # <<<<<<<<<<<<<<
 *         cdef bytes sigdata
 *         sigdata = b''
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__read_from_self(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_v_sigdata = 0;
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("_read_from_self", 0);

  /* "uvloop/loop.pyx":314
 *     cdef _read_from_self(self):
 *         cdef bytes sigdata
 *         sigdata = b''             # <<<<<<<<<<<<<<
 *         while True:
 *             try:
 */
  __Pyx_INCREF(__pyx_kp_b__7);
  __pyx_v_sigdata = __pyx_kp_b__7;

  /* "uvloop/loop.pyx":315
 *         cdef bytes sigdata
 *         sigdata = b''
 *         while True:             # <<<<<<<<<<<<<<
 *             try:
 *                 data = self._ssock.recv(65536)
 */
  while (1) {

    /* "uvloop/loop.pyx":316
 *         sigdata = b''
 *         while True:
 *             try:             # <<<<<<<<<<<<<<
 *                 data = self._ssock.recv(65536)
 *                 if not data:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      /*try:*/ {

        /* "uvloop/loop.pyx":317
 *         while True:
 *             try:
 *                 data = self._ssock.recv(65536)             # <<<<<<<<<<<<<<
 *                 if not data:
 *                     break
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_ssock, __pyx_n_s_recv); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 317, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 317, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF_SET(__pyx_v_data, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "uvloop/loop.pyx":318
 *             try:
 *                 data = self._ssock.recv(65536)
 *                 if not data:             # <<<<<<<<<<<<<<
 *                     break
 *                 sigdata += data
 */
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 318, __pyx_L5_error)
        __pyx_t_7 = ((!__pyx_t_6) != 0);
        if (__pyx_t_7) {

          /* "uvloop/loop.pyx":319
 *                 data = self._ssock.recv(65536)
 *                 if not data:
 *                     break             # <<<<<<<<<<<<<<
 *                 sigdata += data
 *             except InterruptedError:
 */
          goto __pyx_L10_try_break;

          /* "uvloop/loop.pyx":318
 *             try:
 *                 data = self._ssock.recv(65536)
 *                 if not data:             # <<<<<<<<<<<<<<
 *                     break
 *                 sigdata += data
 */
        }

        /* "uvloop/loop.pyx":320
 *                 if not data:
 *                     break
 *                 sigdata += data             # <<<<<<<<<<<<<<
 *             except InterruptedError:
 *                 continue
 */
        __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_v_sigdata, __pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 320, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (!(likely(PyBytes_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_5)->tp_name), 0))) __PYX_ERR(2, 320, __pyx_L5_error)
        __Pyx_DECREF_SET(__pyx_v_sigdata, ((PyObject*)__pyx_t_5));
        __pyx_t_5 = 0;

        /* "uvloop/loop.pyx":316
 *         sigdata = b''
 *         while True:
 *             try:             # <<<<<<<<<<<<<<
 *                 data = self._ssock.recv(65536)
 *                 if not data:
 */
      }
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L12_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":321
 *                     break
 *                 sigdata += data
 *             except InterruptedError:             # <<<<<<<<<<<<<<
 *                 continue
 *             except BlockingIOError:
 */
      __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_8);
      __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 321, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_5, __pyx_t_9);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_ErrRestore(__pyx_t_5, __pyx_t_4, __pyx_t_8);
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_8 = 0;
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop._read_from_self", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(2, 321, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_5);

        /* "uvloop/loop.pyx":322
 *                 sigdata += data
 *             except InterruptedError:
 *                 continue             # <<<<<<<<<<<<<<
 *             except BlockingIOError:
 *                 break
 */
        goto __pyx_L15_except_continue;
        __pyx_L15_except_continue:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L11_try_continue;
      }

      /* "uvloop/loop.pyx":323
 *             except InterruptedError:
 *                 continue
 *             except BlockingIOError:             # <<<<<<<<<<<<<<
 *                 break
 *         if sigdata:
 */
      __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_8);
      __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 323, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_5, __pyx_t_9);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_ErrRestore(__pyx_t_5, __pyx_t_4, __pyx_t_8);
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_8 = 0;
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop._read_from_self", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(2, 323, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_5);

        /* "uvloop/loop.pyx":324
 *                 continue
 *             except BlockingIOError:
 *                 break             # <<<<<<<<<<<<<<
 *         if sigdata:
 *             self._invoke_signals(sigdata)
 */
        goto __pyx_L16_except_break;
        __pyx_L16_except_break:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L10_try_break;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "uvloop/loop.pyx":316
 *         sigdata = b''
 *         while True:
 *             try:             # <<<<<<<<<<<<<<
 *                 data = self._ssock.recv(65536)
 *                 if not data:
 */
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L1_error;
      __pyx_L10_try_break:;
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L4_break;
      __pyx_L11_try_continue:;
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      goto __pyx_L3_continue;
      __pyx_L12_try_end:;
    }
    __pyx_L3_continue:;
  }
  __pyx_L4_break:;

  /* "uvloop/loop.pyx":325
 *             except BlockingIOError:
 *                 break
 *         if sigdata:             # <<<<<<<<<<<<<<
 *             self._invoke_signals(sigdata)
 * 
 */
  __pyx_t_7 = (__pyx_v_sigdata != Py_None)&&(PyBytes_GET_SIZE(__pyx_v_sigdata) != 0);
  if (__pyx_t_7) {

    /* "uvloop/loop.pyx":326
 *                 break
 *         if sigdata:
 *             self._invoke_signals(sigdata)             # <<<<<<<<<<<<<<
 * 
 *     cdef _invoke_signals(self, bytes data):
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_invoke_signals(__pyx_v_self, __pyx_v_sigdata); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 326, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":325
 *             except BlockingIOError:
 *                 break
 *         if sigdata:             # <<<<<<<<<<<<<<
 *             self._invoke_signals(sigdata)
 * 
 */
  }

  /* "uvloop/loop.pyx":312
 *         _noop.noop()  # Might raise ^C
 * 
 *     cdef _read_from_self(self):             # <<<<<<<<<<<<<<
 *         cdef bytes sigdata
 *         sigdata = b''
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.Loop._read_from_self", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sigdata);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":328
 *             self._invoke_signals(sigdata)
 * 
 *     cdef _invoke_signals(self, bytes data):             # <<<<<<<<<<<<<<
 *         cdef set sigs
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__invoke_signals(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_v_sigs = 0;
  PyObject *__pyx_v_signum = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("_invoke_signals", 0);

  /* "uvloop/loop.pyx":331
 *         cdef set sigs
 * 
 *         self._ceval_process_signals()             # <<<<<<<<<<<<<<
 * 
 *         sigs = self._signals.copy()
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__ceval_process_signals(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":333
 *         self._ceval_process_signals()
 * 
 *         sigs = self._signals.copy()             # <<<<<<<<<<<<<<
 *         self._signals.clear()
 *         for signum in data:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_signals, __pyx_n_s_copy); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 333, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 333, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(PySet_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "set", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(2, 333, __pyx_L1_error)
  __pyx_v_sigs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":334
 * 
 *         sigs = self._signals.copy()
 *         self._signals.clear()             # <<<<<<<<<<<<<<
 *         for signum in data:
 *             if not signum:
 */
  if (unlikely(__pyx_v_self->_signals == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
    __PYX_ERR(2, 334, __pyx_L1_error)
  }
  __pyx_t_4 = PySet_Clear(__pyx_v_self->_signals); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 334, __pyx_L1_error)

  /* "uvloop/loop.pyx":335
 *         sigs = self._signals.copy()
 *         self._signals.clear()
 *         for signum in data:             # <<<<<<<<<<<<<<
 *             if not signum:
 *                 # ignore null bytes written by set_wakeup_fd()
 */
  __pyx_t_1 = PyObject_GetIter(__pyx_v_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 335, __pyx_L1_error)
  for (;;) {
    {
      __pyx_t_2 = __pyx_t_5(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(2, 335, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_signum, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":336
 *         self._signals.clear()
 *         for signum in data:
 *             if not signum:             # <<<<<<<<<<<<<<
 *                 # ignore null bytes written by set_wakeup_fd()
 *                 continue
 */
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_signum); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 336, __pyx_L1_error)
    __pyx_t_7 = ((!__pyx_t_6) != 0);
    if (__pyx_t_7) {

      /* "uvloop/loop.pyx":338
 *             if not signum:
 *                 # ignore null bytes written by set_wakeup_fd()
 *                 continue             # <<<<<<<<<<<<<<
 *             sigs.discard(signum)
 *             self._handle_signal(signum)
 */
      goto __pyx_L3_continue;

      /* "uvloop/loop.pyx":336
 *         self._signals.clear()
 *         for signum in data:
 *             if not signum:             # <<<<<<<<<<<<<<
 *                 # ignore null bytes written by set_wakeup_fd()
 *                 continue
 */
    }

    /* "uvloop/loop.pyx":339
 *                 # ignore null bytes written by set_wakeup_fd()
 *                 continue
 *             sigs.discard(signum)             # <<<<<<<<<<<<<<
 *             self._handle_signal(signum)
 * 
 */
    if (unlikely(__pyx_v_sigs == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "discard");
      __PYX_ERR(2, 339, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PySet_Discard(__pyx_v_sigs, __pyx_v_signum); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 339, __pyx_L1_error)

    /* "uvloop/loop.pyx":340
 *                 continue
 *             sigs.discard(signum)
 *             self._handle_signal(signum)             # <<<<<<<<<<<<<<
 * 
 *         for signum in sigs:
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_handle_signal(__pyx_v_self, __pyx_v_signum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":335
 *         sigs = self._signals.copy()
 *         self._signals.clear()
 *         for signum in data:             # <<<<<<<<<<<<<<
 *             if not signum:
 *                 # ignore null bytes written by set_wakeup_fd()
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":342
 *             self._handle_signal(signum)
 * 
 *         for signum in sigs:             # <<<<<<<<<<<<<<
 *             # Since not all signals are registered by add_signal_handler()
 *             # (for instance, we use the default SIGINT handler) not all
 */
  __pyx_t_8 = 0;
  __pyx_t_2 = __Pyx_set_iterator(__pyx_v_sigs, 1, (&__pyx_t_9), (&__pyx_t_10)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_2;
  __pyx_t_2 = 0;
  while (1) {
    __pyx_t_11 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_9, &__pyx_t_8, &__pyx_t_2, __pyx_t_10);
    if (unlikely(__pyx_t_11 == 0)) break;
    if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(2, 342, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_signum, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":349
 *             # from __sighandler; this ensures that signals shouldn't be
 *             # lost even if set_wakeup_fd() couldn't write to the self-pipe.
 *             self._handle_signal(signum)             # <<<<<<<<<<<<<<
 * 
 *     cdef _handle_signal(self, sig):
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_handle_signal(__pyx_v_self, __pyx_v_signum); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 349, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":328
 *             self._invoke_signals(sigdata)
 * 
 *     cdef _invoke_signals(self, bytes data):             # <<<<<<<<<<<<<<
 *         cdef set sigs
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.Loop._invoke_signals", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sigs);
  __Pyx_XDECREF(__pyx_v_signum);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":351
 *             self._handle_signal(signum)
 * 
 *     cdef _handle_signal(self, sig):             # <<<<<<<<<<<<<<
 *         cdef Handle handle
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__handle_signal(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("_handle_signal", 0);

  /* "uvloop/loop.pyx":354
 *         cdef Handle handle
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             handle = <Handle>(self._signal_handlers[sig])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/loop.pyx":355
 * 
 *         try:
 *             handle = <Handle>(self._signal_handlers[sig])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             handle = None
 */
      if (unlikely(__pyx_v_self->_signal_handlers == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 355, __pyx_L3_error)
      }
      __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_self->_signal_handlers, __pyx_v_sig); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 355, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __pyx_t_4;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":354
 *         cdef Handle handle
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             handle = <Handle>(self._signal_handlers[sig])
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":356
 *         try:
 *             handle = <Handle>(self._signal_handlers[sig])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             handle = None
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.Loop._handle_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(2, 356, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);

      /* "uvloop/loop.pyx":357
 *             handle = <Handle>(self._signal_handlers[sig])
 *         except KeyError:
 *             handle = None             # <<<<<<<<<<<<<<
 * 
 *         if handle is None:
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_handle, ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None));
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":354
 *         cdef Handle handle
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             handle = <Handle>(self._signal_handlers[sig])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "uvloop/loop.pyx":359
 *             handle = None
 * 
 *         if handle is None:             # <<<<<<<<<<<<<<
 *             self._ceval_process_signals()
 *             return
 */
  __pyx_t_8 = (((PyObject *)__pyx_v_handle) == Py_None);
  __pyx_t_9 = (__pyx_t_8 != 0);
  if (__pyx_t_9) {

    /* "uvloop/loop.pyx":360
 * 
 *         if handle is None:
 *             self._ceval_process_signals()             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_7 = __pyx_f_6uvloop_4loop_4Loop__ceval_process_signals(__pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 360, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":361
 *         if handle is None:
 *             self._ceval_process_signals()
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if handle._cancelled:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":359
 *             handle = None
 * 
 *         if handle is None:             # <<<<<<<<<<<<<<
 *             self._ceval_process_signals()
 *             return
 */
  }

  /* "uvloop/loop.pyx":363
 *             return
 * 
 *         if handle._cancelled:             # <<<<<<<<<<<<<<
 *             self.remove_signal_handler(sig)  # Remove it properly.
 *         else:
 */
  __pyx_t_9 = (__pyx_v_handle->_cancelled != 0);
  if (__pyx_t_9) {

    /* "uvloop/loop.pyx":364
 * 
 *         if handle._cancelled:
 *             self.remove_signal_handler(sig)  # Remove it properly.             # <<<<<<<<<<<<<<
 *         else:
 *             self._call_soon_handle(handle)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_remove_signal_handler); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_sig); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 364, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_sig};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 364, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_sig};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 364, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 364, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_sig);
        __Pyx_GIVEREF(__pyx_v_sig);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_sig);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_10, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 364, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":363
 *             return
 * 
 *         if handle._cancelled:             # <<<<<<<<<<<<<<
 *             self.remove_signal_handler(sig)  # Remove it properly.
 *         else:
 */
    goto __pyx_L12;
  }

  /* "uvloop/loop.pyx":366
 *             self.remove_signal_handler(sig)  # Remove it properly.
 *         else:
 *             self._call_soon_handle(handle)             # <<<<<<<<<<<<<<
 *             self.handler_async.send()
 * 
 */
  /*else*/ {
    __pyx_t_7 = __pyx_f_6uvloop_4loop_4Loop__call_soon_handle(__pyx_v_self, __pyx_v_handle); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 366, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":367
 *         else:
 *             self._call_soon_handle(handle)
 *             self.handler_async.send()             # <<<<<<<<<<<<<<
 * 
 *     cdef _on_wake(self):
 */
    __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->handler_async->__pyx_base.__pyx_vtab)->send(__pyx_v_self->handler_async); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L12:;

  /* "uvloop/loop.pyx":351
 *             self._handle_signal(signum)
 * 
 *     cdef _handle_signal(self, sig):             # <<<<<<<<<<<<<<
 *         cdef Handle handle
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.Loop._handle_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":369
 *             self.handler_async.send()
 * 
 *     cdef _on_wake(self):             # <<<<<<<<<<<<<<
 *         if (self._ready_len > 0 or self._stopping) \
 *                             and not self.handler_idle.running:
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__on_wake(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_on_wake", 0);

  /* "uvloop/loop.pyx":370
 * 
 *     cdef _on_wake(self):
 *         if (self._ready_len > 0 or self._stopping) \             # <<<<<<<<<<<<<<
 *                             and not self.handler_idle.running:
 *             self.handler_idle.start()
 */
  __pyx_t_2 = ((__pyx_v_self->_ready_len > 0) != 0);
  if (!__pyx_t_2) {
  } else {
    goto __pyx_L5_next_and;
  }
  __pyx_t_2 = (__pyx_v_self->_stopping != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_L5_next_and:;

  /* "uvloop/loop.pyx":371
 *     cdef _on_wake(self):
 *         if (self._ready_len > 0 or self._stopping) \
 *                             and not self.handler_idle.running:             # <<<<<<<<<<<<<<
 *             self.handler_idle.start()
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_self->handler_idle->running != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;

  /* "uvloop/loop.pyx":370
 * 
 *     cdef _on_wake(self):
 *         if (self._ready_len > 0 or self._stopping) \             # <<<<<<<<<<<<<<
 *                             and not self.handler_idle.running:
 *             self.handler_idle.start()
 */
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":372
 *         if (self._ready_len > 0 or self._stopping) \
 *                             and not self.handler_idle.running:
 *             self.handler_idle.start()             # <<<<<<<<<<<<<<
 * 
 *     cdef _on_idle(self):
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_6UVIdle_start(__pyx_v_self->handler_idle); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":370
 * 
 *     cdef _on_wake(self):
 *         if (self._ready_len > 0 or self._stopping) \             # <<<<<<<<<<<<<<
 *                             and not self.handler_idle.running:
 *             self.handler_idle.start()
 */
  }

  /* "uvloop/loop.pyx":369
 *             self.handler_async.send()
 * 
 *     cdef _on_wake(self):             # <<<<<<<<<<<<<<
 *         if (self._ready_len > 0 or self._stopping) \
 *                             and not self.handler_idle.running:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.Loop._on_wake", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":374
 *             self.handler_idle.start()
 * 
 *     cdef _on_idle(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int i, ntodo
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__on_idle(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  CYTHON_UNUSED int __pyx_v_i;
  int __pyx_v_ntodo;
  PyObject *__pyx_v_popleft = 0;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handler = 0;
  PyObject *__pyx_v_started = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_delta = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  char const *__pyx_t_21;
  int __pyx_t_22;
  __Pyx_RefNannySetupContext("_on_idle", 0);

  /* "uvloop/loop.pyx":377
 *         cdef:
 *             int i, ntodo
 *             object popleft = self._ready.popleft             # <<<<<<<<<<<<<<
 *             Handle handler
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_ready, __pyx_n_s_popleft); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_popleft = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":380
 *             Handle handler
 * 
 *         ntodo = len(self._ready)             # <<<<<<<<<<<<<<
 *         if self._debug:
 *             for i from 0 <= i < ntodo:
 */
  __pyx_t_1 = __pyx_v_self->_ready;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(2, 380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_ntodo = __pyx_t_2;

  /* "uvloop/loop.pyx":381
 * 
 *         ntodo = len(self._ready)
 *         if self._debug:             # <<<<<<<<<<<<<<
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()
 */
  __pyx_t_3 = (__pyx_v_self->_debug != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":382
 *         ntodo = len(self._ready)
 *         if self._debug:
 *             for i from 0 <= i < ntodo:             # <<<<<<<<<<<<<<
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 */
    __pyx_t_4 = __pyx_v_ntodo;
    for (__pyx_v_i = 0; __pyx_v_i < __pyx_t_4; __pyx_v_i++) {

      /* "uvloop/loop.pyx":383
 *         if self._debug:
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()             # <<<<<<<<<<<<<<
 *                 if handler._cancelled == 0:
 *                     try:
 */
      __Pyx_INCREF(__pyx_v_popleft);
      __pyx_t_5 = __pyx_v_popleft; __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_6) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 383, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 383, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_handler, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_5));
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":384
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:             # <<<<<<<<<<<<<<
 *                     try:
 *                         started = time_monotonic()
 */
      __pyx_t_3 = ((__pyx_v_handler->_cancelled == 0) != 0);
      if (__pyx_t_3) {

        /* "uvloop/loop.pyx":385
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 *                     try:             # <<<<<<<<<<<<<<
 *                         started = time_monotonic()
 *                         handler._run()
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          /*try:*/ {

            /* "uvloop/loop.pyx":386
 *                 if handler._cancelled == 0:
 *                     try:
 *                         started = time_monotonic()             # <<<<<<<<<<<<<<
 *                         handler._run()
 *                     except BaseException as ex:
 */
            __Pyx_INCREF(__pyx_v_6uvloop_4loop_time_monotonic);
            __pyx_t_1 = __pyx_v_6uvloop_4loop_time_monotonic; __pyx_t_6 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_6)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
              }
            }
            if (__pyx_t_6) {
              __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 386, __pyx_L7_error)
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else {
              __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 386, __pyx_L7_error)
            }
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF_SET(__pyx_v_started, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "uvloop/loop.pyx":387
 *                     try:
 *                         started = time_monotonic()
 *                         handler._run()             # <<<<<<<<<<<<<<
 *                     except BaseException as ex:
 *                         self._stop(ex)
 */
            __pyx_t_5 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_handler); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 387, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "uvloop/loop.pyx":385
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 *                     try:             # <<<<<<<<<<<<<<
 *                         started = time_monotonic()
 *                         handler._run()
 */
          }

          /* "uvloop/loop.pyx":392
 *                         return
 *                     else:
 *                         delta = time_monotonic() - started             # <<<<<<<<<<<<<<
 *                         if delta > self.slow_callback_duration:
 *                             aio_logger.warning(
 */
          /*else:*/ {
            __Pyx_INCREF(__pyx_v_6uvloop_4loop_time_monotonic);
            __pyx_t_1 = __pyx_v_6uvloop_4loop_time_monotonic; __pyx_t_6 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_6)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_6);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
              }
            }
            if (__pyx_t_6) {
              __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 392, __pyx_L9_except_error)
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else {
              __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 392, __pyx_L9_except_error)
            }
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = PyNumber_Subtract(__pyx_t_5, __pyx_v_started); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 392, __pyx_L9_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF_SET(__pyx_v_delta, __pyx_t_1);
            __pyx_t_1 = 0;

            /* "uvloop/loop.pyx":393
 *                     else:
 *                         delta = time_monotonic() - started
 *                         if delta > self.slow_callback_duration:             # <<<<<<<<<<<<<<
 *                             aio_logger.warning(
 *                                 'Executing %s took %.3f seconds',
 */
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_delta, __pyx_v_self->slow_callback_duration, Py_GT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 393, __pyx_L9_except_error)
            __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 393, __pyx_L9_except_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_3) {

              /* "uvloop/loop.pyx":394
 *                         delta = time_monotonic() - started
 *                         if delta > self.slow_callback_duration:
 *                             aio_logger.warning(             # <<<<<<<<<<<<<<
 *                                 'Executing %s took %.3f seconds',
 *                                 handler._format_handle(), delta)
 */
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_warning); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 394, __pyx_L9_except_error)
              __Pyx_GOTREF(__pyx_t_5);

              /* "uvloop/loop.pyx":396
 *                             aio_logger.warning(
 *                                 'Executing %s took %.3f seconds',
 *                                 handler._format_handle(), delta)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
              __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_handler->__pyx_vtab)->_format_handle(__pyx_v_handler); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 396, __pyx_L9_except_error)
              __Pyx_GOTREF(__pyx_t_6);
              __pyx_t_10 = NULL;
              __pyx_t_11 = 0;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
                __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
                if (likely(__pyx_t_10)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                  __Pyx_INCREF(__pyx_t_10);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_5, function);
                  __pyx_t_11 = 1;
                }
              }
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_5)) {
                PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Executing_s_took_3f_seconds, __pyx_t_6, __pyx_v_delta};
                __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 394, __pyx_L9_except_error)
                __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
                PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Executing_s_took_3f_seconds, __pyx_t_6, __pyx_v_delta};
                __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 394, __pyx_L9_except_error)
                __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              } else
              #endif
              {
                __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 394, __pyx_L9_except_error)
                __Pyx_GOTREF(__pyx_t_12);
                if (__pyx_t_10) {
                  __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
                }
                __Pyx_INCREF(__pyx_kp_u_Executing_s_took_3f_seconds);
                __Pyx_GIVEREF(__pyx_kp_u_Executing_s_took_3f_seconds);
                PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Executing_s_took_3f_seconds);
                __Pyx_GIVEREF(__pyx_t_6);
                PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_6);
                __Pyx_INCREF(__pyx_v_delta);
                __Pyx_GIVEREF(__pyx_v_delta);
                PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_v_delta);
                __pyx_t_6 = 0;
                __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 394, __pyx_L9_except_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              }
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

              /* "uvloop/loop.pyx":393
 *                     else:
 *                         delta = time_monotonic() - started
 *                         if delta > self.slow_callback_duration:             # <<<<<<<<<<<<<<
 *                             aio_logger.warning(
 *                                 'Executing %s took %.3f seconds',
 */
            }
          }
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L14_try_end;
          __pyx_L7_error:;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "uvloop/loop.pyx":388
 *                         started = time_monotonic()
 *                         handler._run()
 *                     except BaseException as ex:             # <<<<<<<<<<<<<<
 *                         self._stop(ex)
 *                         return
 */
          __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
          if (__pyx_t_11) {
            __Pyx_AddTraceback("uvloop.loop.Loop._on_idle", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_5, &__pyx_t_12) < 0) __PYX_ERR(2, 388, __pyx_L9_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_INCREF(__pyx_t_5);
            __pyx_v_ex = __pyx_t_5;
            /*try:*/ {

              /* "uvloop/loop.pyx":389
 *                         handler._run()
 *                     except BaseException as ex:
 *                         self._stop(ex)             # <<<<<<<<<<<<<<
 *                         return
 *                     else:
 */
              __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_stop(__pyx_v_self, __pyx_v_ex); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 389, __pyx_L21_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "uvloop/loop.pyx":390
 *                     except BaseException as ex:
 *                         self._stop(ex)
 *                         return             # <<<<<<<<<<<<<<
 *                     else:
 *                         delta = time_monotonic() - started
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_r = Py_None; __Pyx_INCREF(Py_None);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              goto __pyx_L20_return;
            }

            /* "uvloop/loop.pyx":388
 *                         started = time_monotonic()
 *                         handler._run()
 *                     except BaseException as ex:             # <<<<<<<<<<<<<<
 *                         self._stop(ex)
 *                         return
 */
            /*finally:*/ {
              __pyx_L21_error:;
              /*exception exit:*/{
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
                __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
                if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
                __Pyx_XGOTREF(__pyx_t_15);
                __Pyx_XGOTREF(__pyx_t_16);
                __Pyx_XGOTREF(__pyx_t_17);
                __Pyx_XGOTREF(__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_20);
                __pyx_t_11 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
                {
                  __Pyx_DECREF(__pyx_v_ex);
                  __pyx_v_ex = NULL;
                }
                if (PY_MAJOR_VERSION >= 3) {
                  __Pyx_XGIVEREF(__pyx_t_18);
                  __Pyx_XGIVEREF(__pyx_t_19);
                  __Pyx_XGIVEREF(__pyx_t_20);
                  __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
                }
                __Pyx_XGIVEREF(__pyx_t_15);
                __Pyx_XGIVEREF(__pyx_t_16);
                __Pyx_XGIVEREF(__pyx_t_17);
                __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
                __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
                __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
                goto __pyx_L9_except_error;
              }
              __pyx_L20_return: {
                __pyx_t_20 = __pyx_r;
                __pyx_r = 0;
                __Pyx_DECREF(__pyx_v_ex);
                __pyx_v_ex = NULL;
                __pyx_r = __pyx_t_20;
                __pyx_t_20 = 0;
                goto __pyx_L10_except_return;
              }
            }
          }
          goto __pyx_L9_except_error;
          __pyx_L9_except_error:;

          /* "uvloop/loop.pyx":385
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 *                     try:             # <<<<<<<<<<<<<<
 *                         started = time_monotonic()
 *                         handler._run()
 */
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          goto __pyx_L1_error;
          __pyx_L10_except_return:;
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          goto __pyx_L0;
          __pyx_L14_try_end:;
        }

        /* "uvloop/loop.pyx":384
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:             # <<<<<<<<<<<<<<
 *                     try:
 *                         started = time_monotonic()
 */
      }
    }

    /* "uvloop/loop.pyx":381
 * 
 *         ntodo = len(self._ready)
 *         if self._debug:             # <<<<<<<<<<<<<<
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":399
 * 
 *         else:
 *             for i from 0 <= i < ntodo:             # <<<<<<<<<<<<<<
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 */
  /*else*/ {
    __pyx_t_4 = __pyx_v_ntodo;
    for (__pyx_v_i = 0; __pyx_v_i < __pyx_t_4; __pyx_v_i++) {

      /* "uvloop/loop.pyx":400
 *         else:
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()             # <<<<<<<<<<<<<<
 *                 if handler._cancelled == 0:
 *                     try:
 */
      __Pyx_INCREF(__pyx_v_popleft);
      __pyx_t_5 = __pyx_v_popleft; __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_1) {
        __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 400, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        __pyx_t_12 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 400, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __pyx_t_12;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF_SET(__pyx_v_handler, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_5));
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":401
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:             # <<<<<<<<<<<<<<
 *                     try:
 *                         handler._run()
 */
      __pyx_t_3 = ((__pyx_v_handler->_cancelled == 0) != 0);
      if (__pyx_t_3) {

        /* "uvloop/loop.pyx":402
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 *                     try:             # <<<<<<<<<<<<<<
 *                         handler._run()
 *                     except BaseException as ex:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_8, &__pyx_t_7);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_7);
          /*try:*/ {

            /* "uvloop/loop.pyx":403
 *                 if handler._cancelled == 0:
 *                     try:
 *                         handler._run()             # <<<<<<<<<<<<<<
 *                     except BaseException as ex:
 *                         self._stop(ex)
 */
            __pyx_t_5 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_handler); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 403, __pyx_L30_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "uvloop/loop.pyx":402
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 *                     try:             # <<<<<<<<<<<<<<
 *                         handler._run()
 *                     except BaseException as ex:
 */
          }
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          goto __pyx_L37_try_end;
          __pyx_L30_error:;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "uvloop/loop.pyx":404
 *                     try:
 *                         handler._run()
 *                     except BaseException as ex:             # <<<<<<<<<<<<<<
 *                         self._stop(ex)
 *                         return
 */
          __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
          if (__pyx_t_13) {
            __Pyx_AddTraceback("uvloop.loop.Loop._on_idle", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_12, &__pyx_t_1) < 0) __PYX_ERR(2, 404, __pyx_L32_except_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_12);
            __pyx_v_ex = __pyx_t_12;
            /*try:*/ {

              /* "uvloop/loop.pyx":405
 *                         handler._run()
 *                     except BaseException as ex:
 *                         self._stop(ex)             # <<<<<<<<<<<<<<
 *                         return
 * 
 */
              __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_stop(__pyx_v_self, __pyx_v_ex); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 405, __pyx_L43_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "uvloop/loop.pyx":406
 *                     except BaseException as ex:
 *                         self._stop(ex)
 *                         return             # <<<<<<<<<<<<<<
 * 
 *         if len(self._queued_streams):
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_r = Py_None; __Pyx_INCREF(Py_None);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              goto __pyx_L42_return;
            }

            /* "uvloop/loop.pyx":404
 *                     try:
 *                         handler._run()
 *                     except BaseException as ex:             # <<<<<<<<<<<<<<
 *                         self._stop(ex)
 *                         return
 */
            /*finally:*/ {
              __pyx_L43_error:;
              /*exception exit:*/{
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
                __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
                if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_17);
                __Pyx_XGOTREF(__pyx_t_16);
                __Pyx_XGOTREF(__pyx_t_15);
                __pyx_t_13 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
                {
                  __Pyx_DECREF(__pyx_v_ex);
                  __pyx_v_ex = NULL;
                }
                if (PY_MAJOR_VERSION >= 3) {
                  __Pyx_XGIVEREF(__pyx_t_17);
                  __Pyx_XGIVEREF(__pyx_t_16);
                  __Pyx_XGIVEREF(__pyx_t_15);
                  __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
                }
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_ErrRestore(__pyx_t_20, __pyx_t_19, __pyx_t_18);
                __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
                __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_21;
                goto __pyx_L32_except_error;
              }
              __pyx_L42_return: {
                __pyx_t_15 = __pyx_r;
                __pyx_r = 0;
                __Pyx_DECREF(__pyx_v_ex);
                __pyx_v_ex = NULL;
                __pyx_r = __pyx_t_15;
                __pyx_t_15 = 0;
                goto __pyx_L33_except_return;
              }
            }
          }
          goto __pyx_L32_except_error;
          __pyx_L32_except_error:;

          /* "uvloop/loop.pyx":402
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:
 *                     try:             # <<<<<<<<<<<<<<
 *                         handler._run()
 *                     except BaseException as ex:
 */
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
          goto __pyx_L1_error;
          __pyx_L33_except_return:;
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
          goto __pyx_L0;
          __pyx_L37_try_end:;
        }

        /* "uvloop/loop.pyx":401
 *             for i from 0 <= i < ntodo:
 *                 handler = <Handle> popleft()
 *                 if handler._cancelled == 0:             # <<<<<<<<<<<<<<
 *                     try:
 *                         handler._run()
 */
      }
    }
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":408
 *                         return
 * 
 *         if len(self._queued_streams):             # <<<<<<<<<<<<<<
 *             self._exec_queued_writes()
 * 
 */
  __pyx_t_1 = __pyx_v_self->_queued_streams;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(2, 408, __pyx_L1_error)
  }
  __pyx_t_2 = PySet_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(2, 408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":409
 * 
 *         if len(self._queued_streams):
 *             self._exec_queued_writes()             # <<<<<<<<<<<<<<
 * 
 *         self._ready_len = len(self._ready)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_exec_queued_writes(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":408
 *                         return
 * 
 *         if len(self._queued_streams):             # <<<<<<<<<<<<<<
 *             self._exec_queued_writes()
 * 
 */
  }

  /* "uvloop/loop.pyx":411
 *             self._exec_queued_writes()
 * 
 *         self._ready_len = len(self._ready)             # <<<<<<<<<<<<<<
 *         if self._ready_len == 0 and self.handler_idle.running:
 *             self.handler_idle.stop()
 */
  __pyx_t_1 = __pyx_v_self->_ready;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(2, 411, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_self->_ready_len = __pyx_t_2;

  /* "uvloop/loop.pyx":412
 * 
 *         self._ready_len = len(self._ready)
 *         if self._ready_len == 0 and self.handler_idle.running:             # <<<<<<<<<<<<<<
 *             self.handler_idle.stop()
 * 
 */
  __pyx_t_22 = ((__pyx_v_self->_ready_len == 0) != 0);
  if (__pyx_t_22) {
  } else {
    __pyx_t_3 = __pyx_t_22;
    goto __pyx_L51_bool_binop_done;
  }
  __pyx_t_22 = (__pyx_v_self->handler_idle->running != 0);
  __pyx_t_3 = __pyx_t_22;
  __pyx_L51_bool_binop_done:;
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":413
 *         self._ready_len = len(self._ready)
 *         if self._ready_len == 0 and self.handler_idle.running:
 *             self.handler_idle.stop()             # <<<<<<<<<<<<<<
 * 
 *         if self._stopping:
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_6UVIdle_stop(__pyx_v_self->handler_idle); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":412
 * 
 *         self._ready_len = len(self._ready)
 *         if self._ready_len == 0 and self.handler_idle.running:             # <<<<<<<<<<<<<<
 *             self.handler_idle.stop()
 * 
 */
  }

  /* "uvloop/loop.pyx":415
 *             self.handler_idle.stop()
 * 
 *         if self._stopping:             # <<<<<<<<<<<<<<
 *             uv.uv_stop(self.uvloop)  # void
 * 
 */
  __pyx_t_3 = (__pyx_v_self->_stopping != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":416
 * 
 *         if self._stopping:
 *             uv.uv_stop(self.uvloop)  # void             # <<<<<<<<<<<<<<
 * 
 *     cdef _stop(self, exc):
 */
    uv_stop(__pyx_v_self->uvloop);

    /* "uvloop/loop.pyx":415
 *             self.handler_idle.stop()
 * 
 *         if self._stopping:             # <<<<<<<<<<<<<<
 *             uv.uv_stop(self.uvloop)  # void
 * 
 */
  }

  /* "uvloop/loop.pyx":374
 *             self.handler_idle.start()
 * 
 *     cdef _on_idle(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int i, ntodo
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.Loop._on_idle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_popleft);
  __Pyx_XDECREF((PyObject *)__pyx_v_handler);
  __Pyx_XDECREF(__pyx_v_started);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_delta);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":418
 *             uv.uv_stop(self.uvloop)  # void
 * 
 *     cdef _stop(self, exc):             # <<<<<<<<<<<<<<
 *         if exc is not None:
 *             self._last_error = exc
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__stop(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_stop", 0);

  /* "uvloop/loop.pyx":419
 * 
 *     cdef _stop(self, exc):
 *         if exc is not None:             # <<<<<<<<<<<<<<
 *             self._last_error = exc
 *         if self._stopping == 1:
 */
  __pyx_t_1 = (__pyx_v_exc != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":420
 *     cdef _stop(self, exc):
 *         if exc is not None:
 *             self._last_error = exc             # <<<<<<<<<<<<<<
 *         if self._stopping == 1:
 *             return
 */
    __Pyx_INCREF(__pyx_v_exc);
    __Pyx_GIVEREF(__pyx_v_exc);
    __Pyx_GOTREF(__pyx_v_self->_last_error);
    __Pyx_DECREF(__pyx_v_self->_last_error);
    __pyx_v_self->_last_error = __pyx_v_exc;

    /* "uvloop/loop.pyx":419
 * 
 *     cdef _stop(self, exc):
 *         if exc is not None:             # <<<<<<<<<<<<<<
 *             self._last_error = exc
 *         if self._stopping == 1:
 */
  }

  /* "uvloop/loop.pyx":421
 *         if exc is not None:
 *             self._last_error = exc
 *         if self._stopping == 1:             # <<<<<<<<<<<<<<
 *             return
 *         self._stopping = 1
 */
  __pyx_t_2 = ((__pyx_v_self->_stopping == 1) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":422
 *             self._last_error = exc
 *         if self._stopping == 1:
 *             return             # <<<<<<<<<<<<<<
 *         self._stopping = 1
 *         if not self.handler_idle.running:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":421
 *         if exc is not None:
 *             self._last_error = exc
 *         if self._stopping == 1:             # <<<<<<<<<<<<<<
 *             return
 *         self._stopping = 1
 */
  }

  /* "uvloop/loop.pyx":423
 *         if self._stopping == 1:
 *             return
 *         self._stopping = 1             # <<<<<<<<<<<<<<
 *         if not self.handler_idle.running:
 *             self.handler_idle.start()
 */
  __pyx_v_self->_stopping = 1;

  /* "uvloop/loop.pyx":424
 *             return
 *         self._stopping = 1
 *         if not self.handler_idle.running:             # <<<<<<<<<<<<<<
 *             self.handler_idle.start()
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_self->handler_idle->running != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":425
 *         self._stopping = 1
 *         if not self.handler_idle.running:
 *             self.handler_idle.start()             # <<<<<<<<<<<<<<
 * 
 *     cdef __run(self, uv.uv_run_mode mode):
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_6UVIdle_start(__pyx_v_self->handler_idle); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":424
 *             return
 *         self._stopping = 1
 *         if not self.handler_idle.running:             # <<<<<<<<<<<<<<
 *             self.handler_idle.start()
 * 
 */
  }

  /* "uvloop/loop.pyx":418
 *             uv.uv_stop(self.uvloop)  # void
 * 
 *     cdef _stop(self, exc):             # <<<<<<<<<<<<<<
 *         if exc is not None:
 *             self._last_error = exc
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.Loop._stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":427
 *             self.handler_idle.start()
 * 
 *     cdef __run(self, uv.uv_run_mode mode):             # <<<<<<<<<<<<<<
 *         # Although every UVHandle holds a reference to the loop,
 *         # we want to do everything to ensure that the loop will
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop___run(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, uv_run_mode __pyx_v_mode) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__run", 0);

  /* "uvloop/loop.pyx":432
 *         # never deallocate during the run -- so we do some
 *         # manual refs management.
 *         Py_INCREF(self)             # <<<<<<<<<<<<<<
 *         with nogil:
 *             err = uv.uv_run(self.uvloop, mode)
 */
  Py_INCREF(((PyObject *)__pyx_v_self));

  /* "uvloop/loop.pyx":433
 *         # manual refs management.
 *         Py_INCREF(self)
 *         with nogil:             # <<<<<<<<<<<<<<
 *             err = uv.uv_run(self.uvloop, mode)
 *         Py_DECREF(self)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "uvloop/loop.pyx":434
 *         Py_INCREF(self)
 *         with nogil:
 *             err = uv.uv_run(self.uvloop, mode)             # <<<<<<<<<<<<<<
 *         Py_DECREF(self)
 * 
 */
        __pyx_v_err = uv_run(__pyx_v_self->uvloop, __pyx_v_mode);
      }

      /* "uvloop/loop.pyx":433
 *         # manual refs management.
 *         Py_INCREF(self)
 *         with nogil:             # <<<<<<<<<<<<<<
 *             err = uv.uv_run(self.uvloop, mode)
 *         Py_DECREF(self)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "uvloop/loop.pyx":435
 *         with nogil:
 *             err = uv.uv_run(self.uvloop, mode)
 *         Py_DECREF(self)             # <<<<<<<<<<<<<<
 * 
 *         if err < 0:
 */
  Py_DECREF(((PyObject *)__pyx_v_self));

  /* "uvloop/loop.pyx":437
 *         Py_DECREF(self)
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":438
 * 
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *     cdef _run(self, uv.uv_run_mode mode):
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 438, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 438, __pyx_L1_error)

    /* "uvloop/loop.pyx":437
 *         Py_DECREF(self)
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  }

  /* "uvloop/loop.pyx":427
 *             self.handler_idle.start()
 * 
 *     cdef __run(self, uv.uv_run_mode mode):             # <<<<<<<<<<<<<<
 *         # Although every UVHandle holds a reference to the loop,
 *         # we want to do everything to ensure that the loop will
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop.__run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":440
 *             raise convert_error(err)
 * 
 *     cdef _run(self, uv.uv_run_mode mode):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__run(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, uv_run_mode __pyx_v_mode) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  char const *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("_run", 0);

  /* "uvloop/loop.pyx":443
 *         cdef int err
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('unable to start the loop; it was closed')
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_closed == 1) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":444
 * 
 *         if self._closed == 1:
 *             raise RuntimeError('unable to start the loop; it was closed')             # <<<<<<<<<<<<<<
 * 
 *         if self._running == 1:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 444, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 444, __pyx_L1_error)

    /* "uvloop/loop.pyx":443
 *         cdef int err
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('unable to start the loop; it was closed')
 * 
 */
  }

  /* "uvloop/loop.pyx":446
 *             raise RuntimeError('unable to start the loop; it was closed')
 * 
 *         if self._running == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('this event loop is already running.')
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_running == 1) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":447
 * 
 *         if self._running == 1:
 *             raise RuntimeError('this event loop is already running.')             # <<<<<<<<<<<<<<
 * 
 *         if (aio_get_running_loop is not None and
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 447, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 447, __pyx_L1_error)

    /* "uvloop/loop.pyx":446
 *             raise RuntimeError('unable to start the loop; it was closed')
 * 
 *         if self._running == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('this event loop is already running.')
 * 
 */
  }

  /* "uvloop/loop.pyx":449
 *             raise RuntimeError('this event loop is already running.')
 * 
 *         if (aio_get_running_loop is not None and             # <<<<<<<<<<<<<<
 *                 aio_get_running_loop() is not None):
 *             raise RuntimeError(
 */
  __pyx_t_3 = (__pyx_v_6uvloop_4loop_aio_get_running_loop != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L6_bool_binop_done;
  }

  /* "uvloop/loop.pyx":450
 * 
 *         if (aio_get_running_loop is not None and
 *                 aio_get_running_loop() is not None):             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'Cannot run the event loop while another loop is running')
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_get_running_loop);
  __pyx_t_5 = __pyx_v_6uvloop_4loop_aio_get_running_loop; __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 450, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 450, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L6_bool_binop_done:;

  /* "uvloop/loop.pyx":449
 *             raise RuntimeError('this event loop is already running.')
 * 
 *         if (aio_get_running_loop is not None and             # <<<<<<<<<<<<<<
 *                 aio_get_running_loop() is not None):
 *             raise RuntimeError(
 */
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":451
 *         if (aio_get_running_loop is not None and
 *                 aio_get_running_loop() is not None):
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'Cannot run the event loop while another loop is running')
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 451, __pyx_L1_error)

    /* "uvloop/loop.pyx":449
 *             raise RuntimeError('this event loop is already running.')
 * 
 *         if (aio_get_running_loop is not None and             # <<<<<<<<<<<<<<
 *                 aio_get_running_loop() is not None):
 *             raise RuntimeError(
 */
  }

  /* "uvloop/loop.pyx":455
 * 
 *         # reset _last_error
 *         self._last_error = None             # <<<<<<<<<<<<<<
 * 
 *         self._thread_id = PyThread_get_thread_ident()
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_last_error);
  __Pyx_DECREF(__pyx_v_self->_last_error);
  __pyx_v_self->_last_error = Py_None;

  /* "uvloop/loop.pyx":457
 *         self._last_error = None
 * 
 *         self._thread_id = PyThread_get_thread_ident()             # <<<<<<<<<<<<<<
 *         self._thread_is_main = MAIN_THREAD_ID == self._thread_id
 *         self._running = 1
 */
  __pyx_v_self->_thread_id = PyThread_get_thread_ident();

  /* "uvloop/loop.pyx":458
 * 
 *         self._thread_id = PyThread_get_thread_ident()
 *         self._thread_is_main = MAIN_THREAD_ID == self._thread_id             # <<<<<<<<<<<<<<
 *         self._running = 1
 * 
 */
  __pyx_v_self->_thread_is_main = (__pyx_v_6uvloop_4loop_MAIN_THREAD_ID == __pyx_v_self->_thread_id);

  /* "uvloop/loop.pyx":459
 *         self._thread_id = PyThread_get_thread_ident()
 *         self._thread_is_main = MAIN_THREAD_ID == self._thread_id
 *         self._running = 1             # <<<<<<<<<<<<<<
 * 
 *         self.handler_check__exec_writes.start()
 */
  __pyx_v_self->_running = 1;

  /* "uvloop/loop.pyx":461
 *         self._running = 1
 * 
 *         self.handler_check__exec_writes.start()             # <<<<<<<<<<<<<<
 *         self.handler_idle.start()
 * 
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_7UVCheck_start(__pyx_v_self->handler_check__exec_writes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":462
 * 
 *         self.handler_check__exec_writes.start()
 *         self.handler_idle.start()             # <<<<<<<<<<<<<<
 * 
 *         self._recv_signals_start()
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_6UVIdle_start(__pyx_v_self->handler_idle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":464
 *         self.handler_idle.start()
 * 
 *         self._recv_signals_start()             # <<<<<<<<<<<<<<
 * 
 *         if aio_set_running_loop is not None:
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_recv_signals_start(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":466
 *         self._recv_signals_start()
 * 
 *         if aio_set_running_loop is not None:             # <<<<<<<<<<<<<<
 *             aio_set_running_loop(self)
 *         try:
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop_aio_set_running_loop != Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":467
 * 
 *         if aio_set_running_loop is not None:
 *             aio_set_running_loop(self)             # <<<<<<<<<<<<<<
 *         try:
 *             self.__run(mode)
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_set_running_loop);
    __pyx_t_5 = __pyx_v_6uvloop_4loop_aio_set_running_loop; __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 467, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, ((PyObject *)__pyx_v_self)};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 467, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, ((PyObject *)__pyx_v_self)};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 467, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 467, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, ((PyObject *)__pyx_v_self));
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 467, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":466
 *         self._recv_signals_start()
 * 
 *         if aio_set_running_loop is not None:             # <<<<<<<<<<<<<<
 *             aio_set_running_loop(self)
 *         try:
 */
  }

  /* "uvloop/loop.pyx":468
 *         if aio_set_running_loop is not None:
 *             aio_set_running_loop(self)
 *         try:             # <<<<<<<<<<<<<<
 *             self.__run(mode)
 *         finally:
 */
  /*try:*/ {

    /* "uvloop/loop.pyx":469
 *             aio_set_running_loop(self)
 *         try:
 *             self.__run(mode)             # <<<<<<<<<<<<<<
 *         finally:
 *             if aio_set_running_loop is not None:
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->__pyx___run(__pyx_v_self, __pyx_v_mode); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 469, __pyx_L10_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "uvloop/loop.pyx":471
 *             self.__run(mode)
 *         finally:
 *             if aio_set_running_loop is not None:             # <<<<<<<<<<<<<<
 *                 aio_set_running_loop(None)
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_3 = (__pyx_v_6uvloop_4loop_aio_set_running_loop != Py_None);
      __pyx_t_1 = (__pyx_t_3 != 0);
      if (__pyx_t_1) {

        /* "uvloop/loop.pyx":472
 *         finally:
 *             if aio_set_running_loop is not None:
 *                 aio_set_running_loop(None)             # <<<<<<<<<<<<<<
 * 
 *             self._recv_signals_stop()
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_set_running_loop, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 472, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":471
 *             self.__run(mode)
 *         finally:
 *             if aio_set_running_loop is not None:             # <<<<<<<<<<<<<<
 *                 aio_set_running_loop(None)
 * 
 */
      }

      /* "uvloop/loop.pyx":474
 *                 aio_set_running_loop(None)
 * 
 *             self._recv_signals_stop()             # <<<<<<<<<<<<<<
 * 
 *             self.handler_check__exec_writes.stop()
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_recv_signals_stop(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 474, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":476
 *             self._recv_signals_stop()
 * 
 *             self.handler_check__exec_writes.stop()             # <<<<<<<<<<<<<<
 *             self.handler_idle.stop()
 * 
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_7UVCheck_stop(__pyx_v_self->handler_check__exec_writes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":477
 * 
 *             self.handler_check__exec_writes.stop()
 *             self.handler_idle.stop()             # <<<<<<<<<<<<<<
 * 
 *             self._thread_is_main = 0
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_6UVIdle_stop(__pyx_v_self->handler_idle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 477, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":479
 *             self.handler_idle.stop()
 * 
 *             self._thread_is_main = 0             # <<<<<<<<<<<<<<
 *             self._thread_id = 0
 *             self._running = 0
 */
      __pyx_v_self->_thread_is_main = 0;

      /* "uvloop/loop.pyx":480
 * 
 *             self._thread_is_main = 0
 *             self._thread_id = 0             # <<<<<<<<<<<<<<
 *             self._running = 0
 *             self._stopping = 0
 */
      __pyx_v_self->_thread_id = 0;

      /* "uvloop/loop.pyx":481
 *             self._thread_is_main = 0
 *             self._thread_id = 0
 *             self._running = 0             # <<<<<<<<<<<<<<
 *             self._stopping = 0
 * 
 */
      __pyx_v_self->_running = 0;

      /* "uvloop/loop.pyx":482
 *             self._thread_id = 0
 *             self._running = 0
 *             self._stopping = 0             # <<<<<<<<<<<<<<
 * 
 *         if self._last_error is not None:
 */
      __pyx_v_self->_stopping = 0;
      goto __pyx_L11;
    }
    __pyx_L10_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __pyx_t_8 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_10 = __pyx_filename;
      {

        /* "uvloop/loop.pyx":471
 *             self.__run(mode)
 *         finally:
 *             if aio_set_running_loop is not None:             # <<<<<<<<<<<<<<
 *                 aio_set_running_loop(None)
 * 
 */
        __pyx_t_1 = (__pyx_v_6uvloop_4loop_aio_set_running_loop != Py_None);
        __pyx_t_3 = (__pyx_t_1 != 0);
        if (__pyx_t_3) {

          /* "uvloop/loop.pyx":472
 *         finally:
 *             if aio_set_running_loop is not None:
 *                 aio_set_running_loop(None)             # <<<<<<<<<<<<<<
 * 
 *             self._recv_signals_stop()
 */
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_set_running_loop, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 472, __pyx_L14_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/loop.pyx":471
 *             self.__run(mode)
 *         finally:
 *             if aio_set_running_loop is not None:             # <<<<<<<<<<<<<<
 *                 aio_set_running_loop(None)
 * 
 */
        }

        /* "uvloop/loop.pyx":474
 *                 aio_set_running_loop(None)
 * 
 *             self._recv_signals_stop()             # <<<<<<<<<<<<<<
 * 
 *             self.handler_check__exec_writes.stop()
 */
        __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_recv_signals_stop(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 474, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":476
 *             self._recv_signals_stop()
 * 
 *             self.handler_check__exec_writes.stop()             # <<<<<<<<<<<<<<
 *             self.handler_idle.stop()
 * 
 */
        __pyx_t_2 = __pyx_f_6uvloop_4loop_7UVCheck_stop(__pyx_v_self->handler_check__exec_writes); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 476, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":477
 * 
 *             self.handler_check__exec_writes.stop()
 *             self.handler_idle.stop()             # <<<<<<<<<<<<<<
 * 
 *             self._thread_is_main = 0
 */
        __pyx_t_2 = __pyx_f_6uvloop_4loop_6UVIdle_stop(__pyx_v_self->handler_idle); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 477, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":479
 *             self.handler_idle.stop()
 * 
 *             self._thread_is_main = 0             # <<<<<<<<<<<<<<
 *             self._thread_id = 0
 *             self._running = 0
 */
        __pyx_v_self->_thread_is_main = 0;

        /* "uvloop/loop.pyx":480
 * 
 *             self._thread_is_main = 0
 *             self._thread_id = 0             # <<<<<<<<<<<<<<
 *             self._running = 0
 *             self._stopping = 0
 */
        __pyx_v_self->_thread_id = 0;

        /* "uvloop/loop.pyx":481
 *             self._thread_is_main = 0
 *             self._thread_id = 0
 *             self._running = 0             # <<<<<<<<<<<<<<
 *             self._stopping = 0
 * 
 */
        __pyx_v_self->_running = 0;

        /* "uvloop/loop.pyx":482
 *             self._thread_id = 0
 *             self._running = 0
 *             self._stopping = 0             # <<<<<<<<<<<<<<
 * 
 *         if self._last_error is not None:
 */
        __pyx_v_self->_stopping = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      }
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestore(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_10;
      goto __pyx_L1_error;
      __pyx_L14_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      }
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L11:;
  }

  /* "uvloop/loop.pyx":484
 *             self._stopping = 0
 * 
 *         if self._last_error is not None:             # <<<<<<<<<<<<<<
 *             # The loop was stopped with an error with 'loop._stop(error)' call
 *             raise self._last_error
 */
  __pyx_t_3 = (__pyx_v_self->_last_error != Py_None);
  __pyx_t_1 = (__pyx_t_3 != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":486
 *         if self._last_error is not None:
 *             # The loop was stopped with an error with 'loop._stop(error)' call
 *             raise self._last_error             # <<<<<<<<<<<<<<
 * 
 *     cdef _close(self):
 */
    __Pyx_Raise(__pyx_v_self->_last_error, 0, 0, 0);
    __PYX_ERR(2, 486, __pyx_L1_error)

    /* "uvloop/loop.pyx":484
 *             self._stopping = 0
 * 
 *         if self._last_error is not None:             # <<<<<<<<<<<<<<
 *             # The loop was stopped with an error with 'loop._stop(error)' call
 *             raise self._last_error
 */
  }

  /* "uvloop/loop.pyx":440
 *             raise convert_error(err)
 * 
 *     cdef _run(self, uv.uv_run_mode mode):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop._run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":488
 *             raise self._last_error
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__close(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_cb_handle = NULL;
  PyObject *__pyx_v_poll_handle = NULL;
  PyObject *__pyx_v_timer_cbhandle = NULL;
  PyObject *__pyx_v_fileobj = NULL;
  PyObject *__pyx_v_executor = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "uvloop/loop.pyx":491
 *         cdef int err
 * 
 *         if self._running == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Cannot close a running event loop")
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_running == 1) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":492
 * 
 *         if self._running == 1:
 *             raise RuntimeError("Cannot close a running event loop")             # <<<<<<<<<<<<<<
 * 
 *         if self._closed == 1:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 492, __pyx_L1_error)

    /* "uvloop/loop.pyx":491
 *         cdef int err
 * 
 *         if self._running == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Cannot close a running event loop")
 * 
 */
  }

  /* "uvloop/loop.pyx":494
 *             raise RuntimeError("Cannot close a running event loop")
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_closed == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":495
 * 
 *         if self._closed == 1:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._closed = 1
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":494
 *             raise RuntimeError("Cannot close a running event loop")
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/loop.pyx":497
 *             return
 * 
 *         self._closed = 1             # <<<<<<<<<<<<<<
 * 
 *         for cb_handle in self._ready:
 */
  __pyx_v_self->_closed = 1;

  /* "uvloop/loop.pyx":499
 *         self._closed = 1
 * 
 *         for cb_handle in self._ready:             # <<<<<<<<<<<<<<
 *             cb_handle.cancel()
 *         self._ready.clear()
 */
  if (likely(PyList_CheckExact(__pyx_v_self->_ready)) || PyTuple_CheckExact(__pyx_v_self->_ready)) {
    __pyx_t_2 = __pyx_v_self->_ready; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->_ready); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 499, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(2, 499, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 499, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(2, 499, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 499, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(2, 499, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_cb_handle, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":500
 * 
 *         for cb_handle in self._ready:
 *             cb_handle.cancel()             # <<<<<<<<<<<<<<
 *         self._ready.clear()
 *         self._ready_len = 0
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_cb_handle, __pyx_n_s_cancel); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 500, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 500, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 500, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":499
 *         self._closed = 1
 * 
 *         for cb_handle in self._ready:             # <<<<<<<<<<<<<<
 *             cb_handle.cancel()
 *         self._ready.clear()
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":501
 *         for cb_handle in self._ready:
 *             cb_handle.cancel()
 *         self._ready.clear()             # <<<<<<<<<<<<<<
 *         self._ready_len = 0
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_ready, __pyx_n_s_clear); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 501, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 501, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":502
 *             cb_handle.cancel()
 *         self._ready.clear()
 *         self._ready_len = 0             # <<<<<<<<<<<<<<
 * 
 *         if self._polls:
 */
  __pyx_v_self->_ready_len = 0;

  /* "uvloop/loop.pyx":504
 *         self._ready_len = 0
 * 
 *         if self._polls:             # <<<<<<<<<<<<<<
 *             for poll_handle in self._polls.values():
 *                 (<UVHandle>poll_handle)._close()
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_polls); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 504, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":505
 * 
 *         if self._polls:
 *             for poll_handle in self._polls.values():             # <<<<<<<<<<<<<<
 *                 (<UVHandle>poll_handle)._close()
 * 
 */
    __pyx_t_3 = 0;
    if (unlikely(__pyx_v_self->_polls == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(2, 505, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_dict_iterator(__pyx_v_self->_polls, 1, __pyx_n_s_values, (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2);
    __pyx_t_2 = __pyx_t_5;
    __pyx_t_5 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_8, &__pyx_t_3, NULL, &__pyx_t_5, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(2, 505, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_poll_handle, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":506
 *         if self._polls:
 *             for poll_handle in self._polls.values():
 *                 (<UVHandle>poll_handle)._close()             # <<<<<<<<<<<<<<
 * 
 *             self._polls.clear()
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_poll_handle)->__pyx_vtab)->_close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_poll_handle)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 506, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":508
 *                 (<UVHandle>poll_handle)._close()
 * 
 *             self._polls.clear()             # <<<<<<<<<<<<<<
 * 
 *         if self._timers:
 */
    if (unlikely(__pyx_v_self->_polls == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
      __PYX_ERR(2, 508, __pyx_L1_error)
    }
    __pyx_t_11 = __Pyx_PyDict_Clear(__pyx_v_self->_polls); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 508, __pyx_L1_error)

    /* "uvloop/loop.pyx":504
 *         self._ready_len = 0
 * 
 *         if self._polls:             # <<<<<<<<<<<<<<
 *             for poll_handle in self._polls.values():
 *                 (<UVHandle>poll_handle)._close()
 */
  }

  /* "uvloop/loop.pyx":510
 *             self._polls.clear()
 * 
 *         if self._timers:             # <<<<<<<<<<<<<<
 *             for timer_cbhandle in tuple(self._timers):
 *                 timer_cbhandle.cancel()
 */
  __pyx_t_1 = (__pyx_v_self->_timers != Py_None)&&(PySet_GET_SIZE(__pyx_v_self->_timers) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":511
 * 
 *         if self._timers:
 *             for timer_cbhandle in tuple(self._timers):             # <<<<<<<<<<<<<<
 *                 timer_cbhandle.cancel()
 * 
 */
    __pyx_t_2 = PySequence_Tuple(__pyx_v_self->_timers); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 511, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __pyx_t_2; __Pyx_INCREF(__pyx_t_5); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_2); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(2, 511, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_timer_cbhandle, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":512
 *         if self._timers:
 *             for timer_cbhandle in tuple(self._timers):
 *                 timer_cbhandle.cancel()             # <<<<<<<<<<<<<<
 * 
 *         # Close all remaining handles
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_timer_cbhandle, __pyx_n_s_cancel); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 512, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (__pyx_t_7) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 512, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 512, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":511
 * 
 *         if self._timers:
 *             for timer_cbhandle in tuple(self._timers):             # <<<<<<<<<<<<<<
 *                 timer_cbhandle.cancel()
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":510
 *             self._polls.clear()
 * 
 *         if self._timers:             # <<<<<<<<<<<<<<
 *             for timer_cbhandle in tuple(self._timers):
 *                 timer_cbhandle.cancel()
 */
  }

  /* "uvloop/loop.pyx":515
 * 
 *         # Close all remaining handles
 *         self.handler_async._close()             # <<<<<<<<<<<<<<
 *         self.handler_idle._close()
 *         self.handler_check__exec_writes._close()
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->handler_async->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self->handler_async)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":516
 *         # Close all remaining handles
 *         self.handler_async._close()
 *         self.handler_idle._close()             # <<<<<<<<<<<<<<
 *         self.handler_check__exec_writes._close()
 *         __close_all_handles(self)
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->handler_idle->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self->handler_idle)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":517
 *         self.handler_async._close()
 *         self.handler_idle._close()
 *         self.handler_check__exec_writes._close()             # <<<<<<<<<<<<<<
 *         __close_all_handles(self)
 *         self._shutdown_signals()
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->handler_check__exec_writes->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self->handler_check__exec_writes)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":518
 *         self.handler_idle._close()
 *         self.handler_check__exec_writes._close()
 *         __close_all_handles(self)             # <<<<<<<<<<<<<<
 *         self._shutdown_signals()
 *         # During this run there should be no open handles,
 */
  __pyx_f_6uvloop_4loop___close_all_handles(__pyx_v_self);

  /* "uvloop/loop.pyx":519
 *         self.handler_check__exec_writes._close()
 *         __close_all_handles(self)
 *         self._shutdown_signals()             # <<<<<<<<<<<<<<
 *         # During this run there should be no open handles,
 *         # so it should finish right away
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_shutdown_signals(__pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":522
 *         # During this run there should be no open handles,
 *         # so it should finish right away
 *         self.__run(uv.UV_RUN_DEFAULT)             # <<<<<<<<<<<<<<
 * 
 *         if self._fd_to_writer_fileobj:
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->__pyx___run(__pyx_v_self, UV_RUN_DEFAULT); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":524
 *         self.__run(uv.UV_RUN_DEFAULT)
 * 
 *         if self._fd_to_writer_fileobj:             # <<<<<<<<<<<<<<
 *             for fileobj in self._fd_to_writer_fileobj.values():
 *                 socket_dec_io_ref(fileobj)
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_fd_to_writer_fileobj); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 524, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":525
 * 
 *         if self._fd_to_writer_fileobj:
 *             for fileobj in self._fd_to_writer_fileobj.values():             # <<<<<<<<<<<<<<
 *                 socket_dec_io_ref(fileobj)
 *             self._fd_to_writer_fileobj.clear()
 */
    __pyx_t_8 = 0;
    if (unlikely(__pyx_v_self->_fd_to_writer_fileobj == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(2, 525, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_dict_iterator(__pyx_v_self->_fd_to_writer_fileobj, 1, __pyx_n_s_values, (&__pyx_t_3), (&__pyx_t_9)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 525, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_5);
    __pyx_t_5 = __pyx_t_2;
    __pyx_t_2 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_5, __pyx_t_3, &__pyx_t_8, NULL, &__pyx_t_2, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(2, 525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_fileobj, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":526
 *         if self._fd_to_writer_fileobj:
 *             for fileobj in self._fd_to_writer_fileobj.values():
 *                 socket_dec_io_ref(fileobj)             # <<<<<<<<<<<<<<
 *             self._fd_to_writer_fileobj.clear()
 * 
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_v_fileobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 526, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":527
 *             for fileobj in self._fd_to_writer_fileobj.values():
 *                 socket_dec_io_ref(fileobj)
 *             self._fd_to_writer_fileobj.clear()             # <<<<<<<<<<<<<<
 * 
 *         if self._fd_to_reader_fileobj:
 */
    if (unlikely(__pyx_v_self->_fd_to_writer_fileobj == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
      __PYX_ERR(2, 527, __pyx_L1_error)
    }
    __pyx_t_11 = __Pyx_PyDict_Clear(__pyx_v_self->_fd_to_writer_fileobj); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 527, __pyx_L1_error)

    /* "uvloop/loop.pyx":524
 *         self.__run(uv.UV_RUN_DEFAULT)
 * 
 *         if self._fd_to_writer_fileobj:             # <<<<<<<<<<<<<<
 *             for fileobj in self._fd_to_writer_fileobj.values():
 *                 socket_dec_io_ref(fileobj)
 */
  }

  /* "uvloop/loop.pyx":529
 *             self._fd_to_writer_fileobj.clear()
 * 
 *         if self._fd_to_reader_fileobj:             # <<<<<<<<<<<<<<
 *             for fileobj in self._fd_to_reader_fileobj.values():
 *                 socket_dec_io_ref(fileobj)
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_fd_to_reader_fileobj); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 529, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":530
 * 
 *         if self._fd_to_reader_fileobj:
 *             for fileobj in self._fd_to_reader_fileobj.values():             # <<<<<<<<<<<<<<
 *                 socket_dec_io_ref(fileobj)
 *             self._fd_to_reader_fileobj.clear()
 */
    __pyx_t_3 = 0;
    if (unlikely(__pyx_v_self->_fd_to_reader_fileobj == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
      __PYX_ERR(2, 530, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_dict_iterator(__pyx_v_self->_fd_to_reader_fileobj, 1, __pyx_n_s_values, (&__pyx_t_8), (&__pyx_t_9)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 530, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF(__pyx_t_5);
    __pyx_t_5 = __pyx_t_2;
    __pyx_t_2 = 0;
    while (1) {
      __pyx_t_10 = __Pyx_dict_iter_next(__pyx_t_5, __pyx_t_8, &__pyx_t_3, NULL, &__pyx_t_2, NULL, __pyx_t_9);
      if (unlikely(__pyx_t_10 == 0)) break;
      if (unlikely(__pyx_t_10 == -1)) __PYX_ERR(2, 530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_fileobj, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":531
 *         if self._fd_to_reader_fileobj:
 *             for fileobj in self._fd_to_reader_fileobj.values():
 *                 socket_dec_io_ref(fileobj)             # <<<<<<<<<<<<<<
 *             self._fd_to_reader_fileobj.clear()
 * 
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_v_fileobj); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 531, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":532
 *             for fileobj in self._fd_to_reader_fileobj.values():
 *                 socket_dec_io_ref(fileobj)
 *             self._fd_to_reader_fileobj.clear()             # <<<<<<<<<<<<<<
 * 
 *         if self._timers:
 */
    if (unlikely(__pyx_v_self->_fd_to_reader_fileobj == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
      __PYX_ERR(2, 532, __pyx_L1_error)
    }
    __pyx_t_11 = __Pyx_PyDict_Clear(__pyx_v_self->_fd_to_reader_fileobj); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 532, __pyx_L1_error)

    /* "uvloop/loop.pyx":529
 *             self._fd_to_writer_fileobj.clear()
 * 
 *         if self._fd_to_reader_fileobj:             # <<<<<<<<<<<<<<
 *             for fileobj in self._fd_to_reader_fileobj.values():
 *                 socket_dec_io_ref(fileobj)
 */
  }

  /* "uvloop/loop.pyx":534
 *             self._fd_to_reader_fileobj.clear()
 * 
 *         if self._timers:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "new timers were queued during loop closing: {}"
 */
  __pyx_t_1 = (__pyx_v_self->_timers != Py_None)&&(PySet_GET_SIZE(__pyx_v_self->_timers) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":537
 *             raise RuntimeError(
 *                 "new timers were queued during loop closing: {}"
 *                     .format(self._timers))             # <<<<<<<<<<<<<<
 * 
 *         if self._polls:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_new_timers_were_queued_during_lo, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 537, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self->_timers); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 537, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_self->_timers};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 537, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_self->_timers};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 537, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 537, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_self->_timers);
        __Pyx_GIVEREF(__pyx_v_self->_timers);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_self->_timers);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 537, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":535
 * 
 *         if self._timers:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 "new timers were queued during loop closing: {}"
 *                     .format(self._timers))
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 535, __pyx_L1_error)

    /* "uvloop/loop.pyx":534
 *             self._fd_to_reader_fileobj.clear()
 * 
 *         if self._timers:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "new timers were queued during loop closing: {}"
 */
  }

  /* "uvloop/loop.pyx":539
 *                     .format(self._timers))
 * 
 *         if self._polls:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "new poll handles were queued during loop closing: {}"
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_polls); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 539, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":542
 *             raise RuntimeError(
 *                 "new poll handles were queued during loop closing: {}"
 *                     .format(self._polls))             # <<<<<<<<<<<<<<
 * 
 *         if self._ready:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_new_poll_handles_were_queued_dur, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 542, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_self->_polls); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 542, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_self->_polls};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 542, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_self->_polls};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 542, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_INCREF(__pyx_v_self->_polls);
        __Pyx_GIVEREF(__pyx_v_self->_polls);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_self->_polls);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 542, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":540
 * 
 *         if self._polls:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 "new poll handles were queued during loop closing: {}"
 *                     .format(self._polls))
 */
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 540, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(2, 540, __pyx_L1_error)

    /* "uvloop/loop.pyx":539
 *                     .format(self._timers))
 * 
 *         if self._polls:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "new poll handles were queued during loop closing: {}"
 */
  }

  /* "uvloop/loop.pyx":544
 *                     .format(self._polls))
 * 
 *         if self._ready:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "new callbacks were queued during loop closing: {}"
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_ready); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 544, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":547
 *             raise RuntimeError(
 *                 "new callbacks were queued during loop closing: {}"
 *                     .format(self._ready))             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_loop_close(self.uvloop)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_new_callbacks_were_queued_during, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_self->_ready); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 547, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_self->_ready};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 547, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_self->_ready};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 547, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_self->_ready);
        __Pyx_GIVEREF(__pyx_v_self->_ready);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_self->_ready);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":545
 * 
 *         if self._ready:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 "new callbacks were queued during loop closing: {}"
 *                     .format(self._ready))
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 545, __pyx_L1_error)

    /* "uvloop/loop.pyx":544
 *                     .format(self._polls))
 * 
 *         if self._ready:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "new callbacks were queued during loop closing: {}"
 */
  }

  /* "uvloop/loop.pyx":549
 *                     .format(self._ready))
 * 
 *         err = uv.uv_loop_close(self.uvloop)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
  __pyx_v_err = uv_loop_close(__pyx_v_self->uvloop);

  /* "uvloop/loop.pyx":550
 * 
 *         err = uv.uv_loop_close(self.uvloop)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":551
 *         err = uv.uv_loop_close(self.uvloop)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         self.handler_async = None
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 551, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 551, __pyx_L1_error)

    /* "uvloop/loop.pyx":550
 * 
 *         err = uv.uv_loop_close(self.uvloop)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  }

  /* "uvloop/loop.pyx":553
 *             raise convert_error(err)
 * 
 *         self.handler_async = None             # <<<<<<<<<<<<<<
 *         self.handler_idle = None
 *         self.handler_check__exec_writes = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->handler_async);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->handler_async));
  __pyx_v_self->handler_async = ((struct __pyx_obj_6uvloop_4loop_UVAsync *)Py_None);

  /* "uvloop/loop.pyx":554
 * 
 *         self.handler_async = None
 *         self.handler_idle = None             # <<<<<<<<<<<<<<
 *         self.handler_check__exec_writes = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->handler_idle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->handler_idle));
  __pyx_v_self->handler_idle = ((struct __pyx_obj_6uvloop_4loop_UVIdle *)Py_None);

  /* "uvloop/loop.pyx":555
 *         self.handler_async = None
 *         self.handler_idle = None
 *         self.handler_check__exec_writes = None             # <<<<<<<<<<<<<<
 * 
 *         executor = self._default_executor
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->handler_check__exec_writes);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->handler_check__exec_writes));
  __pyx_v_self->handler_check__exec_writes = ((struct __pyx_obj_6uvloop_4loop_UVCheck *)Py_None);

  /* "uvloop/loop.pyx":557
 *         self.handler_check__exec_writes = None
 * 
 *         executor = self._default_executor             # <<<<<<<<<<<<<<
 *         if executor is not None:
 *             self._default_executor = None
 */
  __pyx_t_2 = __pyx_v_self->_default_executor;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_executor = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":558
 * 
 *         executor = self._default_executor
 *         if executor is not None:             # <<<<<<<<<<<<<<
 *             self._default_executor = None
 *             executor.shutdown(wait=False)
 */
  __pyx_t_1 = (__pyx_v_executor != Py_None);
  __pyx_t_12 = (__pyx_t_1 != 0);
  if (__pyx_t_12) {

    /* "uvloop/loop.pyx":559
 *         executor = self._default_executor
 *         if executor is not None:
 *             self._default_executor = None             # <<<<<<<<<<<<<<
 *             executor.shutdown(wait=False)
 * 
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_default_executor);
    __Pyx_DECREF(__pyx_v_self->_default_executor);
    __pyx_v_self->_default_executor = Py_None;

    /* "uvloop/loop.pyx":560
 *         if executor is not None:
 *             self._default_executor = None
 *             executor.shutdown(wait=False)             # <<<<<<<<<<<<<<
 * 
 *     cdef uint64_t _time(self):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_executor, __pyx_n_s_shutdown); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 560, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 560, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_wait, Py_False) < 0) __PYX_ERR(2, 560, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 560, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":558
 * 
 *         executor = self._default_executor
 *         if executor is not None:             # <<<<<<<<<<<<<<
 *             self._default_executor = None
 *             executor.shutdown(wait=False)
 */
  }

  /* "uvloop/loop.pyx":488
 *             raise self._last_error
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cb_handle);
  __Pyx_XDECREF(__pyx_v_poll_handle);
  __Pyx_XDECREF(__pyx_v_timer_cbhandle);
  __Pyx_XDECREF(__pyx_v_fileobj);
  __Pyx_XDECREF(__pyx_v_executor);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":562
 *             executor.shutdown(wait=False)
 * 
 *     cdef uint64_t _time(self):             # <<<<<<<<<<<<<<
 *         # asyncio doesn't have a time cache, neither should uvloop.
 *         uv.uv_update_time(self.uvloop)  # void
 */

static uint64_t __pyx_f_6uvloop_4loop_4Loop__time(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  uint64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_time", 0);

  /* "uvloop/loop.pyx":564
 *     cdef uint64_t _time(self):
 *         # asyncio doesn't have a time cache, neither should uvloop.
 *         uv.uv_update_time(self.uvloop)  # void             # <<<<<<<<<<<<<<
 *         return uv.uv_now(self.uvloop)
 * 
 */
  uv_update_time(__pyx_v_self->uvloop);

  /* "uvloop/loop.pyx":565
 *         # asyncio doesn't have a time cache, neither should uvloop.
 *         uv.uv_update_time(self.uvloop)  # void
 *         return uv.uv_now(self.uvloop)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _queue_write(self, UVStream stream):
 */
  __pyx_r = uv_now(__pyx_v_self->uvloop);
  goto __pyx_L0;

  /* "uvloop/loop.pyx":562
 *             executor.shutdown(wait=False)
 * 
 *     cdef uint64_t _time(self):             # <<<<<<<<<<<<<<
 *         # asyncio doesn't have a time cache, neither should uvloop.
 *         uv.uv_update_time(self.uvloop)  # void
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":567
 *         return uv.uv_now(self.uvloop)
 * 
 *     cdef inline _queue_write(self, UVStream stream):             # <<<<<<<<<<<<<<
 *         self._queued_streams.add(stream)
 *         if not self.handler_check__exec_writes.running:
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__queue_write(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_stream) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_queue_write", 0);

  /* "uvloop/loop.pyx":568
 * 
 *     cdef inline _queue_write(self, UVStream stream):
 *         self._queued_streams.add(stream)             # <<<<<<<<<<<<<<
 *         if not self.handler_check__exec_writes.running:
 *             self.handler_check__exec_writes.start()
 */
  if (unlikely(__pyx_v_self->_queued_streams == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(2, 568, __pyx_L1_error)
  }
  __pyx_t_1 = PySet_Add(__pyx_v_self->_queued_streams, ((PyObject *)__pyx_v_stream)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 568, __pyx_L1_error)

  /* "uvloop/loop.pyx":569
 *     cdef inline _queue_write(self, UVStream stream):
 *         self._queued_streams.add(stream)
 *         if not self.handler_check__exec_writes.running:             # <<<<<<<<<<<<<<
 *             self.handler_check__exec_writes.start()
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_self->handler_check__exec_writes->running != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":570
 *         self._queued_streams.add(stream)
 *         if not self.handler_check__exec_writes.running:
 *             self.handler_check__exec_writes.start()             # <<<<<<<<<<<<<<
 * 
 *     cdef _exec_queued_writes(self):
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_7UVCheck_start(__pyx_v_self->handler_check__exec_writes); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":569
 *     cdef inline _queue_write(self, UVStream stream):
 *         self._queued_streams.add(stream)
 *         if not self.handler_check__exec_writes.running:             # <<<<<<<<<<<<<<
 *             self.handler_check__exec_writes.start()
 * 
 */
  }

  /* "uvloop/loop.pyx":567
 *         return uv.uv_now(self.uvloop)
 * 
 *     cdef inline _queue_write(self, UVStream stream):             # <<<<<<<<<<<<<<
 *         self._queued_streams.add(stream)
 *         if not self.handler_check__exec_writes.running:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.Loop._queue_write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":572
 *             self.handler_check__exec_writes.start()
 * 
 *     cdef _exec_queued_writes(self):             # <<<<<<<<<<<<<<
 *         if len(self._queued_streams) == 0:
 *             if self.handler_check__exec_writes.running:
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__exec_queued_writes(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_stream = 0;
  int __pyx_v_queued_len;
  PyObject *__pyx_v_pystream = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("_exec_queued_writes", 0);

  /* "uvloop/loop.pyx":573
 * 
 *     cdef _exec_queued_writes(self):
 *         if len(self._queued_streams) == 0:             # <<<<<<<<<<<<<<
 *             if self.handler_check__exec_writes.running:
 *                 self.handler_check__exec_writes.stop()
 */
  __pyx_t_1 = __pyx_v_self->_queued_streams;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(2, 573, __pyx_L1_error)
  }
  __pyx_t_2 = PySet_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(2, 573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((__pyx_t_2 == 0) != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":574
 *     cdef _exec_queued_writes(self):
 *         if len(self._queued_streams) == 0:
 *             if self.handler_check__exec_writes.running:             # <<<<<<<<<<<<<<
 *                 self.handler_check__exec_writes.stop()
 *             return
 */
    __pyx_t_3 = (__pyx_v_self->handler_check__exec_writes->running != 0);
    if (__pyx_t_3) {

      /* "uvloop/loop.pyx":575
 *         if len(self._queued_streams) == 0:
 *             if self.handler_check__exec_writes.running:
 *                 self.handler_check__exec_writes.stop()             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop_7UVCheck_stop(__pyx_v_self->handler_check__exec_writes); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 575, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":574
 *     cdef _exec_queued_writes(self):
 *         if len(self._queued_streams) == 0:
 *             if self.handler_check__exec_writes.running:             # <<<<<<<<<<<<<<
 *                 self.handler_check__exec_writes.stop()
 *             return
 */
    }

    /* "uvloop/loop.pyx":576
 *             if self.handler_check__exec_writes.running:
 *                 self.handler_check__exec_writes.stop()
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":573
 * 
 *     cdef _exec_queued_writes(self):
 *         if len(self._queued_streams) == 0:             # <<<<<<<<<<<<<<
 *             if self.handler_check__exec_writes.running:
 *                 self.handler_check__exec_writes.stop()
 */
  }

  /* "uvloop/loop.pyx":582
 *             int queued_len
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             queued_len = len(self._queued_streams)
 * 
 */
  __pyx_t_3 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":583
 * 
 *         if UVLOOP_DEBUG:
 *             queued_len = len(self._queued_streams)             # <<<<<<<<<<<<<<
 * 
 *         for pystream in self._queued_streams:
 */
    __pyx_t_1 = __pyx_v_self->_queued_streams;
    __Pyx_INCREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(2, 583, __pyx_L1_error)
    }
    __pyx_t_2 = PySet_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(2, 583, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_queued_len = __pyx_t_2;

    /* "uvloop/loop.pyx":582
 *             int queued_len
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             queued_len = len(self._queued_streams)
 * 
 */
  }

  /* "uvloop/loop.pyx":585
 *             queued_len = len(self._queued_streams)
 * 
 *         for pystream in self._queued_streams:             # <<<<<<<<<<<<<<
 *             stream = <UVStream>pystream
 *             stream._exec_write()
 */
  __pyx_t_2 = 0;
  __pyx_t_6 = __Pyx_set_iterator(__pyx_v_self->_queued_streams, 1, (&__pyx_t_4), (&__pyx_t_5)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_6;
  __pyx_t_6 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_set_iter_next(__pyx_t_1, __pyx_t_4, &__pyx_t_2, &__pyx_t_6, __pyx_t_5);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(2, 585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_pystream, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":586
 * 
 *         for pystream in self._queued_streams:
 *             stream = <UVStream>pystream             # <<<<<<<<<<<<<<
 *             stream._exec_write()
 * 
 */
    __pyx_t_6 = __pyx_v_pystream;
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_stream, ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":587
 *         for pystream in self._queued_streams:
 *             stream = <UVStream>pystream
 *             stream._exec_write()             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
    __pyx_t_6 = __pyx_f_6uvloop_4loop_8UVStream__exec_write(__pyx_v_stream); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":589
 *             stream._exec_write()
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if len(self._queued_streams) != queued_len:
 *                 raise RuntimeError(
 */
  __pyx_t_3 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":590
 * 
 *         if UVLOOP_DEBUG:
 *             if len(self._queued_streams) != queued_len:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     'loop._queued_streams are not empty after '
 */
    __pyx_t_1 = __pyx_v_self->_queued_streams;
    __Pyx_INCREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(2, 590, __pyx_L1_error)
    }
    __pyx_t_4 = PySet_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(2, 590, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = ((__pyx_t_4 != __pyx_v_queued_len) != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":591
 *         if UVLOOP_DEBUG:
 *             if len(self._queued_streams) != queued_len:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     'loop._queued_streams are not empty after '
 *                     '_exec_queued_writes')
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 591, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 591, __pyx_L1_error)

      /* "uvloop/loop.pyx":590
 * 
 *         if UVLOOP_DEBUG:
 *             if len(self._queued_streams) != queued_len:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     'loop._queued_streams are not empty after '
 */
    }

    /* "uvloop/loop.pyx":589
 *             stream._exec_write()
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if len(self._queued_streams) != queued_len:
 *                 raise RuntimeError(
 */
  }

  /* "uvloop/loop.pyx":595
 *                     '_exec_queued_writes')
 * 
 *         self._queued_streams.clear()             # <<<<<<<<<<<<<<
 * 
 *         if self.handler_check__exec_writes.running:
 */
  if (unlikely(__pyx_v_self->_queued_streams == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "clear");
    __PYX_ERR(2, 595, __pyx_L1_error)
  }
  __pyx_t_8 = PySet_Clear(__pyx_v_self->_queued_streams); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(2, 595, __pyx_L1_error)

  /* "uvloop/loop.pyx":597
 *         self._queued_streams.clear()
 * 
 *         if self.handler_check__exec_writes.running:             # <<<<<<<<<<<<<<
 *             self.handler_check__exec_writes.stop()
 * 
 */
  __pyx_t_3 = (__pyx_v_self->handler_check__exec_writes->running != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":598
 * 
 *         if self.handler_check__exec_writes.running:
 *             self.handler_check__exec_writes.stop()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _call_soon(self, object callback, object args, object context):
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_7UVCheck_stop(__pyx_v_self->handler_check__exec_writes); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":597
 *         self._queued_streams.clear()
 * 
 *         if self.handler_check__exec_writes.running:             # <<<<<<<<<<<<<<
 *             self.handler_check__exec_writes.stop()
 * 
 */
  }

  /* "uvloop/loop.pyx":572
 *             self.handler_check__exec_writes.start()
 * 
 *     cdef _exec_queued_writes(self):             # <<<<<<<<<<<<<<
 *         if len(self._queued_streams) == 0:
 *             if self.handler_check__exec_writes.running:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.Loop._exec_queued_writes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_stream);
  __Pyx_XDECREF(__pyx_v_pystream);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":600
 *             self.handler_check__exec_writes.stop()
 * 
 *     cdef inline _call_soon(self, object callback, object args, object context):             # <<<<<<<<<<<<<<
 *         cdef Handle handle
 *         handle = new_Handle(self, callback, args, context)
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__call_soon(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_args, PyObject *__pyx_v_context) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_call_soon", 0);

  /* "uvloop/loop.pyx":602
 *     cdef inline _call_soon(self, object callback, object args, object context):
 *         cdef Handle handle
 *         handle = new_Handle(self, callback, args, context)             # <<<<<<<<<<<<<<
 *         self._call_soon_handle(handle)
 *         return handle
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_new_Handle(__pyx_v_self, __pyx_v_callback, __pyx_v_args, __pyx_v_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 602, __pyx_L1_error)
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":603
 *         cdef Handle handle
 *         handle = new_Handle(self, callback, args, context)
 *         self._call_soon_handle(handle)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__call_soon_handle(__pyx_v_self, __pyx_v_handle); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":604
 *         handle = new_Handle(self, callback, args, context)
 *         self._call_soon_handle(handle)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _call_soon_handle(self, Handle handle):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = ((PyObject *)__pyx_v_handle);
  goto __pyx_L0;

  /* "uvloop/loop.pyx":600
 *             self.handler_check__exec_writes.stop()
 * 
 *     cdef inline _call_soon(self, object callback, object args, object context):             # <<<<<<<<<<<<<<
 *         cdef Handle handle
 *         handle = new_Handle(self, callback, args, context)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._call_soon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":606
 *         return handle
 * 
 *     cdef inline _call_soon_handle(self, Handle handle):             # <<<<<<<<<<<<<<
 *         self._check_closed()
 *         self._ready.append(handle)
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__call_soon_handle(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("_call_soon_handle", 0);

  /* "uvloop/loop.pyx":607
 * 
 *     cdef inline _call_soon_handle(self, Handle handle):
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         self._ready.append(handle)
 *         self._ready_len += 1;
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":608
 *     cdef inline _call_soon_handle(self, Handle handle):
 *         self._check_closed()
 *         self._ready.append(handle)             # <<<<<<<<<<<<<<
 *         self._ready_len += 1;
 *         if not self.handler_idle.running:
 */
  __pyx_t_2 = __Pyx_PyObject_Append(__pyx_v_self->_ready, ((PyObject *)__pyx_v_handle)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 608, __pyx_L1_error)

  /* "uvloop/loop.pyx":609
 *         self._check_closed()
 *         self._ready.append(handle)
 *         self._ready_len += 1;             # <<<<<<<<<<<<<<
 *         if not self.handler_idle.running:
 *             self.handler_idle.start()
 */
  __pyx_v_self->_ready_len = (__pyx_v_self->_ready_len + 1);

  /* "uvloop/loop.pyx":610
 *         self._ready.append(handle)
 *         self._ready_len += 1;
 *         if not self.handler_idle.running:             # <<<<<<<<<<<<<<
 *             self.handler_idle.start()
 * 
 */
  __pyx_t_3 = ((!(__pyx_v_self->handler_idle->running != 0)) != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":611
 *         self._ready_len += 1;
 *         if not self.handler_idle.running:
 *             self.handler_idle.start()             # <<<<<<<<<<<<<<
 * 
 *     cdef _call_later(self, uint64_t delay, object callback, object args,
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_6UVIdle_start(__pyx_v_self->handler_idle); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 611, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":610
 *         self._ready.append(handle)
 *         self._ready_len += 1;
 *         if not self.handler_idle.running:             # <<<<<<<<<<<<<<
 *             self.handler_idle.start()
 * 
 */
  }

  /* "uvloop/loop.pyx":606
 *         return handle
 * 
 *     cdef inline _call_soon_handle(self, Handle handle):             # <<<<<<<<<<<<<<
 *         self._check_closed()
 *         self._ready.append(handle)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._call_soon_handle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":613
 *             self.handler_idle.start()
 * 
 *     cdef _call_later(self, uint64_t delay, object callback, object args,             # <<<<<<<<<<<<<<
 *                      object context):
 *         return TimerHandle(self, callback, args, delay, context)
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__call_later(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, uint64_t __pyx_v_delay, PyObject *__pyx_v_callback, PyObject *__pyx_v_args, PyObject *__pyx_v_context) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_call_later", 0);

  /* "uvloop/loop.pyx":615
 *     cdef _call_later(self, uint64_t delay, object callback, object args,
 *                      object context):
 *         return TimerHandle(self, callback, args, delay, context)             # <<<<<<<<<<<<<<
 * 
 *     cdef void _handle_exception(self, object ex):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_delay); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self));
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_callback);
  __Pyx_INCREF(__pyx_v_args);
  __Pyx_GIVEREF(__pyx_v_args);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_args);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_context);
  __Pyx_GIVEREF(__pyx_v_context);
  PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_v_context);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop_TimerHandle), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":613
 *             self.handler_idle.start()
 * 
 *     cdef _call_later(self, uint64_t delay, object callback, object args,             # <<<<<<<<<<<<<<
 *                      object context):
 *         return TimerHandle(self, callback, args, delay, context)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop._call_later", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":617
 *         return TimerHandle(self, callback, args, delay, context)
 * 
 *     cdef void _handle_exception(self, object ex):             # <<<<<<<<<<<<<<
 *         if isinstance(ex, Exception):
 *             self.call_exception_handler({'exception': ex})
 */

static void __pyx_f_6uvloop_4loop_4Loop__handle_exception(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_ex) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_handle_exception", 0);

  /* "uvloop/loop.pyx":618
 * 
 *     cdef void _handle_exception(self, object ex):
 *         if isinstance(ex, Exception):             # <<<<<<<<<<<<<<
 *             self.call_exception_handler({'exception': ex})
 *         else:
 */
  __pyx_t_1 = __Pyx_PyException_Check(__pyx_v_ex); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":619
 *     cdef void _handle_exception(self, object ex):
 *         if isinstance(ex, Exception):
 *             self.call_exception_handler({'exception': ex})             # <<<<<<<<<<<<<<
 *         else:
 *             # BaseException
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_u_exception, __pyx_v_ex) < 0) __PYX_ERR(2, 619, __pyx_L1_error)
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 619, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 619, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 619, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 619, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 619, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":618
 * 
 *     cdef void _handle_exception(self, object ex):
 *         if isinstance(ex, Exception):             # <<<<<<<<<<<<<<
 *             self.call_exception_handler({'exception': ex})
 *         else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":622
 *         else:
 *             # BaseException
 *             self._last_error = ex             # <<<<<<<<<<<<<<
 *             # Exit ASAP
 *             self._stop(None)
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_ex);
    __Pyx_GIVEREF(__pyx_v_ex);
    __Pyx_GOTREF(__pyx_v_self->_last_error);
    __Pyx_DECREF(__pyx_v_self->_last_error);
    __pyx_v_self->_last_error = __pyx_v_ex;

    /* "uvloop/loop.pyx":624
 *             self._last_error = ex
 *             # Exit ASAP
 *             self._stop(None)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _check_signal(self, sig):
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_stop(__pyx_v_self, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 624, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":617
 *         return TimerHandle(self, callback, args, delay, context)
 * 
 *     cdef void _handle_exception(self, object ex):             # <<<<<<<<<<<<<<
 *         if isinstance(ex, Exception):
 *             self.call_exception_handler({'exception': ex})
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_WriteUnraisable("uvloop.loop.Loop._handle_exception", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/loop.pyx":626
 *             self._stop(None)
 * 
 *     cdef inline _check_signal(self, sig):             # <<<<<<<<<<<<<<
 *         if not isinstance(sig, int):
 *             raise TypeError('sig must be an int, not {!r}'.format(sig))
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_signal(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("_check_signal", 0);

  /* "uvloop/loop.pyx":627
 * 
 *     cdef inline _check_signal(self, sig):
 *         if not isinstance(sig, int):             # <<<<<<<<<<<<<<
 *             raise TypeError('sig must be an int, not {!r}'.format(sig))
 * 
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_sig); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":628
 *     cdef inline _check_signal(self, sig):
 *         if not isinstance(sig, int):
 *             raise TypeError('sig must be an int, not {!r}'.format(sig))             # <<<<<<<<<<<<<<
 * 
 *         if not (1 <= sig < signal_NSIG):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_sig_must_be_an_int_not_r, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 628, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_sig); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 628, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_sig};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 628, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_sig};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 628, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 628, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_sig);
        __Pyx_GIVEREF(__pyx_v_sig);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_sig);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 628, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 628, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 628, __pyx_L1_error)

    /* "uvloop/loop.pyx":627
 * 
 *     cdef inline _check_signal(self, sig):
 *         if not isinstance(sig, int):             # <<<<<<<<<<<<<<
 *             raise TypeError('sig must be an int, not {!r}'.format(sig))
 * 
 */
  }

  /* "uvloop/loop.pyx":630
 *             raise TypeError('sig must be an int, not {!r}'.format(sig))
 * 
 *         if not (1 <= sig < signal_NSIG):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'sig {} out of range(1, {})'.format(sig, signal_NSIG))
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_int_1, __pyx_v_sig, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 630, __pyx_L1_error)
  if (__Pyx_PyObject_IsTrue(__pyx_t_4)) {
    __Pyx_DECREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_signal_NSIG); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_v_sig, __pyx_t_3, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 630, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = ((!__pyx_t_2) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":632
 *         if not (1 <= sig < signal_NSIG):
 *             raise ValueError(
 *                 'sig {} out of range(1, {})'.format(sig, signal_NSIG))             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _check_closed(self):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_sig_out_of_range_1, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_signal_NSIG); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 632, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sig, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 632, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sig, __pyx_t_6};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 632, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_v_sig);
      __Pyx_GIVEREF(__pyx_v_sig);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_sig);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":631
 * 
 *         if not (1 <= sig < signal_NSIG):
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'sig {} out of range(1, {})'.format(sig, signal_NSIG))
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 631, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 631, __pyx_L1_error)

    /* "uvloop/loop.pyx":630
 *             raise TypeError('sig must be an int, not {!r}'.format(sig))
 * 
 *         if not (1 <= sig < signal_NSIG):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'sig {} out of range(1, {})'.format(sig, signal_NSIG))
 */
  }

  /* "uvloop/loop.pyx":626
 *             self._stop(None)
 * 
 *     cdef inline _check_signal(self, sig):             # <<<<<<<<<<<<<<
 *         if not isinstance(sig, int):
 *             raise TypeError('sig must be an int, not {!r}'.format(sig))
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.Loop._check_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":634
 *                 'sig {} out of range(1, {})'.format(sig, signal_NSIG))
 * 
 *     cdef inline _check_closed(self):             # <<<<<<<<<<<<<<
 *         if self._closed == 1:
 *             raise RuntimeError('Event loop is closed')
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_closed(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_check_closed", 0);

  /* "uvloop/loop.pyx":635
 * 
 *     cdef inline _check_closed(self):
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Event loop is closed')
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_closed == 1) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":636
 *     cdef inline _check_closed(self):
 *         if self._closed == 1:
 *             raise RuntimeError('Event loop is closed')             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _check_thread(self):
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 636, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 636, __pyx_L1_error)

    /* "uvloop/loop.pyx":635
 * 
 *     cdef inline _check_closed(self):
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Event loop is closed')
 * 
 */
  }

  /* "uvloop/loop.pyx":634
 *                 'sig {} out of range(1, {})'.format(sig, signal_NSIG))
 * 
 *     cdef inline _check_closed(self):             # <<<<<<<<<<<<<<
 *         if self._closed == 1:
 *             raise RuntimeError('Event loop is closed')
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop._check_closed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":638
 *             raise RuntimeError('Event loop is closed')
 * 
 *     cdef inline _check_thread(self):             # <<<<<<<<<<<<<<
 *         if self._thread_id == 0:
 *             return
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__check_thread(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  uint64_t __pyx_v_thread_id;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_check_thread", 0);

  /* "uvloop/loop.pyx":639
 * 
 *     cdef inline _check_thread(self):
 *         if self._thread_id == 0:             # <<<<<<<<<<<<<<
 *             return
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()
 */
  __pyx_t_1 = ((__pyx_v_self->_thread_id == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":640
 *     cdef inline _check_thread(self):
 *         if self._thread_id == 0:
 *             return             # <<<<<<<<<<<<<<
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()
 *         if thread_id != self._thread_id:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":639
 * 
 *     cdef inline _check_thread(self):
 *         if self._thread_id == 0:             # <<<<<<<<<<<<<<
 *             return
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()
 */
  }

  /* "uvloop/loop.pyx":641
 *         if self._thread_id == 0:
 *             return
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()             # <<<<<<<<<<<<<<
 *         if thread_id != self._thread_id:
 *             raise RuntimeError(
 */
  __pyx_v_thread_id = ((uint64_t)((int64_t)PyThread_get_thread_ident()));

  /* "uvloop/loop.pyx":642
 *             return
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()
 *         if thread_id != self._thread_id:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "Non-thread-safe operation invoked on an event loop other "
 */
  __pyx_t_1 = ((__pyx_v_thread_id != __pyx_v_self->_thread_id) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":643
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()
 *         if thread_id != self._thread_id:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 "Non-thread-safe operation invoked on an event loop other "
 *                 "than the current one")
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 643, __pyx_L1_error)

    /* "uvloop/loop.pyx":642
 *             return
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()
 *         if thread_id != self._thread_id:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 "Non-thread-safe operation invoked on an event loop other "
 */
  }

  /* "uvloop/loop.pyx":638
 *             raise RuntimeError('Event loop is closed')
 * 
 *     cdef inline _check_thread(self):             # <<<<<<<<<<<<<<
 *         if self._thread_id == 0:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop._check_thread", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":647
 *                 "than the current one")
 * 
 *     cdef inline _new_future(self):             # <<<<<<<<<<<<<<
 *         return aio_Future(loop=self)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_4Loop__new_future(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_new_future", 0);

  /* "uvloop/loop.pyx":648
 * 
 *     cdef inline _new_future(self):
 *         return aio_Future(loop=self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _track_transport(self, UVBaseTransport transport):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_loop, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(2, 648, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_Future, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":647
 *                 "than the current one")
 * 
 *     cdef inline _new_future(self):             # <<<<<<<<<<<<<<
 *         return aio_Future(loop=self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop._new_future", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":650
 *         return aio_Future(loop=self)
 * 
 *     cdef _track_transport(self, UVBaseTransport transport):             # <<<<<<<<<<<<<<
 *         self._transports[transport._fileno()] = transport
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__track_transport(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_transport) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_track_transport", 0);

  /* "uvloop/loop.pyx":651
 * 
 *     cdef _track_transport(self, UVBaseTransport transport):
 *         self._transports[transport._fileno()] = transport             # <<<<<<<<<<<<<<
 * 
 *     cdef _track_process(self, UVProcess proc):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_transport->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._fileno(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_transport)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely(PyObject_SetItem(__pyx_v_self->_transports, __pyx_t_1, ((PyObject *)__pyx_v_transport)) < 0)) __PYX_ERR(2, 651, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":650
 *         return aio_Future(loop=self)
 * 
 *     cdef _track_transport(self, UVBaseTransport transport):             # <<<<<<<<<<<<<<
 *         self._transports[transport._fileno()] = transport
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._track_transport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":653
 *         self._transports[transport._fileno()] = transport
 * 
 *     cdef _track_process(self, UVProcess proc):             # <<<<<<<<<<<<<<
 *         self._processes.add(proc)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__track_process(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_proc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_track_process", 0);

  /* "uvloop/loop.pyx":654
 * 
 *     cdef _track_process(self, UVProcess proc):
 *         self._processes.add(proc)             # <<<<<<<<<<<<<<
 * 
 *     cdef _untrack_process(self, UVProcess proc):
 */
  if (unlikely(__pyx_v_self->_processes == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(2, 654, __pyx_L1_error)
  }
  __pyx_t_1 = PySet_Add(__pyx_v_self->_processes, ((PyObject *)__pyx_v_proc)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 654, __pyx_L1_error)

  /* "uvloop/loop.pyx":653
 *         self._transports[transport._fileno()] = transport
 * 
 *     cdef _track_process(self, UVProcess proc):             # <<<<<<<<<<<<<<
 *         self._processes.add(proc)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop._track_process", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":656
 *         self._processes.add(proc)
 * 
 *     cdef _untrack_process(self, UVProcess proc):             # <<<<<<<<<<<<<<
 *         self._processes.discard(proc)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__untrack_process(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_proc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_untrack_process", 0);

  /* "uvloop/loop.pyx":657
 * 
 *     cdef _untrack_process(self, UVProcess proc):
 *         self._processes.discard(proc)             # <<<<<<<<<<<<<<
 * 
 *     cdef _fileobj_to_fd(self, fileobj):
 */
  if (unlikely(__pyx_v_self->_processes == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "discard");
    __PYX_ERR(2, 657, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PySet_Discard(__pyx_v_self->_processes, ((PyObject *)__pyx_v_proc)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 657, __pyx_L1_error)

  /* "uvloop/loop.pyx":656
 *         self._processes.add(proc)
 * 
 *     cdef _untrack_process(self, UVProcess proc):             # <<<<<<<<<<<<<<
 *         self._processes.discard(proc)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop._untrack_process", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":659
 *         self._processes.discard(proc)
 * 
 *     cdef _fileobj_to_fd(self, fileobj):             # <<<<<<<<<<<<<<
 *         """Return a file descriptor from a file object.
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__fileobj_to_fd(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("_fileobj_to_fd", 0);

  /* "uvloop/loop.pyx":672
 *         """
 *         # Copy of the `selectors._fileobj_to_fd()` function.
 *         if isinstance(fileobj, int):             # <<<<<<<<<<<<<<
 *             fd = fileobj
 *         else:
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_fileobj); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":673
 *         # Copy of the `selectors._fileobj_to_fd()` function.
 *         if isinstance(fileobj, int):
 *             fd = fileobj             # <<<<<<<<<<<<<<
 *         else:
 *             try:
 */
    __Pyx_INCREF(__pyx_v_fileobj);
    __pyx_v_fd = __pyx_v_fileobj;

    /* "uvloop/loop.pyx":672
 *         """
 *         # Copy of the `selectors._fileobj_to_fd()` function.
 *         if isinstance(fileobj, int):             # <<<<<<<<<<<<<<
 *             fd = fileobj
 *         else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":675
 *             fd = fileobj
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 fd = int(fileobj.fileno())
 *             except (AttributeError, TypeError, ValueError):
 */
  /*else*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/loop.pyx":676
 *         else:
 *             try:
 *                 fd = int(fileobj.fileno())             # <<<<<<<<<<<<<<
 *             except (AttributeError, TypeError, ValueError):
 *                 raise ValueError("Invalid file object: "
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_fileobj, __pyx_n_s_fileno); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 676, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (__pyx_t_8) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 676, __pyx_L4_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else {
          __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 676, __pyx_L4_error)
        }
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyNumber_Int(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 676, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_fd = __pyx_t_7;
        __pyx_t_7 = 0;

        /* "uvloop/loop.pyx":675
 *             fd = fileobj
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 fd = int(fileobj.fileno())
 *             except (AttributeError, TypeError, ValueError):
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":677
 *             try:
 *                 fd = int(fileobj.fileno())
 *             except (AttributeError, TypeError, ValueError):             # <<<<<<<<<<<<<<
 *                 raise ValueError("Invalid file object: "
 *                                  "{!r}".format(fileobj)) from None
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("uvloop.loop.Loop._fileobj_to_fd", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(2, 677, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_8);

        /* "uvloop/loop.pyx":679
 *             except (AttributeError, TypeError, ValueError):
 *                 raise ValueError("Invalid file object: "
 *                                  "{!r}".format(fileobj)) from None             # <<<<<<<<<<<<<<
 *         if fd < 0:
 *             raise ValueError("Invalid file descriptor: {}".format(fd))
 */
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Invalid_file_object_r, __pyx_n_s_format); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 679, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
          }
        }
        if (!__pyx_t_12) {
          __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_fileobj); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 679, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_10);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_fileobj};
            __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 679, __pyx_L6_except_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_10);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_fileobj};
            __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 679, __pyx_L6_except_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_10);
          } else
          #endif
          {
            __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 679, __pyx_L6_except_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
            __Pyx_INCREF(__pyx_v_fileobj);
            __Pyx_GIVEREF(__pyx_v_fileobj);
            PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_fileobj);
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 679, __pyx_L6_except_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "uvloop/loop.pyx":678
 *                 fd = int(fileobj.fileno())
 *             except (AttributeError, TypeError, ValueError):
 *                 raise ValueError("Invalid file object: "             # <<<<<<<<<<<<<<
 *                                  "{!r}".format(fileobj)) from None
 *         if fd < 0:
 */
        __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 678, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "uvloop/loop.pyx":679
 *             except (AttributeError, TypeError, ValueError):
 *                 raise ValueError("Invalid file object: "
 *                                  "{!r}".format(fileobj)) from None             # <<<<<<<<<<<<<<
 *         if fd < 0:
 *             raise ValueError("Invalid file descriptor: {}".format(fd))
 */
        __Pyx_Raise(__pyx_t_11, 0, 0, Py_None);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __PYX_ERR(2, 678, __pyx_L6_except_error)
      }
      goto __pyx_L6_except_error;
      __pyx_L6_except_error:;

      /* "uvloop/loop.pyx":675
 *             fd = fileobj
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 fd = int(fileobj.fileno())
 *             except (AttributeError, TypeError, ValueError):
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L9_try_end:;
    }
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":680
 *                 raise ValueError("Invalid file object: "
 *                                  "{!r}".format(fileobj)) from None
 *         if fd < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Invalid file descriptor: {}".format(fd))
 *         return fd
 */
  __pyx_t_8 = PyObject_RichCompare(__pyx_v_fd, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 680, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":681
 *                                  "{!r}".format(fileobj)) from None
 *         if fd < 0:
 *             raise ValueError("Invalid file descriptor: {}".format(fd))             # <<<<<<<<<<<<<<
 *         return fd
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Invalid_file_descriptor, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_fd); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 681, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_fd};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 681, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_fd};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 681, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_8);
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 681, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_INCREF(__pyx_v_fd);
        __Pyx_GIVEREF(__pyx_v_fd);
        PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_fd);
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_11, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 681, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(2, 681, __pyx_L1_error)

    /* "uvloop/loop.pyx":680
 *                 raise ValueError("Invalid file object: "
 *                                  "{!r}".format(fileobj)) from None
 *         if fd < 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("Invalid file descriptor: {}".format(fd))
 *         return fd
 */
  }

  /* "uvloop/loop.pyx":682
 *         if fd < 0:
 *             raise ValueError("Invalid file descriptor: {}".format(fd))
 *         return fd             # <<<<<<<<<<<<<<
 * 
 *     cdef _ensure_fd_no_transport(self, fd):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_fd);
  __pyx_r = __pyx_v_fd;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":659
 *         self._processes.discard(proc)
 * 
 *     cdef _fileobj_to_fd(self, fileobj):             # <<<<<<<<<<<<<<
 *         """Return a file descriptor from a file object.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.Loop._fileobj_to_fd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":684
 *         return fd
 * 
 *     cdef _ensure_fd_no_transport(self, fd):             # <<<<<<<<<<<<<<
 *         cdef UVBaseTransport tr
 *         try:
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__ensure_fd_no_transport(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fd) {
  struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_tr = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_ensure_fd_no_transport", 0);

  /* "uvloop/loop.pyx":686
 *     cdef _ensure_fd_no_transport(self, fd):
 *         cdef UVBaseTransport tr
 *         try:             # <<<<<<<<<<<<<<
 *             tr = <UVBaseTransport>(self._transports[fd])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/loop.pyx":687
 *         cdef UVBaseTransport tr
 *         try:
 *             tr = <UVBaseTransport>(self._transports[fd])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             pass
 */
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_self->_transports, __pyx_v_fd); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 687, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __pyx_t_4;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_tr = ((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":686
 *     cdef _ensure_fd_no_transport(self, fd):
 *         cdef UVBaseTransport tr
 *         try:             # <<<<<<<<<<<<<<
 *             tr = <UVBaseTransport>(self._transports[fd])
 *         except KeyError:
 */
    }

    /* "uvloop/loop.pyx":691
 *             pass
 *         else:
 *             if tr._is_alive():             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     'File descriptor {!r} is used by transport {!r}'.format(
 */
    /*else:*/ {
      __pyx_t_6 = (((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_tr->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_tr)) != 0);
      if (unlikely(__pyx_t_6)) {

        /* "uvloop/loop.pyx":693
 *             if tr._is_alive():
 *                 raise RuntimeError(
 *                     'File descriptor {!r} is used by transport {!r}'.format(             # <<<<<<<<<<<<<<
 *                         fd, tr))
 * 
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_File_descriptor_r_is_used_by_tra, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 693, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);

        /* "uvloop/loop.pyx":694
 *                 raise RuntimeError(
 *                     'File descriptor {!r} is used by transport {!r}'.format(
 *                         fd, tr))             # <<<<<<<<<<<<<<
 * 
 *     cdef _add_reader(self, fileobj, Handle handle):
 */
        __pyx_t_7 = NULL;
        __pyx_t_8 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_8 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_fd, ((PyObject *)__pyx_v_tr)};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 693, __pyx_L5_except_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_fd, ((PyObject *)__pyx_v_tr)};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 693, __pyx_L5_except_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 693, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__pyx_t_7) {
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
          }
          __Pyx_INCREF(__pyx_v_fd);
          __Pyx_GIVEREF(__pyx_v_fd);
          PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_v_fd);
          __Pyx_INCREF(((PyObject *)__pyx_v_tr));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_tr));
          PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, ((PyObject *)__pyx_v_tr));
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 693, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/loop.pyx":692
 *         else:
 *             if tr._is_alive():
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     'File descriptor {!r} is used by transport {!r}'.format(
 *                         fd, tr))
 */
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 692, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(2, 692, __pyx_L5_except_error)

        /* "uvloop/loop.pyx":691
 *             pass
 *         else:
 *             if tr._is_alive():             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     'File descriptor {!r} is used by transport {!r}'.format(
 */
      }
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":688
 *         try:
 *             tr = <UVBaseTransport>(self._transports[fd])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             pass
 *         else:
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_8) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":686
 *     cdef _ensure_fd_no_transport(self, fd):
 *         cdef UVBaseTransport tr
 *         try:             # <<<<<<<<<<<<<<
 *             tr = <UVBaseTransport>(self._transports[fd])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "uvloop/loop.pyx":684
 *         return fd
 * 
 *     cdef _ensure_fd_no_transport(self, fd):             # <<<<<<<<<<<<<<
 *         cdef UVBaseTransport tr
 *         try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.Loop._ensure_fd_no_transport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":696
 *                         fd, tr))
 * 
 *     cdef _add_reader(self, fileobj, Handle handle):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__add_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_poll = 0;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_v_old_fileobj = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("_add_reader", 0);

  /* "uvloop/loop.pyx":700
 *             UVPoll poll
 * 
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         fd = self._fileobj_to_fd(fileobj)
 *         self._ensure_fd_no_transport(fd)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":701
 * 
 *         self._check_closed()
 *         fd = self._fileobj_to_fd(fileobj)             # <<<<<<<<<<<<<<
 *         self._ensure_fd_no_transport(fd)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_fileobj_to_fd(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":702
 *         self._check_closed()
 *         fd = self._fileobj_to_fd(fileobj)
 *         self._ensure_fd_no_transport(fd)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_ensure_fd_no_transport(__pyx_v_self, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":704
 *         self._ensure_fd_no_transport(fd)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/loop.pyx":705
 * 
 *         try:
 *             poll = <UVPoll>(self._polls[fd])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             poll = UVPoll.new(self, fd)
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 705, __pyx_L3_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_polls, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 705, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":704
 *         self._ensure_fd_no_transport(fd)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":706
 *         try:
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             poll = UVPoll.new(self, fd)
 *             self._polls[fd] = poll
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.Loop._add_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(2, 706, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);

      /* "uvloop/loop.pyx":707
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 *             poll = UVPoll.new(self, fd)             # <<<<<<<<<<<<<<
 *             self._polls[fd] = poll
 * 
 */
      __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_fd); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 707, __pyx_L5_except_error)
      __pyx_t_8 = ((PyObject *)__pyx_f_6uvloop_4loop_6UVPoll_new(__pyx_v_self, __pyx_t_6)); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 707, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_poll, ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "uvloop/loop.pyx":708
 *         except KeyError:
 *             poll = UVPoll.new(self, fd)
 *             self._polls[fd] = poll             # <<<<<<<<<<<<<<
 * 
 *         poll.start_reading(handle)
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 708, __pyx_L5_except_error)
      }
      if (unlikely(PyDict_SetItem(__pyx_v_self->_polls, __pyx_v_fd, ((PyObject *)__pyx_v_poll)) < 0)) __PYX_ERR(2, 708, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":704
 *         self._ensure_fd_no_transport(fd)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L8_try_end:;
  }

  /* "uvloop/loop.pyx":710
 *             self._polls[fd] = poll
 * 
 *         poll.start_reading(handle)             # <<<<<<<<<<<<<<
 * 
 *         old_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 */
  __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->start_reading(__pyx_v_poll, __pyx_v_handle); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":712
 *         poll.start_reading(handle)
 * 
 *         old_fileobj = self._fd_to_reader_fileobj.pop(fd, None)             # <<<<<<<<<<<<<<
 *         if old_fileobj is not None:
 *             socket_dec_io_ref(old_fileobj)
 */
  if (unlikely(__pyx_v_self->_fd_to_reader_fileobj == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(2, 712, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyDict_Pop(__pyx_v_self->_fd_to_reader_fileobj, __pyx_v_fd, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_old_fileobj = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":713
 * 
 *         old_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 *         if old_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(old_fileobj)
 * 
 */
  __pyx_t_9 = (__pyx_v_old_fileobj != Py_None);
  __pyx_t_10 = (__pyx_t_9 != 0);
  if (__pyx_t_10) {

    /* "uvloop/loop.pyx":714
 *         old_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 *         if old_fileobj is not None:
 *             socket_dec_io_ref(old_fileobj)             # <<<<<<<<<<<<<<
 * 
 *         self._fd_to_reader_fileobj[fd] = fileobj
 */
    __pyx_t_7 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_v_old_fileobj); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 714, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":713
 * 
 *         old_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 *         if old_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(old_fileobj)
 * 
 */
  }

  /* "uvloop/loop.pyx":716
 *             socket_dec_io_ref(old_fileobj)
 * 
 *         self._fd_to_reader_fileobj[fd] = fileobj             # <<<<<<<<<<<<<<
 *         socket_inc_io_ref(fileobj)
 * 
 */
  if (unlikely(__pyx_v_self->_fd_to_reader_fileobj == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 716, __pyx_L1_error)
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->_fd_to_reader_fileobj, __pyx_v_fd, __pyx_v_fileobj) < 0)) __PYX_ERR(2, 716, __pyx_L1_error)

  /* "uvloop/loop.pyx":717
 * 
 *         self._fd_to_reader_fileobj[fd] = fileobj
 *         socket_inc_io_ref(fileobj)             # <<<<<<<<<<<<<<
 * 
 *     cdef _remove_reader(self, fileobj):
 */
  __pyx_t_7 = __pyx_f_6uvloop_4loop_socket_inc_io_ref(__pyx_v_fileobj); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":696
 *                         fd, tr))
 * 
 *     cdef _add_reader(self, fileobj, Handle handle):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.Loop._add_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_poll);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XDECREF(__pyx_v_old_fileobj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":719
 *         socket_inc_io_ref(fileobj)
 * 
 *     cdef _remove_reader(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__remove_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_poll = 0;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_v_mapped_fileobj = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_remove_reader", 0);

  /* "uvloop/loop.pyx":723
 *             UVPoll poll
 * 
 *         fd = self._fileobj_to_fd(fileobj)             # <<<<<<<<<<<<<<
 *         self._ensure_fd_no_transport(fd)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_fileobj_to_fd(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":724
 * 
 *         fd = self._fileobj_to_fd(fileobj)
 *         self._ensure_fd_no_transport(fd)             # <<<<<<<<<<<<<<
 * 
 *         mapped_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_ensure_fd_no_transport(__pyx_v_self, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":726
 *         self._ensure_fd_no_transport(fd)
 * 
 *         mapped_fileobj = self._fd_to_reader_fileobj.pop(fd, None)             # <<<<<<<<<<<<<<
 *         if mapped_fileobj is not None:
 *             socket_dec_io_ref(mapped_fileobj)
 */
  if (unlikely(__pyx_v_self->_fd_to_reader_fileobj == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(2, 726, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_Pop(__pyx_v_self->_fd_to_reader_fileobj, __pyx_v_fd, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_mapped_fileobj = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":727
 * 
 *         mapped_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 *         if mapped_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 */
  __pyx_t_2 = (__pyx_v_mapped_fileobj != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":728
 *         mapped_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 *         if mapped_fileobj is not None:
 *             socket_dec_io_ref(mapped_fileobj)             # <<<<<<<<<<<<<<
 * 
 *         if self._closed == 1:
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_v_mapped_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":727
 * 
 *         mapped_fileobj = self._fd_to_reader_fileobj.pop(fd, None)
 *         if mapped_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 */
  }

  /* "uvloop/loop.pyx":730
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_3 = ((__pyx_v_self->_closed == 1) != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":731
 * 
 *         if self._closed == 1:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":730
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "uvloop/loop.pyx":733
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/loop.pyx":734
 * 
 *         try:
 *             poll = <UVPoll>(self._polls[fd])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             return False
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 734, __pyx_L5_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_polls, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 734, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":733
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":735
 *         try:
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("uvloop.loop.Loop._remove_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_1, &__pyx_t_9) < 0) __PYX_ERR(2, 735, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_9);

      /* "uvloop/loop.pyx":736
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         result = poll.stop_reading()
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L8_except_return;
    }
    goto __pyx_L7_except_error;
    __pyx_L7_except_error:;

    /* "uvloop/loop.pyx":733
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L8_except_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
    __pyx_L10_try_end:;
  }

  /* "uvloop/loop.pyx":738
 *             return False
 * 
 *         result = poll.stop_reading()             # <<<<<<<<<<<<<<
 *         if not poll.is_active():
 *             del self._polls[fd]
 */
  __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->stop_reading(__pyx_v_poll); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 738, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_v_result = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":739
 * 
 *         result = poll.stop_reading()
 *         if not poll.is_active():             # <<<<<<<<<<<<<<
 *             del self._polls[fd]
 *             poll._close()
 */
  __pyx_t_3 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->is_active(__pyx_v_poll) != 0)) != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":740
 *         result = poll.stop_reading()
 *         if not poll.is_active():
 *             del self._polls[fd]             # <<<<<<<<<<<<<<
 *             poll._close()
 * 
 */
    if (unlikely(__pyx_v_self->_polls == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(2, 740, __pyx_L1_error)
    }
    if (unlikely(PyDict_DelItem(__pyx_v_self->_polls, __pyx_v_fd) < 0)) __PYX_ERR(2, 740, __pyx_L1_error)

    /* "uvloop/loop.pyx":741
 *         if not poll.is_active():
 *             del self._polls[fd]
 *             poll._close()             # <<<<<<<<<<<<<<
 * 
 *         return result
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_poll)); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":739
 * 
 *         result = poll.stop_reading()
 *         if not poll.is_active():             # <<<<<<<<<<<<<<
 *             del self._polls[fd]
 *             poll._close()
 */
  }

  /* "uvloop/loop.pyx":743
 *             poll._close()
 * 
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cdef _has_reader(self, fileobj):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":719
 *         socket_inc_io_ref(fileobj)
 * 
 *     cdef _remove_reader(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.Loop._remove_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_poll);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XDECREF(__pyx_v_mapped_fileobj);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":745
 *         return result
 * 
 *     cdef _has_reader(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__has_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_poll = 0;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_has_reader", 0);

  /* "uvloop/loop.pyx":749
 *             UVPoll poll
 * 
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":750
 * 
 *         self._check_closed()
 *         fd = self._fileobj_to_fd(fileobj)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_fileobj_to_fd(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":752
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/loop.pyx":753
 * 
 *         try:
 *             poll = <UVPoll>(self._polls[fd])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             return False
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 753, __pyx_L3_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_polls, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 753, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":752
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":754
 *         try:
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.Loop._has_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(2, 754, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);

      /* "uvloop/loop.pyx":755
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         return poll.is_reading()
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":752
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "uvloop/loop.pyx":757
 *             return False
 * 
 *         return poll.is_reading()             # <<<<<<<<<<<<<<
 * 
 *     cdef _add_writer(self, fileobj, Handle handle):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->is_reading(__pyx_v_poll); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":745
 *         return result
 * 
 *     cdef _has_reader(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop._has_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_poll);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":759
 *         return poll.is_reading()
 * 
 *     cdef _add_writer(self, fileobj, Handle handle):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__add_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_poll = 0;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_v_old_fileobj = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("_add_writer", 0);

  /* "uvloop/loop.pyx":763
 *             UVPoll poll
 * 
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         fd = self._fileobj_to_fd(fileobj)
 *         self._ensure_fd_no_transport(fd)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":764
 * 
 *         self._check_closed()
 *         fd = self._fileobj_to_fd(fileobj)             # <<<<<<<<<<<<<<
 *         self._ensure_fd_no_transport(fd)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_fileobj_to_fd(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 764, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":765
 *         self._check_closed()
 *         fd = self._fileobj_to_fd(fileobj)
 *         self._ensure_fd_no_transport(fd)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_ensure_fd_no_transport(__pyx_v_self, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 765, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":767
 *         self._ensure_fd_no_transport(fd)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/loop.pyx":768
 * 
 *         try:
 *             poll = <UVPoll>(self._polls[fd])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             poll = UVPoll.new(self, fd)
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 768, __pyx_L3_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_polls, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 768, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":767
 *         self._ensure_fd_no_transport(fd)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":769
 *         try:
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             poll = UVPoll.new(self, fd)
 *             self._polls[fd] = poll
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.Loop._add_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(2, 769, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);

      /* "uvloop/loop.pyx":770
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 *             poll = UVPoll.new(self, fd)             # <<<<<<<<<<<<<<
 *             self._polls[fd] = poll
 * 
 */
      __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_fd); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 770, __pyx_L5_except_error)
      __pyx_t_8 = ((PyObject *)__pyx_f_6uvloop_4loop_6UVPoll_new(__pyx_v_self, __pyx_t_6)); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 770, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_poll, ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "uvloop/loop.pyx":771
 *         except KeyError:
 *             poll = UVPoll.new(self, fd)
 *             self._polls[fd] = poll             # <<<<<<<<<<<<<<
 * 
 *         poll.start_writing(handle)
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 771, __pyx_L5_except_error)
      }
      if (unlikely(PyDict_SetItem(__pyx_v_self->_polls, __pyx_v_fd, ((PyObject *)__pyx_v_poll)) < 0)) __PYX_ERR(2, 771, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":767
 *         self._ensure_fd_no_transport(fd)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L8_try_end:;
  }

  /* "uvloop/loop.pyx":773
 *             self._polls[fd] = poll
 * 
 *         poll.start_writing(handle)             # <<<<<<<<<<<<<<
 * 
 *         old_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 */
  __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->start_writing(__pyx_v_poll, __pyx_v_handle); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 773, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":775
 *         poll.start_writing(handle)
 * 
 *         old_fileobj = self._fd_to_writer_fileobj.pop(fd, None)             # <<<<<<<<<<<<<<
 *         if old_fileobj is not None:
 *             socket_dec_io_ref(old_fileobj)
 */
  if (unlikely(__pyx_v_self->_fd_to_writer_fileobj == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(2, 775, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyDict_Pop(__pyx_v_self->_fd_to_writer_fileobj, __pyx_v_fd, Py_None); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_old_fileobj = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":776
 * 
 *         old_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 *         if old_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(old_fileobj)
 * 
 */
  __pyx_t_9 = (__pyx_v_old_fileobj != Py_None);
  __pyx_t_10 = (__pyx_t_9 != 0);
  if (__pyx_t_10) {

    /* "uvloop/loop.pyx":777
 *         old_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 *         if old_fileobj is not None:
 *             socket_dec_io_ref(old_fileobj)             # <<<<<<<<<<<<<<
 * 
 *         self._fd_to_writer_fileobj[fd] = fileobj
 */
    __pyx_t_7 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_v_old_fileobj); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":776
 * 
 *         old_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 *         if old_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(old_fileobj)
 * 
 */
  }

  /* "uvloop/loop.pyx":779
 *             socket_dec_io_ref(old_fileobj)
 * 
 *         self._fd_to_writer_fileobj[fd] = fileobj             # <<<<<<<<<<<<<<
 *         socket_inc_io_ref(fileobj)
 * 
 */
  if (unlikely(__pyx_v_self->_fd_to_writer_fileobj == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 779, __pyx_L1_error)
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->_fd_to_writer_fileobj, __pyx_v_fd, __pyx_v_fileobj) < 0)) __PYX_ERR(2, 779, __pyx_L1_error)

  /* "uvloop/loop.pyx":780
 * 
 *         self._fd_to_writer_fileobj[fd] = fileobj
 *         socket_inc_io_ref(fileobj)             # <<<<<<<<<<<<<<
 * 
 *     cdef _remove_writer(self, fileobj):
 */
  __pyx_t_7 = __pyx_f_6uvloop_4loop_socket_inc_io_ref(__pyx_v_fileobj); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":759
 *         return poll.is_reading()
 * 
 *     cdef _add_writer(self, fileobj, Handle handle):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.Loop._add_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_poll);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XDECREF(__pyx_v_old_fileobj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":782
 *         socket_inc_io_ref(fileobj)
 * 
 *     cdef _remove_writer(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__remove_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_poll = 0;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_v_mapped_fileobj = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_remove_writer", 0);

  /* "uvloop/loop.pyx":786
 *             UVPoll poll
 * 
 *         fd = self._fileobj_to_fd(fileobj)             # <<<<<<<<<<<<<<
 *         self._ensure_fd_no_transport(fd)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_fileobj_to_fd(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":787
 * 
 *         fd = self._fileobj_to_fd(fileobj)
 *         self._ensure_fd_no_transport(fd)             # <<<<<<<<<<<<<<
 * 
 *         mapped_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_ensure_fd_no_transport(__pyx_v_self, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 787, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":789
 *         self._ensure_fd_no_transport(fd)
 * 
 *         mapped_fileobj = self._fd_to_writer_fileobj.pop(fd, None)             # <<<<<<<<<<<<<<
 *         if mapped_fileobj is not None:
 *             socket_dec_io_ref(mapped_fileobj)
 */
  if (unlikely(__pyx_v_self->_fd_to_writer_fileobj == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
    __PYX_ERR(2, 789, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyDict_Pop(__pyx_v_self->_fd_to_writer_fileobj, __pyx_v_fd, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_mapped_fileobj = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":790
 * 
 *         mapped_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 *         if mapped_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 */
  __pyx_t_2 = (__pyx_v_mapped_fileobj != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":791
 *         mapped_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 *         if mapped_fileobj is not None:
 *             socket_dec_io_ref(mapped_fileobj)             # <<<<<<<<<<<<<<
 * 
 *         if self._closed == 1:
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_v_mapped_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 791, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":790
 * 
 *         mapped_fileobj = self._fd_to_writer_fileobj.pop(fd, None)
 *         if mapped_fileobj is not None:             # <<<<<<<<<<<<<<
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 */
  }

  /* "uvloop/loop.pyx":793
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_3 = ((__pyx_v_self->_closed == 1) != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":794
 * 
 *         if self._closed == 1:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":793
 *             socket_dec_io_ref(mapped_fileobj)
 * 
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "uvloop/loop.pyx":796
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/loop.pyx":797
 * 
 *         try:
 *             poll = <UVPoll>(self._polls[fd])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             return False
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 797, __pyx_L5_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_polls, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 797, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":796
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":798
 *         try:
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("uvloop.loop.Loop._remove_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_1, &__pyx_t_9) < 0) __PYX_ERR(2, 798, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_9);

      /* "uvloop/loop.pyx":799
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         result = poll.stop_writing()
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L8_except_return;
    }
    goto __pyx_L7_except_error;
    __pyx_L7_except_error:;

    /* "uvloop/loop.pyx":796
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L8_except_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
    __pyx_L10_try_end:;
  }

  /* "uvloop/loop.pyx":801
 *             return False
 * 
 *         result = poll.stop_writing()             # <<<<<<<<<<<<<<
 *         if not poll.is_active():
 *             del self._polls[fd]
 */
  __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->stop_writing(__pyx_v_poll); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_v_result = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":802
 * 
 *         result = poll.stop_writing()
 *         if not poll.is_active():             # <<<<<<<<<<<<<<
 *             del self._polls[fd]
 *             poll._close()
 */
  __pyx_t_3 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->is_active(__pyx_v_poll) != 0)) != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":803
 *         result = poll.stop_writing()
 *         if not poll.is_active():
 *             del self._polls[fd]             # <<<<<<<<<<<<<<
 *             poll._close()
 * 
 */
    if (unlikely(__pyx_v_self->_polls == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(2, 803, __pyx_L1_error)
    }
    if (unlikely(PyDict_DelItem(__pyx_v_self->_polls, __pyx_v_fd) < 0)) __PYX_ERR(2, 803, __pyx_L1_error)

    /* "uvloop/loop.pyx":804
 *         if not poll.is_active():
 *             del self._polls[fd]
 *             poll._close()             # <<<<<<<<<<<<<<
 * 
 *         return result
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_poll)); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":802
 * 
 *         result = poll.stop_writing()
 *         if not poll.is_active():             # <<<<<<<<<<<<<<
 *             del self._polls[fd]
 *             poll._close()
 */
  }

  /* "uvloop/loop.pyx":806
 *             poll._close()
 * 
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cdef _has_writer(self, fileobj):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":782
 *         socket_inc_io_ref(fileobj)
 * 
 *     cdef _remove_writer(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.Loop._remove_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_poll);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XDECREF(__pyx_v_mapped_fileobj);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":808
 *         return result
 * 
 *     cdef _has_writer(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__has_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_poll = 0;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_has_writer", 0);

  /* "uvloop/loop.pyx":812
 *             UVPoll poll
 * 
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 812, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":813
 * 
 *         self._check_closed()
 *         fd = self._fileobj_to_fd(fileobj)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_fileobj_to_fd(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 813, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":815
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/loop.pyx":816
 * 
 *         try:
 *             poll = <UVPoll>(self._polls[fd])             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             return False
 */
      if (unlikely(__pyx_v_self->_polls == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 816, __pyx_L3_error)
      }
      __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_self->_polls, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 816, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __pyx_t_1;
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":815
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":817
 *         try:
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.Loop._has_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(2, 817, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);

      /* "uvloop/loop.pyx":818
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         return poll.is_writing()
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":815
 *         fd = self._fileobj_to_fd(fileobj)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             poll = <UVPoll>(self._polls[fd])
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "uvloop/loop.pyx":820
 *             return False
 * 
 *         return poll.is_writing()             # <<<<<<<<<<<<<<
 * 
 *     cdef _getaddrinfo(self, object host, object port,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->is_writing(__pyx_v_poll); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":808
 *         return result
 * 
 *     cdef _has_writer(self, fileobj):             # <<<<<<<<<<<<<<
 *         cdef:
 *             UVPoll poll
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop._has_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_poll);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":842
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if AddrInfo.isinstance(result):
 *                 try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_12_getaddrinfo_1callback(PyObject *__pyx_self, PyObject *__pyx_v_result); /*proto*/
static PyMethodDef __pyx_mdef_6uvloop_4loop_4Loop_12_getaddrinfo_1callback = {"callback", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_12_getaddrinfo_1callback, METH_O, 0};
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_12_getaddrinfo_1callback(PyObject *__pyx_self, PyObject *__pyx_v_result) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("callback (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_12_getaddrinfo_callback(__pyx_self, ((PyObject *)__pyx_v_result));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_12_getaddrinfo_callback(PyObject *__pyx_self, PyObject *__pyx_v_result) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *__pyx_cur_scope;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *__pyx_outer_scope;
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "uvloop/loop.pyx":843
 * 
 *         def callback(result):
 *             if AddrInfo.isinstance(result):             # <<<<<<<<<<<<<<
 *                 try:
 *                     if unpack == 0:
 */
  __pyx_t_1 = (__pyx_f_6uvloop_4loop_8AddrInfo_isinstance(__pyx_v_result) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":844
 *         def callback(result):
 *             if AddrInfo.isinstance(result):
 *                 try:             # <<<<<<<<<<<<<<
 *                     if unpack == 0:
 *                         data = result
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "uvloop/loop.pyx":845
 *             if AddrInfo.isinstance(result):
 *                 try:
 *                     if unpack == 0:             # <<<<<<<<<<<<<<
 *                         data = result
 *                     else:
 */
        __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_unpack == 0) != 0);
        if (__pyx_t_1) {

          /* "uvloop/loop.pyx":846
 *                 try:
 *                     if unpack == 0:
 *                         data = result             # <<<<<<<<<<<<<<
 *                     else:
 *                         data = (<AddrInfo>result).unpack()
 */
          __Pyx_INCREF(__pyx_v_result);
          __pyx_v_data = __pyx_v_result;

          /* "uvloop/loop.pyx":845
 *             if AddrInfo.isinstance(result):
 *                 try:
 *                     if unpack == 0:             # <<<<<<<<<<<<<<
 *                         data = result
 *                     else:
 */
          goto __pyx_L10;
        }

        /* "uvloop/loop.pyx":848
 *                         data = result
 *                     else:
 *                         data = (<AddrInfo>result).unpack()             # <<<<<<<<<<<<<<
 *                 except Exception as ex:
 *                     if not fut.cancelled():
 */
        /*else*/ {
          __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_AddrInfo *)((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_v_result)->__pyx_vtab)->unpack(((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_v_result)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 848, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_v_data = __pyx_t_5;
          __pyx_t_5 = 0;
        }
        __pyx_L10:;

        /* "uvloop/loop.pyx":844
 *         def callback(result):
 *             if AddrInfo.isinstance(result):
 *                 try:             # <<<<<<<<<<<<<<
 *                     if unpack == 0:
 *                         data = result
 */
      }

      /* "uvloop/loop.pyx":853
 *                         fut.set_exception(ex)
 *                 else:
 *                     if not fut.cancelled():             # <<<<<<<<<<<<<<
 *                         fut.set_result(data)
 *             else:
 */
      /*else:*/ {
        if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 853, __pyx_L6_except_error) }
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 853, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (__pyx_t_7) {
          __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 853, __pyx_L6_except_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else {
          __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 853, __pyx_L6_except_error)
        }
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 853, __pyx_L6_except_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = ((!__pyx_t_1) != 0);
        if (__pyx_t_8) {

          /* "uvloop/loop.pyx":854
 *                 else:
 *                     if not fut.cancelled():
 *                         fut.set_result(data)             # <<<<<<<<<<<<<<
 *             else:
 *                 if not fut.cancelled():
 */
          if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 854, __pyx_L6_except_error) }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 854, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          if (!__pyx_t_7) {
            __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 854, __pyx_L6_except_error)
            __Pyx_GOTREF(__pyx_t_5);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_data};
              __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 854, __pyx_L6_except_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_data};
              __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 854, __pyx_L6_except_error)
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 854, __pyx_L6_except_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
              __Pyx_INCREF(__pyx_v_data);
              __Pyx_GIVEREF(__pyx_v_data);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_data);
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 854, __pyx_L6_except_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "uvloop/loop.pyx":853
 *                         fut.set_exception(ex)
 *                 else:
 *                     if not fut.cancelled():             # <<<<<<<<<<<<<<
 *                         fut.set_result(data)
 *             else:
 */
        }
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":849
 *                     else:
 *                         data = (<AddrInfo>result).unpack()
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     if not fut.cancelled():
 *                         fut.set_exception(ex)
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop._getaddrinfo.callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_9) < 0) __PYX_ERR(2, 849, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_ex = __pyx_t_6;
        /*try:*/ {

          /* "uvloop/loop.pyx":850
 *                         data = (<AddrInfo>result).unpack()
 *                 except Exception as ex:
 *                     if not fut.cancelled():             # <<<<<<<<<<<<<<
 *                         fut.set_exception(ex)
 *                 else:
 */
          if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 850, __pyx_L17_error) }
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 850, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
            }
          }
          if (__pyx_t_12) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 850, __pyx_L17_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          } else {
            __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 850, __pyx_L17_error)
          }
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(2, 850, __pyx_L17_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_1 = ((!__pyx_t_8) != 0);
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":851
 *                 except Exception as ex:
 *                     if not fut.cancelled():
 *                         fut.set_exception(ex)             # <<<<<<<<<<<<<<
 *                 else:
 *                     if not fut.cancelled():
 */
            if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 851, __pyx_L17_error) }
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 851, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_12 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_11, function);
              }
            }
            if (!__pyx_t_12) {
              __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_ex); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 851, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_7);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_11)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_ex};
                __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 851, __pyx_L17_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_7);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_ex};
                __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 851, __pyx_L17_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_7);
              } else
              #endif
              {
                __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 851, __pyx_L17_error)
                __Pyx_GOTREF(__pyx_t_13);
                __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
                __Pyx_INCREF(__pyx_v_ex);
                __Pyx_GIVEREF(__pyx_v_ex);
                PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_ex);
                __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 851, __pyx_L17_error)
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "uvloop/loop.pyx":850
 *                         data = (<AddrInfo>result).unpack()
 *                 except Exception as ex:
 *                     if not fut.cancelled():             # <<<<<<<<<<<<<<
 *                         fut.set_exception(ex)
 *                 else:
 */
          }
        }

        /* "uvloop/loop.pyx":849
 *                     else:
 *                         data = (<AddrInfo>result).unpack()
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     if not fut.cancelled():
 *                         fut.set_exception(ex)
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L18;
          }
          __pyx_L17_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __pyx_t_10 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
            }
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
            goto __pyx_L6_except_error;
          }
          __pyx_L18:;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;
      __pyx_L6_except_error:;

      /* "uvloop/loop.pyx":844
 *         def callback(result):
 *             if AddrInfo.isinstance(result):
 *                 try:             # <<<<<<<<<<<<<<
 *                     if unpack == 0:
 *                         data = result
 */
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      __pyx_L9_try_end:;
    }

    /* "uvloop/loop.pyx":843
 * 
 *         def callback(result):
 *             if AddrInfo.isinstance(result):             # <<<<<<<<<<<<<<
 *                 try:
 *                     if unpack == 0:
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":856
 *                         fut.set_result(data)
 *             else:
 *                 if not fut.cancelled():             # <<<<<<<<<<<<<<
 *                     fut.set_exception(result)
 * 
 */
  /*else*/ {
    if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 856, __pyx_L1_error) }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 856, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 856, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 856, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 856, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_8 = ((!__pyx_t_1) != 0);
    if (__pyx_t_8) {

      /* "uvloop/loop.pyx":857
 *             else:
 *                 if not fut.cancelled():
 *                     fut.set_exception(result)             # <<<<<<<<<<<<<<
 * 
 *         AddrInfoRequest(self, host, port, family, type, proto, flags, callback)
 */
      if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 857, __pyx_L1_error) }
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 857, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_result); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 857, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_result};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 857, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_result};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 857, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 857, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_v_result);
          __Pyx_GIVEREF(__pyx_v_result);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_result);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 857, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/loop.pyx":856
 *                         fut.set_result(data)
 *             else:
 *                 if not fut.cancelled():             # <<<<<<<<<<<<<<
 *                     fut.set_exception(result)
 * 
 */
    }
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":842
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if AddrInfo.isinstance(result):
 *                 try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.Loop._getaddrinfo.callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":822
 *         return poll.is_writing()
 * 
 *     cdef _getaddrinfo(self, object host, object port,             # <<<<<<<<<<<<<<
 *                       int family, int type,
 *                       int proto, int flags,
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__getaddrinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags, int __pyx_v_unpack) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *__pyx_cur_scope;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("_getaddrinfo", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct___getaddrinfo(__pyx_ptype_6uvloop_4loop___pyx_scope_struct___getaddrinfo, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 822, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_unpack = __pyx_v_unpack;
  __Pyx_INCREF(__pyx_v_host);
  __Pyx_INCREF(__pyx_v_port);

  /* "uvloop/loop.pyx":827
 *                       int unpack):
 * 
 *         if isinstance(port, str):             # <<<<<<<<<<<<<<
 *             port = port.encode()
 *         elif isinstance(port, int):
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_port); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":828
 * 
 *         if isinstance(port, str):
 *             port = port.encode()             # <<<<<<<<<<<<<<
 *         elif isinstance(port, int):
 *             port = str(port).encode()
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_port, __pyx_n_s_encode); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 828, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 828, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_port, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":827
 *                       int unpack):
 * 
 *         if isinstance(port, str):             # <<<<<<<<<<<<<<
 *             port = port.encode()
 *         elif isinstance(port, int):
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":829
 *         if isinstance(port, str):
 *             port = port.encode()
 *         elif isinstance(port, int):             # <<<<<<<<<<<<<<
 *             port = str(port).encode()
 *         if port is not None and not isinstance(port, bytes):
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_port); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":830
 *             port = port.encode()
 *         elif isinstance(port, int):
 *             port = str(port).encode()             # <<<<<<<<<<<<<<
 *         if port is not None and not isinstance(port, bytes):
 *             raise TypeError('port must be a str, bytes or int')
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_port); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyUnicode_AsEncodedString(((PyObject*)__pyx_t_3), NULL, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 830, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_port, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":829
 *         if isinstance(port, str):
 *             port = port.encode()
 *         elif isinstance(port, int):             # <<<<<<<<<<<<<<
 *             port = str(port).encode()
 *         if port is not None and not isinstance(port, bytes):
 */
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":831
 *         elif isinstance(port, int):
 *             port = str(port).encode()
 *         if port is not None and not isinstance(port, bytes):             # <<<<<<<<<<<<<<
 *             raise TypeError('port must be a str, bytes or int')
 * 
 */
  __pyx_t_2 = (__pyx_v_port != Py_None);
  __pyx_t_6 = (__pyx_t_2 != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_6 = PyBytes_Check(__pyx_v_port); 
  __pyx_t_2 = ((!(__pyx_t_6 != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":832
 *             port = str(port).encode()
 *         if port is not None and not isinstance(port, bytes):
 *             raise TypeError('port must be a str, bytes or int')             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(host, str):
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 832, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 832, __pyx_L1_error)

    /* "uvloop/loop.pyx":831
 *         elif isinstance(port, int):
 *             port = str(port).encode()
 *         if port is not None and not isinstance(port, bytes):             # <<<<<<<<<<<<<<
 *             raise TypeError('port must be a str, bytes or int')
 * 
 */
  }

  /* "uvloop/loop.pyx":834
 *             raise TypeError('port must be a str, bytes or int')
 * 
 *         if isinstance(host, str):             # <<<<<<<<<<<<<<
 *             host = host.encode('idna')
 *         if host is not None:
 */
  __pyx_t_1 = PyUnicode_Check(__pyx_v_host); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":835
 * 
 *         if isinstance(host, str):
 *             host = host.encode('idna')             # <<<<<<<<<<<<<<
 *         if host is not None:
 *             if not isinstance(host, bytes):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_host, __pyx_n_s_encode); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_host, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":834
 *             raise TypeError('port must be a str, bytes or int')
 * 
 *         if isinstance(host, str):             # <<<<<<<<<<<<<<
 *             host = host.encode('idna')
 *         if host is not None:
 */
  }

  /* "uvloop/loop.pyx":836
 *         if isinstance(host, str):
 *             host = host.encode('idna')
 *         if host is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(host, bytes):
 *                 raise TypeError('host must be a str or bytes')
 */
  __pyx_t_2 = (__pyx_v_host != Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":837
 *             host = host.encode('idna')
 *         if host is not None:
 *             if not isinstance(host, bytes):             # <<<<<<<<<<<<<<
 *                 raise TypeError('host must be a str or bytes')
 * 
 */
    __pyx_t_1 = PyBytes_Check(__pyx_v_host); 
    __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/loop.pyx":838
 *         if host is not None:
 *             if not isinstance(host, bytes):
 *                 raise TypeError('host must be a str or bytes')             # <<<<<<<<<<<<<<
 * 
 *         fut = self._new_future()
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 838, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 838, __pyx_L1_error)

      /* "uvloop/loop.pyx":837
 *             host = host.encode('idna')
 *         if host is not None:
 *             if not isinstance(host, bytes):             # <<<<<<<<<<<<<<
 *                 raise TypeError('host must be a str or bytes')
 * 
 */
    }

    /* "uvloop/loop.pyx":836
 *         if isinstance(host, str):
 *             host = host.encode('idna')
 *         if host is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(host, bytes):
 *                 raise TypeError('host must be a str or bytes')
 */
  }

  /* "uvloop/loop.pyx":840
 *                 raise TypeError('host must be a str or bytes')
 * 
 *         fut = self._new_future()             # <<<<<<<<<<<<<<
 * 
 *         def callback(result):
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_fut = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":842
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if AddrInfo.isinstance(result):
 *                 try:
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_4Loop_12_getaddrinfo_1callback, 0, __pyx_n_s_Loop__getaddrinfo_locals_callbac, ((PyObject*)__pyx_cur_scope), __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__22)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_callback = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":859
 *                     fut.set_exception(result)
 * 
 *         AddrInfoRequest(self, host, port, family, type, proto, flags, callback)             # <<<<<<<<<<<<<<
 *         return fut
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_family); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_proto); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = PyTuple_New(8); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_8, 0, ((PyObject *)__pyx_v_self));
  __Pyx_INCREF(__pyx_v_host);
  __Pyx_GIVEREF(__pyx_v_host);
  PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_host);
  __Pyx_INCREF(__pyx_v_port);
  __Pyx_GIVEREF(__pyx_v_port);
  PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_v_port);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_8, 3, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_8, 4, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_8, 5, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_8, 6, __pyx_t_7);
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  PyTuple_SET_ITEM(__pyx_t_8, 7, __pyx_v_callback);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop_AddrInfoRequest), __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":860
 * 
 *         AddrInfoRequest(self, host, port, family, type, proto, flags, callback)
 *         return fut             # <<<<<<<<<<<<<<
 * 
 *     cdef _getnameinfo(self, system.sockaddr *addr, int flags):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fut);
  __pyx_r = __pyx_cur_scope->__pyx_v_fut;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":822
 *         return poll.is_writing()
 * 
 *     cdef _getaddrinfo(self, object host, object port,             # <<<<<<<<<<<<<<
 *                       int family, int type,
 *                       int proto, int flags,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.Loop._getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_host);
  __Pyx_XDECREF(__pyx_v_port);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":866
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if isinstance(result, tuple):
 *                 fut.set_result(result)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_12_getnameinfo_1callback(PyObject *__pyx_self, PyObject *__pyx_v_result); /*proto*/
static PyMethodDef __pyx_mdef_6uvloop_4loop_4Loop_12_getnameinfo_1callback = {"callback", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_12_getnameinfo_1callback, METH_O, 0};
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_12_getnameinfo_1callback(PyObject *__pyx_self, PyObject *__pyx_v_result) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("callback (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_12_getnameinfo_callback(__pyx_self, ((PyObject *)__pyx_v_result));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_12_getnameinfo_callback(PyObject *__pyx_self, PyObject *__pyx_v_result) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *__pyx_cur_scope;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("callback", 0);
  __pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "uvloop/loop.pyx":867
 * 
 *         def callback(result):
 *             if isinstance(result, tuple):             # <<<<<<<<<<<<<<
 *                 fut.set_result(result)
 *             else:
 */
  __pyx_t_1 = PyTuple_Check(__pyx_v_result); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":868
 *         def callback(result):
 *             if isinstance(result, tuple):
 *                 fut.set_result(result)             # <<<<<<<<<<<<<<
 *             else:
 *                 fut.set_exception(result)
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 868, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 868, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 868, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_result};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 868, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_result};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 868, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 868, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_result);
        __Pyx_GIVEREF(__pyx_v_result);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_result);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 868, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":867
 * 
 *         def callback(result):
 *             if isinstance(result, tuple):             # <<<<<<<<<<<<<<
 *                 fut.set_result(result)
 *             else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":870
 *                 fut.set_result(result)
 *             else:
 *                 fut.set_exception(result)             # <<<<<<<<<<<<<<
 * 
 *         nr = NameInfoRequest(self, callback)
 */
  /*else*/ {
    if (unlikely(!__pyx_cur_scope->__pyx_v_fut)) { __Pyx_RaiseClosureNameError("fut"); __PYX_ERR(2, 870, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 870, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_result};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 870, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_result};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 870, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 870, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_result);
        __Pyx_GIVEREF(__pyx_v_result);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_result);
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 870, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":866
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if isinstance(result, tuple):
 *                 fut.set_result(result)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.Loop._getnameinfo.callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":862
 *         return fut
 * 
 *     cdef _getnameinfo(self, system.sockaddr *addr, int flags):             # <<<<<<<<<<<<<<
 *         cdef NameInfoRequest nr
 *         fut = self._new_future()
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__getnameinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct sockaddr *__pyx_v_addr, int __pyx_v_flags) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *__pyx_cur_scope;
  struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_nr = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_getnameinfo", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_1__getnameinfo(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_1__getnameinfo, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 862, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "uvloop/loop.pyx":864
 *     cdef _getnameinfo(self, system.sockaddr *addr, int flags):
 *         cdef NameInfoRequest nr
 *         fut = self._new_future()             # <<<<<<<<<<<<<<
 * 
 *         def callback(result):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 864, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_fut = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":866
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if isinstance(result, tuple):
 *                 fut.set_result(result)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_4Loop_12_getnameinfo_1callback, 0, __pyx_n_s_Loop__getnameinfo_locals_callbac, ((PyObject*)__pyx_cur_scope), __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__24)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_callback = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":872
 *                 fut.set_exception(result)
 * 
 *         nr = NameInfoRequest(self, callback)             # <<<<<<<<<<<<<<
 *         nr.query(addr, flags)
 *         return fut
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self));
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_callback);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop_NameInfoRequest), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_nr = ((struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":873
 * 
 *         nr = NameInfoRequest(self, callback)
 *         nr.query(addr, flags)             # <<<<<<<<<<<<<<
 *         return fut
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_NameInfoRequest *)__pyx_v_nr->__pyx_base.__pyx_vtab)->query(__pyx_v_nr, __pyx_v_addr, __pyx_v_flags); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":874
 *         nr = NameInfoRequest(self, callback)
 *         nr.query(addr, flags)
 *         return fut             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_recv(self, fut, sock, n):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fut);
  __pyx_r = __pyx_cur_scope->__pyx_v_fut;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":862
 *         return fut
 * 
 *     cdef _getnameinfo(self, system.sockaddr *addr, int flags):             # <<<<<<<<<<<<<<
 *         cdef NameInfoRequest nr
 *         fut = self._new_future()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop._getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_nr);
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":876
 *         return fut
 * 
 *     cdef _sock_recv(self, fut, sock, n):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_recv(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_n) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  __Pyx_RefNannySetupContext("_sock_recv", 0);

  /* "uvloop/loop.pyx":877
 * 
 *     cdef _sock_recv(self, fut, sock, n):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":878
 *     cdef _sock_recv(self, fut, sock, n):
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():             # <<<<<<<<<<<<<<
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 878, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 878, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 878, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 878, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":880
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'_sock_recv is called on a cancelled Future')
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 880, __pyx_L1_error)

      /* "uvloop/loop.pyx":878
 *     cdef _sock_recv(self, fut, sock, n):
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():             # <<<<<<<<<<<<<<
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(
 */
    }

    /* "uvloop/loop.pyx":883
 *                     f'_sock_recv is called on a cancelled Future')
 * 
 *             if not self._has_reader(sock):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a reader '
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_has_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 883, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 883, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = ((!__pyx_t_1) != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":885
 *             if not self._has_reader(sock):
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a reader '             # <<<<<<<<<<<<<<
 *                     f'in the _sock_recv callback')
 * 
 */
      __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = 0;
      __pyx_t_7 = 127;
      __Pyx_INCREF(__pyx_kp_u_socket);
      __pyx_t_6 += 7;
      __Pyx_GIVEREF(__pyx_kp_u_socket);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_socket);
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_sock), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
      __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_INCREF(__pyx_kp_u_does_not_have_a_reader_in_the);
      __pyx_t_6 += 50;
      __Pyx_GIVEREF(__pyx_kp_u_does_not_have_a_reader_in_the);
      PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_does_not_have_a_reader_in_the);
      __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":884
 * 
 *             if not self._has_reader(sock):
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'socket {sock!r} does not have a reader '
 *                     f'in the _sock_recv callback')
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 884, __pyx_L1_error)

      /* "uvloop/loop.pyx":883
 *                     f'_sock_recv is called on a cancelled Future')
 * 
 *             if not self._has_reader(sock):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a reader '
 */
    }

    /* "uvloop/loop.pyx":877
 * 
 *     cdef _sock_recv(self, fut, sock, n):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 */
  }

  /* "uvloop/loop.pyx":888
 *                     f'in the _sock_recv callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             data = sock.recv(n)
 *         except (BlockingIOError, InterruptedError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "uvloop/loop.pyx":889
 * 
 *         try:
 *             data = sock.recv(n)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             # No need to re-add the reader, let's just wait until
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_recv); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 889, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 889, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_n};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 889, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_n};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 889, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 889, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_n);
          __Pyx_GIVEREF(__pyx_v_n);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_n);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 889, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_data = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":888
 *                     f'in the _sock_recv callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             data = sock.recv(n)
 *         except (BlockingIOError, InterruptedError):
 */
    }

    /* "uvloop/loop.pyx":898
 *             self._remove_reader(sock)
 *         else:
 *             fut.set_result(data)             # <<<<<<<<<<<<<<
 *             self._remove_reader(sock)
 * 
 */
    /*else:*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 898, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_11 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_11) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 898, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_data};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 898, __pyx_L8_except_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_data};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 898, __pyx_L8_except_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 898, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_11); __pyx_t_11 = NULL;
          __Pyx_INCREF(__pyx_v_data);
          __Pyx_GIVEREF(__pyx_v_data);
          PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_data);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 898, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":899
 *         else:
 *             fut.set_result(data)
 *             self._remove_reader(sock)             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_recv_into(self, fut, sock, buf):
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 899, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":890
 *         try:
 *             data = sock.recv(n)
 *         except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *             # No need to re-add the reader, let's just wait until
 *             # the poll handler calls this callback again.
 */
    __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 890, __pyx_L8_except_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 890, __pyx_L8_except_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_13 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_11) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_ErrRestore(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_t_2 = 0; __pyx_t_3 = 0; __pyx_t_4 = 0;
    if (__pyx_t_13) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L7_exception_handled;
    }

    /* "uvloop/loop.pyx":894
 *             # the poll handler calls this callback again.
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)
 */
    __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_13) {
      __Pyx_AddTraceback("uvloop.loop.Loop._sock_recv", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(2, 894, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_exc = __pyx_t_3;
      /*try:*/ {

        /* "uvloop/loop.pyx":895
 *             pass
 *         except Exception as exc:
 *             fut.set_exception(exc)             # <<<<<<<<<<<<<<
 *             self._remove_reader(sock)
 *         else:
 */
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 895, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_14 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
          }
        }
        if (!__pyx_t_14) {
          __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_exc); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 895, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_12);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
            __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 895, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_12);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
            __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 895, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_12);
          } else
          #endif
          {
            __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(2, 895, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
            __Pyx_INCREF(__pyx_v_exc);
            __Pyx_GIVEREF(__pyx_v_exc);
            PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_v_exc);
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_15, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 895, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "uvloop/loop.pyx":896
 *         except Exception as exc:
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)             # <<<<<<<<<<<<<<
 *         else:
 *             fut.set_result(data)
 */
        __pyx_t_12 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 896, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }

      /* "uvloop/loop.pyx":894
 *             # the poll handler calls this callback again.
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L18;
        }
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __pyx_t_13 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L8_except_error;
        }
        __pyx_L18:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/loop.pyx":888
 *                     f'in the _sock_recv callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             data = sock.recv(n)
 *         except (BlockingIOError, InterruptedError):
 */
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    __pyx_L11_try_end:;
  }

  /* "uvloop/loop.pyx":876
 *         return fut
 * 
 *     cdef _sock_recv(self, fut, sock, n):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_recv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":901
 *             self._remove_reader(sock)
 * 
 *     cdef _sock_recv_into(self, fut, sock, buf):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_recv_into(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_buf) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  __Pyx_RefNannySetupContext("_sock_recv_into", 0);

  /* "uvloop/loop.pyx":902
 * 
 *     cdef _sock_recv_into(self, fut, sock, buf):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":903
 *     cdef _sock_recv_into(self, fut, sock, buf):
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():             # <<<<<<<<<<<<<<
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 903, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 903, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 903, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 903, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":905
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'_sock_recv_into is called on a cancelled Future')
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 905, __pyx_L1_error)

      /* "uvloop/loop.pyx":903
 *     cdef _sock_recv_into(self, fut, sock, buf):
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():             # <<<<<<<<<<<<<<
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(
 */
    }

    /* "uvloop/loop.pyx":908
 *                     f'_sock_recv_into is called on a cancelled Future')
 * 
 *             if not self._has_reader(sock):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a reader '
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_has_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 908, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 908, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = ((!__pyx_t_1) != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":910
 *             if not self._has_reader(sock):
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a reader '             # <<<<<<<<<<<<<<
 *                     f'in the _sock_recv_into callback')
 * 
 */
      __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 910, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = 0;
      __pyx_t_7 = 127;
      __Pyx_INCREF(__pyx_kp_u_socket);
      __pyx_t_6 += 7;
      __Pyx_GIVEREF(__pyx_kp_u_socket);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_socket);
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_sock), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 910, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
      __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_INCREF(__pyx_kp_u_does_not_have_a_reader_in_the_2);
      __pyx_t_6 += 55;
      __Pyx_GIVEREF(__pyx_kp_u_does_not_have_a_reader_in_the_2);
      PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_does_not_have_a_reader_in_the_2);
      __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 910, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":909
 * 
 *             if not self._has_reader(sock):
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'socket {sock!r} does not have a reader '
 *                     f'in the _sock_recv_into callback')
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 909, __pyx_L1_error)

      /* "uvloop/loop.pyx":908
 *                     f'_sock_recv_into is called on a cancelled Future')
 * 
 *             if not self._has_reader(sock):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a reader '
 */
    }

    /* "uvloop/loop.pyx":902
 * 
 *     cdef _sock_recv_into(self, fut, sock, buf):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 */
  }

  /* "uvloop/loop.pyx":913
 *                     f'in the _sock_recv_into callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             data = sock.recv_into(buf)
 *         except (BlockingIOError, InterruptedError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "uvloop/loop.pyx":914
 * 
 *         try:
 *             data = sock.recv_into(buf)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             # No need to re-add the reader, let's just wait until
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_recv_into); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 914, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_buf); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 914, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_buf};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 914, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_buf};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 914, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 914, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_buf);
          __Pyx_GIVEREF(__pyx_v_buf);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_buf);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 914, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_data = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":913
 *                     f'in the _sock_recv_into callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             data = sock.recv_into(buf)
 *         except (BlockingIOError, InterruptedError):
 */
    }

    /* "uvloop/loop.pyx":923
 *             self._remove_reader(sock)
 *         else:
 *             fut.set_result(data)             # <<<<<<<<<<<<<<
 *             self._remove_reader(sock)
 * 
 */
    /*else:*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 923, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_11 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_11) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 923, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_data};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 923, __pyx_L8_except_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_data};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 923, __pyx_L8_except_error)
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 923, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_11); __pyx_t_11 = NULL;
          __Pyx_INCREF(__pyx_v_data);
          __Pyx_GIVEREF(__pyx_v_data);
          PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_data);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 923, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":924
 *         else:
 *             fut.set_result(data)
 *             self._remove_reader(sock)             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_sendall(self, fut, sock, data):
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 924, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":915
 *         try:
 *             data = sock.recv_into(buf)
 *         except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *             # No need to re-add the reader, let's just wait until
 *             # the poll handler calls this callback again.
 */
    __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 915, __pyx_L8_except_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 915, __pyx_L8_except_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_13 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_11) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_12);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_ErrRestore(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_t_2 = 0; __pyx_t_3 = 0; __pyx_t_4 = 0;
    if (__pyx_t_13) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L7_exception_handled;
    }

    /* "uvloop/loop.pyx":919
 *             # the poll handler calls this callback again.
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)
 */
    __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_13) {
      __Pyx_AddTraceback("uvloop.loop.Loop._sock_recv_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(2, 919, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_exc = __pyx_t_3;
      /*try:*/ {

        /* "uvloop/loop.pyx":920
 *             pass
 *         except Exception as exc:
 *             fut.set_exception(exc)             # <<<<<<<<<<<<<<
 *             self._remove_reader(sock)
 *         else:
 */
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 920, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_14 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
          }
        }
        if (!__pyx_t_14) {
          __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_exc); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 920, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_12);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
            __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 920, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_12);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
            PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
            __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 920, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_12);
          } else
          #endif
          {
            __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(2, 920, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
            __Pyx_INCREF(__pyx_v_exc);
            __Pyx_GIVEREF(__pyx_v_exc);
            PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_v_exc);
            __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_15, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 920, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

        /* "uvloop/loop.pyx":921
 *         except Exception as exc:
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)             # <<<<<<<<<<<<<<
 *         else:
 *             fut.set_result(data)
 */
        __pyx_t_12 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 921, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }

      /* "uvloop/loop.pyx":919
 *             # the poll handler calls this callback again.
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L18;
        }
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __pyx_t_13 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L8_except_error;
        }
        __pyx_L18:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/loop.pyx":913
 *                     f'in the _sock_recv_into callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             data = sock.recv_into(buf)
 *         except (BlockingIOError, InterruptedError):
 */
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    __pyx_L11_try_end:;
  }

  /* "uvloop/loop.pyx":901
 *             self._remove_reader(sock)
 * 
 *     cdef _sock_recv_into(self, fut, sock, buf):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_recv_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":926
 *             self._remove_reader(sock)
 * 
 *     cdef _sock_sendall(self, fut, sock, data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             Handle handle
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_sendall(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_data) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  int __pyx_v_n;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  __Pyx_RefNannySetupContext("_sock_sendall", 0);
  __Pyx_INCREF(__pyx_v_data);

  /* "uvloop/loop.pyx":931
 *             int n
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":932
 * 
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():             # <<<<<<<<<<<<<<
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 932, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 932, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 932, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 932, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":934
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'_sock_sendall is called on a cancelled Future')
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 934, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 934, __pyx_L1_error)

      /* "uvloop/loop.pyx":932
 * 
 *         if UVLOOP_DEBUG:
 *             if fut.cancelled():             # <<<<<<<<<<<<<<
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(
 */
    }

    /* "uvloop/loop.pyx":937
 *                     f'_sock_sendall is called on a cancelled Future')
 * 
 *             if not self._has_writer(sock):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a writer '
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_has_writer(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 937, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = ((!__pyx_t_1) != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":939
 *             if not self._has_writer(sock):
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a writer '             # <<<<<<<<<<<<<<
 *                     f'in the _sock_sendall callback')
 * 
 */
      __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_6 = 0;
      __pyx_t_7 = 127;
      __Pyx_INCREF(__pyx_kp_u_socket);
      __pyx_t_6 += 7;
      __Pyx_GIVEREF(__pyx_kp_u_socket);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_socket);
      __pyx_t_3 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_sock), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_3) : __pyx_t_7;
      __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_INCREF(__pyx_kp_u_does_not_have_a_writer_in_the);
      __pyx_t_6 += 53;
      __Pyx_GIVEREF(__pyx_kp_u_does_not_have_a_writer_in_the);
      PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_does_not_have_a_writer_in_the);
      __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 939, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":938
 * 
 *             if not self._has_writer(sock):
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'socket {sock!r} does not have a writer '
 *                     f'in the _sock_sendall callback')
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 938, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 938, __pyx_L1_error)

      /* "uvloop/loop.pyx":937
 *                     f'_sock_sendall is called on a cancelled Future')
 * 
 *             if not self._has_writer(sock):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     f'socket {sock!r} does not have a writer '
 */
    }

    /* "uvloop/loop.pyx":931
 *             int n
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 */
  }

  /* "uvloop/loop.pyx":942
 *                     f'in the _sock_sendall callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             n = sock.send(data)
 *         except (BlockingIOError, InterruptedError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "uvloop/loop.pyx":943
 * 
 *         try:
 *             n = sock.send(data)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             # Try next time.
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_send); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 943, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 943, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_data};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 943, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_data};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 943, __pyx_L6_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 943, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_data);
          __Pyx_GIVEREF(__pyx_v_data);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_data);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_11, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 943, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 943, __pyx_L6_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_n = __pyx_t_12;

      /* "uvloop/loop.pyx":942
 *                     f'in the _sock_sendall callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             n = sock.send(data)
 *         except (BlockingIOError, InterruptedError):
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":944
 *         try:
 *             n = sock.send(data)
 *         except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *             # Try next time.
 *             return
 */
    __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_3, &__pyx_t_11);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 944, __pyx_L8_except_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_13 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 944, __pyx_L8_except_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_12 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_4) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_13);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_ErrRestore(__pyx_t_2, __pyx_t_3, __pyx_t_11);
    __pyx_t_2 = 0; __pyx_t_3 = 0; __pyx_t_11 = 0;
    if (__pyx_t_12) {
      __Pyx_AddTraceback("uvloop.loop.Loop._sock_sendall", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_3, &__pyx_t_2) < 0) __PYX_ERR(2, 944, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);

      /* "uvloop/loop.pyx":946
 *         except (BlockingIOError, InterruptedError):
 *             # Try next time.
 *             return             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             fut.set_exception(exc)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L9_except_return;
    }

    /* "uvloop/loop.pyx":947
 *             # Try next time.
 *             return
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_writer(sock)
 */
    __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_12) {
      __Pyx_AddTraceback("uvloop.loop.Loop._sock_sendall", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_11) < 0) __PYX_ERR(2, 947, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_exc = __pyx_t_3;
      /*try:*/ {

        /* "uvloop/loop.pyx":948
 *             return
 *         except Exception as exc:
 *             fut.set_exception(exc)             # <<<<<<<<<<<<<<
 *             self._remove_writer(sock)
 *             return
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 948, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_14 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_14)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_14);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        if (!__pyx_t_14) {
          __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_exc); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 948, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
            __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 948, __pyx_L19_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_13);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
            __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 948, __pyx_L19_error)
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_GOTREF(__pyx_t_13);
          } else
          #endif
          {
            __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(2, 948, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
            __Pyx_INCREF(__pyx_v_exc);
            __Pyx_GIVEREF(__pyx_v_exc);
            PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_v_exc);
            __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_15, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 948, __pyx_L19_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "uvloop/loop.pyx":949
 *         except Exception as exc:
 *             fut.set_exception(exc)
 *             self._remove_writer(sock)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
        __pyx_t_13 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_writer(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 949, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "uvloop/loop.pyx":950
 *             fut.set_exception(exc)
 *             self._remove_writer(sock)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._remove_writer(sock)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L18_return;
      }

      /* "uvloop/loop.pyx":947
 *             # Try next time.
 *             return
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_writer(sock)
 */
      /*finally:*/ {
        __pyx_L19_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __pyx_t_12 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L8_except_error;
        }
        __pyx_L18_return: {
          __pyx_t_23 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          __pyx_r = __pyx_t_23;
          __pyx_t_23 = 0;
          goto __pyx_L9_except_return;
        }
      }
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/loop.pyx":942
 *                     f'in the _sock_sendall callback')
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             n = sock.send(data)
 *         except (BlockingIOError, InterruptedError):
 */
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L9_except_return:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L0;
    __pyx_L11_try_end:;
  }

  /* "uvloop/loop.pyx":952
 *             return
 * 
 *         self._remove_writer(sock)             # <<<<<<<<<<<<<<
 * 
 *         if n == len(data):
 */
  __pyx_t_11 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_writer(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "uvloop/loop.pyx":954
 *         self._remove_writer(sock)
 * 
 *         if n == len(data):             # <<<<<<<<<<<<<<
 *             fut.set_result(None)
 *         else:
 */
  __pyx_t_6 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(2, 954, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_v_n == __pyx_t_6) != 0);
  if (__pyx_t_5) {

    /* "uvloop/loop.pyx":955
 * 
 *         if n == len(data):
 *             fut.set_result(None)             # <<<<<<<<<<<<<<
 *         else:
 *             if n:
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 955, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":954
 *         self._remove_writer(sock)
 * 
 *         if n == len(data):             # <<<<<<<<<<<<<<
 *             fut.set_result(None)
 *         else:
 */
    goto __pyx_L25;
  }

  /* "uvloop/loop.pyx":957
 *             fut.set_result(None)
 *         else:
 *             if n:             # <<<<<<<<<<<<<<
 *                 if not isinstance(data, memoryview):
 *                     data = memoryview(data)
 */
  /*else*/ {
    __pyx_t_5 = (__pyx_v_n != 0);
    if (__pyx_t_5) {

      /* "uvloop/loop.pyx":958
 *         else:
 *             if n:
 *                 if not isinstance(data, memoryview):             # <<<<<<<<<<<<<<
 *                     data = memoryview(data)
 *                 data = data[n:]
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 958, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_IsInstance(__pyx_v_data, __pyx_t_3); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(2, 958, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_1 = ((!(__pyx_t_5 != 0)) != 0);
      if (__pyx_t_1) {

        /* "uvloop/loop.pyx":959
 *             if n:
 *                 if not isinstance(data, memoryview):
 *                     data = memoryview(data)             # <<<<<<<<<<<<<<
 *                 data = data[n:]
 * 
 */
        __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 959, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_data); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 959, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_11);
        __pyx_t_11 = 0;

        /* "uvloop/loop.pyx":958
 *         else:
 *             if n:
 *                 if not isinstance(data, memoryview):             # <<<<<<<<<<<<<<
 *                     data = memoryview(data)
 *                 data = data[n:]
 */
      }

      /* "uvloop/loop.pyx":960
 *                 if not isinstance(data, memoryview):
 *                     data = memoryview(data)
 *                 data = data[n:]             # <<<<<<<<<<<<<<
 * 
 *             handle = new_MethodHandle3(
 */
      __pyx_t_11 = __Pyx_PyObject_GetSlice(__pyx_v_data, __pyx_v_n, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 960, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "uvloop/loop.pyx":957
 *             fut.set_result(None)
 *         else:
 *             if n:             # <<<<<<<<<<<<<<
 *                 if not isinstance(data, memoryview):
 *                     data = memoryview(data)
 */
    }

    /* "uvloop/loop.pyx":962
 *                 data = data[n:]
 * 
 *             handle = new_MethodHandle3(             # <<<<<<<<<<<<<<
 *                 self,
 *                 "Loop._sock_sendall",
 */
    __pyx_t_11 = __pyx_f_6uvloop_4loop_new_MethodHandle3(__pyx_v_self, __pyx_kp_u_Loop__sock_sendall, ((__pyx_t_6uvloop_4loop_method3_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_sock_sendall), ((PyObject *)__pyx_v_self), __pyx_v_fut, __pyx_v_sock, __pyx_v_data); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (!(likely(((__pyx_t_11) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_11, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 962, __pyx_L1_error)
    __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_11);
    __pyx_t_11 = 0;

    /* "uvloop/loop.pyx":969
 *                 fut, sock, data)
 * 
 *             self._add_writer(sock, handle)             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_accept(self, fut, sock):
 */
    __pyx_t_11 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_add_writer(__pyx_v_self, __pyx_v_sock, __pyx_v_handle); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 969, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __pyx_L25:;

  /* "uvloop/loop.pyx":926
 *             self._remove_reader(sock)
 * 
 *     cdef _sock_sendall(self, fut, sock, data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             Handle handle
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_sendall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":971
 *             self._add_writer(sock, handle)
 * 
 *     cdef _sock_accept(self, fut, sock):             # <<<<<<<<<<<<<<
 *         try:
 *             conn, address = sock.accept()
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_accept(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock) {
  PyObject *__pyx_v_conn = NULL;
  PyObject *__pyx_v_address = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  __Pyx_RefNannySetupContext("_sock_accept", 0);

  /* "uvloop/loop.pyx":972
 * 
 *     cdef _sock_accept(self, fut, sock):
 *         try:             # <<<<<<<<<<<<<<
 *             conn, address = sock.accept()
 *             conn.setblocking(False)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/loop.pyx":973
 *     cdef _sock_accept(self, fut, sock):
 *         try:
 *             conn, address = sock.accept()             # <<<<<<<<<<<<<<
 *             conn.setblocking(False)
 *         except (BlockingIOError, InterruptedError):
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_accept); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 973, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 973, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 973, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
        PyObject* sequence = __pyx_t_4;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(2, 973, __pyx_L3_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 973, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 973, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 973, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
        index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(2, 973, __pyx_L3_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(2, 973, __pyx_L3_error)
        __pyx_L10_unpacking_done:;
      }
      __pyx_v_conn = __pyx_t_5;
      __pyx_t_5 = 0;
      __pyx_v_address = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":974
 *         try:
 *             conn, address = sock.accept()
 *             conn.setblocking(False)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             # There is an active reader for _sock_accept, so
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_conn, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 974, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 974, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":972
 * 
 *     cdef _sock_accept(self, fut, sock):
 *         try:             # <<<<<<<<<<<<<<
 *             conn, address = sock.accept()
 *             conn.setblocking(False)
 */
    }

    /* "uvloop/loop.pyx":983
 *             self._remove_reader(sock)
 *         else:
 *             fut.set_result((conn, address))             # <<<<<<<<<<<<<<
 *             self._remove_reader(sock)
 * 
 */
    /*else:*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 983, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 983, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_conn);
      __Pyx_GIVEREF(__pyx_v_conn);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_conn);
      __Pyx_INCREF(__pyx_v_address);
      __Pyx_GIVEREF(__pyx_v_address);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_address);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 983, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 983, __pyx_L5_except_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 983, __pyx_L5_except_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 983, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 983, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":984
 *         else:
 *             fut.set_result((conn, address))
 *             self._remove_reader(sock)             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_connect(self, sock, address):
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 984, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":975
 *             conn, address = sock.accept()
 *             conn.setblocking(False)
 *         except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *             # There is an active reader for _sock_accept, so
 *             # do nothing, it will be called again.
 */
    __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_4, &__pyx_t_9);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 975, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 975, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_5) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_ErrRestore(__pyx_t_6, __pyx_t_4, __pyx_t_9);
    __pyx_t_6 = 0; __pyx_t_4 = 0; __pyx_t_9 = 0;
    if (__pyx_t_10) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }

    /* "uvloop/loop.pyx":979
 *             # do nothing, it will be called again.
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.Loop._sock_accept", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_4, &__pyx_t_6) < 0) __PYX_ERR(2, 979, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_exc = __pyx_t_4;
      /*try:*/ {

        /* "uvloop/loop.pyx":980
 *             pass
 *         except Exception as exc:
 *             fut.set_exception(exc)             # <<<<<<<<<<<<<<
 *             self._remove_reader(sock)
 *         else:
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 980, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_11 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (!__pyx_t_11) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_exc); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 980, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_7);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_exc};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 980, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_exc};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 980, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          {
            __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 980, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
            __Pyx_INCREF(__pyx_v_exc);
            __Pyx_GIVEREF(__pyx_v_exc);
            PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_v_exc);
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 980, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "uvloop/loop.pyx":981
 *         except Exception as exc:
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)             # <<<<<<<<<<<<<<
 *         else:
 *             fut.set_result((conn, address))
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_v_sock); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 981, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }

      /* "uvloop/loop.pyx":979
 *             # do nothing, it will be called again.
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *             self._remove_reader(sock)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L17;
        }
        __pyx_L16_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_10 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L5_except_error;
        }
        __pyx_L17:;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":972
 * 
 *     cdef _sock_accept(self, fut, sock):
 *         try:             # <<<<<<<<<<<<<<
 *             conn, address = sock.accept()
 *             conn.setblocking(False)
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "uvloop/loop.pyx":971
 *             self._add_writer(sock, handle)
 * 
 *     cdef _sock_accept(self, fut, sock):             # <<<<<<<<<<<<<<
 *         try:
 *             conn, address = sock.accept()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_accept", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_conn);
  __Pyx_XDECREF(__pyx_v_address);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":998
 * 
 *         fut = self._new_future()
 *         fut.add_done_callback(lambda fut: self._remove_writer(sock))             # <<<<<<<<<<<<<<
 * 
 *         handle = new_MethodHandle3(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_13_sock_connect_lambda(PyObject *__pyx_self, PyObject *__pyx_v_fut); /*proto*/
static PyMethodDef __pyx_mdef_6uvloop_4loop_4Loop_13_sock_connect_lambda = {"lambda", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_13_sock_connect_lambda, METH_O, 0};
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_13_sock_connect_lambda(PyObject *__pyx_self, PyObject *__pyx_v_fut) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda(__pyx_self, ((PyObject *)__pyx_v_fut));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_fut) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *__pyx_cur_scope;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("lambda", 0);
  __pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(2, 998, __pyx_L1_error) }
  if (unlikely(!__pyx_cur_scope->__pyx_v_sock)) { __Pyx_RaiseClosureNameError("sock"); __PYX_ERR(2, 998, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_sock;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_remove_writer(__pyx_cur_scope->__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_connect.lambda", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":986
 *             self._remove_reader(sock)
 * 
 *     cdef _sock_connect(self, sock, address):             # <<<<<<<<<<<<<<
 *         cdef:
 *             Handle handle
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_connect(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_address) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *__pyx_cur_scope;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_v_fut = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("_sock_connect", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_2__sock_connect(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_2__sock_connect, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 986, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);

  /* "uvloop/loop.pyx":990
 *             Handle handle
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             sock.connect(address)
 *         except (BlockingIOError, InterruptedError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/loop.pyx":991
 * 
 *         try:
 *             sock.connect(address)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             pass
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_connect); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 991, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_address); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 991, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_address};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 991, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_address};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 991, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 991, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_INCREF(__pyx_v_address);
          __Pyx_GIVEREF(__pyx_v_address);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_address);
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 991, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":990
 *             Handle handle
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             sock.connect(address)
 *         except (BlockingIOError, InterruptedError):
 */
    }

    /* "uvloop/loop.pyx":995
 *             pass
 *         else:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         fut = self._new_future()
 */
    /*else:*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":992
 *         try:
 *             sock.connect(address)
 *         except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *             pass
 *         else:
 */
    __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7);
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 992, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 992, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_6) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_4, __pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_ErrRestore(__pyx_t_4, __pyx_t_5, __pyx_t_7);
    __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_7 = 0;
    if (__pyx_t_9) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/loop.pyx":990
 *             Handle handle
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             sock.connect(address)
 *         except (BlockingIOError, InterruptedError):
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  }

  /* "uvloop/loop.pyx":997
 *             return
 * 
 *         fut = self._new_future()             # <<<<<<<<<<<<<<
 *         fut.add_done_callback(lambda fut: self._remove_writer(sock))
 * 
 */
  __pyx_t_7 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 997, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_fut = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":998
 * 
 *         fut = self._new_future()
 *         fut.add_done_callback(lambda fut: self._remove_writer(sock))             # <<<<<<<<<<<<<<
 * 
 *         handle = new_MethodHandle3(
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_add_done_callback); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_4Loop_13_sock_connect_lambda, 0, __pyx_n_s_Loop__sock_connect_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_uvloop_loop, __pyx_d, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 998, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_7);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_4};
      __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 998, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_4};
      __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 998, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 998, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 998, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":1001
 * 
 *         handle = new_MethodHandle3(
 *             self,             # <<<<<<<<<<<<<<
 *             "Loop._sock_connect",
 *             <method3_t>self._sock_connect_cb,
 */
  __pyx_t_7 = ((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_t_7);

  /* "uvloop/loop.pyx":1004
 *             "Loop._sock_connect",
 *             <method3_t>self._sock_connect_cb,
 *             self,             # <<<<<<<<<<<<<<
 *             fut, sock, address)
 * 
 */
  __pyx_t_5 = ((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1005
 *             <method3_t>self._sock_connect_cb,
 *             self,
 *             fut, sock, address)             # <<<<<<<<<<<<<<
 * 
 *         self._add_writer(sock, handle)
 */
  __pyx_t_6 = __pyx_cur_scope->__pyx_v_sock;
  __Pyx_INCREF(__pyx_t_6);

  /* "uvloop/loop.pyx":1000
 *         fut.add_done_callback(lambda fut: self._remove_writer(sock))
 * 
 *         handle = new_MethodHandle3(             # <<<<<<<<<<<<<<
 *             self,
 *             "Loop._sock_connect",
 */
  __pyx_t_4 = __pyx_f_6uvloop_4loop_new_MethodHandle3(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_7), __pyx_kp_u_Loop__sock_connect, ((__pyx_t_6uvloop_4loop_method3_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_connect_cb), __pyx_t_5, __pyx_v_fut, __pyx_t_6, __pyx_v_address); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1000, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 1000, __pyx_L1_error)
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":1007
 *             fut, sock, address)
 * 
 *         self._add_writer(sock, handle)             # <<<<<<<<<<<<<<
 *         return fut
 * 
 */
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_sock;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_add_writer(__pyx_cur_scope->__pyx_v_self, __pyx_t_4, __pyx_v_handle); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/loop.pyx":1008
 * 
 *         self._add_writer(sock, handle)
 *         return fut             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_connect_cb(self, fut, sock, address):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_fut);
  __pyx_r = __pyx_v_fut;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":986
 *             self._remove_reader(sock)
 * 
 *     cdef _sock_connect(self, sock, address):             # <<<<<<<<<<<<<<
 *         cdef:
 *             Handle handle
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XDECREF(__pyx_v_fut);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1010
 *         return fut
 * 
 *     cdef _sock_connect_cb(self, fut, sock, address):             # <<<<<<<<<<<<<<
 *         if fut.cancelled():
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_connect_cb(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fut, PyObject *__pyx_v_sock, PyObject *__pyx_v_address) {
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  __Pyx_RefNannySetupContext("_sock_connect_cb", 0);

  /* "uvloop/loop.pyx":1011
 * 
 *     cdef _sock_connect_cb(self, fut, sock, address):
 *         if fut.cancelled():             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1011, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1011, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1011, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 1011, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "uvloop/loop.pyx":1012
 *     cdef _sock_connect_cb(self, fut, sock, address):
 *         if fut.cancelled():
 *             return             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1011
 * 
 *     cdef _sock_connect_cb(self, fut, sock, address):
 *         if fut.cancelled():             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/loop.pyx":1014
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             err = sock.getsockopt(uv.SOL_SOCKET, uv.SO_ERROR)
 *             if err != 0:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "uvloop/loop.pyx":1015
 * 
 *         try:
 *             err = sock.getsockopt(uv.SOL_SOCKET, uv.SO_ERROR)             # <<<<<<<<<<<<<<
 *             if err != 0:
 *                 # Jump to any except clause below.
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_getsockopt); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1015, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyInt_From_int(SOL_SOCKET); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1015, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = __Pyx_PyInt_From_int(SO_ERROR); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1015, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_3, __pyx_t_8};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1015, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_3, __pyx_t_8};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1015, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1015, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_8);
        __pyx_t_3 = 0;
        __pyx_t_8 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1015, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_err = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":1016
 *         try:
 *             err = sock.getsockopt(uv.SOL_SOCKET, uv.SO_ERROR)
 *             if err != 0:             # <<<<<<<<<<<<<<
 *                 # Jump to any except clause below.
 *                 raise OSError(err, 'Connect call failed %s' % (address,))
 */
      __pyx_t_1 = PyObject_RichCompare(__pyx_v_err, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1016, __pyx_L4_error)
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 1016, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_t_4)) {

        /* "uvloop/loop.pyx":1018
 *             if err != 0:
 *                 # Jump to any except clause below.
 *                 raise OSError(err, 'Connect call failed %s' % (address,))             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             # socket is still registered, the callback will be retried later
 */
        __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_v_address), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1018, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Connect_call_failed, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1018, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1018, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_err);
        __Pyx_GIVEREF(__pyx_v_err);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_err);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1018, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(2, 1018, __pyx_L4_error)

        /* "uvloop/loop.pyx":1016
 *         try:
 *             err = sock.getsockopt(uv.SOL_SOCKET, uv.SO_ERROR)
 *             if err != 0:             # <<<<<<<<<<<<<<
 *                 # Jump to any except clause below.
 *                 raise OSError(err, 'Connect call failed %s' % (address,))
 */
      }

      /* "uvloop/loop.pyx":1014
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             err = sock.getsockopt(uv.SOL_SOCKET, uv.SO_ERROR)
 *             if err != 0:
 */
    }

    /* "uvloop/loop.pyx":1025
 *             fut.set_exception(exc)
 *         else:
 *             fut.set_result(None)             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_set_reuseport(self, int fd):
 */
    /*else:*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1025, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1025, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":1019
 *                 # Jump to any except clause below.
 *                 raise OSError(err, 'Connect call failed %s' % (address,))
 *         except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *             # socket is still registered, the callback will be retried later
 *             pass
 */
    __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_2, &__pyx_t_11);
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1019, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1019, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_8) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_ErrRestore(__pyx_t_1, __pyx_t_2, __pyx_t_11);
    __pyx_t_1 = 0; __pyx_t_2 = 0; __pyx_t_11 = 0;
    if (__pyx_t_10) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L5_exception_handled;
    }

    /* "uvloop/loop.pyx":1022
 *             # socket is still registered, the callback will be retried later
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *         else:
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.Loop._sock_connect_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_2, &__pyx_t_1) < 0) __PYX_ERR(2, 1022, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      /*try:*/ {

        /* "uvloop/loop.pyx":1023
 *             pass
 *         except Exception as exc:
 *             fut.set_exception(exc)             # <<<<<<<<<<<<<<
 *         else:
 *             fut.set_result(None)
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1023, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_9) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1023, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_exc};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1023, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_exc};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1023, __pyx_L16_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          {
            __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1023, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_9); __pyx_t_9 = NULL;
            __Pyx_INCREF(__pyx_v_exc);
            __Pyx_GIVEREF(__pyx_v_exc);
            PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_v_exc);
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_12, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1023, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }

      /* "uvloop/loop.pyx":1022
 *             # socket is still registered, the callback will be retried later
 *             pass
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             fut.set_exception(exc)
 *         else:
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L17;
        }
        __pyx_L16_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_10 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L6_except_error;
        }
        __pyx_L17:;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/loop.pyx":1014
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             err = sock.getsockopt(uv.SOL_SOCKET, uv.SO_ERROR)
 *             if err != 0:
 */
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L9_try_end:;
  }

  /* "uvloop/loop.pyx":1010
 *         return fut
 * 
 *     cdef _sock_connect_cb(self, fut, sock, address):             # <<<<<<<<<<<<<<
 *         if fut.cancelled():
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_connect_cb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1027
 *             fut.set_result(None)
 * 
 *     cdef _sock_set_reuseport(self, int fd):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int err
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__sock_set_reuseport(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, int __pyx_v_fd) {
  int __pyx_v_err;
  int __pyx_v_reuseport_flag;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_sock_set_reuseport", 0);

  /* "uvloop/loop.pyx":1030
 *         cdef:
 *             int err
 *             int reuseport_flag = 1             # <<<<<<<<<<<<<<
 * 
 *         err = system.setsockopt(
 */
  __pyx_v_reuseport_flag = 1;

  /* "uvloop/loop.pyx":1032
 *             int reuseport_flag = 1
 * 
 *         err = system.setsockopt(             # <<<<<<<<<<<<<<
 *             fd,
 *             uv.SOL_SOCKET,
 */
  __pyx_v_err = setsockopt(__pyx_v_fd, SOL_SOCKET, __pyx_v_6uvloop_4loop_SO_REUSEPORT, ((char *)(&__pyx_v_reuseport_flag)), (sizeof(__pyx_v_reuseport_flag)));

  /* "uvloop/loop.pyx":1039
 *             sizeof(reuseport_flag))
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(-errno.errno)
 * 
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":1040
 * 
 *         if err < 0:
 *             raise convert_error(-errno.errno)             # <<<<<<<<<<<<<<
 * 
 *     cdef _set_coroutine_debug(self, bint enabled):
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error((-errno)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1040, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1040, __pyx_L1_error)

    /* "uvloop/loop.pyx":1039
 *             sizeof(reuseport_flag))
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(-errno.errno)
 * 
 */
  }

  /* "uvloop/loop.pyx":1027
 *             fut.set_result(None)
 * 
 *     cdef _sock_set_reuseport(self, int fd):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int err
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_set_reuseport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1042
 *             raise convert_error(-errno.errno)
 * 
 *     cdef _set_coroutine_debug(self, bint enabled):             # <<<<<<<<<<<<<<
 *         enabled = bool(enabled)
 *         if self._coroutine_debug_set == enabled:
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__set_coroutine_debug(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, int __pyx_v_enabled) {
  PyObject *__pyx_v_wrapper = NULL;
  PyObject *__pyx_v_current_wrapper = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("_set_coroutine_debug", 0);

  /* "uvloop/loop.pyx":1043
 * 
 *     cdef _set_coroutine_debug(self, bint enabled):
 *         enabled = bool(enabled)             # <<<<<<<<<<<<<<
 *         if self._coroutine_debug_set == enabled:
 *             return
 */
  __pyx_t_1 = __pyx_v_enabled;
  __pyx_v_enabled = (!(!__pyx_t_1));

  /* "uvloop/loop.pyx":1044
 *     cdef _set_coroutine_debug(self, bint enabled):
 *         enabled = bool(enabled)
 *         if self._coroutine_debug_set == enabled:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_coroutine_debug_set == __pyx_v_enabled) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1045
 *         enabled = bool(enabled)
 *         if self._coroutine_debug_set == enabled:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if PY37:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1044
 *     cdef _set_coroutine_debug(self, bint enabled):
 *         enabled = bool(enabled)
 *         if self._coroutine_debug_set == enabled:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/loop.pyx":1047
 *             return
 * 
 *         if PY37:             # <<<<<<<<<<<<<<
 *             if enabled:
 *                 self._coroutine_origin_tracking_saved_depth = (
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1048
 * 
 *         if PY37:
 *             if enabled:             # <<<<<<<<<<<<<<
 *                 self._coroutine_origin_tracking_saved_depth = (
 *                     sys.get_coroutine_origin_tracking_depth())
 */
    __pyx_t_1 = (__pyx_v_enabled != 0);
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":1050
 *             if enabled:
 *                 self._coroutine_origin_tracking_saved_depth = (
 *                     sys.get_coroutine_origin_tracking_depth())             # <<<<<<<<<<<<<<
 *                 sys.set_coroutine_origin_tracking_depth(
 *                     DEBUG_STACK_DEPTH)
 */
      __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1050, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get_coroutine_origin_tracking_de); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1050, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_3) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1050, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1050, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1050, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":1049
 *         if PY37:
 *             if enabled:
 *                 self._coroutine_origin_tracking_saved_depth = (             # <<<<<<<<<<<<<<
 *                     sys.get_coroutine_origin_tracking_depth())
 *                 sys.set_coroutine_origin_tracking_depth(
 */
      __pyx_v_self->_coroutine_origin_tracking_saved_depth = __pyx_t_5;

      /* "uvloop/loop.pyx":1051
 *                 self._coroutine_origin_tracking_saved_depth = (
 *                     sys.get_coroutine_origin_tracking_depth())
 *                 sys.set_coroutine_origin_tracking_depth(             # <<<<<<<<<<<<<<
 *                     DEBUG_STACK_DEPTH)
 *             else:
 */
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_coroutine_origin_tracking_de); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1051, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":1048
 * 
 *         if PY37:
 *             if enabled:             # <<<<<<<<<<<<<<
 *                 self._coroutine_origin_tracking_saved_depth = (
 *                     sys.get_coroutine_origin_tracking_depth())
 */
      goto __pyx_L5;
    }

    /* "uvloop/loop.pyx":1054
 *                     DEBUG_STACK_DEPTH)
 *             else:
 *                 sys.set_coroutine_origin_tracking_depth(             # <<<<<<<<<<<<<<
 *                     self._coroutine_origin_tracking_saved_depth)
 * 
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1054, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_coroutine_origin_tracking_de); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1054, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1055
 *             else:
 *                 sys.set_coroutine_origin_tracking_depth(
 *                     self._coroutine_origin_tracking_saved_depth)             # <<<<<<<<<<<<<<
 * 
 *             self._coroutine_debug_set = enabled
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->_coroutine_origin_tracking_saved_depth); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1055, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1054, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1054, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1054, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1054, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_4);
          __pyx_t_4 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1054, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L5:;

    /* "uvloop/loop.pyx":1057
 *                     self._coroutine_origin_tracking_saved_depth)
 * 
 *             self._coroutine_debug_set = enabled             # <<<<<<<<<<<<<<
 *         else:
 *             wrapper = aio_debug_wrapper
 */
    __pyx_v_self->_coroutine_debug_set = __pyx_v_enabled;

    /* "uvloop/loop.pyx":1047
 *             return
 * 
 *         if PY37:             # <<<<<<<<<<<<<<
 *             if enabled:
 *                 self._coroutine_origin_tracking_saved_depth = (
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":1059
 *             self._coroutine_debug_set = enabled
 *         else:
 *             wrapper = aio_debug_wrapper             # <<<<<<<<<<<<<<
 *             current_wrapper = sys_get_coroutine_wrapper()
 * 
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_debug_wrapper);
    __pyx_v_wrapper = __pyx_v_6uvloop_4loop_aio_debug_wrapper;

    /* "uvloop/loop.pyx":1060
 *         else:
 *             wrapper = aio_debug_wrapper
 *             current_wrapper = sys_get_coroutine_wrapper()             # <<<<<<<<<<<<<<
 * 
 *             if enabled:
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_sys_get_coroutine_wrapper);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_sys_get_coroutine_wrapper; __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1060, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1060, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_current_wrapper = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":1062
 *             current_wrapper = sys_get_coroutine_wrapper()
 * 
 *             if enabled:             # <<<<<<<<<<<<<<
 *                 if current_wrapper not in (None, wrapper):
 *                     _warn_with_source(
 */
    __pyx_t_1 = (__pyx_v_enabled != 0);
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":1063
 * 
 *             if enabled:
 *                 if current_wrapper not in (None, wrapper):             # <<<<<<<<<<<<<<
 *                     _warn_with_source(
 *                         "loop.set_debug(True): cannot set debug coroutine "
 */
      __Pyx_INCREF(__pyx_v_current_wrapper);
      __pyx_t_2 = __pyx_v_current_wrapper;
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1063, __pyx_L1_error)
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(2, 1063, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_8) {
      } else {
        __pyx_t_1 = __pyx_t_8;
        goto __pyx_L8_bool_binop_done;
      }
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_v_wrapper, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1063, __pyx_L1_error)
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(2, 1063, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_1 = __pyx_t_8;
      __pyx_L8_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = (__pyx_t_1 != 0);
      if (__pyx_t_8) {

        /* "uvloop/loop.pyx":1066
 *                     _warn_with_source(
 *                         "loop.set_debug(True): cannot set debug coroutine "
 *                         "wrapper; another wrapper is already set %r" %             # <<<<<<<<<<<<<<
 *                         current_wrapper, RuntimeWarning, self)
 *                 else:
 */
        __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_loop_set_debug_True_cannot_set_d, __pyx_v_current_wrapper); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1066, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);

        /* "uvloop/loop.pyx":1064
 *             if enabled:
 *                 if current_wrapper not in (None, wrapper):
 *                     _warn_with_source(             # <<<<<<<<<<<<<<
 *                         "loop.set_debug(True): cannot set debug coroutine "
 *                         "wrapper; another wrapper is already set %r" %
 */
        __pyx_t_3 = __pyx_f_6uvloop_4loop__warn_with_source(__pyx_t_2, __pyx_builtin_RuntimeWarning, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1064, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/loop.pyx":1063
 * 
 *             if enabled:
 *                 if current_wrapper not in (None, wrapper):             # <<<<<<<<<<<<<<
 *                     _warn_with_source(
 *                         "loop.set_debug(True): cannot set debug coroutine "
 */
        goto __pyx_L7;
      }

      /* "uvloop/loop.pyx":1069
 *                         current_wrapper, RuntimeWarning, self)
 *                 else:
 *                     sys_set_coroutine_wrapper(wrapper)             # <<<<<<<<<<<<<<
 *                     self._coroutine_debug_set = True
 *             else:
 */
      /*else*/ {
        __Pyx_INCREF(__pyx_v_6uvloop_4loop_sys_set_coroutine_wrapper);
        __pyx_t_2 = __pyx_v_6uvloop_4loop_sys_set_coroutine_wrapper; __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        if (!__pyx_t_7) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_wrapper); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1069, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_2)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_wrapper};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1069, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_wrapper};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1069, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          {
            __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1069, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7); __pyx_t_7 = NULL;
            __Pyx_INCREF(__pyx_v_wrapper);
            __Pyx_GIVEREF(__pyx_v_wrapper);
            PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_wrapper);
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1069, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/loop.pyx":1070
 *                 else:
 *                     sys_set_coroutine_wrapper(wrapper)
 *                     self._coroutine_debug_set = True             # <<<<<<<<<<<<<<
 *             else:
 *                 if current_wrapper not in (None, wrapper):
 */
        __pyx_v_self->_coroutine_debug_set = 1;
      }
      __pyx_L7:;

      /* "uvloop/loop.pyx":1062
 *             current_wrapper = sys_get_coroutine_wrapper()
 * 
 *             if enabled:             # <<<<<<<<<<<<<<
 *                 if current_wrapper not in (None, wrapper):
 *                     _warn_with_source(
 */
      goto __pyx_L6;
    }

    /* "uvloop/loop.pyx":1072
 *                     self._coroutine_debug_set = True
 *             else:
 *                 if current_wrapper not in (None, wrapper):             # <<<<<<<<<<<<<<
 *                     _warn_with_source(
 *                         "loop.set_debug(False): cannot unset debug coroutine "
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_v_current_wrapper);
      __pyx_t_3 = __pyx_v_current_wrapper;
      __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1072, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1072, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_1) {
      } else {
        __pyx_t_8 = __pyx_t_1;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_2 = PyObject_RichCompare(__pyx_t_3, __pyx_v_wrapper, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1072, __pyx_L1_error)
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1072, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_8 = __pyx_t_1;
      __pyx_L11_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_1 = (__pyx_t_8 != 0);
      if (__pyx_t_1) {

        /* "uvloop/loop.pyx":1075
 *                     _warn_with_source(
 *                         "loop.set_debug(False): cannot unset debug coroutine "
 *                         "wrapper; another wrapper was set %r" %             # <<<<<<<<<<<<<<
 *                         current_wrapper, RuntimeWarning, self)
 *                 else:
 */
        __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_loop_set_debug_False_cannot_unse, __pyx_v_current_wrapper); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1075, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);

        /* "uvloop/loop.pyx":1073
 *             else:
 *                 if current_wrapper not in (None, wrapper):
 *                     _warn_with_source(             # <<<<<<<<<<<<<<
 *                         "loop.set_debug(False): cannot unset debug coroutine "
 *                         "wrapper; another wrapper was set %r" %
 */
        __pyx_t_2 = __pyx_f_6uvloop_4loop__warn_with_source(__pyx_t_3, __pyx_builtin_RuntimeWarning, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1073, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":1072
 *                     self._coroutine_debug_set = True
 *             else:
 *                 if current_wrapper not in (None, wrapper):             # <<<<<<<<<<<<<<
 *                     _warn_with_source(
 *                         "loop.set_debug(False): cannot unset debug coroutine "
 */
        goto __pyx_L10;
      }

      /* "uvloop/loop.pyx":1078
 *                         current_wrapper, RuntimeWarning, self)
 *                 else:
 *                     sys_set_coroutine_wrapper(None)             # <<<<<<<<<<<<<<
 *                     self._coroutine_debug_set = False
 * 
 */
      /*else*/ {
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_sys_set_coroutine_wrapper, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1078, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":1079
 *                 else:
 *                     sys_set_coroutine_wrapper(None)
 *                     self._coroutine_debug_set = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_v_self->_coroutine_debug_set = 0;
      }
      __pyx_L10:;
    }
    __pyx_L6:;
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":1042
 *             raise convert_error(-errno.errno)
 * 
 *     cdef _set_coroutine_debug(self, bint enabled):             # <<<<<<<<<<<<<<
 *         enabled = bool(enabled)
 *         if self._coroutine_debug_set == enabled:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop._set_coroutine_debug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrapper);
  __Pyx_XDECREF(__pyx_v_current_wrapper);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1082
 * 
 * 
 *     cdef _create_server(self, system.sockaddr *addr,             # <<<<<<<<<<<<<<
 *                         object protocol_factory,
 *                         Server server,
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__create_server(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, struct sockaddr *__pyx_v_addr, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, int __pyx_v_reuse_port, PyObject *__pyx_v_backlog, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_tcp = 0;
  int __pyx_v_bind_flags;
  PyObject *__pyx_v_err = NULL;
  PyObject *__pyx_v_pyaddr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  struct __pyx_opt_args_6uvloop_4loop_9TCPServer_bind __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  __Pyx_RefNannySetupContext("_create_server", 0);

  /* "uvloop/loop.pyx":1093
 *             int bind_flags
 * 
 *         tcp = TCPServer.new(self, protocol_factory, server, ssl,             # <<<<<<<<<<<<<<
 *                             addr.sa_family, ssl_handshake_timeout)
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_6uvloop_4loop_9TCPServer_new(__pyx_v_self, __pyx_v_protocol_factory, __pyx_v_server, __pyx_v_ssl, __pyx_v_addr->sa_family, __pyx_v_ssl_handshake_timeout)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1093, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tcp = ((struct __pyx_obj_6uvloop_4loop_TCPServer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1096
 *                             addr.sa_family, ssl_handshake_timeout)
 * 
 *         if reuse_port:             # <<<<<<<<<<<<<<
 *             self._sock_set_reuseport(tcp._fileno())
 * 
 */
  __pyx_t_2 = (__pyx_v_reuse_port != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1097
 * 
 *         if reuse_port:
 *             self._sock_set_reuseport(tcp._fileno())             # <<<<<<<<<<<<<<
 * 
 *         if addr.sa_family == uv.AF_INET6:
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._fileno(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_tcp)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1097, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_sock_set_reuseport(__pyx_v_self, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1096
 *                             addr.sa_family, ssl_handshake_timeout)
 * 
 *         if reuse_port:             # <<<<<<<<<<<<<<
 *             self._sock_set_reuseport(tcp._fileno())
 * 
 */
  }

  /* "uvloop/loop.pyx":1099
 *             self._sock_set_reuseport(tcp._fileno())
 * 
 *         if addr.sa_family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *             # Disable IPv4/IPv6 dual stack support (enabled by
 *             # default on Linux) which makes a single socket
 */
  __pyx_t_2 = ((__pyx_v_addr->sa_family == AF_INET6) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1103
 *             # default on Linux) which makes a single socket
 *             # listen on both address families.
 *             bind_flags = uv.UV_TCP_IPV6ONLY             # <<<<<<<<<<<<<<
 *         else:
 *             bind_flags = 0
 */
    __pyx_v_bind_flags = UV_TCP_IPV6ONLY;

    /* "uvloop/loop.pyx":1099
 *             self._sock_set_reuseport(tcp._fileno())
 * 
 *         if addr.sa_family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *             # Disable IPv4/IPv6 dual stack support (enabled by
 *             # default on Linux) which makes a single socket
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":1105
 *             bind_flags = uv.UV_TCP_IPV6ONLY
 *         else:
 *             bind_flags = 0             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  /*else*/ {
    __pyx_v_bind_flags = 0;
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":1107
 *             bind_flags = 0
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             tcp.bind(addr, bind_flags)
 *             tcp.listen(backlog)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/loop.pyx":1108
 * 
 *         try:
 *             tcp.bind(addr, bind_flags)             # <<<<<<<<<<<<<<
 *             tcp.listen(backlog)
 *         except OSError as err:
 */
      __pyx_t_7.__pyx_n = 1;
      __pyx_t_7.flags = __pyx_v_bind_flags;
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->bind(__pyx_v_tcp, __pyx_v_addr, &__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1108, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":1109
 *         try:
 *             tcp.bind(addr, bind_flags)
 *             tcp.listen(backlog)             # <<<<<<<<<<<<<<
 *         except OSError as err:
 *             pyaddr = __convert_sockaddr_to_pyaddr(addr)
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.listen(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_tcp), __pyx_v_backlog); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1109, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":1107
 *             bind_flags = 0
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             tcp.bind(addr, bind_flags)
 *             tcp.listen(backlog)
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1110
 *             tcp.bind(addr, bind_flags)
 *             tcp.listen(backlog)
 *         except OSError as err:             # <<<<<<<<<<<<<<
 *             pyaddr = __convert_sockaddr_to_pyaddr(addr)
 *             tcp._close()
 */
    __pyx_t_3 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
    if (__pyx_t_3) {
      __Pyx_AddTraceback("uvloop.loop.Loop._create_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(2, 1110, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_v_err = __pyx_t_8;
      /*try:*/ {

        /* "uvloop/loop.pyx":1111
 *             tcp.listen(backlog)
 *         except OSError as err:
 *             pyaddr = __convert_sockaddr_to_pyaddr(addr)             # <<<<<<<<<<<<<<
 *             tcp._close()
 *             raise OSError(err.errno, 'error while attempting '
 */
        __pyx_t_10 = __pyx_f_6uvloop_4loop___convert_sockaddr_to_pyaddr(__pyx_v_addr); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 1111, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_v_pyaddr = __pyx_t_10;
        __pyx_t_10 = 0;

        /* "uvloop/loop.pyx":1112
 *         except OSError as err:
 *             pyaddr = __convert_sockaddr_to_pyaddr(addr)
 *             tcp._close()             # <<<<<<<<<<<<<<
 *             raise OSError(err.errno, 'error while attempting '
 *                           'to bind on address %r: %s'
 */
        __pyx_t_10 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_tcp)); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 1112, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "uvloop/loop.pyx":1113
 *             pyaddr = __convert_sockaddr_to_pyaddr(addr)
 *             tcp._close()
 *             raise OSError(err.errno, 'error while attempting '             # <<<<<<<<<<<<<<
 *                           'to bind on address %r: %s'
 *                           % (pyaddr, err.strerror.lower()))
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_errno); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 1113, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = PyTuple_New(4); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1113, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = 0;
        __pyx_t_13 = 127;
        __Pyx_INCREF(__pyx_kp_u_error_while_attempting_to_bind_o);
        __pyx_t_12 += 42;
        __Pyx_GIVEREF(__pyx_kp_u_error_while_attempting_to_bind_o);
        PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_kp_u_error_while_attempting_to_bind_o);

        /* "uvloop/loop.pyx":1115
 *             raise OSError(err.errno, 'error while attempting '
 *                           'to bind on address %r: %s'
 *                           % (pyaddr, err.strerror.lower()))             # <<<<<<<<<<<<<<
 *         except Exception:
 *             tcp._close()
 */
        __pyx_t_14 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_pyaddr), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 1115, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_13;
        __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_14);
        __pyx_t_14 = 0;
        __Pyx_INCREF(__pyx_kp_u__33);
        __pyx_t_12 += 2;
        __Pyx_GIVEREF(__pyx_kp_u__33);
        PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_kp_u__33);
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_err, __pyx_n_s_strerror); if (unlikely(!__pyx_t_15)) __PYX_ERR(2, 1115, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_lower); if (unlikely(!__pyx_t_16)) __PYX_ERR(2, 1115, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
          if (likely(__pyx_t_15)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_16, function);
          }
        }
        if (__pyx_t_15) {
          __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 1115, __pyx_L16_error)
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        } else {
          __pyx_t_14 = __Pyx_PyObject_CallNoArg(__pyx_t_16); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 1115, __pyx_L16_error)
        }
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_16 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_14), __pyx_empty_unicode); if (unlikely(!__pyx_t_16)) __PYX_ERR(2, 1115, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_16) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_16) : __pyx_t_13;
        __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_16);
        __Pyx_GIVEREF(__pyx_t_16);
        PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_t_16);
        __pyx_t_16 = 0;

        /* "uvloop/loop.pyx":1113
 *             pyaddr = __convert_sockaddr_to_pyaddr(addr)
 *             tcp._close()
 *             raise OSError(err.errno, 'error while attempting '             # <<<<<<<<<<<<<<
 *                           'to bind on address %r: %s'
 *                           % (pyaddr, err.strerror.lower()))
 */
        __pyx_t_16 = __Pyx_PyUnicode_Join(__pyx_t_11, 4, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_16)) __PYX_ERR(2, 1113, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1113, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_16);
        PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_16);
        __pyx_t_10 = 0;
        __pyx_t_16 = 0;
        __pyx_t_16 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_t_11, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(2, 1113, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_Raise(__pyx_t_16, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __PYX_ERR(2, 1113, __pyx_L16_error)
      }

      /* "uvloop/loop.pyx":1110
 *             tcp.bind(addr, bind_flags)
 *             tcp.listen(backlog)
 *         except OSError as err:             # <<<<<<<<<<<<<<
 *             pyaddr = __convert_sockaddr_to_pyaddr(addr)
 *             tcp._close()
 */
      /*finally:*/ {
        __pyx_L16_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __pyx_t_3 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_err);
            __pyx_v_err = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
          }
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __pyx_lineno = __pyx_t_3; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
          goto __pyx_L7_except_error;
        }
      }
    }

    /* "uvloop/loop.pyx":1116
 *                           'to bind on address %r: %s'
 *                           % (pyaddr, err.strerror.lower()))
 *         except Exception:             # <<<<<<<<<<<<<<
 *             tcp._close()
 *             raise
 */
    __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_17) {
      __Pyx_AddTraceback("uvloop.loop.Loop._create_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(2, 1116, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_1);

      /* "uvloop/loop.pyx":1117
 *                           % (pyaddr, err.strerror.lower()))
 *         except Exception:
 *             tcp._close()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_16 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_tcp)); if (unlikely(!__pyx_t_16)) __PYX_ERR(2, 1117, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

      /* "uvloop/loop.pyx":1118
 *         except Exception:
 *             tcp._close()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         return tcp
 */
      __Pyx_GIVEREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_8, __pyx_t_1);
      __pyx_t_9 = 0; __pyx_t_8 = 0; __pyx_t_1 = 0; 
      __PYX_ERR(2, 1118, __pyx_L7_except_error)
    }
    goto __pyx_L7_except_error;
    __pyx_L7_except_error:;

    /* "uvloop/loop.pyx":1107
 *             bind_flags = 0
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             tcp.bind(addr, bind_flags)
 *             tcp.listen(backlog)
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L10_try_end:;
  }

  /* "uvloop/loop.pyx":1120
 *             raise
 * 
 *         return tcp             # <<<<<<<<<<<<<<
 * 
 *     def _get_backend_id(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_tcp));
  __pyx_r = ((PyObject *)__pyx_v_tcp);
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1082
 * 
 * 
 *     cdef _create_server(self, system.sockaddr *addr,             # <<<<<<<<<<<<<<
 *                         object protocol_factory,
 *                         Server server,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("uvloop.loop.Loop._create_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tcp);
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_XDECREF(__pyx_v_pyaddr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1122
 *         return tcp
 * 
 *     def _get_backend_id(self):             # <<<<<<<<<<<<<<
 *         """This method is used by uvloop tests and is not part of the API."""
 *         return uv.uv_backend_fd(self.uvloop)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_9_get_backend_id(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_8_get_backend_id[] = "Loop._get_backend_id(self)\nThis method is used by uvloop tests and is not part of the API.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_9_get_backend_id(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_backend_id (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_8_get_backend_id(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_8_get_backend_id(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_get_backend_id", 0);

  /* "uvloop/loop.pyx":1124
 *     def _get_backend_id(self):
 *         """This method is used by uvloop tests and is not part of the API."""
 *         return uv.uv_backend_fd(self.uvloop)             # <<<<<<<<<<<<<<
 * 
 *     cdef _print_debug_info(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(uv_backend_fd(__pyx_v_self->uvloop)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1122
 *         return tcp
 * 
 *     def _get_backend_id(self):             # <<<<<<<<<<<<<<
 *         """This method is used by uvloop tests and is not part of the API."""
 *         return uv.uv_backend_fd(self.uvloop)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._get_backend_id", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1126
 *         return uv.uv_backend_fd(self.uvloop)
 * 
 *     cdef _print_debug_info(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int err
 */

static PyObject *__pyx_f_6uvloop_4loop_4Loop__print_debug_info(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  int __pyx_v_err;
  uv_rusage_t __pyx_v_rusage;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("_print_debug_info", 0);

  /* "uvloop/loop.pyx":1131
 *             uv.uv_rusage_t rusage
 * 
 *         err = uv.uv_getrusage(&rusage)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
  __pyx_v_err = uv_getrusage((&__pyx_v_rusage));

  /* "uvloop/loop.pyx":1132
 * 
 *         err = uv.uv_getrusage(&rusage)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":1133
 *         err = uv.uv_getrusage(&rusage)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         ################### OS
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1133, __pyx_L1_error)

    /* "uvloop/loop.pyx":1132
 * 
 *         err = uv.uv_getrusage(&rusage)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  }

  /* "uvloop/loop.pyx":1137
 *         ################### OS
 * 
 *         print('---- Process info: -----')             # <<<<<<<<<<<<<<
 *         print('Process memory:            {}'.format(rusage.ru_maxrss))
 *         print('Number of signals:         {}'.format(rusage.ru_nsignals))
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1138
 * 
 *         print('---- Process info: -----')
 *         print('Process memory:            {}'.format(rusage.ru_maxrss))             # <<<<<<<<<<<<<<
 *         print('Number of signals:         {}'.format(rusage.ru_nsignals))
 *         print('')
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Process_memory, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_uint64_t(__pyx_v_rusage.ru_maxrss); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1138, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1138, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1138, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1139
 *         print('---- Process info: -----')
 *         print('Process memory:            {}'.format(rusage.ru_maxrss))
 *         print('Number of signals:         {}'.format(rusage.ru_nsignals))             # <<<<<<<<<<<<<<
 *         print('')
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Number_of_signals, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_rusage.ru_nsignals); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1139, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1139, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1139, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1139, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1140
 *         print('Process memory:            {}'.format(rusage.ru_maxrss))
 *         print('Number of signals:         {}'.format(rusage.ru_nsignals))
 *         print('')             # <<<<<<<<<<<<<<
 * 
 *         ################### Loop
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1144
 *         ################### Loop
 * 
 *         print('--- Loop debug info: ---')             # <<<<<<<<<<<<<<
 *         print('Loop time:                 {}'.format(self.time()))
 *         print('Errors logged:             {}'.format(
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1145
 * 
 *         print('--- Loop debug info: ---')
 *         print('Loop time:                 {}'.format(self.time()))             # <<<<<<<<<<<<<<
 *         print('Errors logged:             {}'.format(
 *             self._debug_exception_handler_cnt))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Loop_time, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_time); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1145, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1145, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1145, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1145, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1145, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1145, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1146
 *         print('--- Loop debug info: ---')
 *         print('Loop time:                 {}'.format(self.time()))
 *         print('Errors logged:             {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_exception_handler_cnt))
 *         print()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Errors_logged, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/loop.pyx":1147
 *         print('Loop time:                 {}'.format(self.time()))
 *         print('Errors logged:             {}'.format(
 *             self._debug_exception_handler_cnt))             # <<<<<<<<<<<<<<
 *         print()
 *         print('Callback handles:          {: <8} | {}'.format(
 */
  __pyx_t_4 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_exception_handler_cnt); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1146, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1146, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1146, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1146
 *         print('--- Loop debug info: ---')
 *         print('Loop time:                 {}'.format(self.time()))
 *         print('Errors logged:             {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_exception_handler_cnt))
 *         print()
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1148
 *         print('Errors logged:             {}'.format(
 *             self._debug_exception_handler_cnt))
 *         print()             # <<<<<<<<<<<<<<
 *         print('Callback handles:          {: <8} | {}'.format(
 *             self._debug_cb_handles_count,
 */
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1149
 *             self._debug_exception_handler_cnt))
 *         print()
 *         print('Callback handles:          {: <8} | {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_cb_handles_count,
 *             self._debug_cb_handles_total))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Callback_handles_8, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1150
 *         print()
 *         print('Callback handles:          {: <8} | {}'.format(
 *             self._debug_cb_handles_count,             # <<<<<<<<<<<<<<
 *             self._debug_cb_handles_total))
 *         print('Timer handles:             {: <8} | {}'.format(
 */
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_handles_count); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1150, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/loop.pyx":1151
 *         print('Callback handles:          {: <8} | {}'.format(
 *             self._debug_cb_handles_count,
 *             self._debug_cb_handles_total))             # <<<<<<<<<<<<<<
 *         print('Timer handles:             {: <8} | {}'.format(
 *             self._debug_cb_timer_handles_count,
 */
  __pyx_t_4 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_handles_total); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_6, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1149, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_6, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1149, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_4);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1149, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1149
 *             self._debug_exception_handler_cnt))
 *         print()
 *         print('Callback handles:          {: <8} | {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_cb_handles_count,
 *             self._debug_cb_handles_total))
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1152
 *             self._debug_cb_handles_count,
 *             self._debug_cb_handles_total))
 *         print('Timer handles:             {: <8} | {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_cb_timer_handles_count,
 *             self._debug_cb_timer_handles_total))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Timer_handles_8, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/loop.pyx":1153
 *             self._debug_cb_handles_total))
 *         print('Timer handles:             {: <8} | {}'.format(
 *             self._debug_cb_timer_handles_count,             # <<<<<<<<<<<<<<
 *             self._debug_cb_timer_handles_total))
 *         print()
 */
  __pyx_t_8 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_timer_handles_count); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);

  /* "uvloop/loop.pyx":1154
 *         print('Timer handles:             {: <8} | {}'.format(
 *             self._debug_cb_timer_handles_count,
 *             self._debug_cb_timer_handles_total))             # <<<<<<<<<<<<<<
 *         print()
 * 
 */
  __pyx_t_4 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_timer_handles_total); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_8, __pyx_t_4};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1152, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_8, __pyx_t_4};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1152, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_7, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_7, __pyx_t_4);
    __pyx_t_8 = 0;
    __pyx_t_4 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1152
 *             self._debug_cb_handles_count,
 *             self._debug_cb_handles_total))
 *         print('Timer handles:             {: <8} | {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_cb_timer_handles_count,
 *             self._debug_cb_timer_handles_total))
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1155
 *             self._debug_cb_timer_handles_count,
 *             self._debug_cb_timer_handles_total))
 *         print()             # <<<<<<<<<<<<<<
 * 
 *         print('                        alive  | closed  |')
 */
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1157
 *         print()
 * 
 *         print('                        alive  | closed  |')             # <<<<<<<<<<<<<<
 *         print('UVHandles               python | libuv   | total')
 *         print('                        objs   | handles |')
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1158
 * 
 *         print('                        alive  | closed  |')
 *         print('UVHandles               python | libuv   | total')             # <<<<<<<<<<<<<<
 *         print('                        objs   | handles |')
 *         print('-------------------------------+---------+---------')
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1159
 *         print('                        alive  | closed  |')
 *         print('UVHandles               python | libuv   | total')
 *         print('                        objs   | handles |')             # <<<<<<<<<<<<<<
 *         print('-------------------------------+---------+---------')
 *         for name in sorted(self._debug_handles_total):
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__39, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1160
 *         print('UVHandles               python | libuv   | total')
 *         print('                        objs   | handles |')
 *         print('-------------------------------+---------+---------')             # <<<<<<<<<<<<<<
 *         for name in sorted(self._debug_handles_total):
 *             print('    {: <18} {: >7} | {: >7} | {: >7}'.format(
 */
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1161
 *         print('                        objs   | handles |')
 *         print('-------------------------------+---------+---------')
 *         for name in sorted(self._debug_handles_total):             # <<<<<<<<<<<<<<
 *             print('    {: <18} {: >7} | {: >7} | {: >7}'.format(
 *                 name,
 */
  __pyx_t_3 = __pyx_v_self->_debug_handles_total;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5 = PySequence_List(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_9 = PyList_Sort(__pyx_t_2); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(2, 1161, __pyx_L1_error)
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(2, 1161, __pyx_L1_error)
  }
  __pyx_t_5 = __pyx_t_2; __Pyx_INCREF(__pyx_t_5); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_5)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_10); __Pyx_INCREF(__pyx_t_2); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(2, 1161, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_5, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1161, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":1162
 *         print('-------------------------------+---------+---------')
 *         for name in sorted(self._debug_handles_total):
 *             print('    {: <18} {: >7} | {: >7} | {: >7}'.format(             # <<<<<<<<<<<<<<
 *                 name,
 *                 self._debug_handles_current[name],
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_18_7_7_7, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/loop.pyx":1164
 *             print('    {: <18} {: >7} | {: >7} | {: >7}'.format(
 *                 name,
 *                 self._debug_handles_current[name],             # <<<<<<<<<<<<<<
 *                 self._debug_handles_closed[name],
 *                 self._debug_handles_total[name]))
 */
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_self->_debug_handles_current, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "uvloop/loop.pyx":1165
 *                 name,
 *                 self._debug_handles_current[name],
 *                 self._debug_handles_closed[name],             # <<<<<<<<<<<<<<
 *                 self._debug_handles_total[name]))
 *         print()
 */
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_self->_debug_handles_closed, __pyx_v_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);

    /* "uvloop/loop.pyx":1166
 *                 self._debug_handles_current[name],
 *                 self._debug_handles_closed[name],
 *                 self._debug_handles_total[name]))             # <<<<<<<<<<<<<<
 *         print()
 * 
 */
    __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_v_self->_debug_handles_total, __pyx_v_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_11 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_11, __pyx_v_name, __pyx_t_4, __pyx_t_8, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1162, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[5] = {__pyx_t_11, __pyx_v_name, __pyx_t_4, __pyx_t_8, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 4+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1162, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(4+__pyx_t_7); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1162, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (__pyx_t_11) {
        __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
      }
      __Pyx_INCREF(__pyx_v_name);
      __Pyx_GIVEREF(__pyx_v_name);
      PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_7, __pyx_v_name);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_7, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_7, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_12, 3+__pyx_t_7, __pyx_t_6);
      __pyx_t_4 = 0;
      __pyx_t_8 = 0;
      __pyx_t_6 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1162, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":1162
 *         print('-------------------------------+---------+---------')
 *         for name in sorted(self._debug_handles_total):
 *             print('    {: <18} {: >7} | {: >7} | {: >7}'.format(             # <<<<<<<<<<<<<<
 *                 name,
 *                 self._debug_handles_current[name],
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":1161
 *         print('                        objs   | handles |')
 *         print('-------------------------------+---------+---------')
 *         for name in sorted(self._debug_handles_total):             # <<<<<<<<<<<<<<
 *             print('    {: <18} {: >7} | {: >7} | {: >7}'.format(
 *                 name,
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1167
 *                 self._debug_handles_closed[name],
 *                 self._debug_handles_total[name]))
 *         print()             # <<<<<<<<<<<<<<
 * 
 *         print('uv_handle_t (current: {}; freed: {}; total: {})'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1169
 *         print()
 * 
 *         print('uv_handle_t (current: {}; freed: {}; total: {})'.format(             # <<<<<<<<<<<<<<
 *             self._debug_uv_handles_total - self._debug_uv_handles_freed,
 *             self._debug_uv_handles_freed,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_uv_handle_t_current_freed_total, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1170
 * 
 *         print('uv_handle_t (current: {}; freed: {}; total: {})'.format(
 *             self._debug_uv_handles_total - self._debug_uv_handles_freed,             # <<<<<<<<<<<<<<
 *             self._debug_uv_handles_freed,
 *             self._debug_uv_handles_total))
 */
  __pyx_t_2 = __Pyx_PyInt_From_uint64_t((__pyx_v_self->_debug_uv_handles_total - __pyx_v_self->_debug_uv_handles_freed)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/loop.pyx":1171
 *         print('uv_handle_t (current: {}; freed: {}; total: {})'.format(
 *             self._debug_uv_handles_total - self._debug_uv_handles_freed,
 *             self._debug_uv_handles_freed,             # <<<<<<<<<<<<<<
 *             self._debug_uv_handles_total))
 *         print()
 */
  __pyx_t_12 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_uv_handles_freed); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1171, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);

  /* "uvloop/loop.pyx":1172
 *             self._debug_uv_handles_total - self._debug_uv_handles_freed,
 *             self._debug_uv_handles_freed,
 *             self._debug_uv_handles_total))             # <<<<<<<<<<<<<<
 *         print()
 * 
 */
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_uv_handles_total); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_2, __pyx_t_12, __pyx_t_6};
    __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1169, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_t_2, __pyx_t_12, __pyx_t_6};
    __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1169, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_7, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_12);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_7, __pyx_t_12);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 2+__pyx_t_7, __pyx_t_6);
    __pyx_t_2 = 0;
    __pyx_t_12 = 0;
    __pyx_t_6 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1169
 *         print()
 * 
 *         print('uv_handle_t (current: {}; freed: {}; total: {})'.format(             # <<<<<<<<<<<<<<
 *             self._debug_uv_handles_total - self._debug_uv_handles_freed,
 *             self._debug_uv_handles_freed,
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1173
 *             self._debug_uv_handles_freed,
 *             self._debug_uv_handles_total))
 *         print()             # <<<<<<<<<<<<<<
 * 
 *         print('--- Streams debug info: ---')
 */
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1175
 *         print()
 * 
 *         print('--- Streams debug info: ---')             # <<<<<<<<<<<<<<
 *         print('Write errors:              {}'.format(
 *             self._debug_stream_write_errors_total))
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__42, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1176
 * 
 *         print('--- Streams debug info: ---')
 *         print('Write errors:              {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_errors_total))
 *         print('Write without poll:        {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Write_errors, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1177
 *         print('--- Streams debug info: ---')
 *         print('Write errors:              {}'.format(
 *             self._debug_stream_write_errors_total))             # <<<<<<<<<<<<<<
 *         print('Write without poll:        {}'.format(
 *             self._debug_stream_write_tries))
 */
  __pyx_t_4 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_errors_total); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1176, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1176, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1176, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1176
 * 
 *         print('--- Streams debug info: ---')
 *         print('Write errors:              {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_errors_total))
 *         print('Write without poll:        {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1178
 *         print('Write errors:              {}'.format(
 *             self._debug_stream_write_errors_total))
 *         print('Write without poll:        {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_tries))
 *         print('Write contexts:            {: <8} | {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Write_without_poll, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1179
 *             self._debug_stream_write_errors_total))
 *         print('Write without poll:        {}'.format(
 *             self._debug_stream_write_tries))             # <<<<<<<<<<<<<<
 *         print('Write contexts:            {: <8} | {}'.format(
 *             self._debug_stream_write_ctx_cnt,
 */
  __pyx_t_12 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_tries); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1178, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_12};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1178, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_12};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1178, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_12);
      __pyx_t_12 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1178
 *         print('Write errors:              {}'.format(
 *             self._debug_stream_write_errors_total))
 *         print('Write without poll:        {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_tries))
 *         print('Write contexts:            {: <8} | {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1180
 *         print('Write without poll:        {}'.format(
 *             self._debug_stream_write_tries))
 *         print('Write contexts:            {: <8} | {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_ctx_cnt,
 *             self._debug_stream_write_ctx_total))
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Write_contexts_8, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1181
 *             self._debug_stream_write_tries))
 *         print('Write contexts:            {: <8} | {}'.format(
 *             self._debug_stream_write_ctx_cnt,             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_ctx_total))
 *         print('Write failed callbacks:    {}'.format(
 */
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_ctx_cnt); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/loop.pyx":1182
 *         print('Write contexts:            {: <8} | {}'.format(
 *             self._debug_stream_write_ctx_cnt,
 *             self._debug_stream_write_ctx_total))             # <<<<<<<<<<<<<<
 *         print('Write failed callbacks:    {}'.format(
 *             self._debug_stream_write_cb_errors_total))
 */
  __pyx_t_12 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_ctx_total); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_6, __pyx_t_12};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1180, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_6, __pyx_t_12};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1180, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  } else
  #endif
  {
    __pyx_t_2 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_7, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_12);
    PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_7, __pyx_t_12);
    __pyx_t_6 = 0;
    __pyx_t_12 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1180
 *         print('Write without poll:        {}'.format(
 *             self._debug_stream_write_tries))
 *         print('Write contexts:            {: <8} | {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_ctx_cnt,
 *             self._debug_stream_write_ctx_total))
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1183
 *             self._debug_stream_write_ctx_cnt,
 *             self._debug_stream_write_ctx_total))
 *         print('Write failed callbacks:    {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_cb_errors_total))
 *         print()
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Write_failed_callbacks, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1184
 *             self._debug_stream_write_ctx_total))
 *         print('Write failed callbacks:    {}'.format(
 *             self._debug_stream_write_cb_errors_total))             # <<<<<<<<<<<<<<
 *         print()
 *         print('Read errors:               {}'.format(
 */
  __pyx_t_2 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_cb_errors_total); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1184, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_12) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1183, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1183, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1183, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_12); __pyx_t_12 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1183, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1183
 *             self._debug_stream_write_ctx_cnt,
 *             self._debug_stream_write_ctx_total))
 *         print('Write failed callbacks:    {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_write_cb_errors_total))
 *         print()
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1185
 *         print('Write failed callbacks:    {}'.format(
 *             self._debug_stream_write_cb_errors_total))
 *         print()             # <<<<<<<<<<<<<<
 *         print('Read errors:               {}'.format(
 *             self._debug_stream_read_errors_total))
 */
  __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1186
 *             self._debug_stream_write_cb_errors_total))
 *         print()
 *         print('Read errors:               {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_errors_total))
 *         print('Read callbacks:            {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Read_errors, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1187
 *         print()
 *         print('Read errors:               {}'.format(
 *             self._debug_stream_read_errors_total))             # <<<<<<<<<<<<<<
 *         print('Read callbacks:            {}'.format(
 *             self._debug_stream_read_cb_total))
 */
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_errors_total); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1186, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1186, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1186, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1186
 *             self._debug_stream_write_cb_errors_total))
 *         print()
 *         print('Read errors:               {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_errors_total))
 *         print('Read callbacks:            {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1188
 *         print('Read errors:               {}'.format(
 *             self._debug_stream_read_errors_total))
 *         print('Read callbacks:            {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_cb_total))
 *         print('Read failed callbacks:     {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Read_callbacks, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1189
 *             self._debug_stream_read_errors_total))
 *         print('Read callbacks:            {}'.format(
 *             self._debug_stream_read_cb_total))             # <<<<<<<<<<<<<<
 *         print('Read failed callbacks:     {}'.format(
 *             self._debug_stream_read_cb_errors_total))
 */
  __pyx_t_12 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_cb_total); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1188, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1188, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1188, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_12);
      __pyx_t_12 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1188, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1188
 *         print('Read errors:               {}'.format(
 *             self._debug_stream_read_errors_total))
 *         print('Read callbacks:            {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_cb_total))
 *         print('Read failed callbacks:     {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1190
 *         print('Read callbacks:            {}'.format(
 *             self._debug_stream_read_cb_total))
 *         print('Read failed callbacks:     {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_cb_errors_total))
 *         print('Read EOFs:                 {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Read_failed_callbacks, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1191
 *             self._debug_stream_read_cb_total))
 *         print('Read failed callbacks:     {}'.format(
 *             self._debug_stream_read_cb_errors_total))             # <<<<<<<<<<<<<<
 *         print('Read EOFs:                 {}'.format(
 *             self._debug_stream_read_eof_total))
 */
  __pyx_t_2 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_cb_errors_total); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_12) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1190, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1190, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1190, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_12); __pyx_t_12 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1190, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1190
 *         print('Read callbacks:            {}'.format(
 *             self._debug_stream_read_cb_total))
 *         print('Read failed callbacks:     {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_cb_errors_total))
 *         print('Read EOFs:                 {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1192
 *         print('Read failed callbacks:     {}'.format(
 *             self._debug_stream_read_cb_errors_total))
 *         print('Read EOFs:                 {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_eof_total))
 *         print('Read EOF failed callbacks: {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Read_EOFs, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1193
 *             self._debug_stream_read_cb_errors_total))
 *         print('Read EOFs:                 {}'.format(
 *             self._debug_stream_read_eof_total))             # <<<<<<<<<<<<<<
 *         print('Read EOF failed callbacks: {}'.format(
 *             self._debug_stream_read_eof_cb_errors_total))
 */
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_eof_total); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1192, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1192, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1192, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1192, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1192
 *         print('Read failed callbacks:     {}'.format(
 *             self._debug_stream_read_cb_errors_total))
 *         print('Read EOFs:                 {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_eof_total))
 *         print('Read EOF failed callbacks: {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1194
 *         print('Read EOFs:                 {}'.format(
 *             self._debug_stream_read_eof_total))
 *         print('Read EOF failed callbacks: {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_eof_cb_errors_total))
 *         print()
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Read_EOF_failed_callbacks, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1195
 *             self._debug_stream_read_eof_total))
 *         print('Read EOF failed callbacks: {}'.format(
 *             self._debug_stream_read_eof_cb_errors_total))             # <<<<<<<<<<<<<<
 *         print()
 *         print('Listen errors:             {}'.format(
 */
  __pyx_t_12 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_eof_cb_errors_total); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1194, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1194, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1194, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1194, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_12);
      __pyx_t_12 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1194, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1194
 *         print('Read EOFs:                 {}'.format(
 *             self._debug_stream_read_eof_total))
 *         print('Read EOF failed callbacks: {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_read_eof_cb_errors_total))
 *         print()
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1196
 *         print('Read EOF failed callbacks: {}'.format(
 *             self._debug_stream_read_eof_cb_errors_total))
 *         print()             # <<<<<<<<<<<<<<
 *         print('Listen errors:             {}'.format(
 *             self._debug_stream_listen_errors_total))
 */
  __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1197
 *             self._debug_stream_read_eof_cb_errors_total))
 *         print()
 *         print('Listen errors:             {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_listen_errors_total))
 *         print('Shutdown errors            {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Listen_errors, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1198
 *         print()
 *         print('Listen errors:             {}'.format(
 *             self._debug_stream_listen_errors_total))             # <<<<<<<<<<<<<<
 *         print('Shutdown errors            {}'.format(
 *             self._debug_stream_shutdown_errors_total))
 */
  __pyx_t_2 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_listen_errors_total); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_12) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1197, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1197, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_12); __pyx_t_12 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1197
 *             self._debug_stream_read_eof_cb_errors_total))
 *         print()
 *         print('Listen errors:             {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_listen_errors_total))
 *         print('Shutdown errors            {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1199
 *         print('Listen errors:             {}'.format(
 *             self._debug_stream_listen_errors_total))
 *         print('Shutdown errors            {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_shutdown_errors_total))
 *         print()
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Shutdown_errors, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1200
 *             self._debug_stream_listen_errors_total))
 *         print('Shutdown errors            {}'.format(
 *             self._debug_stream_shutdown_errors_total))             # <<<<<<<<<<<<<<
 *         print()
 * 
 */
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_shutdown_errors_total); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1199, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1199, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1199, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1199, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1199
 *         print('Listen errors:             {}'.format(
 *             self._debug_stream_listen_errors_total))
 *         print('Shutdown errors            {}'.format(             # <<<<<<<<<<<<<<
 *             self._debug_stream_shutdown_errors_total))
 *         print()
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1201
 *         print('Shutdown errors            {}'.format(
 *             self._debug_stream_shutdown_errors_total))
 *         print()             # <<<<<<<<<<<<<<
 * 
 *         print('--- Polls debug info: ---')
 */
  __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1203
 *         print()
 * 
 *         print('--- Polls debug info: ---')             # <<<<<<<<<<<<<<
 *         print('Read events:               {}'.format(
 *             self._poll_read_events_total))
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1204
 * 
 *         print('--- Polls debug info: ---')
 *         print('Read events:               {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_read_events_total))
 *         print('Read callbacks failed:     {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Read_events, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1205
 *         print('--- Polls debug info: ---')
 *         print('Read events:               {}'.format(
 *             self._poll_read_events_total))             # <<<<<<<<<<<<<<
 *         print('Read callbacks failed:     {}'.format(
 *             self._poll_read_cb_errors_total))
 */
  __pyx_t_12 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_read_events_total); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1204, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1204, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1204, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_12);
      __pyx_t_12 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1204, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1204
 * 
 *         print('--- Polls debug info: ---')
 *         print('Read events:               {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_read_events_total))
 *         print('Read callbacks failed:     {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1204, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1206
 *         print('Read events:               {}'.format(
 *             self._poll_read_events_total))
 *         print('Read callbacks failed:     {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_read_cb_errors_total))
 *         print('Write events:              {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Read_callbacks_failed, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1207
 *             self._poll_read_events_total))
 *         print('Read callbacks failed:     {}'.format(
 *             self._poll_read_cb_errors_total))             # <<<<<<<<<<<<<<
 *         print('Write events:              {}'.format(
 *             self._poll_write_events_total))
 */
  __pyx_t_2 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_read_cb_errors_total); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_12) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1206, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1206, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1206, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_12); __pyx_t_12 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1206
 *         print('Read events:               {}'.format(
 *             self._poll_read_events_total))
 *         print('Read callbacks failed:     {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_read_cb_errors_total))
 *         print('Write events:              {}'.format(
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1208
 *         print('Read callbacks failed:     {}'.format(
 *             self._poll_read_cb_errors_total))
 *         print('Write events:              {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_write_events_total))
 *         print('Write callbacks failed:    {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Write_events, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1209
 *             self._poll_read_cb_errors_total))
 *         print('Write events:              {}'.format(
 *             self._poll_write_events_total))             # <<<<<<<<<<<<<<
 *         print('Write callbacks failed:    {}'.format(
 *             self._poll_write_cb_errors_total))
 */
  __pyx_t_6 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_write_events_total); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1208, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1208, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1208, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1208
 *         print('Read callbacks failed:     {}'.format(
 *             self._poll_read_cb_errors_total))
 *         print('Write events:              {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_write_events_total))
 *         print('Write callbacks failed:    {}'.format(
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1210
 *         print('Write events:              {}'.format(
 *             self._poll_write_events_total))
 *         print('Write callbacks failed:    {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_write_cb_errors_total))
 *         print()
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Write_callbacks_failed, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1211
 *             self._poll_write_events_total))
 *         print('Write callbacks failed:    {}'.format(
 *             self._poll_write_cb_errors_total))             # <<<<<<<<<<<<<<
 *         print()
 * 
 */
  __pyx_t_12 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_write_cb_errors_total); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 1211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1210, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1210, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_12};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1210, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_12);
      __pyx_t_12 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1210
 *         print('Write events:              {}'.format(
 *             self._poll_write_events_total))
 *         print('Write callbacks failed:    {}'.format(             # <<<<<<<<<<<<<<
 *             self._poll_write_cb_errors_total))
 *         print()
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1212
 *         print('Write callbacks failed:    {}'.format(
 *             self._poll_write_cb_errors_total))
 *         print()             # <<<<<<<<<<<<<<
 * 
 *         print('--- Sock ops successful on 1st try: ---')
 */
  __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_builtin_print); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1214
 *         print()
 * 
 *         print('--- Sock ops successful on 1st try: ---')             # <<<<<<<<<<<<<<
 *         print('Socket try-writes:         {}'.format(
 *             self._sock_try_write_total))
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1215
 * 
 *         print('--- Sock ops successful on 1st try: ---')
 *         print('Socket try-writes:         {}'.format(             # <<<<<<<<<<<<<<
 *             self._sock_try_write_total))
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Socket_try_writes, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/loop.pyx":1216
 *         print('--- Sock ops successful on 1st try: ---')
 *         print('Socket try-writes:         {}'.format(
 *             self._sock_try_write_total))             # <<<<<<<<<<<<<<
 * 
 *         print(flush=True)
 */
  __pyx_t_2 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_sock_try_write_total); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_12) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1215, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1215, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_2};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1215, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_12); __pyx_t_12 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1215, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1215
 * 
 *         print('--- Sock ops successful on 1st try: ---')
 *         print('Socket try-writes:         {}'.format(             # <<<<<<<<<<<<<<
 *             self._sock_try_write_total))
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1218
 *             self._sock_try_write_total))
 * 
 *         print(flush=True)             # <<<<<<<<<<<<<<
 * 
 *     property print_debug_info:
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_flush, Py_True) < 0) __PYX_ERR(2, 1218, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":1126
 *         return uv.uv_backend_fd(self.uvloop)
 * 
 *     cdef _print_debug_info(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int err
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.Loop._print_debug_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1221
 * 
 *     property print_debug_info:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 return lambda: self._print_debug_info()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_16print_debug_info_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_16print_debug_info_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_16print_debug_info___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1223
 *         def __get__(self):
 *             if UVLOOP_DEBUG:
 *                 return lambda: self._print_debug_info()             # <<<<<<<<<<<<<<
 *             else:
 *                 raise AttributeError('print_debug_info')
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_16print_debug_info_7__get___lambda1(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6uvloop_4loop_4Loop_16print_debug_info_7__get___lambda1 = {"lambda1", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_16print_debug_info_7__get___lambda1, METH_NOARGS, 0};
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_16print_debug_info_7__get___lambda1(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda1 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda1(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda1(PyObject *__pyx_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *__pyx_cur_scope;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("lambda1", 0);
  __pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(2, 1223, __pyx_L1_error) }
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_print_debug_info(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.print_debug_info.__get__.lambda1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1221
 * 
 *     property print_debug_info:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 return lambda: self._print_debug_info()
 */

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_16print_debug_info___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_3___get__(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_3___get__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1221, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);

  /* "uvloop/loop.pyx":1222
 *     property print_debug_info:
 *         def __get__(self):
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 return lambda: self._print_debug_info()
 *             else:
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (likely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":1223
 *         def __get__(self):
 *             if UVLOOP_DEBUG:
 *                 return lambda: self._print_debug_info()             # <<<<<<<<<<<<<<
 *             else:
 *                 raise AttributeError('print_debug_info')
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_4Loop_16print_debug_info_7__get___lambda1, 0, __pyx_n_s_Loop___get___locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_uvloop_loop, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1222
 *     property print_debug_info:
 *         def __get__(self):
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 return lambda: self._print_debug_info()
 *             else:
 */
  }

  /* "uvloop/loop.pyx":1225
 *                 return lambda: self._print_debug_info()
 *             else:
 *                 raise AttributeError('print_debug_info')             # <<<<<<<<<<<<<<
 * 
 *     # Public API
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_AttributeError, __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1225, __pyx_L1_error)
  }

  /* "uvloop/loop.pyx":1221
 * 
 *     property print_debug_info:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 return lambda: self._print_debug_info()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop.print_debug_info.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1229
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<{}.{} running={} closed={} debug={}>'.format(
 *                     self.__class__.__module__,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_11__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_11__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_10__repr__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_10__repr__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/loop.pyx":1230
 * 
 *     def __repr__(self):
 *         return '<{}.{} running={} closed={} debug={}>'.format(             # <<<<<<<<<<<<<<
 *                     self.__class__.__module__,
 *                     self.__class__.__name__,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_running_closed_debug, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/loop.pyx":1231
 *     def __repr__(self):
 *         return '<{}.{} running={} closed={} debug={}>'.format(
 *                     self.__class__.__module__,             # <<<<<<<<<<<<<<
 *                     self.__class__.__name__,
 *                     self.is_running(),
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_module); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1232
 *         return '<{}.{} running={} closed={} debug={}>'.format(
 *                     self.__class__.__module__,
 *                     self.__class__.__name__,             # <<<<<<<<<<<<<<
 *                     self.is_running(),
 *                     self.is_closed(),
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1233
 *                     self.__class__.__module__,
 *                     self.__class__.__name__,
 *                     self.is_running(),             # <<<<<<<<<<<<<<
 *                     self.is_closed(),
 *                     self.get_debug())
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_running); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_7) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1233, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1233, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/loop.pyx":1234
 *                     self.__class__.__name__,
 *                     self.is_running(),
 *                     self.is_closed(),             # <<<<<<<<<<<<<<
 *                     self.get_debug())
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_closed); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (__pyx_t_8) {
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1234, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  } else {
    __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1234, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":1235
 *                     self.is_running(),
 *                     self.is_closed(),
 *                     self.get_debug())             # <<<<<<<<<<<<<<
 * 
 *     def call_soon(self, callback, *args, context=None):
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_debug); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1235, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1235, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_10 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_10 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[6] = {__pyx_t_8, __pyx_t_4, __pyx_t_5, __pyx_t_3, __pyx_t_6, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 5+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1230, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[6] = {__pyx_t_8, __pyx_t_4, __pyx_t_5, __pyx_t_3, __pyx_t_6, __pyx_t_7};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 5+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1230, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(5+__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_10, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_10, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_10, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_10, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_9, 4+__pyx_t_10, __pyx_t_7);
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_3 = 0;
    __pyx_t_6 = 0;
    __pyx_t_7 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1229
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<{}.{} running={} closed={} debug={}>'.format(
 *                     self.__class__.__module__,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.Loop.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1237
 *                     self.get_debug())
 * 
 *     def call_soon(self, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Arrange for a callback to be called as soon as possible.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_13call_soon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_12call_soon[] = "Loop.call_soon(self, callback, *args, context=None)\nArrange for a callback to be called as soon as possible.\n\n        This operates as a FIFO queue: callbacks are called in the\n        order in which they are registered.  Each callback will be\n        called exactly once.\n\n        Any positional arguments after the callback will be passed to\n        the callback when it is called.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_13call_soon(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_context = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_soon (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_callback,&__pyx_n_s_context,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (kw_args == 1) {
        const Py_ssize_t index = 1;
        PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
        if (value) { values[index] = value; kw_args--; }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_soon") < 0)) __PYX_ERR(2, 1237, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_callback = values[0];
    __pyx_v_context = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_soon", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1237, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.call_soon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_12call_soon(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_callback, __pyx_v_context, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_12call_soon(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("call_soon", 0);

  /* "uvloop/loop.pyx":1247
 *         the callback when it is called.
 *         """
 *         if self._debug == 1:             # <<<<<<<<<<<<<<
 *             self._check_thread()
 *         if args:
 */
  __pyx_t_1 = ((__pyx_v_self->_debug == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1248
 *         """
 *         if self._debug == 1:
 *             self._check_thread()             # <<<<<<<<<<<<<<
 *         if args:
 *             return self._call_soon(callback, args, context)
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__check_thread(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":1247
 *         the callback when it is called.
 *         """
 *         if self._debug == 1:             # <<<<<<<<<<<<<<
 *             self._check_thread()
 *         if args:
 */
  }

  /* "uvloop/loop.pyx":1249
 *         if self._debug == 1:
 *             self._check_thread()
 *         if args:             # <<<<<<<<<<<<<<
 *             return self._call_soon(callback, args, context)
 *         else:
 */
  __pyx_t_1 = (PyTuple_GET_SIZE(__pyx_v_args) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1250
 *             self._check_thread()
 *         if args:
 *             return self._call_soon(callback, args, context)             # <<<<<<<<<<<<<<
 *         else:
 *             return self._call_soon(callback, None, context)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__call_soon(__pyx_v_self, __pyx_v_callback, __pyx_v_args, __pyx_v_context); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1249
 *         if self._debug == 1:
 *             self._check_thread()
 *         if args:             # <<<<<<<<<<<<<<
 *             return self._call_soon(callback, args, context)
 *         else:
 */
  }

  /* "uvloop/loop.pyx":1252
 *             return self._call_soon(callback, args, context)
 *         else:
 *             return self._call_soon(callback, None, context)             # <<<<<<<<<<<<<<
 * 
 *     def call_soon_threadsafe(self, callback, *args, context=None):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__call_soon(__pyx_v_self, __pyx_v_callback, Py_None, __pyx_v_context); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "uvloop/loop.pyx":1237
 *                     self.get_debug())
 * 
 *     def call_soon(self, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Arrange for a callback to be called as soon as possible.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop.call_soon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1254
 *             return self._call_soon(callback, None, context)
 * 
 *     def call_soon_threadsafe(self, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Like call_soon(), but thread-safe."""
 *         if not args:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_15call_soon_threadsafe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_14call_soon_threadsafe[] = "Loop.call_soon_threadsafe(self, callback, *args, context=None)\nLike call_soon(), but thread-safe.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_15call_soon_threadsafe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_context = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_soon_threadsafe (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_callback,&__pyx_n_s_context,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (kw_args == 1) {
        const Py_ssize_t index = 1;
        PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
        if (value) { values[index] = value; kw_args--; }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_soon_threadsafe") < 0)) __PYX_ERR(2, 1254, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_callback = values[0];
    __pyx_v_context = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_soon_threadsafe", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1254, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.call_soon_threadsafe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_14call_soon_threadsafe(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_callback, __pyx_v_context, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_14call_soon_threadsafe(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args) {
  PyObject *__pyx_v_handle = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("call_soon_threadsafe", 0);
  __Pyx_INCREF(__pyx_v_args);

  /* "uvloop/loop.pyx":1256
 *     def call_soon_threadsafe(self, callback, *args, context=None):
 *         """Like call_soon(), but thread-safe."""
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = None
 *         handle = self._call_soon(callback, args, context)
 */
  __pyx_t_1 = (PyTuple_GET_SIZE(__pyx_v_args) != 0);
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1257
 *         """Like call_soon(), but thread-safe."""
 *         if not args:
 *             args = None             # <<<<<<<<<<<<<<
 *         handle = self._call_soon(callback, args, context)
 *         self.handler_async.send()
 */
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)Py_None));

    /* "uvloop/loop.pyx":1256
 *     def call_soon_threadsafe(self, callback, *args, context=None):
 *         """Like call_soon(), but thread-safe."""
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = None
 *         handle = self._call_soon(callback, args, context)
 */
  }

  /* "uvloop/loop.pyx":1258
 *         if not args:
 *             args = None
 *         handle = self._call_soon(callback, args, context)             # <<<<<<<<<<<<<<
 *         self.handler_async.send()
 *         return handle
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_4Loop__call_soon(__pyx_v_self, __pyx_v_callback, __pyx_v_args, __pyx_v_context); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_handle = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1259
 *             args = None
 *         handle = self._call_soon(callback, args, context)
 *         self.handler_async.send()             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->handler_async->__pyx_base.__pyx_vtab)->send(__pyx_v_self->handler_async); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1260
 *         handle = self._call_soon(callback, args, context)
 *         self.handler_async.send()
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     def call_later(self, delay, callback, *args, context=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_handle);
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1254
 *             return self._call_soon(callback, None, context)
 * 
 *     def call_soon_threadsafe(self, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Like call_soon(), but thread-safe."""
 *         if not args:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.Loop.call_soon_threadsafe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1262
 *         return handle
 * 
 *     def call_later(self, delay, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Arrange for a callback to be called at a given time.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_17call_later(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_16call_later[] = "Loop.call_later(self, delay, callback, *args, context=None)\nArrange for a callback to be called at a given time.\n\n        Return a Handle: an opaque object with a cancel() method that\n        can be used to cancel the call.\n\n        The delay can be an int or float, expressed in seconds.  It is\n        always relative to the current time.\n\n        Each callback will be called exactly once.  If two callbacks\n        are scheduled for exactly the same time, it undefined which\n        will be called first.\n\n        Any positional arguments after the callback will be passed to\n        the callback when it is called.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_17call_later(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_delay = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_context = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_later (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_delay,&__pyx_n_s_callback,&__pyx_n_s_context,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_delay)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("call_later", 0, 2, 2, 1); __PYX_ERR(2, 1262, __pyx_L3_error)
        }
      }
      if (kw_args == 1) {
        const Py_ssize_t index = 2;
        PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
        if (value) { values[index] = value; kw_args--; }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_later") < 0)) __PYX_ERR(2, 1262, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_delay = values[0];
    __pyx_v_callback = values[1];
    __pyx_v_context = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_later", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1262, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.call_later", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_16call_later(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_delay, __pyx_v_callback, __pyx_v_context, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_16call_later(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_delay, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args) {
  uint64_t __pyx_v_when;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  uint64_t __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("call_later", 0);
  __Pyx_INCREF(__pyx_v_delay);
  __Pyx_INCREF(__pyx_v_args);

  /* "uvloop/loop.pyx":1280
 *         cdef uint64_t when
 * 
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         if self._debug == 1:
 *             self._check_thread()
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1281
 * 
 *         self._check_closed()
 *         if self._debug == 1:             # <<<<<<<<<<<<<<
 *             self._check_thread()
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->_debug == 1) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1282
 *         self._check_closed()
 *         if self._debug == 1:
 *             self._check_thread()             # <<<<<<<<<<<<<<
 * 
 *         if delay < 0:
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_thread(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1281
 * 
 *         self._check_closed()
 *         if self._debug == 1:             # <<<<<<<<<<<<<<
 *             self._check_thread()
 * 
 */
  }

  /* "uvloop/loop.pyx":1284
 *             self._check_thread()
 * 
 *         if delay < 0:             # <<<<<<<<<<<<<<
 *             delay = 0
 *         elif delay == py_inf:
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_delay, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1284, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1285
 * 
 *         if delay < 0:
 *             delay = 0             # <<<<<<<<<<<<<<
 *         elif delay == py_inf:
 *             # ~100 years sounds like a good approximation of
 */
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_DECREF_SET(__pyx_v_delay, __pyx_int_0);

    /* "uvloop/loop.pyx":1284
 *             self._check_thread()
 * 
 *         if delay < 0:             # <<<<<<<<<<<<<<
 *             delay = 0
 *         elif delay == py_inf:
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":1286
 *         if delay < 0:
 *             delay = 0
 *         elif delay == py_inf:             # <<<<<<<<<<<<<<
 *             # ~100 years sounds like a good approximation of
 *             # infinity for a Python application.
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_delay, __pyx_v_6uvloop_4loop_py_inf, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1286, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1286, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1289
 *             # ~100 years sounds like a good approximation of
 *             # infinity for a Python application.
 *             delay = 3600 * 24 * 365 * 100             # <<<<<<<<<<<<<<
 * 
 *         when = <uint64_t>(delay * 1000)
 */
    __Pyx_INCREF(__pyx_int_3153600000);
    __Pyx_DECREF_SET(__pyx_v_delay, __pyx_int_3153600000);

    /* "uvloop/loop.pyx":1286
 *         if delay < 0:
 *             delay = 0
 *         elif delay == py_inf:             # <<<<<<<<<<<<<<
 *             # ~100 years sounds like a good approximation of
 *             # infinity for a Python application.
 */
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":1291
 *             delay = 3600 * 24 * 365 * 100
 * 
 *         when = <uint64_t>(delay * 1000)             # <<<<<<<<<<<<<<
 *         if not args:
 *             args = None
 */
  __pyx_t_1 = PyNumber_Multiply(__pyx_v_delay, __pyx_int_1000); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_As_uint64_t(__pyx_t_1); if (unlikely((__pyx_t_3 == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_when = ((uint64_t)__pyx_t_3);

  /* "uvloop/loop.pyx":1292
 * 
 *         when = <uint64_t>(delay * 1000)
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = None
 *         if when == 0:
 */
  __pyx_t_2 = (PyTuple_GET_SIZE(__pyx_v_args) != 0);
  __pyx_t_4 = ((!__pyx_t_2) != 0);
  if (__pyx_t_4) {

    /* "uvloop/loop.pyx":1293
 *         when = <uint64_t>(delay * 1000)
 *         if not args:
 *             args = None             # <<<<<<<<<<<<<<
 *         if when == 0:
 *             return self._call_soon(callback, args, context)
 */
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)Py_None));

    /* "uvloop/loop.pyx":1292
 * 
 *         when = <uint64_t>(delay * 1000)
 *         if not args:             # <<<<<<<<<<<<<<
 *             args = None
 *         if when == 0:
 */
  }

  /* "uvloop/loop.pyx":1294
 *         if not args:
 *             args = None
 *         if when == 0:             # <<<<<<<<<<<<<<
 *             return self._call_soon(callback, args, context)
 *         else:
 */
  __pyx_t_4 = ((__pyx_v_when == 0) != 0);
  if (__pyx_t_4) {

    /* "uvloop/loop.pyx":1295
 *             args = None
 *         if when == 0:
 *             return self._call_soon(callback, args, context)             # <<<<<<<<<<<<<<
 *         else:
 *             return self._call_later(when, callback, args, context)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__call_soon(__pyx_v_self, __pyx_v_callback, __pyx_v_args, __pyx_v_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1294
 *         if not args:
 *             args = None
 *         if when == 0:             # <<<<<<<<<<<<<<
 *             return self._call_soon(callback, args, context)
 *         else:
 */
  }

  /* "uvloop/loop.pyx":1297
 *             return self._call_soon(callback, args, context)
 *         else:
 *             return self._call_later(when, callback, args, context)             # <<<<<<<<<<<<<<
 * 
 *     def call_at(self, when, callback, *args, context=None):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_call_later(__pyx_v_self, __pyx_v_when, __pyx_v_callback, __pyx_v_args, __pyx_v_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "uvloop/loop.pyx":1262
 *         return handle
 * 
 *     def call_later(self, delay, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Arrange for a callback to be called at a given time.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.call_later", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_delay);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1299
 *             return self._call_later(when, callback, args, context)
 * 
 *     def call_at(self, when, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Like call_later(), but uses an absolute time.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_19call_at(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_18call_at[] = "Loop.call_at(self, when, callback, *args, context=None)\nLike call_later(), but uses an absolute time.\n\n        Absolute time corresponds to the event loop's time() method.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_19call_at(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_when = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_context = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_at (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_when,&__pyx_n_s_callback,&__pyx_n_s_context,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_when)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("call_at", 0, 2, 2, 1); __PYX_ERR(2, 1299, __pyx_L3_error)
        }
      }
      if (kw_args == 1) {
        const Py_ssize_t index = 2;
        PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
        if (value) { values[index] = value; kw_args--; }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "call_at") < 0)) __PYX_ERR(2, 1299, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_when = values[0];
    __pyx_v_callback = values[1];
    __pyx_v_context = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_at", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1299, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.call_at", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_18call_at(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_when, __pyx_v_callback, __pyx_v_context, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_18call_at(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_when, PyObject *__pyx_v_callback, PyObject *__pyx_v_context, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("call_at", 0);

  /* "uvloop/loop.pyx":1304
 *         Absolute time corresponds to the event loop's time() method.
 *         """
 *         return self.call_later(             # <<<<<<<<<<<<<<
 *             when - self.time(), callback, *args, context=context)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_call_later); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/loop.pyx":1305
 *         """
 *         return self.call_later(
 *             when - self.time(), callback, *args, context=context)             # <<<<<<<<<<<<<<
 * 
 *     def time(self):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1305, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1305, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Subtract(__pyx_v_when, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1304
 *         Absolute time corresponds to the event loop's time() method.
 *         """
 *         return self.call_later(             # <<<<<<<<<<<<<<
 *             when - self.time(), callback, *args, context=context)
 * 
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_callback);
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":1305
 *         """
 *         return self.call_later(
 *             when - self.time(), callback, *args, context=context)             # <<<<<<<<<<<<<<
 * 
 *     def time(self):
 */
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_context, __pyx_v_context) < 0) __PYX_ERR(2, 1305, __pyx_L1_error)

  /* "uvloop/loop.pyx":1304
 *         Absolute time corresponds to the event loop's time() method.
 *         """
 *         return self.call_later(             # <<<<<<<<<<<<<<
 *             when - self.time(), callback, *args, context=context)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1299
 *             return self._call_later(when, callback, args, context)
 * 
 *     def call_at(self, when, callback, *args, context=None):             # <<<<<<<<<<<<<<
 *         """Like call_later(), but uses an absolute time.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop.call_at", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1307
 *             when - self.time(), callback, *args, context=context)
 * 
 *     def time(self):             # <<<<<<<<<<<<<<
 *         """Return the time according to the event loop's clock.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_21time(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_20time[] = "Loop.time(self)\nReturn the time according to the event loop's clock.\n\n        This is a float expressed in seconds since an epoch, but the\n        epoch, precision, accuracy and drift are unspecified and may\n        differ per event loop.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_21time(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("time (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_20time(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_20time(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("time", 0);

  /* "uvloop/loop.pyx":1314
 *         differ per event loop.
 *         """
 *         return self._time() / 1000             # <<<<<<<<<<<<<<
 * 
 *     def stop(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble((((double)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_time(__pyx_v_self)) / 1000.0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1307
 *             when - self.time(), callback, *args, context=context)
 * 
 *     def time(self):             # <<<<<<<<<<<<<<
 *         """Return the time according to the event loop's clock.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.time", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1316
 *         return self._time() / 1000
 * 
 *     def stop(self):             # <<<<<<<<<<<<<<
 *         """Stop running the event loop.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23stop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_22stop[] = "Loop.stop(self)\nStop running the event loop.\n\n        Every callback already scheduled will still run.  This simply informs\n        run_forever to stop looping after a complete iteration.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23stop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stop (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_22stop(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_22stop(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("stop", 0);

  /* "uvloop/loop.pyx":1323
 *         """
 *         self._call_soon_handle(
 *             new_MethodHandle1(             # <<<<<<<<<<<<<<
 *                 self,
 *                 "Loop._stop",
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_new_MethodHandle1(__pyx_v_self, __pyx_kp_u_Loop__stop, ((__pyx_t_6uvloop_4loop_method1_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_stop), ((PyObject *)__pyx_v_self), Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 1323, __pyx_L1_error)

  /* "uvloop/loop.pyx":1322
 *         run_forever to stop looping after a complete iteration.
 *         """
 *         self._call_soon_handle(             # <<<<<<<<<<<<<<
 *             new_MethodHandle1(
 *                 self,
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__call_soon_handle(__pyx_v_self, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1316
 *         return self._time() / 1000
 * 
 *     def stop(self):             # <<<<<<<<<<<<<<
 *         """Stop running the event loop.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop.stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1330
 *                 None))
 * 
 *     def run_forever(self):             # <<<<<<<<<<<<<<
 *         """Run the event loop until stop() is called."""
 *         self._check_closed()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_25run_forever(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_24run_forever[] = "Loop.run_forever(self)\nRun the event loop until stop() is called.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_25run_forever(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("run_forever (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_24run_forever(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_24run_forever(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  uv_run_mode __pyx_v_mode;
  PyObject *__pyx_v_old_agen_hooks = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("run_forever", 0);

  /* "uvloop/loop.pyx":1332
 *     def run_forever(self):
 *         """Run the event loop until stop() is called."""
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         mode = uv.UV_RUN_DEFAULT
 *         if self._stopping:
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1332, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1333
 *         """Run the event loop until stop() is called."""
 *         self._check_closed()
 *         mode = uv.UV_RUN_DEFAULT             # <<<<<<<<<<<<<<
 *         if self._stopping:
 *             # loop.stop() was called right before loop.run_forever().
 */
  __pyx_v_mode = UV_RUN_DEFAULT;

  /* "uvloop/loop.pyx":1334
 *         self._check_closed()
 *         mode = uv.UV_RUN_DEFAULT
 *         if self._stopping:             # <<<<<<<<<<<<<<
 *             # loop.stop() was called right before loop.run_forever().
 *             # This is how asyncio loop behaves.
 */
  __pyx_t_2 = (__pyx_v_self->_stopping != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1337
 *             # loop.stop() was called right before loop.run_forever().
 *             # This is how asyncio loop behaves.
 *             mode = uv.UV_RUN_NOWAIT             # <<<<<<<<<<<<<<
 *         self._set_coroutine_debug(self._debug)
 *         if self._asyncgens is not None:
 */
    __pyx_v_mode = UV_RUN_NOWAIT;

    /* "uvloop/loop.pyx":1334
 *         self._check_closed()
 *         mode = uv.UV_RUN_DEFAULT
 *         if self._stopping:             # <<<<<<<<<<<<<<
 *             # loop.stop() was called right before loop.run_forever().
 *             # This is how asyncio loop behaves.
 */
  }

  /* "uvloop/loop.pyx":1338
 *             # This is how asyncio loop behaves.
 *             mode = uv.UV_RUN_NOWAIT
 *         self._set_coroutine_debug(self._debug)             # <<<<<<<<<<<<<<
 *         if self._asyncgens is not None:
 *             old_agen_hooks = sys.get_asyncgen_hooks()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_set_coroutine_debug(__pyx_v_self, __pyx_v_self->_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1339
 *             mode = uv.UV_RUN_NOWAIT
 *         self._set_coroutine_debug(self._debug)
 *         if self._asyncgens is not None:             # <<<<<<<<<<<<<<
 *             old_agen_hooks = sys.get_asyncgen_hooks()
 *             sys.set_asyncgen_hooks(firstiter=self._asyncgen_firstiter_hook,
 */
  __pyx_t_2 = (__pyx_v_self->_asyncgens != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":1340
 *         self._set_coroutine_debug(self._debug)
 *         if self._asyncgens is not None:
 *             old_agen_hooks = sys.get_asyncgen_hooks()             # <<<<<<<<<<<<<<
 *             sys.set_asyncgen_hooks(firstiter=self._asyncgen_firstiter_hook,
 *                                    finalizer=self._asyncgen_finalizer_hook)
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get_asyncgen_hooks); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1340, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1340, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_old_agen_hooks = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1341
 *         if self._asyncgens is not None:
 *             old_agen_hooks = sys.get_asyncgen_hooks()
 *             sys.set_asyncgen_hooks(firstiter=self._asyncgen_firstiter_hook,             # <<<<<<<<<<<<<<
 *                                    finalizer=self._asyncgen_finalizer_hook)
 *         try:
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_set_asyncgen_hooks); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_asyncgen_firstiter_hook); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_firstiter, __pyx_t_4) < 0) __PYX_ERR(2, 1341, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":1342
 *             old_agen_hooks = sys.get_asyncgen_hooks()
 *             sys.set_asyncgen_hooks(firstiter=self._asyncgen_firstiter_hook,
 *                                    finalizer=self._asyncgen_finalizer_hook)             # <<<<<<<<<<<<<<
 *         try:
 *             self._run(mode)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_asyncgen_finalizer_hook); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1342, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_finalizer, __pyx_t_4) < 0) __PYX_ERR(2, 1341, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":1341
 *         if self._asyncgens is not None:
 *             old_agen_hooks = sys.get_asyncgen_hooks()
 *             sys.set_asyncgen_hooks(firstiter=self._asyncgen_firstiter_hook,             # <<<<<<<<<<<<<<
 *                                    finalizer=self._asyncgen_finalizer_hook)
 *         try:
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1341, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":1339
 *             mode = uv.UV_RUN_NOWAIT
 *         self._set_coroutine_debug(self._debug)
 *         if self._asyncgens is not None:             # <<<<<<<<<<<<<<
 *             old_agen_hooks = sys.get_asyncgen_hooks()
 *             sys.set_asyncgen_hooks(firstiter=self._asyncgen_firstiter_hook,
 */
  }

  /* "uvloop/loop.pyx":1343
 *             sys.set_asyncgen_hooks(firstiter=self._asyncgen_firstiter_hook,
 *                                    finalizer=self._asyncgen_finalizer_hook)
 *         try:             # <<<<<<<<<<<<<<
 *             self._run(mode)
 *         finally:
 */
  /*try:*/ {

    /* "uvloop/loop.pyx":1344
 *                                    finalizer=self._asyncgen_finalizer_hook)
 *         try:
 *             self._run(mode)             # <<<<<<<<<<<<<<
 *         finally:
 *             self._set_coroutine_debug(False)
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_run(__pyx_v_self, __pyx_v_mode); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1344, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "uvloop/loop.pyx":1346
 *             self._run(mode)
 *         finally:
 *             self._set_coroutine_debug(False)             # <<<<<<<<<<<<<<
 *             if self._asyncgens is not None:
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_set_coroutine_debug(__pyx_v_self, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1346, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1347
 *         finally:
 *             self._set_coroutine_debug(False)
 *             if self._asyncgens is not None:             # <<<<<<<<<<<<<<
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 * 
 */
      __pyx_t_3 = (__pyx_v_self->_asyncgens != Py_None);
      __pyx_t_2 = (__pyx_t_3 != 0);
      if (__pyx_t_2) {

        /* "uvloop/loop.pyx":1348
 *             self._set_coroutine_debug(False)
 *             if self._asyncgens is not None:
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1348, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_asyncgen_hooks); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1348, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_v_old_agen_hooks)) { __Pyx_RaiseUnboundLocalError("old_agen_hooks"); __PYX_ERR(2, 1348, __pyx_L1_error) }
        __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_v_old_agen_hooks); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1348, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1348, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "uvloop/loop.pyx":1347
 *         finally:
 *             self._set_coroutine_debug(False)
 *             if self._asyncgens is not None:             # <<<<<<<<<<<<<<
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 * 
 */
      }
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {

        /* "uvloop/loop.pyx":1346
 *             self._run(mode)
 *         finally:
 *             self._set_coroutine_debug(False)             # <<<<<<<<<<<<<<
 *             if self._asyncgens is not None:
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 */
        __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_set_coroutine_debug(__pyx_v_self, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1346, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "uvloop/loop.pyx":1347
 *         finally:
 *             self._set_coroutine_debug(False)
 *             if self._asyncgens is not None:             # <<<<<<<<<<<<<<
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 * 
 */
        __pyx_t_2 = (__pyx_v_self->_asyncgens != Py_None);
        __pyx_t_3 = (__pyx_t_2 != 0);
        if (__pyx_t_3) {

          /* "uvloop/loop.pyx":1348
 *             self._set_coroutine_debug(False)
 *             if self._asyncgens is not None:
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
          __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1348, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_set_asyncgen_hooks); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1348, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_v_old_agen_hooks)) { __Pyx_RaiseUnboundLocalError("old_agen_hooks"); __PYX_ERR(2, 1348, __pyx_L10_error) }
          __pyx_t_5 = __Pyx_PySequence_Tuple(__pyx_v_old_agen_hooks); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1348, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1348, __pyx_L10_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "uvloop/loop.pyx":1347
 *         finally:
 *             self._set_coroutine_debug(False)
 *             if self._asyncgens is not None:             # <<<<<<<<<<<<<<
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 * 
 */
        }
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
      __pyx_L10_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "uvloop/loop.pyx":1330
 *                 None))
 * 
 *     def run_forever(self):             # <<<<<<<<<<<<<<
 *         """Run the event loop until stop() is called."""
 *         self._check_closed()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.Loop.run_forever", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_old_agen_hooks);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1350
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         """Close the event loop.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_26close[] = "Loop.close(self)\nClose the event loop.\n\n        The event loop must not be running.\n\n        This is idempotent and irreversible.\n\n        No other methods should be called after this one.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_26close(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_26close(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("close", 0);

  /* "uvloop/loop.pyx":1359
 *         No other methods should be called after this one.
 *         """
 *         self._close()             # <<<<<<<<<<<<<<
 * 
 *     def get_debug(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_close(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1350
 *                 sys.set_asyncgen_hooks(*old_agen_hooks)
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         """Close the event loop.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1361
 *         self._close()
 * 
 *     def get_debug(self):             # <<<<<<<<<<<<<<
 *         return bool(self._debug)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29get_debug(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_28get_debug[] = "Loop.get_debug(self)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29get_debug(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_debug (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_28get_debug(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_28get_debug(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_debug", 0);

  /* "uvloop/loop.pyx":1362
 * 
 *     def get_debug(self):
 *         return bool(self._debug)             # <<<<<<<<<<<<<<
 * 
 *     def set_debug(self, enabled):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->_debug;
  __pyx_t_2 = __Pyx_PyBool_FromLong((!(!__pyx_t_1))); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1362, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1361
 *         self._close()
 * 
 *     def get_debug(self):             # <<<<<<<<<<<<<<
 *         return bool(self._debug)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop.get_debug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1364
 *         return bool(self._debug)
 * 
 *     def set_debug(self, enabled):             # <<<<<<<<<<<<<<
 *         self._debug = bool(enabled)
 *         if self.is_running():
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_31set_debug(PyObject *__pyx_v_self, PyObject *__pyx_v_enabled); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_30set_debug[] = "Loop.set_debug(self, enabled)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_31set_debug(PyObject *__pyx_v_self, PyObject *__pyx_v_enabled) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_debug (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_30set_debug(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_enabled));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_30set_debug(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_enabled) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("set_debug", 0);

  /* "uvloop/loop.pyx":1365
 * 
 *     def set_debug(self, enabled):
 *         self._debug = bool(enabled)             # <<<<<<<<<<<<<<
 *         if self.is_running():
 *             self.call_soon_threadsafe(self._set_coroutine_debug, self, self._debug)
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_enabled); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1365, __pyx_L1_error)
  __pyx_v_self->_debug = (!(!__pyx_t_1));

  /* "uvloop/loop.pyx":1366
 *     def set_debug(self, enabled):
 *         self._debug = bool(enabled)
 *         if self.is_running():             # <<<<<<<<<<<<<<
 *             self.call_soon_threadsafe(self._set_coroutine_debug, self, self._debug)
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_running); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1366, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1366, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1366, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1367
 *         self._debug = bool(enabled)
 *         if self.is_running():
 *             self.call_soon_threadsafe(self._set_coroutine_debug, self, self._debug)             # <<<<<<<<<<<<<<
 * 
 *     def is_running(self):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_call_soon_threadsafe); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_CFunc_object____Loop____bint___to_py(((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_set_coroutine_debug); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_self->_debug); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1367, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, ((PyObject *)__pyx_v_self), __pyx_t_5};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1367, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, ((PyObject *)__pyx_v_self), __pyx_t_5};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1367, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_4);
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, ((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_t_5);
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1367, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":1366
 *     def set_debug(self, enabled):
 *         self._debug = bool(enabled)
 *         if self.is_running():             # <<<<<<<<<<<<<<
 *             self.call_soon_threadsafe(self._set_coroutine_debug, self, self._debug)
 * 
 */
  }

  /* "uvloop/loop.pyx":1364
 *         return bool(self._debug)
 * 
 *     def set_debug(self, enabled):             # <<<<<<<<<<<<<<
 *         self._debug = bool(enabled)
 *         if self.is_running():
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.Loop.set_debug", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1369
 *             self.call_soon_threadsafe(self._set_coroutine_debug, self, self._debug)
 * 
 *     def is_running(self):             # <<<<<<<<<<<<<<
 *         """Return whether the event loop is currently running."""
 *         return bool(self._running)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_33is_running(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_32is_running[] = "Loop.is_running(self)\nReturn whether the event loop is currently running.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_33is_running(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_running (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_32is_running(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_32is_running(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("is_running", 0);

  /* "uvloop/loop.pyx":1371
 *     def is_running(self):
 *         """Return whether the event loop is currently running."""
 *         return bool(self._running)             # <<<<<<<<<<<<<<
 * 
 *     def is_closed(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->_running;
  __pyx_t_2 = __Pyx_PyBool_FromLong((!(!__pyx_t_1))); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1369
 *             self.call_soon_threadsafe(self._set_coroutine_debug, self, self._debug)
 * 
 *     def is_running(self):             # <<<<<<<<<<<<<<
 *         """Return whether the event loop is currently running."""
 *         return bool(self._running)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop.is_running", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1373
 *         return bool(self._running)
 * 
 *     def is_closed(self):             # <<<<<<<<<<<<<<
 *         """Returns True if the event loop was closed."""
 *         return bool(self._closed)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_35is_closed(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_34is_closed[] = "Loop.is_closed(self)\nReturns True if the event loop was closed.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_35is_closed(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_closed (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_34is_closed(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_34is_closed(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("is_closed", 0);

  /* "uvloop/loop.pyx":1375
 *     def is_closed(self):
 *         """Returns True if the event loop was closed."""
 *         return bool(self._closed)             # <<<<<<<<<<<<<<
 * 
 *     def create_future(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_v_self->_closed;
  __pyx_t_2 = __Pyx_PyBool_FromLong((!(!__pyx_t_1))); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1373
 *         return bool(self._running)
 * 
 *     def is_closed(self):             # <<<<<<<<<<<<<<
 *         """Returns True if the event loop was closed."""
 *         return bool(self._closed)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Loop.is_closed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1377
 *         return bool(self._closed)
 * 
 *     def create_future(self):             # <<<<<<<<<<<<<<
 *         """Create a Future object attached to the loop."""
 *         return self._new_future()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_37create_future(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_36create_future[] = "Loop.create_future(self)\nCreate a Future object attached to the loop.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_37create_future(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_future (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_36create_future(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_36create_future(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("create_future", 0);

  /* "uvloop/loop.pyx":1379
 *     def create_future(self):
 *         """Create a Future object attached to the loop."""
 *         return self._new_future()             # <<<<<<<<<<<<<<
 * 
 *     def create_task(self, coro):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1377
 *         return bool(self._closed)
 * 
 *     def create_future(self):             # <<<<<<<<<<<<<<
 *         """Create a Future object attached to the loop."""
 *         return self._new_future()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.create_future", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1381
 *         return self._new_future()
 * 
 *     def create_task(self, coro):             # <<<<<<<<<<<<<<
 *         """Schedule a coroutine object.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_39create_task(PyObject *__pyx_v_self, PyObject *__pyx_v_coro); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_38create_task[] = "Loop.create_task(self, coro)\nSchedule a coroutine object.\n\n        Return a task object.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_39create_task(PyObject *__pyx_v_self, PyObject *__pyx_v_coro) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_task (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_38create_task(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_coro));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_38create_task(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_coro) {
  PyObject *__pyx_v_task = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("create_task", 0);

  /* "uvloop/loop.pyx":1386
 *         Return a task object.
 *         """
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         if self._task_factory is None:
 *             task = aio_Task(coro, loop=self)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1387
 *         """
 *         self._check_closed()
 *         if self._task_factory is None:             # <<<<<<<<<<<<<<
 *             task = aio_Task(coro, loop=self)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_self->_task_factory == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":1388
 *         self._check_closed()
 *         if self._task_factory is None:
 *             task = aio_Task(coro, loop=self)             # <<<<<<<<<<<<<<
 *         else:
 *             task = self._task_factory(self, coro)
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_coro);
    __Pyx_GIVEREF(__pyx_v_coro);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_coro);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loop, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(2, 1388, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_Task, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_task = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":1387
 *         """
 *         self._check_closed()
 *         if self._task_factory is None:             # <<<<<<<<<<<<<<
 *             task = aio_Task(coro, loop=self)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":1390
 *             task = aio_Task(coro, loop=self)
 *         else:
 *             task = self._task_factory(self, coro)             # <<<<<<<<<<<<<<
 *         return task
 * 
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_self->_task_factory);
    __pyx_t_4 = __pyx_v_self->_task_factory; __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_self), __pyx_v_coro};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1390, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_self), __pyx_v_coro};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1390, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_1) {
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
      }
      __Pyx_INCREF(((PyObject *)__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, ((PyObject *)__pyx_v_self));
      __Pyx_INCREF(__pyx_v_coro);
      __Pyx_GIVEREF(__pyx_v_coro);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_coro);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_task = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":1391
 *         else:
 *             task = self._task_factory(self, coro)
 *         return task             # <<<<<<<<<<<<<<
 * 
 *     def set_task_factory(self, factory):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_task);
  __pyx_r = __pyx_v_task;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1381
 *         return self._new_future()
 * 
 *     def create_task(self, coro):             # <<<<<<<<<<<<<<
 *         """Schedule a coroutine object.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop.create_task", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_task);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1393
 *         return task
 * 
 *     def set_task_factory(self, factory):             # <<<<<<<<<<<<<<
 *         """Set a task factory that will be used by loop.create_task().
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_41set_task_factory(PyObject *__pyx_v_self, PyObject *__pyx_v_factory); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_40set_task_factory[] = "Loop.set_task_factory(self, factory)\nSet a task factory that will be used by loop.create_task().\n\n        If factory is None the default task factory will be set.\n\n        If factory is a callable, it should have a signature matching\n        '(loop, coro)', where 'loop' will be a reference to the active\n        event loop, 'coro' will be a coroutine object.  The callable\n        must return a Future.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_41set_task_factory(PyObject *__pyx_v_self, PyObject *__pyx_v_factory) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_task_factory (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_40set_task_factory(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_factory));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_40set_task_factory(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_factory) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("set_task_factory", 0);

  /* "uvloop/loop.pyx":1403
 *         must return a Future.
 *         """
 *         if factory is not None and not callable(factory):             # <<<<<<<<<<<<<<
 *             raise TypeError('task factory must be a callable or None')
 *         self._task_factory = factory
 */
  __pyx_t_2 = (__pyx_v_factory != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyCallable_Check(__pyx_v_factory); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 1403, __pyx_L1_error)
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":1404
 *         """
 *         if factory is not None and not callable(factory):
 *             raise TypeError('task factory must be a callable or None')             # <<<<<<<<<<<<<<
 *         self._task_factory = factory
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__46, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 1404, __pyx_L1_error)

    /* "uvloop/loop.pyx":1403
 *         must return a Future.
 *         """
 *         if factory is not None and not callable(factory):             # <<<<<<<<<<<<<<
 *             raise TypeError('task factory must be a callable or None')
 *         self._task_factory = factory
 */
  }

  /* "uvloop/loop.pyx":1405
 *         if factory is not None and not callable(factory):
 *             raise TypeError('task factory must be a callable or None')
 *         self._task_factory = factory             # <<<<<<<<<<<<<<
 * 
 *     def get_task_factory(self):
 */
  __Pyx_INCREF(__pyx_v_factory);
  __Pyx_GIVEREF(__pyx_v_factory);
  __Pyx_GOTREF(__pyx_v_self->_task_factory);
  __Pyx_DECREF(__pyx_v_self->_task_factory);
  __pyx_v_self->_task_factory = __pyx_v_factory;

  /* "uvloop/loop.pyx":1393
 *         return task
 * 
 *     def set_task_factory(self, factory):             # <<<<<<<<<<<<<<
 *         """Set a task factory that will be used by loop.create_task().
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop.set_task_factory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1407
 *         self._task_factory = factory
 * 
 *     def get_task_factory(self):             # <<<<<<<<<<<<<<
 *         """Return a task factory, or None if the default one is in use."""
 *         return self._task_factory
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_43get_task_factory(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_42get_task_factory[] = "Loop.get_task_factory(self)\nReturn a task factory, or None if the default one is in use.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_43get_task_factory(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_task_factory (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_42get_task_factory(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_42get_task_factory(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_task_factory", 0);

  /* "uvloop/loop.pyx":1409
 *     def get_task_factory(self):
 *         """Return a task factory, or None if the default one is in use."""
 *         return self._task_factory             # <<<<<<<<<<<<<<
 * 
 *     def run_until_complete(self, future):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_task_factory);
  __pyx_r = __pyx_v_self->_task_factory;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1407
 *         self._task_factory = factory
 * 
 *     def get_task_factory(self):             # <<<<<<<<<<<<<<
 *         """Return a task factory, or None if the default one is in use."""
 *         return self._task_factory
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1411
 *         return self._task_factory
 * 
 *     def run_until_complete(self, future):             # <<<<<<<<<<<<<<
 *         """Run until the Future is done.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_45run_until_complete(PyObject *__pyx_v_self, PyObject *__pyx_v_future); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_44run_until_complete[] = "Loop.run_until_complete(self, future)\nRun until the Future is done.\n\n        If the argument is a coroutine, it is wrapped in a Task.\n\n        WARNING: It would be disastrous to call run_until_complete()\n        with the same coroutine twice -- it would wrap it in two\n        different Tasks and that can't be good.\n\n        Return the Future's result, or raise its exception.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_45run_until_complete(PyObject *__pyx_v_self, PyObject *__pyx_v_future) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("run_until_complete (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_44run_until_complete(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_future));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1431
 *             future._log_destroy_pending = False
 * 
 *         done_cb = lambda fut: self.stop()             # <<<<<<<<<<<<<<
 * 
 *         future.add_done_callback(done_cb)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_18run_until_complete_lambda2(PyObject *__pyx_self, PyObject *__pyx_v_fut); /*proto*/
static PyMethodDef __pyx_mdef_6uvloop_4loop_4Loop_18run_until_complete_lambda2 = {"lambda2", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_18run_until_complete_lambda2, METH_O, 0};
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_18run_until_complete_lambda2(PyObject *__pyx_self, PyObject *__pyx_v_fut) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda2 (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda2(__pyx_self, ((PyObject *)__pyx_v_fut));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda2(PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_fut) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *__pyx_cur_scope;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("lambda2", 0);
  __pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_v_self)) { __Pyx_RaiseClosureNameError("self"); __PYX_ERR(2, 1431, __pyx_L1_error) }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_stop); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1431, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1431, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.Loop.run_until_complete.lambda2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1411
 *         return self._task_factory
 * 
 *     def run_until_complete(self, future):             # <<<<<<<<<<<<<<
 *         """Run until the Future is done.
 * 
 */

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_44run_until_complete(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_future) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *__pyx_cur_scope;
  int __pyx_v_new_task;
  PyObject *__pyx_v_done_cb = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  __Pyx_RefNannySetupContext("run_until_complete", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_4_run_until_complete(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_4_run_until_complete, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1411, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_INCREF(__pyx_v_future);

  /* "uvloop/loop.pyx":1422
 *         Return the Future's result, or raise its exception.
 *         """
 *         self._check_closed()             # <<<<<<<<<<<<<<
 * 
 *         new_task = not isfuture(future)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1424
 *         self._check_closed()
 * 
 *         new_task = not isfuture(future)             # <<<<<<<<<<<<<<
 *         future = aio_ensure_future(future, loop=self)
 *         if new_task:
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_isfuture(__pyx_v_future); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1424, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_new_task = (!__pyx_t_2);

  /* "uvloop/loop.pyx":1425
 * 
 *         new_task = not isfuture(future)
 *         future = aio_ensure_future(future, loop=self)             # <<<<<<<<<<<<<<
 *         if new_task:
 *             # An exception is raised if the future didn't complete, so there
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_future);
  __Pyx_GIVEREF(__pyx_v_future);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_future);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loop, ((PyObject *)__pyx_cur_scope->__pyx_v_self)) < 0) __PYX_ERR(2, 1425, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_ensure_future, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF_SET(__pyx_v_future, __pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":1426
 *         new_task = not isfuture(future)
 *         future = aio_ensure_future(future, loop=self)
 *         if new_task:             # <<<<<<<<<<<<<<
 *             # An exception is raised if the future didn't complete, so there
 *             # is no need to log the "destroy pending task" message
 */
  __pyx_t_2 = (__pyx_v_new_task != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1429
 *             # An exception is raised if the future didn't complete, so there
 *             # is no need to log the "destroy pending task" message
 *             future._log_destroy_pending = False             # <<<<<<<<<<<<<<
 * 
 *         done_cb = lambda fut: self.stop()
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_future, __pyx_n_s_log_destroy_pending, Py_False) < 0) __PYX_ERR(2, 1429, __pyx_L1_error)

    /* "uvloop/loop.pyx":1426
 *         new_task = not isfuture(future)
 *         future = aio_ensure_future(future, loop=self)
 *         if new_task:             # <<<<<<<<<<<<<<
 *             # An exception is raised if the future didn't complete, so there
 *             # is no need to log the "destroy pending task" message
 */
  }

  /* "uvloop/loop.pyx":1431
 *             future._log_destroy_pending = False
 * 
 *         done_cb = lambda fut: self.stop()             # <<<<<<<<<<<<<<
 * 
 *         future.add_done_callback(done_cb)
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_4Loop_18run_until_complete_lambda2, 0, __pyx_n_s_run_until_complete_locals_lambda, ((PyObject*)__pyx_cur_scope), __pyx_n_s_uvloop_loop, __pyx_d, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_done_cb = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":1433
 *         done_cb = lambda fut: self.stop()
 * 
 *         future.add_done_callback(done_cb)             # <<<<<<<<<<<<<<
 *         try:
 *             self.run_forever()
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_add_done_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_done_cb); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_done_cb};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1433, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_done_cb};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1433, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_done_cb);
      __Pyx_GIVEREF(__pyx_v_done_cb);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_done_cb);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":1434
 * 
 *         future.add_done_callback(done_cb)
 *         try:             # <<<<<<<<<<<<<<
 *             self.run_forever()
 *         except:
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "uvloop/loop.pyx":1435
 *         future.add_done_callback(done_cb)
 *         try:
 *             self.run_forever()             # <<<<<<<<<<<<<<
 *         except:
 *             if new_task and future.done() and not future.cancelled():
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_run_forever); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1435, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (__pyx_t_5) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1435, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else {
          __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1435, __pyx_L7_error)
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/loop.pyx":1434
 * 
 *         future.add_done_callback(done_cb)
 *         try:             # <<<<<<<<<<<<<<
 *             self.run_forever()
 *         except:
 */
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1436
 *         try:
 *             self.run_forever()
 *         except:             # <<<<<<<<<<<<<<
 *             if new_task and future.done() and not future.cancelled():
 *                 # The coroutine raised a BaseException. Consume the exception
 */
      /*except:*/ {
        __Pyx_AddTraceback("uvloop.loop.Loop.run_until_complete", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_5) < 0) __PYX_ERR(2, 1436, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_5);

        /* "uvloop/loop.pyx":1437
 *             self.run_forever()
 *         except:
 *             if new_task and future.done() and not future.cancelled():             # <<<<<<<<<<<<<<
 *                 # The coroutine raised a BaseException. Consume the exception
 *                 # to not log a warning, the caller doesn't have access to the
 */
        __pyx_t_9 = (__pyx_v_new_task != 0);
        if (__pyx_t_9) {
        } else {
          __pyx_t_2 = __pyx_t_9;
          goto __pyx_L16_bool_binop_done;
        }
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_done); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        if (__pyx_t_11) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_9) {
        } else {
          __pyx_t_2 = __pyx_t_9;
          goto __pyx_L16_bool_binop_done;
        }
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        if (__pyx_t_11) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(2, 1437, __pyx_L9_except_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_12 = ((!__pyx_t_9) != 0);
        __pyx_t_2 = __pyx_t_12;
        __pyx_L16_bool_binop_done:;
        if (__pyx_t_2) {

          /* "uvloop/loop.pyx":1441
 *                 # to not log a warning, the caller doesn't have access to the
 *                 # local task.
 *                 future.exception()             # <<<<<<<<<<<<<<
 *             raise
 *         finally:
 */
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_exception); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 1441, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          if (__pyx_t_11) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1441, __pyx_L9_except_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          } else {
            __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1441, __pyx_L9_except_error)
          }
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "uvloop/loop.pyx":1437
 *             self.run_forever()
 *         except:
 *             if new_task and future.done() and not future.cancelled():             # <<<<<<<<<<<<<<
 *                 # The coroutine raised a BaseException. Consume the exception
 *                 # to not log a warning, the caller doesn't have access to the
 */
        }

        /* "uvloop/loop.pyx":1442
 *                 # local task.
 *                 future.exception()
 *             raise             # <<<<<<<<<<<<<<
 *         finally:
 *             future.remove_done_callback(done_cb)
 */
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_3, __pyx_t_5);
        __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_5 = 0; 
        __PYX_ERR(2, 1442, __pyx_L9_except_error)
      }
      __pyx_L9_except_error:;

      /* "uvloop/loop.pyx":1434
 * 
 *         future.add_done_callback(done_cb)
 *         try:             # <<<<<<<<<<<<<<
 *             self.run_forever()
 *         except:
 */
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L5_error;
      __pyx_L12_try_end:;
    }
  }

  /* "uvloop/loop.pyx":1444
 *             raise
 *         finally:
 *             future.remove_done_callback(done_cb)             # <<<<<<<<<<<<<<
 *         if not future.done():
 *             raise RuntimeError('Event loop stopped before Future completed.')
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_remove_done_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1444, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_done_cb); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_done_cb};
          __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_done_cb};
          __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_5);
        } else
        #endif
        {
          __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1444, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_done_cb);
          __Pyx_GIVEREF(__pyx_v_done_cb);
          PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_v_done_cb);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_8 = 0; __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6) < 0)) __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      __pyx_t_13 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
      {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_remove_done_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1444, __pyx_L20_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_1) {
          __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_done_cb); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_5);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_done_cb};
            __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L20_error)
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_GOTREF(__pyx_t_5);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_done_cb};
            __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L20_error)
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_GOTREF(__pyx_t_5);
          } else
          #endif
          {
            __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1444, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1); __pyx_t_1 = NULL;
            __Pyx_INCREF(__pyx_v_done_cb);
            __Pyx_GIVEREF(__pyx_v_done_cb);
            PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_done_cb);
            __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1444, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      }
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ErrRestore(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      __pyx_t_8 = 0; __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
      goto __pyx_L1_error;
      __pyx_L20_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/loop.pyx":1445
 *         finally:
 *             future.remove_done_callback(done_cb)
 *         if not future.done():             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Event loop stopped before Future completed.')
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_done); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1445, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1445, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_12 = ((!__pyx_t_2) != 0);
  if (unlikely(__pyx_t_12)) {

    /* "uvloop/loop.pyx":1446
 *             future.remove_done_callback(done_cb)
 *         if not future.done():
 *             raise RuntimeError('Event loop stopped before Future completed.')             # <<<<<<<<<<<<<<
 * 
 *         return future.result()
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(2, 1446, __pyx_L1_error)

    /* "uvloop/loop.pyx":1445
 *         finally:
 *             future.remove_done_callback(done_cb)
 *         if not future.done():             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Event loop stopped before Future completed.')
 * 
 */
  }

  /* "uvloop/loop.pyx":1448
 *             raise RuntimeError('Event loop stopped before Future completed.')
 * 
 *         return future.result()             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_future, __pyx_n_s_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1448, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1448, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":1411
 *         return self._task_factory
 * 
 *     def run_until_complete(self, future):             # <<<<<<<<<<<<<<
 *         """Run until the Future is done.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("uvloop.loop.Loop.run_until_complete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_done_cb);
  __Pyx_XDECREF(__pyx_v_future);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_48generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1451
 * 
 *     @cython.iterable_coroutine
 *     async def getaddrinfo(self, object host, object port, *,             # <<<<<<<<<<<<<<
 *                           int family=0, int type=0, int proto=0, int flags=0):
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_47getaddrinfo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_46getaddrinfo[] = "Loop.getaddrinfo(self, host, port, *, int family=0, int type=0, int proto=0, int flags=0)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_47getaddrinfo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_host = 0;
  PyObject *__pyx_v_port = 0;
  int __pyx_v_family;
  int __pyx_v_type;
  int __pyx_v_proto;
  int __pyx_v_flags;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getaddrinfo (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_host,&__pyx_n_s_port,&__pyx_n_s_family,&__pyx_n_s_type,&__pyx_n_s_proto,&__pyx_n_s_flags,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_host)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_port)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("getaddrinfo", 1, 2, 2, 1); __PYX_ERR(2, 1451, __pyx_L3_error)
        }
      }
      if (kw_args > 0 && likely(kw_args <= 4)) {
        Py_ssize_t index;
        for (index = 2; index < 6 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "getaddrinfo") < 0)) __PYX_ERR(2, 1451, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_host = values[0];
    __pyx_v_port = values[1];
    if (values[2]) {
      __pyx_v_family = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_family == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1452, __pyx_L3_error)
    } else {
      __pyx_v_family = ((int)0);
    }
    if (values[3]) {
      __pyx_v_type = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1452, __pyx_L3_error)
    } else {
      __pyx_v_type = ((int)0);
    }
    if (values[4]) {
      __pyx_v_proto = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_proto == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1452, __pyx_L3_error)
    } else {
      __pyx_v_proto = ((int)0);
    }
    if (values[5]) {
      __pyx_v_flags = __Pyx_PyInt_As_int(values[5]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1452, __pyx_L3_error)
    } else {
      __pyx_v_flags = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getaddrinfo", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1451, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_46getaddrinfo(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_host, __pyx_v_port, __pyx_v_family, __pyx_v_type, __pyx_v_proto, __pyx_v_flags);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_46getaddrinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getaddrinfo", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1451, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_host = __pyx_v_host;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_host);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_host);
  __pyx_cur_scope->__pyx_v_port = __pyx_v_port;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_port);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_port);
  __pyx_cur_scope->__pyx_v_family = __pyx_v_family;
  __pyx_cur_scope->__pyx_v_type = __pyx_v_type;
  __pyx_cur_scope->__pyx_v_proto = __pyx_v_proto;
  __pyx_cur_scope->__pyx_v_flags = __pyx_v_flags;
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_48generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_getaddrinfo, __pyx_n_s_Loop_getaddrinfo, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1451, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_48generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getaddrinfo", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L5_resume_from_await;
    case 2: goto __pyx_L6_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1451, __pyx_L1_error)

  /* "uvloop/loop.pyx":1454
 *                           int family=0, int type=0, int proto=0, int flags=0):
 * 
 *         addr = __static_getaddrinfo_pyaddr(host, port, family,             # <<<<<<<<<<<<<<
 *                                            type, proto, flags)
 *         if addr is not None:
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___static_getaddrinfo_pyaddr(__pyx_cur_scope->__pyx_v_host, __pyx_cur_scope->__pyx_v_port, __pyx_cur_scope->__pyx_v_family, __pyx_cur_scope->__pyx_v_type, __pyx_cur_scope->__pyx_v_proto, __pyx_cur_scope->__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_addr = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1456
 *         addr = __static_getaddrinfo_pyaddr(host, port, family,
 *                                            type, proto, flags)
 *         if addr is not None:             # <<<<<<<<<<<<<<
 *             fut = self._new_future()
 *             fut.set_result([addr])
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_addr != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":1457
 *                                            type, proto, flags)
 *         if addr is not None:
 *             fut = self._new_future()             # <<<<<<<<<<<<<<
 *             fut.set_result([addr])
 *             return await fut
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_v_fut = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1458
 *         if addr is not None:
 *             fut = self._new_future()
 *             fut.set_result([addr])             # <<<<<<<<<<<<<<
 *             return await fut
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_addr);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_addr);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_cur_scope->__pyx_v_addr);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1458, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1458, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1458, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1459
 *             fut = self._new_future()
 *             fut.set_result([addr])
 *             return await fut             # <<<<<<<<<<<<<<
 * 
 *         return await self._getaddrinfo(
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_fut);
    __Pyx_XGOTREF(__pyx_r);
    if (likely(__pyx_r)) {
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, awaiting value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L5_resume_from_await:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1459, __pyx_L1_error)
      __pyx_t_1 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_1);
    } else {
      __pyx_t_1 = NULL;
      if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_1) < 0) __PYX_ERR(2, 1459, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1456
 *         addr = __static_getaddrinfo_pyaddr(host, port, family,
 *                                            type, proto, flags)
 *         if addr is not None:             # <<<<<<<<<<<<<<
 *             fut = self._new_future()
 *             fut.set_result([addr])
 */
  }

  /* "uvloop/loop.pyx":1461
 *             return await fut
 * 
 *         return await self._getaddrinfo(             # <<<<<<<<<<<<<<
 *             host, port, family, type, proto, flags, 1)
 * 
 */
  __Pyx_XDECREF(__pyx_r);

  /* "uvloop/loop.pyx":1462
 * 
 *         return await self._getaddrinfo(
 *             host, port, family, type, proto, flags, 1)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_getaddrinfo(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_host, __pyx_cur_scope->__pyx_v_port, __pyx_cur_scope->__pyx_v_family, __pyx_cur_scope->__pyx_v_type, __pyx_cur_scope->__pyx_v_proto, __pyx_cur_scope->__pyx_v_flags, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 2;
    return __pyx_r;
    __pyx_L6_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1461, __pyx_L1_error)
    __pyx_t_1 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_1);
  } else {
    __pyx_t_1 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_1) < 0) __PYX_ERR(2, 1461, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":1451
 * 
 *     @cython.iterable_coroutine
 *     async def getaddrinfo(self, object host, object port, *,             # <<<<<<<<<<<<<<
 *                           int family=0, int type=0, int proto=0, int flags=0):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_51generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1465
 * 
 *     @cython.iterable_coroutine
 *     async def getnameinfo(self, sockaddr, int flags=0):             # <<<<<<<<<<<<<<
 *         cdef:
 *             AddrInfo ai_cnt
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_50getnameinfo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_49getnameinfo[] = "Loop.getnameinfo(self, sockaddr, int flags=0)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_50getnameinfo(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sockaddr = 0;
  int __pyx_v_flags;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getnameinfo (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sockaddr,&__pyx_n_s_flags,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sockaddr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_flags);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "getnameinfo") < 0)) __PYX_ERR(2, 1465, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_sockaddr = values[0];
    if (values[1]) {
      __pyx_v_flags = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1465, __pyx_L3_error)
    } else {
      __pyx_v_flags = ((int)0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getnameinfo", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1465, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_49getnameinfo(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_sockaddr, __pyx_v_flags);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_49getnameinfo(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sockaddr, int __pyx_v_flags) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getnameinfo", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_6_getnameinfo(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_6_getnameinfo, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1465, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sockaddr = __pyx_v_sockaddr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sockaddr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sockaddr);
  __pyx_cur_scope->__pyx_v_flags = __pyx_v_flags;
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_51generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_getnameinfo, __pyx_n_s_Loop_getnameinfo, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1465, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_51generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  struct addrinfo *__pyx_t_7;
  int __pyx_t_8;
  unsigned long __pyx_t_9;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getnameinfo", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L17_resume_from_await;
    case 2: goto __pyx_L21_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1465, __pyx_L1_error)

  /* "uvloop/loop.pyx":1471
 *             system.sockaddr_in6 *sin6
 * 
 *         if not isinstance(sockaddr, tuple):             # <<<<<<<<<<<<<<
 *             raise TypeError('getnameinfo() argument 1 must be a tuple')
 * 
 */
  __pyx_t_1 = PyTuple_Check(__pyx_cur_scope->__pyx_v_sockaddr); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":1472
 * 
 *         if not isinstance(sockaddr, tuple):
 *             raise TypeError('getnameinfo() argument 1 must be a tuple')             # <<<<<<<<<<<<<<
 * 
 *         sl = len(sockaddr)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 1472, __pyx_L1_error)

    /* "uvloop/loop.pyx":1471
 *             system.sockaddr_in6 *sin6
 * 
 *         if not isinstance(sockaddr, tuple):             # <<<<<<<<<<<<<<
 *             raise TypeError('getnameinfo() argument 1 must be a tuple')
 * 
 */
  }

  /* "uvloop/loop.pyx":1474
 *             raise TypeError('getnameinfo() argument 1 must be a tuple')
 * 
 *         sl = len(sockaddr)             # <<<<<<<<<<<<<<
 * 
 *         if sl < 2 or sl > 4:
 */
  __pyx_t_4 = PyObject_Length(__pyx_cur_scope->__pyx_v_sockaddr); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(2, 1474, __pyx_L1_error)
  __pyx_cur_scope->__pyx_v_sl = __pyx_t_4;

  /* "uvloop/loop.pyx":1476
 *         sl = len(sockaddr)
 * 
 *         if sl < 2 or sl > 4:             # <<<<<<<<<<<<<<
 *             raise ValueError('sockaddr must be a tuple of 2, 3 or 4 values')
 * 
 */
  __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_sl < 2) != 0);
  if (!__pyx_t_1) {
  } else {
    __pyx_t_2 = __pyx_t_1;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_sl > 4) != 0);
  __pyx_t_2 = __pyx_t_1;
  __pyx_L6_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":1477
 * 
 *         if sl < 2 or sl > 4:
 *             raise ValueError('sockaddr must be a tuple of 2, 3 or 4 values')             # <<<<<<<<<<<<<<
 * 
 *         if sl > 2:
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1477, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 1477, __pyx_L1_error)

    /* "uvloop/loop.pyx":1476
 *         sl = len(sockaddr)
 * 
 *         if sl < 2 or sl > 4:             # <<<<<<<<<<<<<<
 *             raise ValueError('sockaddr must be a tuple of 2, 3 or 4 values')
 * 
 */
  }

  /* "uvloop/loop.pyx":1479
 *             raise ValueError('sockaddr must be a tuple of 2, 3 or 4 values')
 * 
 *         if sl > 2:             # <<<<<<<<<<<<<<
 *             flowinfo = sockaddr[2]
 *             if flowinfo < 0 or flowinfo > 0xfffff:
 */
  __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_sl > 2) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1480
 * 
 *         if sl > 2:
 *             flowinfo = sockaddr[2]             # <<<<<<<<<<<<<<
 *             if flowinfo < 0 or flowinfo > 0xfffff:
 *                 if PY37:
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_sockaddr, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_v_flowinfo = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":1481
 *         if sl > 2:
 *             flowinfo = sockaddr[2]
 *             if flowinfo < 0 or flowinfo > 0xfffff:             # <<<<<<<<<<<<<<
 *                 if PY37:
 *                     msg = 'getnameinfo(): flowinfo must be 0-1048575.'
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_flowinfo, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1481, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1481, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_1) {
    } else {
      __pyx_t_2 = __pyx_t_1;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_flowinfo, __pyx_int_1048575, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1481, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1481, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __pyx_t_1;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":1482
 *             flowinfo = sockaddr[2]
 *             if flowinfo < 0 or flowinfo > 0xfffff:
 *                 if PY37:             # <<<<<<<<<<<<<<
 *                     msg = 'getnameinfo(): flowinfo must be 0-1048575.'
 *                 else:
 */
      __pyx_t_2 = (__pyx_v_6uvloop_4loop_PY37 != 0);
      if (__pyx_t_2) {

        /* "uvloop/loop.pyx":1483
 *             if flowinfo < 0 or flowinfo > 0xfffff:
 *                 if PY37:
 *                     msg = 'getnameinfo(): flowinfo must be 0-1048575.'             # <<<<<<<<<<<<<<
 *                 else:
 *                     msg = 'getsockaddrarg: flowinfo must be 0-1048575.'
 */
        __Pyx_INCREF(__pyx_kp_u_getnameinfo_flowinfo_must_be_0_1);
        __Pyx_GIVEREF(__pyx_kp_u_getnameinfo_flowinfo_must_be_0_1);
        __pyx_cur_scope->__pyx_v_msg = __pyx_kp_u_getnameinfo_flowinfo_must_be_0_1;

        /* "uvloop/loop.pyx":1482
 *             flowinfo = sockaddr[2]
 *             if flowinfo < 0 or flowinfo > 0xfffff:
 *                 if PY37:             # <<<<<<<<<<<<<<
 *                     msg = 'getnameinfo(): flowinfo must be 0-1048575.'
 *                 else:
 */
        goto __pyx_L12;
      }

      /* "uvloop/loop.pyx":1485
 *                     msg = 'getnameinfo(): flowinfo must be 0-1048575.'
 *                 else:
 *                     msg = 'getsockaddrarg: flowinfo must be 0-1048575.'             # <<<<<<<<<<<<<<
 *                 raise OverflowError(msg)
 *         else:
 */
      /*else*/ {
        __Pyx_INCREF(__pyx_kp_u_getsockaddrarg_flowinfo_must_be);
        __Pyx_GIVEREF(__pyx_kp_u_getsockaddrarg_flowinfo_must_be);
        __pyx_cur_scope->__pyx_v_msg = __pyx_kp_u_getsockaddrarg_flowinfo_must_be;
      }
      __pyx_L12:;

      /* "uvloop/loop.pyx":1486
 *                 else:
 *                     msg = 'getsockaddrarg: flowinfo must be 0-1048575.'
 *                 raise OverflowError(msg)             # <<<<<<<<<<<<<<
 *         else:
 *             flowinfo = 0
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_OverflowError, __pyx_cur_scope->__pyx_v_msg); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1486, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 1486, __pyx_L1_error)

      /* "uvloop/loop.pyx":1481
 *         if sl > 2:
 *             flowinfo = sockaddr[2]
 *             if flowinfo < 0 or flowinfo > 0xfffff:             # <<<<<<<<<<<<<<
 *                 if PY37:
 *                     msg = 'getnameinfo(): flowinfo must be 0-1048575.'
 */
    }

    /* "uvloop/loop.pyx":1479
 *             raise ValueError('sockaddr must be a tuple of 2, 3 or 4 values')
 * 
 *         if sl > 2:             # <<<<<<<<<<<<<<
 *             flowinfo = sockaddr[2]
 *             if flowinfo < 0 or flowinfo > 0xfffff:
 */
    goto __pyx_L8;
  }

  /* "uvloop/loop.pyx":1488
 *                 raise OverflowError(msg)
 *         else:
 *             flowinfo = 0             # <<<<<<<<<<<<<<
 * 
 *         if sl > 3:
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    __pyx_cur_scope->__pyx_v_flowinfo = __pyx_int_0;
  }
  __pyx_L8:;

  /* "uvloop/loop.pyx":1490
 *             flowinfo = 0
 * 
 *         if sl > 3:             # <<<<<<<<<<<<<<
 *             scope_id = sockaddr[3]
 *             if scope_id < 0 or scope_id > 2 ** 32:
 */
  __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_sl > 3) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1491
 * 
 *         if sl > 3:
 *             scope_id = sockaddr[3]             # <<<<<<<<<<<<<<
 *             if scope_id < 0 or scope_id > 2 ** 32:
 *                 raise OverflowError(
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_sockaddr, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1491, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_v_scope_id = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":1492
 *         if sl > 3:
 *             scope_id = sockaddr[3]
 *             if scope_id < 0 or scope_id > 2 ** 32:             # <<<<<<<<<<<<<<
 *                 raise OverflowError(
 *                     'getsockaddrarg: scope_id must be unsigned 32 bit integer')
 */
    __pyx_t_3 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_scope_id, __pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1492, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1492, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_1) {
    } else {
      __pyx_t_2 = __pyx_t_1;
      goto __pyx_L15_bool_binop_done;
    }
    __pyx_t_3 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_scope_id, __pyx_int_4294967296, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1492, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1492, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __pyx_t_1;
    __pyx_L15_bool_binop_done:;
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/loop.pyx":1493
 *             scope_id = sockaddr[3]
 *             if scope_id < 0 or scope_id > 2 ** 32:
 *                 raise OverflowError(             # <<<<<<<<<<<<<<
 *                     'getsockaddrarg: scope_id must be unsigned 32 bit integer')
 *         else:
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_OverflowError, __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1493, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 1493, __pyx_L1_error)

      /* "uvloop/loop.pyx":1492
 *         if sl > 3:
 *             scope_id = sockaddr[3]
 *             if scope_id < 0 or scope_id > 2 ** 32:             # <<<<<<<<<<<<<<
 *                 raise OverflowError(
 *                     'getsockaddrarg: scope_id must be unsigned 32 bit integer')
 */
    }

    /* "uvloop/loop.pyx":1490
 *             flowinfo = 0
 * 
 *         if sl > 3:             # <<<<<<<<<<<<<<
 *             scope_id = sockaddr[3]
 *             if scope_id < 0 or scope_id > 2 ** 32:
 */
    goto __pyx_L13;
  }

  /* "uvloop/loop.pyx":1496
 *                     'getsockaddrarg: scope_id must be unsigned 32 bit integer')
 *         else:
 *             scope_id = 0             # <<<<<<<<<<<<<<
 * 
 *         ai_cnt = await self._getaddrinfo(
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    __pyx_cur_scope->__pyx_v_scope_id = __pyx_int_0;
  }
  __pyx_L13:;

  /* "uvloop/loop.pyx":1499
 * 
 *         ai_cnt = await self._getaddrinfo(
 *             sockaddr[0], sockaddr[1],             # <<<<<<<<<<<<<<
 *             uv.AF_UNSPEC,         # family
 *             uv.SOCK_DGRAM,        # type
 */
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_sockaddr, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_sockaddr, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/loop.pyx":1498
 *             scope_id = 0
 * 
 *         ai_cnt = await self._getaddrinfo(             # <<<<<<<<<<<<<<
 *             sockaddr[0], sockaddr[1],
 *             uv.AF_UNSPEC,         # family
 */
  __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_getaddrinfo(__pyx_cur_scope->__pyx_v_self, __pyx_t_3, __pyx_t_5, AF_UNSPEC, SOCK_DGRAM, 0, AI_NUMERICHOST, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L17_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1498, __pyx_L1_error)
    __pyx_t_6 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_6);
  } else {
    __pyx_t_6 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_6) < 0) __PYX_ERR(2, 1498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_6uvloop_4loop_AddrInfo))))) __PYX_ERR(2, 1498, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_cur_scope->__pyx_v_ai_cnt = ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "uvloop/loop.pyx":1506
 *             0)                    # unpack
 * 
 *         ai = ai_cnt.data             # <<<<<<<<<<<<<<
 * 
 *         if ai.ai_next:
 */
  __pyx_t_7 = __pyx_cur_scope->__pyx_v_ai_cnt->data;
  __pyx_cur_scope->__pyx_v_ai = __pyx_t_7;

  /* "uvloop/loop.pyx":1508
 *         ai = ai_cnt.data
 * 
 *         if ai.ai_next:             # <<<<<<<<<<<<<<
 *             raise OSError("sockaddr resolved to multiple addresses")
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_ai->ai_next != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":1509
 * 
 *         if ai.ai_next:
 *             raise OSError("sockaddr resolved to multiple addresses")             # <<<<<<<<<<<<<<
 * 
 *         if ai.ai_family == uv.AF_INET:
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1509, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(2, 1509, __pyx_L1_error)

    /* "uvloop/loop.pyx":1508
 *         ai = ai_cnt.data
 * 
 *         if ai.ai_next:             # <<<<<<<<<<<<<<
 *             raise OSError("sockaddr resolved to multiple addresses")
 * 
 */
  }

  /* "uvloop/loop.pyx":1511
 *             raise OSError("sockaddr resolved to multiple addresses")
 * 
 *         if ai.ai_family == uv.AF_INET:             # <<<<<<<<<<<<<<
 *             if sl > 2:
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")
 */
  __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_ai->ai_family == AF_INET) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1512
 * 
 *         if ai.ai_family == uv.AF_INET:
 *             if sl > 2:             # <<<<<<<<<<<<<<
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")
 *         elif ai.ai_family == uv.AF_INET6:
 */
    __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_sl > 2) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/loop.pyx":1513
 *         if ai.ai_family == uv.AF_INET:
 *             if sl > 2:
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")             # <<<<<<<<<<<<<<
 *         elif ai.ai_family == uv.AF_INET6:
 *             # Modify some fields in `ai`
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_tuple__52, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 1513, __pyx_L1_error)

      /* "uvloop/loop.pyx":1512
 * 
 *         if ai.ai_family == uv.AF_INET:
 *             if sl > 2:             # <<<<<<<<<<<<<<
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")
 *         elif ai.ai_family == uv.AF_INET6:
 */
    }

    /* "uvloop/loop.pyx":1511
 *             raise OSError("sockaddr resolved to multiple addresses")
 * 
 *         if ai.ai_family == uv.AF_INET:             # <<<<<<<<<<<<<<
 *             if sl > 2:
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")
 */
    goto __pyx_L19;
  }

  /* "uvloop/loop.pyx":1514
 *             if sl > 2:
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")
 *         elif ai.ai_family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *             # Modify some fields in `ai`
 *             sin6 = <system.sockaddr_in6*> ai.ai_addr
 */
  __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_ai->ai_family == AF_INET6) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1516
 *         elif ai.ai_family == uv.AF_INET6:
 *             # Modify some fields in `ai`
 *             sin6 = <system.sockaddr_in6*> ai.ai_addr             # <<<<<<<<<<<<<<
 *             sin6.sin6_flowinfo = system.htonl(flowinfo)
 *             sin6.sin6_scope_id = scope_id
 */
    __pyx_cur_scope->__pyx_v_sin6 = ((struct sockaddr_in6 *)__pyx_cur_scope->__pyx_v_ai->ai_addr);

    /* "uvloop/loop.pyx":1517
 *             # Modify some fields in `ai`
 *             sin6 = <system.sockaddr_in6*> ai.ai_addr
 *             sin6.sin6_flowinfo = system.htonl(flowinfo)             # <<<<<<<<<<<<<<
 *             sin6.sin6_scope_id = scope_id
 * 
 */
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_flowinfo); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1517, __pyx_L1_error)
    __pyx_cur_scope->__pyx_v_sin6->sin6_flowinfo = htonl(__pyx_t_8);

    /* "uvloop/loop.pyx":1518
 *             sin6 = <system.sockaddr_in6*> ai.ai_addr
 *             sin6.sin6_flowinfo = system.htonl(flowinfo)
 *             sin6.sin6_scope_id = scope_id             # <<<<<<<<<<<<<<
 * 
 *         return await self._getnameinfo(ai.ai_addr, flags)
 */
    __pyx_t_9 = __Pyx_PyInt_As_unsigned_long(__pyx_cur_scope->__pyx_v_scope_id); if (unlikely((__pyx_t_9 == (unsigned long)-1) && PyErr_Occurred())) __PYX_ERR(2, 1518, __pyx_L1_error)
    __pyx_cur_scope->__pyx_v_sin6->sin6_scope_id = __pyx_t_9;

    /* "uvloop/loop.pyx":1514
 *             if sl > 2:
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")
 *         elif ai.ai_family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *             # Modify some fields in `ai`
 *             sin6 = <system.sockaddr_in6*> ai.ai_addr
 */
  }
  __pyx_L19:;

  /* "uvloop/loop.pyx":1520
 *             sin6.sin6_scope_id = scope_id
 * 
 *         return await self._getnameinfo(ai.ai_addr, flags)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_getnameinfo(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_ai->ai_addr, __pyx_cur_scope->__pyx_v_flags); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 2;
    return __pyx_r;
    __pyx_L21_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1520, __pyx_L1_error)
    __pyx_t_6 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_6);
  } else {
    __pyx_t_6 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_6) < 0) __PYX_ERR(2, 1520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":1465
 * 
 *     @cython.iterable_coroutine
 *     async def getnameinfo(self, sockaddr, int flags=0):             # <<<<<<<<<<<<<<
 *         cdef:
 *             AddrInfo ai_cnt
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("getnameinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_54generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1523
 * 
 *     @cython.iterable_coroutine
 *     async def start_tls(self, transport, protocol, sslcontext, *,             # <<<<<<<<<<<<<<
 *                         server_side=False,
 *                         server_hostname=None,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_53start_tls(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_52start_tls[] = "Loop.start_tls(self, transport, protocol, sslcontext, *, server_side=False, server_hostname=None, ssl_handshake_timeout=None)\nUpgrade transport to TLS.\n\n        Return a new transport that *protocol* should start using\n        immediately.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_53start_tls(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_transport = 0;
  PyObject *__pyx_v_protocol = 0;
  PyObject *__pyx_v_sslcontext = 0;
  PyObject *__pyx_v_server_side = 0;
  PyObject *__pyx_v_server_hostname = 0;
  PyObject *__pyx_v_ssl_handshake_timeout = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start_tls (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_transport,&__pyx_n_s_protocol,&__pyx_n_s_sslcontext,&__pyx_n_s_server_side,&__pyx_n_s_server_hostname,&__pyx_n_s_ssl_handshake_timeout,0};
    PyObject* values[6] = {0,0,0,0,0,0};

    /* "uvloop/loop.pyx":1524
 *     @cython.iterable_coroutine
 *     async def start_tls(self, transport, protocol, sslcontext, *,
 *                         server_side=False,             # <<<<<<<<<<<<<<
 *                         server_hostname=None,
 *                         ssl_handshake_timeout=None):
 */
    values[3] = ((PyObject *)Py_False);

    /* "uvloop/loop.pyx":1525
 *     async def start_tls(self, transport, protocol, sslcontext, *,
 *                         server_side=False,
 *                         server_hostname=None,             # <<<<<<<<<<<<<<
 *                         ssl_handshake_timeout=None):
 *         """Upgrade transport to TLS.
 */
    values[4] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1526
 *                         server_side=False,
 *                         server_hostname=None,
 *                         ssl_handshake_timeout=None):             # <<<<<<<<<<<<<<
 *         """Upgrade transport to TLS.
 * 
 */
    values[5] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_transport)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("start_tls", 1, 3, 3, 1); __PYX_ERR(2, 1523, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sslcontext)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("start_tls", 1, 3, 3, 2); __PYX_ERR(2, 1523, __pyx_L3_error)
        }
      }
      if (kw_args > 0 && likely(kw_args <= 3)) {
        Py_ssize_t index;
        for (index = 3; index < 6 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "start_tls") < 0)) __PYX_ERR(2, 1523, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_transport = values[0];
    __pyx_v_protocol = values[1];
    __pyx_v_sslcontext = values[2];
    __pyx_v_server_side = values[3];
    __pyx_v_server_hostname = values[4];
    __pyx_v_ssl_handshake_timeout = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("start_tls", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1523, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.start_tls", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_52start_tls(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_transport, __pyx_v_protocol, __pyx_v_sslcontext, __pyx_v_server_side, __pyx_v_server_hostname, __pyx_v_ssl_handshake_timeout);

  /* "uvloop/loop.pyx":1523
 * 
 *     @cython.iterable_coroutine
 *     async def start_tls(self, transport, protocol, sslcontext, *,             # <<<<<<<<<<<<<<
 *                         server_side=False,
 *                         server_hostname=None,
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_52start_tls(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_transport, PyObject *__pyx_v_protocol, PyObject *__pyx_v_sslcontext, PyObject *__pyx_v_server_side, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start_tls", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_7_start_tls(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_7_start_tls, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1523, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_transport = __pyx_v_transport;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_transport);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_transport);
  __pyx_cur_scope->__pyx_v_protocol = __pyx_v_protocol;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
  __pyx_cur_scope->__pyx_v_sslcontext = __pyx_v_sslcontext;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sslcontext);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sslcontext);
  __pyx_cur_scope->__pyx_v_server_side = __pyx_v_server_side;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_side);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_side);
  __pyx_cur_scope->__pyx_v_server_hostname = __pyx_v_server_hostname;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_hostname);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_hostname);
  __pyx_cur_scope->__pyx_v_ssl_handshake_timeout = __pyx_v_ssl_handshake_timeout;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_54generator2, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_start_tls, __pyx_n_s_Loop_start_tls, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1523, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.start_tls", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_54generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_UCS4 __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start_tls", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L14_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1523, __pyx_L1_error)

  /* "uvloop/loop.pyx":1532
 *         immediately.
 *         """
 *         if not isinstance(sslcontext, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 f'sslcontext is expected to be an instance of ssl.SSLContext, '
 */
  __pyx_t_1 = __pyx_v_6uvloop_4loop_ssl_SSLContext;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_sslcontext, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 1532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/loop.pyx":1535
 *             raise TypeError(
 *                 f'sslcontext is expected to be an instance of ssl.SSLContext, '
 *                 f'got {sslcontext!r}')             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(transport, (TCPTransport, UnixTransport)):
 */
    __pyx_t_1 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_cur_scope->__pyx_v_sslcontext), __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1535, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "uvloop/loop.pyx":1534
 *         if not isinstance(sslcontext, ssl_SSLContext):
 *             raise TypeError(
 *                 f'sslcontext is expected to be an instance of ssl.SSLContext, '             # <<<<<<<<<<<<<<
 *                 f'got {sslcontext!r}')
 * 
 */
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_sslcontext_is_expected_to_be_an, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1534, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1533
 *         """
 *         if not isinstance(sslcontext, ssl_SSLContext):
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 f'sslcontext is expected to be an instance of ssl.SSLContext, '
 *                 f'got {sslcontext!r}')
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 1533, __pyx_L1_error)

    /* "uvloop/loop.pyx":1532
 *         immediately.
 *         """
 *         if not isinstance(sslcontext, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 f'sslcontext is expected to be an instance of ssl.SSLContext, '
 */
  }

  /* "uvloop/loop.pyx":1537
 *                 f'got {sslcontext!r}')
 * 
 *         if not isinstance(transport, (TCPTransport, UnixTransport)):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 f'transport {transport!r} is not supported by start_tls()')
 */
  __pyx_t_2 = __Pyx_TypeCheck(__pyx_cur_scope->__pyx_v_transport, __pyx_ptype_6uvloop_4loop_TCPTransport); 
  __pyx_t_5 = (__pyx_t_2 != 0);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_TypeCheck(__pyx_cur_scope->__pyx_v_transport, __pyx_ptype_6uvloop_4loop_UnixTransport); 
  __pyx_t_2 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":1539
 *         if not isinstance(transport, (TCPTransport, UnixTransport)):
 *             raise TypeError(
 *                 f'transport {transport!r} is not supported by start_tls()')             # <<<<<<<<<<<<<<
 * 
 *         waiter = self._new_future()
 */
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = 0;
    __pyx_t_7 = 127;
    __Pyx_INCREF(__pyx_kp_u_transport_2);
    __pyx_t_6 += 10;
    __Pyx_GIVEREF(__pyx_kp_u_transport_2);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_transport_2);
    __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_cur_scope->__pyx_v_transport), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_7) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_7;
    __pyx_t_6 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
    __pyx_t_4 = 0;
    __Pyx_INCREF(__pyx_kp_u_is_not_supported_by_start_tls);
    __pyx_t_6 += 32;
    __Pyx_GIVEREF(__pyx_kp_u_is_not_supported_by_start_tls);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_is_not_supported_by_start_tls);
    __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1539, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":1538
 * 
 *         if not isinstance(transport, (TCPTransport, UnixTransport)):
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 f'transport {transport!r} is not supported by start_tls()')
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 1538, __pyx_L1_error)

    /* "uvloop/loop.pyx":1537
 *                 f'got {sslcontext!r}')
 * 
 *         if not isinstance(transport, (TCPTransport, UnixTransport)):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 f'transport {transport!r} is not supported by start_tls()')
 */
  }

  /* "uvloop/loop.pyx":1541
 *                 f'transport {transport!r} is not supported by start_tls()')
 * 
 *         waiter = self._new_future()             # <<<<<<<<<<<<<<
 *         ssl_protocol = SSLProtocol(
 *             self, protocol, sslcontext, waiter,
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_waiter = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1542
 * 
 *         waiter = self._new_future()
 *         ssl_protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *             self, protocol, sslcontext, waiter,
 *             server_side, server_hostname,
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_SSLProtocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/loop.pyx":1544
 *         ssl_protocol = SSLProtocol(
 *             self, protocol, sslcontext, waiter,
 *             server_side, server_hostname,             # <<<<<<<<<<<<<<
 *             ssl_handshake_timeout=ssl_handshake_timeout,
 *             call_connection_made=False)
 */
  __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_protocol);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sslcontext);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sslcontext);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_cur_scope->__pyx_v_sslcontext);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_waiter);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_waiter);
  PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_cur_scope->__pyx_v_waiter);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_side);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_side);
  PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_cur_scope->__pyx_v_server_side);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_hostname);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_hostname);
  PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_cur_scope->__pyx_v_server_hostname);

  /* "uvloop/loop.pyx":1545
 *             self, protocol, sslcontext, waiter,
 *             server_side, server_hostname,
 *             ssl_handshake_timeout=ssl_handshake_timeout,             # <<<<<<<<<<<<<<
 *             call_connection_made=False)
 * 
 */
  __pyx_t_8 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_ssl_handshake_timeout, __pyx_cur_scope->__pyx_v_ssl_handshake_timeout) < 0) __PYX_ERR(2, 1545, __pyx_L1_error)

  /* "uvloop/loop.pyx":1546
 *             server_side, server_hostname,
 *             ssl_handshake_timeout=ssl_handshake_timeout,
 *             call_connection_made=False)             # <<<<<<<<<<<<<<
 * 
 *         # Pause early so that "ssl_protocol.data_received()" doesn't
 */
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_call_connection_made, Py_False) < 0) __PYX_ERR(2, 1545, __pyx_L1_error)

  /* "uvloop/loop.pyx":1542
 * 
 *         waiter = self._new_future()
 *         ssl_protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *             self, protocol, sslcontext, waiter,
 *             server_side, server_hostname,
 */
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_cur_scope->__pyx_v_ssl_protocol = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":1550
 *         # Pause early so that "ssl_protocol.data_received()" doesn't
 *         # have a chance to get called before "ssl_protocol.connection_made()".
 *         transport.pause_reading()             # <<<<<<<<<<<<<<
 * 
 *         transport.set_protocol(ssl_protocol)
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_transport, __pyx_n_s_pause_reading); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1550, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1550, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":1552
 *         transport.pause_reading()
 * 
 *         transport.set_protocol(ssl_protocol)             # <<<<<<<<<<<<<<
 *         conmade_cb = self.call_soon(ssl_protocol.connection_made, transport)
 *         resume_cb = self.call_soon(transport.resume_reading)
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_transport, __pyx_n_s_set_protocol); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_cur_scope->__pyx_v_ssl_protocol); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1552, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_ssl_protocol};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1552, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_cur_scope->__pyx_v_ssl_protocol};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1552, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_protocol);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_protocol);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_cur_scope->__pyx_v_ssl_protocol);
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_1, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1552, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":1553
 * 
 *         transport.set_protocol(ssl_protocol)
 *         conmade_cb = self.call_soon(ssl_protocol.connection_made, transport)             # <<<<<<<<<<<<<<
 *         resume_cb = self.call_soon(transport.resume_reading)
 * 
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_ssl_protocol, __pyx_n_s_connection_made); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  __pyx_t_10 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
      __pyx_t_10 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_8)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_1, __pyx_cur_scope->__pyx_v_transport};
    __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1553, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_1, __pyx_cur_scope->__pyx_v_transport};
    __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1553, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  {
    __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_t_1);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_transport);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_transport);
    PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_cur_scope->__pyx_v_transport);
    __pyx_t_1 = 0;
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_cur_scope->__pyx_v_conmade_cb = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":1554
 *         transport.set_protocol(ssl_protocol)
 *         conmade_cb = self.call_soon(ssl_protocol.connection_made, transport)
 *         resume_cb = self.call_soon(transport.resume_reading)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_transport, __pyx_n_s_resume_reading); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1554, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_GOTREF(__pyx_t_9);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_11};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_11};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1554, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_11);
      __pyx_t_11 = 0;
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_4, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1554, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_cur_scope->__pyx_v_resume_cb = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":1556
 *         resume_cb = self.call_soon(transport.resume_reading)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
    __Pyx_XGOTREF(__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_14);
    /*try:*/ {

      /* "uvloop/loop.pyx":1557
 * 
 *         try:
 *             await waiter             # <<<<<<<<<<<<<<
 *         except Exception:
 *             transport.close()
 */
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_12;
        __Pyx_XGIVEREF(__pyx_t_13);
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_13;
        __Pyx_XGIVEREF(__pyx_t_14);
        __pyx_cur_scope->__pyx_t_2 = __pyx_t_14;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L14_resume_from_await:;
        __pyx_t_12 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_12);
        __pyx_t_13 = __pyx_cur_scope->__pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = 0;
        __Pyx_XGOTREF(__pyx_t_13);
        __pyx_t_14 = __pyx_cur_scope->__pyx_t_2;
        __pyx_cur_scope->__pyx_t_2 = 0;
        __Pyx_XGOTREF(__pyx_t_14);
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1557, __pyx_L8_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 1557, __pyx_L8_error)
        }
      }

      /* "uvloop/loop.pyx":1556
 *         resume_cb = self.call_soon(transport.resume_reading)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    goto __pyx_L13_try_end;
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":1558
 *         try:
 *             await waiter
 *         except Exception:             # <<<<<<<<<<<<<<
 *             transport.close()
 *             conmade_cb.cancel()
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.Loop.start_tls", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_4) < 0) __PYX_ERR(2, 1558, __pyx_L10_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_4);

      /* "uvloop/loop.pyx":1559
 *             await waiter
 *         except Exception:
 *             transport.close()             # <<<<<<<<<<<<<<
 *             conmade_cb.cancel()
 *             resume_cb.cancel()
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_transport, __pyx_n_s_close); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1559, __pyx_L10_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_15 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_15)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (__pyx_t_15) {
        __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_15); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1559, __pyx_L10_except_error)
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1559, __pyx_L10_except_error)
      }
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "uvloop/loop.pyx":1560
 *         except Exception:
 *             transport.close()
 *             conmade_cb.cancel()             # <<<<<<<<<<<<<<
 *             resume_cb.cancel()
 *             raise
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_conmade_cb, __pyx_n_s_cancel); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1560, __pyx_L10_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_15 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_15)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (__pyx_t_15) {
        __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_15); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1560, __pyx_L10_except_error)
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1560, __pyx_L10_except_error)
      }
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "uvloop/loop.pyx":1561
 *             transport.close()
 *             conmade_cb.cancel()
 *             resume_cb.cancel()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_resume_cb, __pyx_n_s_cancel); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1561, __pyx_L10_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_15 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_15)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_15);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (__pyx_t_15) {
        __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_15); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1561, __pyx_L10_except_error)
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1561, __pyx_L10_except_error)
      }
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "uvloop/loop.pyx":1562
 *             conmade_cb.cancel()
 *             resume_cb.cancel()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         return ssl_protocol._app_transport
 */
      __Pyx_GIVEREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_8, __pyx_t_4);
      __pyx_t_9 = 0; __pyx_t_8 = 0; __pyx_t_4 = 0; 
      __PYX_ERR(2, 1562, __pyx_L10_except_error)
    }
    goto __pyx_L10_except_error;
    __pyx_L10_except_error:;

    /* "uvloop/loop.pyx":1556
 *         resume_cb = self.call_soon(transport.resume_reading)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_XGIVEREF(__pyx_t_13);
    __Pyx_XGIVEREF(__pyx_t_14);
    __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
    goto __pyx_L1_error;
    __pyx_L13_try_end:;
  }

  /* "uvloop/loop.pyx":1564
 *             raise
 * 
 *         return ssl_protocol._app_transport             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_ssl_protocol, __pyx_n_s_app_transport); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":1523
 * 
 *     @cython.iterable_coroutine
 *     async def start_tls(self, transport, protocol, sslcontext, *,             # <<<<<<<<<<<<<<
 *                         server_side=False,
 *                         server_hostname=None,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("start_tls", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_57generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1567
 * 
 *     @cython.iterable_coroutine
 *     async def create_server(self, protocol_factory, host=None, port=None,             # <<<<<<<<<<<<<<
 *                             *,
 *                             int family=uv.AF_UNSPEC,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_56create_server(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_55create_server[] = "Loop.create_server(self, protocol_factory, host=None, port=None, *, int family=uv.AF_UNSPEC, int flags=uv.AI_PASSIVE, sock=None, backlog=100, ssl=None, reuse_address=None, reuse_port=None, ssl_handshake_timeout=None)\nA coroutine which creates a TCP server bound to host and port.\n\n        The return value is a Server object which can be used to stop\n        the service.\n\n        If host is an empty string or None all interfaces are assumed\n        and a list of multiple sockets will be returned (most likely\n        one for IPv4 and another one for IPv6). The host parameter can also be a\n        sequence (e.g. list) of hosts to bind to.\n\n        family can be set to either AF_INET or AF_INET6 to force the\n        socket to use IPv4 or IPv6. If not set it will be determined\n        from host (defaults to AF_UNSPEC).\n\n        flags is a bitmask for getaddrinfo().\n\n        sock can optionally be specified in order to use a preexisting\n        socket object.\n\n        backlog is the maximum number of queued connections passed to\n        listen() (defaults to 100).\n\n        ssl can be set to an SSLContext to enable SSL over the\n        accepted connections.\n\n        reuse_address tells the kernel to reuse a local socket in\n        TIME_WAIT state, without waiting for its natural timeout to\n        expire. If not specified will automatically be set to True on\n        UNIX.\n\n        reuse_port tells the kernel to allow this endpoint to be bound to\n        the same port as other existing endpoints are bound to, so long as\n        they all set this flag when being created. This option is not\n        supported on Windows.\n\n        ssl_handshake_timeout is the time in seconds that an SSL server\n        will wait for completion of the SSL handshake before aborting the\n        connection. Default is 60s.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_56create_server(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_host = 0;
  PyObject *__pyx_v_port = 0;
  int __pyx_v_family;
  int __pyx_v_flags;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_backlog = 0;
  PyObject *__pyx_v_ssl = 0;
  CYTHON_UNUSED PyObject *__pyx_v_reuse_address = 0;
  PyObject *__pyx_v_reuse_port = 0;
  PyObject *__pyx_v_ssl_handshake_timeout = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_server (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_host,&__pyx_n_s_port,&__pyx_n_s_family,&__pyx_n_s_flags,&__pyx_n_s_sock,&__pyx_n_s_backlog,&__pyx_n_s_ssl,&__pyx_n_s_reuse_address,&__pyx_n_s_reuse_port,&__pyx_n_s_ssl_handshake_timeout,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1571
 *                             int family=uv.AF_UNSPEC,
 *                             int flags=uv.AI_PASSIVE,
 *                             sock=None,             # <<<<<<<<<<<<<<
 *                             backlog=100,
 *                             ssl=None,
 */
    values[5] = ((PyObject *)Py_None);
    values[6] = ((PyObject *)__pyx_int_100);

    /* "uvloop/loop.pyx":1573
 *                             sock=None,
 *                             backlog=100,
 *                             ssl=None,             # <<<<<<<<<<<<<<
 *                             reuse_address=None,  # ignored, libuv sets it
 *                             reuse_port=None,
 */
    values[7] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1574
 *                             backlog=100,
 *                             ssl=None,
 *                             reuse_address=None,  # ignored, libuv sets it             # <<<<<<<<<<<<<<
 *                             reuse_port=None,
 *                             ssl_handshake_timeout=None):
 */
    values[8] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1575
 *                             ssl=None,
 *                             reuse_address=None,  # ignored, libuv sets it
 *                             reuse_port=None,             # <<<<<<<<<<<<<<
 *                             ssl_handshake_timeout=None):
 *         """A coroutine which creates a TCP server bound to host and port.
 */
    values[9] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1576
 *                             reuse_address=None,  # ignored, libuv sets it
 *                             reuse_port=None,
 *                             ssl_handshake_timeout=None):             # <<<<<<<<<<<<<<
 *         """A coroutine which creates a TCP server bound to host and port.
 * 
 */
    values[10] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_host);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_port);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (kw_args > 0 && likely(kw_args <= 8)) {
        Py_ssize_t index;
        for (index = 3; index < 11 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_server") < 0)) __PYX_ERR(2, 1567, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_host = values[1];
    __pyx_v_port = values[2];
    if (values[3]) {
      __pyx_v_family = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_family == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1569, __pyx_L3_error)
    } else {
      __pyx_v_family = __pyx_k__53;
    }
    if (values[4]) {
      __pyx_v_flags = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1570, __pyx_L3_error)
    } else {
      __pyx_v_flags = __pyx_k__54;
    }
    __pyx_v_sock = values[5];
    __pyx_v_backlog = values[6];
    __pyx_v_ssl = values[7];
    __pyx_v_reuse_address = values[8];
    __pyx_v_reuse_port = values[9];
    __pyx_v_ssl_handshake_timeout = values[10];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_server", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1567, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_55create_server(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_host, __pyx_v_port, __pyx_v_family, __pyx_v_flags, __pyx_v_sock, __pyx_v_backlog, __pyx_v_ssl, __pyx_v_reuse_address, __pyx_v_reuse_port, __pyx_v_ssl_handshake_timeout);

  /* "uvloop/loop.pyx":1567
 * 
 *     @cython.iterable_coroutine
 *     async def create_server(self, protocol_factory, host=None, port=None,             # <<<<<<<<<<<<<<
 *                             *,
 *                             int family=uv.AF_UNSPEC,
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_55create_server(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_flags, PyObject *__pyx_v_sock, PyObject *__pyx_v_backlog, PyObject *__pyx_v_ssl, CYTHON_UNUSED PyObject *__pyx_v_reuse_address, PyObject *__pyx_v_reuse_port, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_server", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_8_create_server(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_8_create_server, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1567, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_host = __pyx_v_host;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_host);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_host);
  __pyx_cur_scope->__pyx_v_port = __pyx_v_port;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_port);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_port);
  __pyx_cur_scope->__pyx_v_family = __pyx_v_family;
  __pyx_cur_scope->__pyx_v_flags = __pyx_v_flags;
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_backlog = __pyx_v_backlog;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_backlog);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_backlog);
  __pyx_cur_scope->__pyx_v_ssl = __pyx_v_ssl;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl);
  __pyx_cur_scope->__pyx_v_reuse_address = __pyx_v_reuse_address;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_reuse_address);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_reuse_address);
  __pyx_cur_scope->__pyx_v_reuse_port = __pyx_v_reuse_port;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_reuse_port);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_reuse_port);
  __pyx_cur_scope->__pyx_v_ssl_handshake_timeout = __pyx_v_ssl_handshake_timeout;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_57generator3, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_create_server, __pyx_n_s_Loop_create_server, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1567, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_57generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  struct addrinfo *__pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_server", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L10_resume_from_await;
    case 2: goto __pyx_L26_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1567, __pyx_L1_error)

  /* "uvloop/loop.pyx":1621
 *             Server server
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *             if host is not None or port is not None:
 *                 raise ValueError(
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1622
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    __pyx_t_3 = (__pyx_cur_scope->__pyx_v_host != Py_None);
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_port != Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L8_bool_binop_done:;
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1623
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_server(
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1623, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 1623, __pyx_L1_error)

      /* "uvloop/loop.pyx":1622
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    }

    /* "uvloop/loop.pyx":1625
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_server(             # <<<<<<<<<<<<<<
 *                 protocol_factory, sock=sock, ssl=ssl)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_create_unix_server); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "uvloop/loop.pyx":1626
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_server(
 *                 protocol_factory, sock=sock, ssl=ssl)             # <<<<<<<<<<<<<<
 * 
 *         server = Server(self)
 */
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_cur_scope->__pyx_v_protocol_factory);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_sock, __pyx_cur_scope->__pyx_v_sock) < 0) __PYX_ERR(2, 1626, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ssl, __pyx_cur_scope->__pyx_v_ssl) < 0) __PYX_ERR(2, 1626, __pyx_L1_error)

    /* "uvloop/loop.pyx":1625
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_server(             # <<<<<<<<<<<<<<
 *                 protocol_factory, sock=sock, ssl=ssl)
 * 
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1625, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XGOTREF(__pyx_r);
    if (likely(__pyx_r)) {
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, awaiting value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L10_resume_from_await:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1625, __pyx_L1_error)
      __pyx_t_7 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_7);
    } else {
      __pyx_t_7 = NULL;
      if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_7) < 0) __PYX_ERR(2, 1625, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1621
 *             Server server
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *             if host is not None or port is not None:
 *                 raise ValueError(
 */
  }

  /* "uvloop/loop.pyx":1628
 *                 protocol_factory, sock=sock, ssl=ssl)
 * 
 *         server = Server(self)             # <<<<<<<<<<<<<<
 * 
 *         if ssl is not None:
 */
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6uvloop_4loop_Server), ((PyObject *)__pyx_cur_scope->__pyx_v_self)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_cur_scope->__pyx_v_server = ((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":1630
 *         server = Server(self)
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_ssl != Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":1631
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 */
    __pyx_t_7 = __pyx_v_6uvloop_4loop_ssl_SSLContext;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_3 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_ssl, __pyx_t_7); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 1631, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_1 = ((!(__pyx_t_3 != 0)) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1632
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')             # <<<<<<<<<<<<<<
 *         else:
 *             if ssl_handshake_timeout is not None:
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__56, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(2, 1632, __pyx_L1_error)

      /* "uvloop/loop.pyx":1631
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 */
    }

    /* "uvloop/loop.pyx":1630
 *         server = Server(self)
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 */
    goto __pyx_L11;
  }

  /* "uvloop/loop.pyx":1634
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_ssl_handshake_timeout != Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":1635
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1635, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(2, 1635, __pyx_L1_error)

      /* "uvloop/loop.pyx":1634
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    }
  }
  __pyx_L11:;

  /* "uvloop/loop.pyx":1638
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_host != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_3 = __pyx_t_2;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_port != Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  __pyx_t_3 = __pyx_t_1;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":1639
 * 
 *         if host is not None or port is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    __pyx_t_3 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1640
 *         if host is not None or port is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(2, 1640, __pyx_L1_error)

      /* "uvloop/loop.pyx":1639
 * 
 *         if host is not None or port is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    }

    /* "uvloop/loop.pyx":1643
 *                     'host/port and sock can not be specified at the same time')
 * 
 *             reuse_port = bool(reuse_port)             # <<<<<<<<<<<<<<
 *             if reuse_port and not has_SO_REUSEPORT:
 *                 raise ValueError(
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_reuse_port); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1643, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyBool_FromLong((!(!__pyx_t_1))); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_reuse_port);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_reuse_port, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":1644
 * 
 *             reuse_port = bool(reuse_port)
 *             if reuse_port and not has_SO_REUSEPORT:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'reuse_port not supported by socket module')
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_reuse_port); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 1644, __pyx_L1_error)
    if (__pyx_t_3) {
    } else {
      __pyx_t_1 = __pyx_t_3;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_3 = ((!(__pyx_v_6uvloop_4loop_has_SO_REUSEPORT != 0)) != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L19_bool_binop_done:;
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1645
 *             reuse_port = bool(reuse_port)
 *             if reuse_port and not has_SO_REUSEPORT:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'reuse_port not supported by socket module')
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(2, 1645, __pyx_L1_error)

      /* "uvloop/loop.pyx":1644
 * 
 *             reuse_port = bool(reuse_port)
 *             if reuse_port and not has_SO_REUSEPORT:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'reuse_port not supported by socket module')
 */
    }

    /* "uvloop/loop.pyx":1648
 *                     'reuse_port not supported by socket module')
 * 
 *             if host == '':             # <<<<<<<<<<<<<<
 *                 hosts = [None]
 *             elif (isinstance(host, str) or not isinstance(host, col_Iterable)):
 */
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_cur_scope->__pyx_v_host, __pyx_kp_u__7, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1648, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":1649
 * 
 *             if host == '':
 *                 hosts = [None]             # <<<<<<<<<<<<<<
 *             elif (isinstance(host, str) or not isinstance(host, col_Iterable)):
 *                 hosts = [host]
 */
      __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1649, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      PyList_SET_ITEM(__pyx_t_7, 0, Py_None);
      __Pyx_GIVEREF(__pyx_t_7);
      __pyx_cur_scope->__pyx_v_hosts = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":1648
 *                     'reuse_port not supported by socket module')
 * 
 *             if host == '':             # <<<<<<<<<<<<<<
 *                 hosts = [None]
 *             elif (isinstance(host, str) or not isinstance(host, col_Iterable)):
 */
      goto __pyx_L21;
    }

    /* "uvloop/loop.pyx":1650
 *             if host == '':
 *                 hosts = [None]
 *             elif (isinstance(host, str) or not isinstance(host, col_Iterable)):             # <<<<<<<<<<<<<<
 *                 hosts = [host]
 *             else:
 */
    __pyx_t_3 = PyUnicode_Check(__pyx_cur_scope->__pyx_v_host); 
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L22_bool_binop_done;
    }
    __pyx_t_7 = __pyx_v_6uvloop_4loop_col_Iterable;
    __Pyx_INCREF(__pyx_t_7);
    __pyx_t_2 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_host, __pyx_t_7); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 1650, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L22_bool_binop_done:;
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":1651
 *                 hosts = [None]
 *             elif (isinstance(host, str) or not isinstance(host, col_Iterable)):
 *                 hosts = [host]             # <<<<<<<<<<<<<<
 *             else:
 *                 hosts = host
 */
      __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_host);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_host);
      PyList_SET_ITEM(__pyx_t_7, 0, __pyx_cur_scope->__pyx_v_host);
      __Pyx_GIVEREF(__pyx_t_7);
      __pyx_cur_scope->__pyx_v_hosts = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":1650
 *             if host == '':
 *                 hosts = [None]
 *             elif (isinstance(host, str) or not isinstance(host, col_Iterable)):             # <<<<<<<<<<<<<<
 *                 hosts = [host]
 *             else:
 */
      goto __pyx_L21;
    }

    /* "uvloop/loop.pyx":1653
 *                 hosts = [host]
 *             else:
 *                 hosts = host             # <<<<<<<<<<<<<<
 * 
 *             fs = [self._getaddrinfo(host, port, family,
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_host);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_host);
      __pyx_cur_scope->__pyx_v_hosts = __pyx_cur_scope->__pyx_v_host;
    }
    __pyx_L21:;

    /* "uvloop/loop.pyx":1655
 *                 hosts = host
 * 
 *             fs = [self._getaddrinfo(host, port, family,             # <<<<<<<<<<<<<<
 *                                     uv.SOCK_STREAM, 0, flags,
 *                                     0) for host in hosts]
 */
    { /* enter inner scope */
      __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1655, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);

      /* "uvloop/loop.pyx":1657
 *             fs = [self._getaddrinfo(host, port, family,
 *                                     uv.SOCK_STREAM, 0, flags,
 *                                     0) for host in hosts]             # <<<<<<<<<<<<<<
 * 
 *             infos = await aio_gather(*fs, loop=self)
 */
      if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_hosts)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_hosts)) {
        __pyx_t_4 = __pyx_cur_scope->__pyx_v_hosts; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_hosts); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1657, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_9 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1657, __pyx_L1_error)
      }
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_4))) {
            if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_5); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(2, 1657, __pyx_L1_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1657, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          } else {
            if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_5); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(2, 1657, __pyx_L1_error)
            #else
            __pyx_t_5 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1657, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
          }
        } else {
          __pyx_t_5 = __pyx_t_9(__pyx_t_4);
          if (unlikely(!__pyx_t_5)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(2, 1657, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_5);
        }
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_7genexpr__pyx_v_host);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_7genexpr__pyx_v_host, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;

        /* "uvloop/loop.pyx":1655
 *                 hosts = host
 * 
 *             fs = [self._getaddrinfo(host, port, family,             # <<<<<<<<<<<<<<
 *                                     uv.SOCK_STREAM, 0, flags,
 *                                     0) for host in hosts]
 */
        __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_getaddrinfo(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_7genexpr__pyx_v_host, __pyx_cur_scope->__pyx_v_port, __pyx_cur_scope->__pyx_v_family, SOCK_STREAM, 0, __pyx_cur_scope->__pyx_v_flags, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1655, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_7, (PyObject*)__pyx_t_5))) __PYX_ERR(2, 1655, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "uvloop/loop.pyx":1657
 *             fs = [self._getaddrinfo(host, port, family,
 *                                     uv.SOCK_STREAM, 0, flags,
 *                                     0) for host in hosts]             # <<<<<<<<<<<<<<
 * 
 *             infos = await aio_gather(*fs, loop=self)
 */
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } /* exit inner scope */
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_cur_scope->__pyx_v_fs = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":1659
 *                                     0) for host in hosts]
 * 
 *             infos = await aio_gather(*fs, loop=self)             # <<<<<<<<<<<<<<
 * 
 *             completed = False
 */
    __pyx_t_7 = PySequence_Tuple(__pyx_cur_scope->__pyx_v_fs); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loop, ((PyObject *)__pyx_cur_scope->__pyx_v_self)) < 0) __PYX_ERR(2, 1659, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_gather, __pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1659, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_r);
    if (likely(__pyx_r)) {
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, awaiting value */
      __pyx_generator->resume_label = 2;
      return __pyx_r;
      __pyx_L26_resume_from_await:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1659, __pyx_L1_error)
      __pyx_t_5 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_5);
    } else {
      __pyx_t_5 = NULL;
      if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_5) < 0) __PYX_ERR(2, 1659, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_cur_scope->__pyx_v_infos = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":1661
 *             infos = await aio_gather(*fs, loop=self)
 * 
 *             completed = False             # <<<<<<<<<<<<<<
 *             try:
 *                 for info in infos:
 */
    __pyx_cur_scope->__pyx_v_completed = 0;

    /* "uvloop/loop.pyx":1662
 * 
 *             completed = False
 *             try:             # <<<<<<<<<<<<<<
 *                 for info in infos:
 *                     addrinfo = (<AddrInfo>info).data
 */
    /*try:*/ {

      /* "uvloop/loop.pyx":1663
 *             completed = False
 *             try:
 *                 for info in infos:             # <<<<<<<<<<<<<<
 *                     addrinfo = (<AddrInfo>info).data
 *                     while addrinfo != NULL:
 */
      if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_infos)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_infos)) {
        __pyx_t_5 = __pyx_cur_scope->__pyx_v_infos; __Pyx_INCREF(__pyx_t_5); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
      } else {
        __pyx_t_8 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_infos); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1663, __pyx_L28_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_9 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1663, __pyx_L28_error)
      }
      for (;;) {
        if (likely(!__pyx_t_9)) {
          if (likely(PyList_CheckExact(__pyx_t_5))) {
            if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(2, 1663, __pyx_L28_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1663, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          } else {
            if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(2, 1663, __pyx_L28_error)
            #else
            __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1663, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
          }
        } else {
          __pyx_t_4 = __pyx_t_9(__pyx_t_5);
          if (unlikely(!__pyx_t_4)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(2, 1663, __pyx_L28_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_info);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_info, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;

        /* "uvloop/loop.pyx":1664
 *             try:
 *                 for info in infos:
 *                     addrinfo = (<AddrInfo>info).data             # <<<<<<<<<<<<<<
 *                     while addrinfo != NULL:
 *                         if addrinfo.ai_family == uv.AF_UNSPEC:
 */
        __pyx_t_10 = ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_cur_scope->__pyx_v_info)->data;
        __pyx_cur_scope->__pyx_v_addrinfo = __pyx_t_10;

        /* "uvloop/loop.pyx":1665
 *                 for info in infos:
 *                     addrinfo = (<AddrInfo>info).data
 *                     while addrinfo != NULL:             # <<<<<<<<<<<<<<
 *                         if addrinfo.ai_family == uv.AF_UNSPEC:
 *                             raise RuntimeError('AF_UNSPEC in DNS results')
 */
        while (1) {
          __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_addrinfo != NULL) != 0);
          if (!__pyx_t_1) break;

          /* "uvloop/loop.pyx":1666
 *                     addrinfo = (<AddrInfo>info).data
 *                     while addrinfo != NULL:
 *                         if addrinfo.ai_family == uv.AF_UNSPEC:             # <<<<<<<<<<<<<<
 *                             raise RuntimeError('AF_UNSPEC in DNS results')
 * 
 */
          __pyx_t_1 = ((__pyx_cur_scope->__pyx_v_addrinfo->ai_family == AF_UNSPEC) != 0);
          if (unlikely(__pyx_t_1)) {

            /* "uvloop/loop.pyx":1667
 *                     while addrinfo != NULL:
 *                         if addrinfo.ai_family == uv.AF_UNSPEC:
 *                             raise RuntimeError('AF_UNSPEC in DNS results')             # <<<<<<<<<<<<<<
 * 
 *                         tcp = self._create_server(
 */
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__60, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1667, __pyx_L28_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_Raise(__pyx_t_4, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __PYX_ERR(2, 1667, __pyx_L28_error)

            /* "uvloop/loop.pyx":1666
 *                     addrinfo = (<AddrInfo>info).data
 *                     while addrinfo != NULL:
 *                         if addrinfo.ai_family == uv.AF_UNSPEC:             # <<<<<<<<<<<<<<
 *                             raise RuntimeError('AF_UNSPEC in DNS results')
 * 
 */
          }

          /* "uvloop/loop.pyx":1671
 *                         tcp = self._create_server(
 *                             addrinfo.ai_addr, protocol_factory, server,
 *                             ssl, reuse_port, backlog, ssl_handshake_timeout)             # <<<<<<<<<<<<<<
 * 
 *                         server._add_server(<TCPServer>tcp)
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_reuse_port); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1671, __pyx_L28_error)

          /* "uvloop/loop.pyx":1669
 *                             raise RuntimeError('AF_UNSPEC in DNS results')
 * 
 *                         tcp = self._create_server(             # <<<<<<<<<<<<<<
 *                             addrinfo.ai_addr, protocol_factory, server,
 *                             ssl, reuse_port, backlog, ssl_handshake_timeout)
 */
          __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_create_server(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_addrinfo->ai_addr, __pyx_cur_scope->__pyx_v_protocol_factory, __pyx_cur_scope->__pyx_v_server, __pyx_cur_scope->__pyx_v_ssl, __pyx_t_1, __pyx_cur_scope->__pyx_v_backlog, __pyx_cur_scope->__pyx_v_ssl_handshake_timeout); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1669, __pyx_L28_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_TCPServer))))) __PYX_ERR(2, 1669, __pyx_L28_error)
          __Pyx_XGOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_tcp));
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tcp, ((struct __pyx_obj_6uvloop_4loop_TCPServer *)__pyx_t_4));
          __Pyx_GIVEREF(__pyx_t_4);
          __pyx_t_4 = 0;

          /* "uvloop/loop.pyx":1673
 *                             ssl, reuse_port, backlog, ssl_handshake_timeout)
 * 
 *                         server._add_server(<TCPServer>tcp)             # <<<<<<<<<<<<<<
 * 
 *                         addrinfo = addrinfo.ai_next
 */
          __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_cur_scope->__pyx_v_server->__pyx_vtab)->_add_server(__pyx_cur_scope->__pyx_v_server, ((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_cur_scope->__pyx_v_tcp)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1673, __pyx_L28_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "uvloop/loop.pyx":1675
 *                         server._add_server(<TCPServer>tcp)
 * 
 *                         addrinfo = addrinfo.ai_next             # <<<<<<<<<<<<<<
 * 
 *                 completed = True
 */
          __pyx_t_10 = __pyx_cur_scope->__pyx_v_addrinfo->ai_next;
          __pyx_cur_scope->__pyx_v_addrinfo = __pyx_t_10;
        }

        /* "uvloop/loop.pyx":1663
 *             completed = False
 *             try:
 *                 for info in infos:             # <<<<<<<<<<<<<<
 *                     addrinfo = (<AddrInfo>info).data
 *                     while addrinfo != NULL:
 */
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":1677
 *                         addrinfo = addrinfo.ai_next
 * 
 *                 completed = True             # <<<<<<<<<<<<<<
 *             finally:
 *                 if not completed:
 */
      __pyx_cur_scope->__pyx_v_completed = 1;
    }

    /* "uvloop/loop.pyx":1679
 *                 completed = True
 *             finally:
 *                 if not completed:             # <<<<<<<<<<<<<<
 *                     server.close()
 *         else:
 */
    /*finally:*/ {
      /*normal exit:*/{
        __pyx_t_1 = ((!(__pyx_cur_scope->__pyx_v_completed != 0)) != 0);
        if (__pyx_t_1) {

          /* "uvloop/loop.pyx":1680
 *             finally:
 *                 if not completed:
 *                     server.close()             # <<<<<<<<<<<<<<
 *         else:
 *             if sock is None:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_server), __pyx_n_s_close); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1680, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
            }
          }
          if (__pyx_t_7) {
            __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1680, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          } else {
            __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1680, __pyx_L1_error)
          }
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "uvloop/loop.pyx":1679
 *                 completed = True
 *             finally:
 *                 if not completed:             # <<<<<<<<<<<<<<
 *                     server.close()
 *         else:
 */
        }
        goto __pyx_L29;
      }
      __pyx_L28_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_assign
        __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
        if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        __pyx_t_11 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
        {
          __pyx_t_1 = ((!(__pyx_cur_scope->__pyx_v_completed != 0)) != 0);
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":1680
 *             finally:
 *                 if not completed:
 *                     server.close()             # <<<<<<<<<<<<<<
 *         else:
 *             if sock is None:
 */
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_server), __pyx_n_s_close); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1680, __pyx_L37_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_7 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_4, function);
              }
            }
            if (__pyx_t_7) {
              __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1680, __pyx_L37_error)
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else {
              __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1680, __pyx_L37_error)
            }
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "uvloop/loop.pyx":1679
 *                 completed = True
 *             finally:
 *                 if not completed:             # <<<<<<<<<<<<<<
 *                     server.close()
 *         else:
 */
          }
        }
        if (PY_MAJOR_VERSION >= 3) {
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
        }
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
        __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
        __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
        goto __pyx_L1_error;
        __pyx_L37_error:;
        if (PY_MAJOR_VERSION >= 3) {
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
        }
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
        goto __pyx_L1_error;
      }
      __pyx_L29:;
    }

    /* "uvloop/loop.pyx":1638
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
    goto __pyx_L14;
  }

  /* "uvloop/loop.pyx":1682
 *                     server.close()
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('Neither host/port nor sock were specified')
 *             if not _is_sock_stream(sock.type):
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_sock == Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":1683
 *         else:
 *             if sock is None:
 *                 raise ValueError('Neither host/port nor sock were specified')             # <<<<<<<<<<<<<<
 *             if not _is_sock_stream(sock.type):
 *                 raise ValueError(
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(2, 1683, __pyx_L1_error)

      /* "uvloop/loop.pyx":1682
 *                     server.close()
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('Neither host/port nor sock were specified')
 *             if not _is_sock_stream(sock.type):
 */
    }

    /* "uvloop/loop.pyx":1684
 *             if sock is None:
 *                 raise ValueError('Neither host/port nor sock were specified')
 *             if not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A Stream Socket was expected, got {!r}'.format(sock))
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __pyx_f_6uvloop_4loop__is_sock_stream(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1684, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 1684, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = ((!__pyx_t_3) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1686
 *             if not _is_sock_stream(sock.type):
 *                 raise ValueError(
 *                     'A Stream Socket was expected, got {!r}'.format(sock))             # <<<<<<<<<<<<<<
 * 
 *             # libuv will set the socket to non-blocking mode, but
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_A_Stream_Socket_was_expected_got, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1686, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1686, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1686, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1686, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_cur_scope->__pyx_v_sock);
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1686, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":1685
 *                 raise ValueError('Neither host/port nor sock were specified')
 *             if not _is_sock_stream(sock.type):
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'A Stream Socket was expected, got {!r}'.format(sock))
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1685, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(2, 1685, __pyx_L1_error)

      /* "uvloop/loop.pyx":1684
 *             if sock is None:
 *                 raise ValueError('Neither host/port nor sock were specified')
 *             if not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A Stream Socket was expected, got {!r}'.format(sock))
 */
    }

    /* "uvloop/loop.pyx":1690
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *             tcp = TCPServer.new(self, protocol_factory, server, ssl,
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__62, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":1692
 *             sock.setblocking(False)
 * 
 *             tcp = TCPServer.new(self, protocol_factory, server, ssl,             # <<<<<<<<<<<<<<
 *                                 uv.AF_UNSPEC, ssl_handshake_timeout)
 * 
 */
    __pyx_t_4 = ((PyObject *)__pyx_f_6uvloop_4loop_9TCPServer_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol_factory, __pyx_cur_scope->__pyx_v_server, __pyx_cur_scope->__pyx_v_ssl, AF_UNSPEC, __pyx_cur_scope->__pyx_v_ssl_handshake_timeout)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_tcp = ((struct __pyx_obj_6uvloop_4loop_TCPServer *)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":1695
 *                                 uv.AF_UNSPEC, ssl_handshake_timeout)
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 tcp._open(sock.fileno())
 *                 tcp.listen(backlog)
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_19);
      __Pyx_XGOTREF(__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_17);
      /*try:*/ {

        /* "uvloop/loop.pyx":1696
 * 
 *             try:
 *                 tcp._open(sock.fileno())             # <<<<<<<<<<<<<<
 *                 tcp.listen(backlog)
 *             except Exception:
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1696, __pyx_L41_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (__pyx_t_6) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1696, __pyx_L41_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else {
          __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1696, __pyx_L41_error)
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1696, __pyx_L41_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_cur_scope->__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_tcp), __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1696, __pyx_L41_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/loop.pyx":1697
 *             try:
 *                 tcp._open(sock.fileno())
 *                 tcp.listen(backlog)             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 tcp._close()
 */
        __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_cur_scope->__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.listen(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_cur_scope->__pyx_v_tcp), __pyx_cur_scope->__pyx_v_backlog); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1697, __pyx_L41_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/loop.pyx":1695
 *                                 uv.AF_UNSPEC, ssl_handshake_timeout)
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 tcp._open(sock.fileno())
 *                 tcp.listen(backlog)
 */
      }
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      goto __pyx_L46_try_end;
      __pyx_L41_error:;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1698
 *                 tcp._open(sock.fileno())
 *                 tcp.listen(backlog)
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 tcp._close()
 *                 raise
 */
      __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_12) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(2, 1698, __pyx_L43_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_6);

        /* "uvloop/loop.pyx":1699
 *                 tcp.listen(backlog)
 *             except Exception:
 *                 tcp._close()             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_cur_scope->__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tcp)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1699, __pyx_L43_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "uvloop/loop.pyx":1700
 *             except Exception:
 *                 tcp._close()
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *             tcp._attach_fileobj(sock)
 */
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_5, __pyx_t_6);
        __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; 
        __PYX_ERR(2, 1700, __pyx_L43_except_error)
      }
      goto __pyx_L43_except_error;
      __pyx_L43_except_error:;

      /* "uvloop/loop.pyx":1695
 *                                 uv.AF_UNSPEC, ssl_handshake_timeout)
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 tcp._open(sock.fileno())
 *                 tcp.listen(backlog)
 */
      __Pyx_XGIVEREF(__pyx_t_19);
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_18, __pyx_t_17);
      goto __pyx_L1_error;
      __pyx_L46_try_end:;
    }

    /* "uvloop/loop.pyx":1702
 *                 raise
 * 
 *             tcp._attach_fileobj(sock)             # <<<<<<<<<<<<<<
 *             server._add_server(tcp)
 * 
 */
    __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_cur_scope->__pyx_v_tcp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._attach_fileobj(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_tcp), __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1702, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":1703
 * 
 *             tcp._attach_fileobj(sock)
 *             server._add_server(tcp)             # <<<<<<<<<<<<<<
 * 
 *         server._ref()
 */
    __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_cur_scope->__pyx_v_server->__pyx_vtab)->_add_server(__pyx_cur_scope->__pyx_v_server, ((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_cur_scope->__pyx_v_tcp)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L14:;

  /* "uvloop/loop.pyx":1705
 *             server._add_server(tcp)
 * 
 *         server._ref()             # <<<<<<<<<<<<<<
 *         return server
 * 
 */
  __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_cur_scope->__pyx_v_server->__pyx_vtab)->_ref(__pyx_cur_scope->__pyx_v_server); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/loop.pyx":1706
 * 
 *         server._ref()
 *         return server             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(((PyObject *)__pyx_cur_scope->__pyx_v_server));
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":1567
 * 
 *     @cython.iterable_coroutine
 *     async def create_server(self, protocol_factory, host=None, port=None,             # <<<<<<<<<<<<<<
 *                             *,
 *                             int family=uv.AF_UNSPEC,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("create_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_60generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1709
 * 
 *     @cython.iterable_coroutine
 *     async def create_connection(self, protocol_factory, host=None, port=None, *,             # <<<<<<<<<<<<<<
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,
 *                                 local_addr=None, server_hostname=None,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_59create_connection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_58create_connection[] = "Loop.create_connection(self, protocol_factory, host=None, port=None, *, ssl=None, family=0, proto=0, flags=0, sock=None, local_addr=None, server_hostname=None, ssl_handshake_timeout=None)\nConnect to a TCP server.\n\n        Create a streaming transport connection to a given Internet host and\n        port: socket family AF_INET or socket.AF_INET6 depending on host (or\n        family if specified), socket type SOCK_STREAM. protocol_factory must be\n        a callable returning a protocol instance.\n\n        This method is a coroutine which will try to establish the connection\n        in the background.  When successful, the coroutine returns a\n        (transport, protocol) pair.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_59create_connection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_host = 0;
  PyObject *__pyx_v_port = 0;
  PyObject *__pyx_v_ssl = 0;
  PyObject *__pyx_v_family = 0;
  PyObject *__pyx_v_proto = 0;
  PyObject *__pyx_v_flags = 0;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_local_addr = 0;
  PyObject *__pyx_v_server_hostname = 0;
  PyObject *__pyx_v_ssl_handshake_timeout = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_connection (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_host,&__pyx_n_s_port,&__pyx_n_s_ssl,&__pyx_n_s_family,&__pyx_n_s_proto,&__pyx_n_s_flags,&__pyx_n_s_sock,&__pyx_n_s_local_addr,&__pyx_n_s_server_hostname,&__pyx_n_s_ssl_handshake_timeout,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1710
 *     @cython.iterable_coroutine
 *     async def create_connection(self, protocol_factory, host=None, port=None, *,
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,             # <<<<<<<<<<<<<<
 *                                 local_addr=None, server_hostname=None,
 *                                 ssl_handshake_timeout=None):
 */
    values[3] = ((PyObject *)Py_None);
    values[4] = ((PyObject *)__pyx_int_0);
    values[5] = ((PyObject *)__pyx_int_0);
    values[6] = ((PyObject *)__pyx_int_0);
    values[7] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1711
 *     async def create_connection(self, protocol_factory, host=None, port=None, *,
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,
 *                                 local_addr=None, server_hostname=None,             # <<<<<<<<<<<<<<
 *                                 ssl_handshake_timeout=None):
 *         """Connect to a TCP server.
 */
    values[8] = ((PyObject *)Py_None);
    values[9] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1712
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,
 *                                 local_addr=None, server_hostname=None,
 *                                 ssl_handshake_timeout=None):             # <<<<<<<<<<<<<<
 *         """Connect to a TCP server.
 * 
 */
    values[10] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_host);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_port);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (kw_args > 0 && likely(kw_args <= 8)) {
        Py_ssize_t index;
        for (index = 3; index < 11 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_connection") < 0)) __PYX_ERR(2, 1709, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_host = values[1];
    __pyx_v_port = values[2];
    __pyx_v_ssl = values[3];
    __pyx_v_family = values[4];
    __pyx_v_proto = values[5];
    __pyx_v_flags = values[6];
    __pyx_v_sock = values[7];
    __pyx_v_local_addr = values[8];
    __pyx_v_server_hostname = values[9];
    __pyx_v_ssl_handshake_timeout = values[10];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_connection", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1709, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_58create_connection(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_host, __pyx_v_port, __pyx_v_ssl, __pyx_v_family, __pyx_v_proto, __pyx_v_flags, __pyx_v_sock, __pyx_v_local_addr, __pyx_v_server_hostname, __pyx_v_ssl_handshake_timeout);

  /* "uvloop/loop.pyx":1709
 * 
 *     @cython.iterable_coroutine
 *     async def create_connection(self, protocol_factory, host=None, port=None, *,             # <<<<<<<<<<<<<<
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,
 *                                 local_addr=None, server_hostname=None,
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_17create_connection_2generator22(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1880
 *                 # If they all have the same str(), raise one.
 *                 model = str(exceptions[0])
 *                 if all(str(exc) == model for exc in exceptions):             # <<<<<<<<<<<<<<
 *                     raise exceptions[0]
 *                 # Raise a combined exception so the user can see all
 */

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_17create_connection_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_10_genexpr(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_10_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1880, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_17create_connection_2generator22, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_create_connection_locals_genexpr, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1880, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_connection.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_17create_connection_2generator22(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1880, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exceptions)) { __Pyx_RaiseClosureNameError("exceptions"); __PYX_ERR(2, 1880, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exceptions == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(2, 1880, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_exceptions; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(2, 1880, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_exc);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_exc, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_cur_scope->__pyx_v_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_model)) { __Pyx_RaiseClosureNameError("model"); __PYX_ERR(2, 1880, __pyx_L1_error) }
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_cur_scope->__pyx_outer_scope->__pyx_v_model, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 1880, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = ((!__pyx_t_4) != 0);
    if (__pyx_t_5) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_True);
    __pyx_r = Py_True;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_17create_connection_5generator23(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1885
 *                 # the various error messages.
 *                 raise OSError('Multiple exceptions: {}'.format(
 *                     ', '.join(str(exc) for exc in exceptions)))             # <<<<<<<<<<<<<<
 *         else:
 *             if sock is None:
 */

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_17create_connection_3genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_11_genexpr(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_11_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1885, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_17create_connection_5generator23, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_create_connection_locals_genexpr, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1885, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_connection.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_17create_connection_5generator23(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1885, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(2, 1885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exceptions)) { __Pyx_RaiseClosureNameError("exceptions"); __PYX_ERR(2, 1885, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_exceptions == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(2, 1885, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_cur_scope->__pyx_outer_scope->__pyx_v_exceptions; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(2, 1885, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_exc);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_exc, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_cur_scope->__pyx_v_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1885, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_3))) __PYX_ERR(2, 1885, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":1709
 * 
 *     @cython.iterable_coroutine
 *     async def create_connection(self, protocol_factory, host=None, port=None, *,             # <<<<<<<<<<<<<<
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,
 *                                 local_addr=None, server_hostname=None,
 */

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_58create_connection(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_host, PyObject *__pyx_v_port, PyObject *__pyx_v_ssl, PyObject *__pyx_v_family, PyObject *__pyx_v_proto, PyObject *__pyx_v_flags, PyObject *__pyx_v_sock, PyObject *__pyx_v_local_addr, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_connection", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_9_create_connection(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_9_create_connection, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1709, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_host = __pyx_v_host;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_host);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_host);
  __pyx_cur_scope->__pyx_v_port = __pyx_v_port;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_port);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_port);
  __pyx_cur_scope->__pyx_v_ssl = __pyx_v_ssl;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl);
  __pyx_cur_scope->__pyx_v_family = __pyx_v_family;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_family);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_family);
  __pyx_cur_scope->__pyx_v_proto = __pyx_v_proto;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto);
  __pyx_cur_scope->__pyx_v_flags = __pyx_v_flags;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_flags);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_flags);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_local_addr = __pyx_v_local_addr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_local_addr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_local_addr);
  __pyx_cur_scope->__pyx_v_server_hostname = __pyx_v_server_hostname;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_hostname);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_hostname);
  __pyx_cur_scope->__pyx_v_ssl_handshake_timeout = __pyx_v_ssl_handshake_timeout;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_60generator4, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_create_connection, __pyx_n_s_Loop_create_connection, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1709, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_60generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  struct addrinfo *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  char const *__pyx_t_21;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  char const *__pyx_t_28;
  PyObject *__pyx_t_29 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_connection", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L10_resume_from_await;
    case 2: goto __pyx_L29_resume_from_await;
    case 3: goto __pyx_L68_resume_from_await;
    case 4: goto __pyx_L93_resume_from_await;
    case 5: goto __pyx_L103_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1709, __pyx_L1_error)

  /* "uvloop/loop.pyx":1725
 *         """
 *         cdef:
 *             AddrInfo ai_local = None             # <<<<<<<<<<<<<<
 *             AddrInfo ai_remote
 *             TCPTransport tr
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_cur_scope->__pyx_v_ai_local = ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)Py_None);

  /* "uvloop/loop.pyx":1729
 *             TCPTransport tr
 * 
 *             system.addrinfo *rai = NULL             # <<<<<<<<<<<<<<
 *             system.addrinfo *lai = NULL
 * 
 */
  __pyx_cur_scope->__pyx_v_rai = NULL;

  /* "uvloop/loop.pyx":1730
 * 
 *             system.addrinfo *rai = NULL
 *             system.addrinfo *lai = NULL             # <<<<<<<<<<<<<<
 * 
 *             system.addrinfo *rai_iter = NULL
 */
  __pyx_cur_scope->__pyx_v_lai = NULL;

  /* "uvloop/loop.pyx":1732
 *             system.addrinfo *lai = NULL
 * 
 *             system.addrinfo *rai_iter = NULL             # <<<<<<<<<<<<<<
 *             system.addrinfo *lai_iter = NULL
 * 
 */
  __pyx_cur_scope->__pyx_v_rai_iter = NULL;

  /* "uvloop/loop.pyx":1733
 * 
 *             system.addrinfo *rai_iter = NULL
 *             system.addrinfo *lai_iter = NULL             # <<<<<<<<<<<<<<
 * 
 *             system.addrinfo rai_static
 */
  __pyx_cur_scope->__pyx_v_lai_iter = NULL;

  /* "uvloop/loop.pyx":1744
 *             object ssl_waiter
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *             if host is not None or port is not None:
 *                 raise ValueError(
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_4, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 1744, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1745
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    __pyx_t_3 = (__pyx_cur_scope->__pyx_v_host != Py_None);
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_port != Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L8_bool_binop_done:;
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1746
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_connection(
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__63, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1746, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 1746, __pyx_L1_error)

      /* "uvloop/loop.pyx":1745
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    }

    /* "uvloop/loop.pyx":1748
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_connection(             # <<<<<<<<<<<<<<
 *                 protocol_factory, None,
 *                 sock=sock, ssl=ssl, server_hostname=server_hostname)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_create_unix_connection); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "uvloop/loop.pyx":1749
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_connection(
 *                 protocol_factory, None,             # <<<<<<<<<<<<<<
 *                 sock=sock, ssl=ssl, server_hostname=server_hostname)
 * 
 */
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_cur_scope->__pyx_v_protocol_factory);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_5, 1, Py_None);

    /* "uvloop/loop.pyx":1750
 *             return await self.create_unix_connection(
 *                 protocol_factory, None,
 *                 sock=sock, ssl=ssl, server_hostname=server_hostname)             # <<<<<<<<<<<<<<
 * 
 *         app_protocol = protocol = protocol_factory()
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1750, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_sock, __pyx_cur_scope->__pyx_v_sock) < 0) __PYX_ERR(2, 1750, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ssl, __pyx_cur_scope->__pyx_v_ssl) < 0) __PYX_ERR(2, 1750, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_server_hostname, __pyx_cur_scope->__pyx_v_server_hostname) < 0) __PYX_ERR(2, 1750, __pyx_L1_error)

    /* "uvloop/loop.pyx":1748
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_connection(             # <<<<<<<<<<<<<<
 *                 protocol_factory, None,
 *                 sock=sock, ssl=ssl, server_hostname=server_hostname)
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XGOTREF(__pyx_r);
    if (likely(__pyx_r)) {
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, awaiting value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L10_resume_from_await:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1748, __pyx_L1_error)
      __pyx_t_7 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_7);
    } else {
      __pyx_t_7 = NULL;
      if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_7) < 0) __PYX_ERR(2, 1748, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
    }
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1744
 *             object ssl_waiter
 * 
 *         if sock is not None and sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *             if host is not None or port is not None:
 *                 raise ValueError(
 */
  }

  /* "uvloop/loop.pyx":1752
 *                 sock=sock, ssl=ssl, server_hostname=server_hostname)
 * 
 *         app_protocol = protocol = protocol_factory()             # <<<<<<<<<<<<<<
 *         ssl_waiter = None
 *         if ssl:
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_protocol_factory; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1752, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1752, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_cur_scope->__pyx_v_app_protocol = __pyx_t_7;
  __Pyx_INCREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_cur_scope->__pyx_v_protocol = __pyx_t_7;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":1753
 * 
 *         app_protocol = protocol = protocol_factory()
 *         ssl_waiter = None             # <<<<<<<<<<<<<<
 *         if ssl:
 *             if server_hostname is None:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_cur_scope->__pyx_v_ssl_waiter = Py_None;

  /* "uvloop/loop.pyx":1754
 *         app_protocol = protocol = protocol_factory()
 *         ssl_waiter = None
 *         if ssl:             # <<<<<<<<<<<<<<
 *             if server_hostname is None:
 *                 if not host:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ssl); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1754, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1755
 *         ssl_waiter = None
 *         if ssl:
 *             if server_hostname is None:             # <<<<<<<<<<<<<<
 *                 if not host:
 *                     raise ValueError('You must set server_hostname '
 */
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_server_hostname == Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "uvloop/loop.pyx":1756
 *         if ssl:
 *             if server_hostname is None:
 *                 if not host:             # <<<<<<<<<<<<<<
 *                     raise ValueError('You must set server_hostname '
 *                                      'when using ssl without a host')
 */
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_host); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 1756, __pyx_L1_error)
      __pyx_t_1 = ((!__pyx_t_3) != 0);
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/loop.pyx":1757
 *             if server_hostname is None:
 *                 if not host:
 *                     raise ValueError('You must set server_hostname '             # <<<<<<<<<<<<<<
 *                                      'when using ssl without a host')
 *                 server_hostname = host
 */
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__64, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1757, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_Raise(__pyx_t_7, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __PYX_ERR(2, 1757, __pyx_L1_error)

        /* "uvloop/loop.pyx":1756
 *         if ssl:
 *             if server_hostname is None:
 *                 if not host:             # <<<<<<<<<<<<<<
 *                     raise ValueError('You must set server_hostname '
 *                                      'when using ssl without a host')
 */
      }

      /* "uvloop/loop.pyx":1759
 *                     raise ValueError('You must set server_hostname '
 *                                      'when using ssl without a host')
 *                 server_hostname = host             # <<<<<<<<<<<<<<
 * 
 *             ssl_waiter = self._new_future()
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_host);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_server_hostname);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_server_hostname, __pyx_cur_scope->__pyx_v_host);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_host);

      /* "uvloop/loop.pyx":1755
 *         ssl_waiter = None
 *         if ssl:
 *             if server_hostname is None:             # <<<<<<<<<<<<<<
 *                 if not host:
 *                     raise ValueError('You must set server_hostname '
 */
    }

    /* "uvloop/loop.pyx":1761
 *                 server_hostname = host
 * 
 *             ssl_waiter = self._new_future()             # <<<<<<<<<<<<<<
 *             sslcontext = None if isinstance(ssl, bool) else ssl
 *             protocol = SSLProtocol(
 */
    __pyx_t_7 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_ssl_waiter);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_ssl_waiter, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":1762
 * 
 *             ssl_waiter = self._new_future()
 *             sslcontext = None if isinstance(ssl, bool) else ssl             # <<<<<<<<<<<<<<
 *             protocol = SSLProtocol(
 *                 self, app_protocol, sslcontext, ssl_waiter,
 */
    __pyx_t_4 = ((PyObject*)&PyBool_Type);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_1 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_ssl, __pyx_t_4); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(2, 1762, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if ((__pyx_t_1 != 0)) {
      __Pyx_INCREF(Py_None);
      __pyx_t_7 = Py_None;
    } else {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
      __pyx_t_7 = __pyx_cur_scope->__pyx_v_ssl;
    }
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_cur_scope->__pyx_v_sslcontext = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":1763
 *             ssl_waiter = self._new_future()
 *             sslcontext = None if isinstance(ssl, bool) else ssl
 *             protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_SSLProtocol); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);

    /* "uvloop/loop.pyx":1765
 *             protocol = SSLProtocol(
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,             # <<<<<<<<<<<<<<
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *         else:
 */
    __pyx_t_4 = PyTuple_New(6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_app_protocol);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sslcontext);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sslcontext);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_cur_scope->__pyx_v_sslcontext);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_waiter);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_waiter);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_cur_scope->__pyx_v_ssl_waiter);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    PyTuple_SET_ITEM(__pyx_t_4, 4, Py_False);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_hostname);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_hostname);
    PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_cur_scope->__pyx_v_server_hostname);

    /* "uvloop/loop.pyx":1766
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,
 *                 ssl_handshake_timeout=ssl_handshake_timeout)             # <<<<<<<<<<<<<<
 *         else:
 *             if server_hostname is not None:
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_ssl_handshake_timeout, __pyx_cur_scope->__pyx_v_ssl_handshake_timeout) < 0) __PYX_ERR(2, 1766, __pyx_L1_error)

    /* "uvloop/loop.pyx":1763
 *             ssl_waiter = self._new_future()
 *             sslcontext = None if isinstance(ssl, bool) else ssl
 *             protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_protocol);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_protocol, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":1754
 *         app_protocol = protocol = protocol_factory()
 *         ssl_waiter = None
 *         if ssl:             # <<<<<<<<<<<<<<
 *             if server_hostname is None:
 *                 if not host:
 */
    goto __pyx_L11;
  }

  /* "uvloop/loop.pyx":1768
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *         else:
 *             if server_hostname is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_server_hostname != Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":1769
 *         else:
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')             # <<<<<<<<<<<<<<
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1769, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 1769, __pyx_L1_error)

      /* "uvloop/loop.pyx":1768
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *         else:
 *             if server_hostname is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 */
    }

    /* "uvloop/loop.pyx":1770
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    __pyx_t_3 = (__pyx_cur_scope->__pyx_v_ssl_handshake_timeout != Py_None);
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1771
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1771, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 1771, __pyx_L1_error)

      /* "uvloop/loop.pyx":1770
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    }
  }
  __pyx_L11:;

  /* "uvloop/loop.pyx":1774
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
  __pyx_t_3 = (__pyx_cur_scope->__pyx_v_host != Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L17_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_port != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L17_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":1775
 * 
 *         if host is not None or port is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":1776
 *         if host is not None or port is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__67, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1776, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 1776, __pyx_L1_error)

      /* "uvloop/loop.pyx":1775
 * 
 *         if host is not None or port is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host/port and sock can not be specified at the same time')
 */
    }

    /* "uvloop/loop.pyx":1779
 *                     'host/port and sock can not be specified at the same time')
 * 
 *             fs = []             # <<<<<<<<<<<<<<
 *             f1 = f2 = None
 * 
 */
    __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_cur_scope->__pyx_v_fs = ((PyObject*)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":1780
 * 
 *             fs = []
 *             f1 = f2 = None             # <<<<<<<<<<<<<<
 * 
 *             addr = __static_getaddrinfo(
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __pyx_cur_scope->__pyx_v_f1 = Py_None;
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __pyx_cur_scope->__pyx_v_f2 = Py_None;

    /* "uvloop/loop.pyx":1783
 * 
 *             addr = __static_getaddrinfo(
 *                     host, port, family, uv.SOCK_STREAM,             # <<<<<<<<<<<<<<
 *                     proto, <system.sockaddr*>&rai_addr_static)
 *             if addr is None:
 */
    __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_family); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1783, __pyx_L1_error)

    /* "uvloop/loop.pyx":1784
 *             addr = __static_getaddrinfo(
 *                     host, port, family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&rai_addr_static)             # <<<<<<<<<<<<<<
 *             if addr is None:
 *                 f1 = self._getaddrinfo(
 */
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_proto); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1784, __pyx_L1_error)

    /* "uvloop/loop.pyx":1782
 *             f1 = f2 = None
 * 
 *             addr = __static_getaddrinfo(             # <<<<<<<<<<<<<<
 *                     host, port, family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&rai_addr_static)
 */
    __pyx_t_6 = __pyx_f_6uvloop_4loop___static_getaddrinfo(__pyx_cur_scope->__pyx_v_host, __pyx_cur_scope->__pyx_v_port, __pyx_t_8, SOCK_STREAM, __pyx_t_9, ((struct sockaddr *)(&__pyx_cur_scope->__pyx_v_rai_addr_static))); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1782, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_cur_scope->__pyx_v_addr = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":1785
 *                     host, port, family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&rai_addr_static)
 *             if addr is None:             # <<<<<<<<<<<<<<
 *                 f1 = self._getaddrinfo(
 *                     host, port, family,
 */
    __pyx_t_3 = (__pyx_cur_scope->__pyx_v_addr == Py_None);
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":1787
 *             if addr is None:
 *                 f1 = self._getaddrinfo(
 *                     host, port, family,             # <<<<<<<<<<<<<<
 *                     uv.SOCK_STREAM, proto, flags,
 *                     0)  # 0 == don't unpack
 */
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_family); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1787, __pyx_L1_error)

      /* "uvloop/loop.pyx":1788
 *                 f1 = self._getaddrinfo(
 *                     host, port, family,
 *                     uv.SOCK_STREAM, proto, flags,             # <<<<<<<<<<<<<<
 *                     0)  # 0 == don't unpack
 * 
 */
      __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_proto); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1788, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_flags); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1788, __pyx_L1_error)

      /* "uvloop/loop.pyx":1786
 *                     proto, <system.sockaddr*>&rai_addr_static)
 *             if addr is None:
 *                 f1 = self._getaddrinfo(             # <<<<<<<<<<<<<<
 *                     host, port, family,
 *                     uv.SOCK_STREAM, proto, flags,
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_getaddrinfo(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_host, __pyx_cur_scope->__pyx_v_port, __pyx_t_9, SOCK_STREAM, __pyx_t_8, __pyx_t_10, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1786, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_f1);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_f1, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":1791
 *                     0)  # 0 == don't unpack
 * 
 *                 fs.append(f1)             # <<<<<<<<<<<<<<
 *             else:
 *                 rai_static.ai_addr = <system.sockaddr*>&rai_addr_static
 */
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_fs, __pyx_cur_scope->__pyx_v_f1); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 1791, __pyx_L1_error)

      /* "uvloop/loop.pyx":1785
 *                     host, port, family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&rai_addr_static)
 *             if addr is None:             # <<<<<<<<<<<<<<
 *                 f1 = self._getaddrinfo(
 *                     host, port, family,
 */
      goto __pyx_L20;
    }

    /* "uvloop/loop.pyx":1793
 *                 fs.append(f1)
 *             else:
 *                 rai_static.ai_addr = <system.sockaddr*>&rai_addr_static             # <<<<<<<<<<<<<<
 *                 rai_static.ai_next = NULL
 *                 rai = &rai_static
 */
    /*else*/ {
      __pyx_cur_scope->__pyx_v_rai_static.ai_addr = ((struct sockaddr *)(&__pyx_cur_scope->__pyx_v_rai_addr_static));

      /* "uvloop/loop.pyx":1794
 *             else:
 *                 rai_static.ai_addr = <system.sockaddr*>&rai_addr_static
 *                 rai_static.ai_next = NULL             # <<<<<<<<<<<<<<
 *                 rai = &rai_static
 * 
 */
      __pyx_cur_scope->__pyx_v_rai_static.ai_next = NULL;

      /* "uvloop/loop.pyx":1795
 *                 rai_static.ai_addr = <system.sockaddr*>&rai_addr_static
 *                 rai_static.ai_next = NULL
 *                 rai = &rai_static             # <<<<<<<<<<<<<<
 * 
 *             if local_addr is not None:
 */
      __pyx_cur_scope->__pyx_v_rai = (&__pyx_cur_scope->__pyx_v_rai_static);
    }
    __pyx_L20:;

    /* "uvloop/loop.pyx":1797
 *                 rai = &rai_static
 * 
 *             if local_addr is not None:             # <<<<<<<<<<<<<<
 *                 if not isinstance(local_addr, (tuple, list)) or \
 *                         len(local_addr) != 2:
 */
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_local_addr != Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "uvloop/loop.pyx":1798
 * 
 *             if local_addr is not None:
 *                 if not isinstance(local_addr, (tuple, list)) or \             # <<<<<<<<<<<<<<
 *                         len(local_addr) != 2:
 *                     raise ValueError(
 */
      __pyx_t_2 = PyTuple_Check(__pyx_cur_scope->__pyx_v_local_addr); 
      __pyx_t_12 = (__pyx_t_2 != 0);
      if (!__pyx_t_12) {
      } else {
        __pyx_t_1 = __pyx_t_12;
        goto __pyx_L25_bool_binop_done;
      }
      __pyx_t_12 = PyList_Check(__pyx_cur_scope->__pyx_v_local_addr); 
      __pyx_t_2 = (__pyx_t_12 != 0);
      __pyx_t_1 = __pyx_t_2;
      __pyx_L25_bool_binop_done:;
      __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
      if (!__pyx_t_2) {
      } else {
        __pyx_t_3 = __pyx_t_2;
        goto __pyx_L23_bool_binop_done;
      }

      /* "uvloop/loop.pyx":1799
 *             if local_addr is not None:
 *                 if not isinstance(local_addr, (tuple, list)) or \
 *                         len(local_addr) != 2:             # <<<<<<<<<<<<<<
 *                     raise ValueError(
 *                         'local_addr must be a tuple of host and port')
 */
      __pyx_t_13 = PyObject_Length(__pyx_cur_scope->__pyx_v_local_addr); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(2, 1799, __pyx_L1_error)
      __pyx_t_2 = ((__pyx_t_13 != 2) != 0);
      __pyx_t_3 = __pyx_t_2;
      __pyx_L23_bool_binop_done:;

      /* "uvloop/loop.pyx":1798
 * 
 *             if local_addr is not None:
 *                 if not isinstance(local_addr, (tuple, list)) or \             # <<<<<<<<<<<<<<
 *                         len(local_addr) != 2:
 *                     raise ValueError(
 */
      if (unlikely(__pyx_t_3)) {

        /* "uvloop/loop.pyx":1800
 *                 if not isinstance(local_addr, (tuple, list)) or \
 *                         len(local_addr) != 2:
 *                     raise ValueError(             # <<<<<<<<<<<<<<
 *                         'local_addr must be a tuple of host and port')
 * 
 */
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1800, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(2, 1800, __pyx_L1_error)

        /* "uvloop/loop.pyx":1798
 * 
 *             if local_addr is not None:
 *                 if not isinstance(local_addr, (tuple, list)) or \             # <<<<<<<<<<<<<<
 *                         len(local_addr) != 2:
 *                     raise ValueError(
 */
      }

      /* "uvloop/loop.pyx":1804
 * 
 *                 addr = __static_getaddrinfo(
 *                     local_addr[0], local_addr[1],             # <<<<<<<<<<<<<<
 *                     family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&lai_addr_static)
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_local_addr, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_local_addr, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1804, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "uvloop/loop.pyx":1805
 *                 addr = __static_getaddrinfo(
 *                     local_addr[0], local_addr[1],
 *                     family, uv.SOCK_STREAM,             # <<<<<<<<<<<<<<
 *                     proto, <system.sockaddr*>&lai_addr_static)
 *                 if addr is None:
 */
      __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_family); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1805, __pyx_L1_error)

      /* "uvloop/loop.pyx":1806
 *                     local_addr[0], local_addr[1],
 *                     family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&lai_addr_static)             # <<<<<<<<<<<<<<
 *                 if addr is None:
 *                     f2 = self._getaddrinfo(
 */
      __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_proto); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1806, __pyx_L1_error)

      /* "uvloop/loop.pyx":1803
 *                         'local_addr must be a tuple of host and port')
 * 
 *                 addr = __static_getaddrinfo(             # <<<<<<<<<<<<<<
 *                     local_addr[0], local_addr[1],
 *                     family, uv.SOCK_STREAM,
 */
      __pyx_t_4 = __pyx_f_6uvloop_4loop___static_getaddrinfo(__pyx_t_6, __pyx_t_5, __pyx_t_10, SOCK_STREAM, __pyx_t_8, ((struct sockaddr *)(&__pyx_cur_scope->__pyx_v_lai_addr_static))); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1803, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_addr);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_addr, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1807
 *                     family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&lai_addr_static)
 *                 if addr is None:             # <<<<<<<<<<<<<<
 *                     f2 = self._getaddrinfo(
 *                         local_addr[0], local_addr[1], family,
 */
      __pyx_t_3 = (__pyx_cur_scope->__pyx_v_addr == Py_None);
      __pyx_t_2 = (__pyx_t_3 != 0);
      if (__pyx_t_2) {

        /* "uvloop/loop.pyx":1809
 *                 if addr is None:
 *                     f2 = self._getaddrinfo(
 *                         local_addr[0], local_addr[1], family,             # <<<<<<<<<<<<<<
 *                         uv.SOCK_STREAM, proto, flags,
 *                         0)  # 0 == don't unpack
 */
        __pyx_t_4 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_local_addr, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1809, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_local_addr, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1809, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_family); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1809, __pyx_L1_error)

        /* "uvloop/loop.pyx":1810
 *                     f2 = self._getaddrinfo(
 *                         local_addr[0], local_addr[1], family,
 *                         uv.SOCK_STREAM, proto, flags,             # <<<<<<<<<<<<<<
 *                         0)  # 0 == don't unpack
 * 
 */
        __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_proto); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1810, __pyx_L1_error)
        __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_cur_scope->__pyx_v_flags); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1810, __pyx_L1_error)

        /* "uvloop/loop.pyx":1808
 *                     proto, <system.sockaddr*>&lai_addr_static)
 *                 if addr is None:
 *                     f2 = self._getaddrinfo(             # <<<<<<<<<<<<<<
 *                         local_addr[0], local_addr[1], family,
 *                         uv.SOCK_STREAM, proto, flags,
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_getaddrinfo(__pyx_cur_scope->__pyx_v_self, __pyx_t_4, __pyx_t_5, __pyx_t_8, SOCK_STREAM, __pyx_t_10, __pyx_t_9, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1808, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_f2);
        __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_f2, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_t_6 = 0;

        /* "uvloop/loop.pyx":1813
 *                         0)  # 0 == don't unpack
 * 
 *                     fs.append(f2)             # <<<<<<<<<<<<<<
 *                 else:
 *                     lai_static.ai_addr = <system.sockaddr*>&lai_addr_static
 */
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_fs, __pyx_cur_scope->__pyx_v_f2); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 1813, __pyx_L1_error)

        /* "uvloop/loop.pyx":1807
 *                     family, uv.SOCK_STREAM,
 *                     proto, <system.sockaddr*>&lai_addr_static)
 *                 if addr is None:             # <<<<<<<<<<<<<<
 *                     f2 = self._getaddrinfo(
 *                         local_addr[0], local_addr[1], family,
 */
        goto __pyx_L27;
      }

      /* "uvloop/loop.pyx":1815
 *                     fs.append(f2)
 *                 else:
 *                     lai_static.ai_addr = <system.sockaddr*>&lai_addr_static             # <<<<<<<<<<<<<<
 *                     lai_static.ai_next = NULL
 *                     lai = &lai_static
 */
      /*else*/ {
        __pyx_cur_scope->__pyx_v_lai_static.ai_addr = ((struct sockaddr *)(&__pyx_cur_scope->__pyx_v_lai_addr_static));

        /* "uvloop/loop.pyx":1816
 *                 else:
 *                     lai_static.ai_addr = <system.sockaddr*>&lai_addr_static
 *                     lai_static.ai_next = NULL             # <<<<<<<<<<<<<<
 *                     lai = &lai_static
 * 
 */
        __pyx_cur_scope->__pyx_v_lai_static.ai_next = NULL;

        /* "uvloop/loop.pyx":1817
 *                     lai_static.ai_addr = <system.sockaddr*>&lai_addr_static
 *                     lai_static.ai_next = NULL
 *                     lai = &lai_static             # <<<<<<<<<<<<<<
 * 
 *             if len(fs):
 */
        __pyx_cur_scope->__pyx_v_lai = (&__pyx_cur_scope->__pyx_v_lai_static);
      }
      __pyx_L27:;

      /* "uvloop/loop.pyx":1797
 *                 rai = &rai_static
 * 
 *             if local_addr is not None:             # <<<<<<<<<<<<<<
 *                 if not isinstance(local_addr, (tuple, list)) or \
 *                         len(local_addr) != 2:
 */
    }

    /* "uvloop/loop.pyx":1819
 *                     lai = &lai_static
 * 
 *             if len(fs):             # <<<<<<<<<<<<<<
 *                 await aio_wait(fs, loop=self)
 * 
 */
    __pyx_t_13 = PyList_GET_SIZE(__pyx_cur_scope->__pyx_v_fs); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(2, 1819, __pyx_L1_error)
    __pyx_t_2 = (__pyx_t_13 != 0);
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":1820
 * 
 *             if len(fs):
 *                 await aio_wait(fs, loop=self)             # <<<<<<<<<<<<<<
 * 
 *             if rai is NULL:
 */
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fs);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fs);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_cur_scope->__pyx_v_fs);
      __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_loop, ((PyObject *)__pyx_cur_scope->__pyx_v_self)) < 0) __PYX_ERR(2, 1820, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_wait, __pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 2;
        return __pyx_r;
        __pyx_L29_resume_from_await:;
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1820, __pyx_L1_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 1820, __pyx_L1_error)
        }
      }

      /* "uvloop/loop.pyx":1819
 *                     lai = &lai_static
 * 
 *             if len(fs):             # <<<<<<<<<<<<<<
 *                 await aio_wait(fs, loop=self)
 * 
 */
    }

    /* "uvloop/loop.pyx":1822
 *                 await aio_wait(fs, loop=self)
 * 
 *             if rai is NULL:             # <<<<<<<<<<<<<<
 *                 ai_remote = f1.result()
 *                 if ai_remote.data is NULL:
 */
    __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_rai == NULL) != 0);
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":1823
 * 
 *             if rai is NULL:
 *                 ai_remote = f1.result()             # <<<<<<<<<<<<<<
 *                 if ai_remote.data is NULL:
 *                     raise OSError('getaddrinfo() returned empty list')
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f1, __pyx_n_s_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1823, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1823, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1823, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_AddrInfo))))) __PYX_ERR(2, 1823, __pyx_L1_error)
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_cur_scope->__pyx_v_ai_remote = ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1824
 *             if rai is NULL:
 *                 ai_remote = f1.result()
 *                 if ai_remote.data is NULL:             # <<<<<<<<<<<<<<
 *                     raise OSError('getaddrinfo() returned empty list')
 *                 rai = ai_remote.data
 */
      __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_ai_remote->data == NULL) != 0);
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/loop.pyx":1825
 *                 ai_remote = f1.result()
 *                 if ai_remote.data is NULL:
 *                     raise OSError('getaddrinfo() returned empty list')             # <<<<<<<<<<<<<<
 *                 rai = ai_remote.data
 * 
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_tuple__69, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(2, 1825, __pyx_L1_error)

        /* "uvloop/loop.pyx":1824
 *             if rai is NULL:
 *                 ai_remote = f1.result()
 *                 if ai_remote.data is NULL:             # <<<<<<<<<<<<<<
 *                     raise OSError('getaddrinfo() returned empty list')
 *                 rai = ai_remote.data
 */
      }

      /* "uvloop/loop.pyx":1826
 *                 if ai_remote.data is NULL:
 *                     raise OSError('getaddrinfo() returned empty list')
 *                 rai = ai_remote.data             # <<<<<<<<<<<<<<
 * 
 *             if lai is NULL and f2 is not None:
 */
      __pyx_t_14 = __pyx_cur_scope->__pyx_v_ai_remote->data;
      __pyx_cur_scope->__pyx_v_rai = __pyx_t_14;

      /* "uvloop/loop.pyx":1822
 *                 await aio_wait(fs, loop=self)
 * 
 *             if rai is NULL:             # <<<<<<<<<<<<<<
 *                 ai_remote = f1.result()
 *                 if ai_remote.data is NULL:
 */
    }

    /* "uvloop/loop.pyx":1828
 *                 rai = ai_remote.data
 * 
 *             if lai is NULL and f2 is not None:             # <<<<<<<<<<<<<<
 *                 ai_local = f2.result()
 *                 if ai_local.data is NULL:
 */
    __pyx_t_3 = ((__pyx_cur_scope->__pyx_v_lai == NULL) != 0);
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L33_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_cur_scope->__pyx_v_f2 != Py_None);
    __pyx_t_1 = (__pyx_t_3 != 0);
    __pyx_t_2 = __pyx_t_1;
    __pyx_L33_bool_binop_done:;
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":1829
 * 
 *             if lai is NULL and f2 is not None:
 *                 ai_local = f2.result()             # <<<<<<<<<<<<<<
 *                 if ai_local.data is NULL:
 *                     raise OSError(
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_f2, __pyx_n_s_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1829, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1829, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1829, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_AddrInfo))))) __PYX_ERR(2, 1829, __pyx_L1_error)
      __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_ai_local));
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_ai_local, ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_t_4));
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1830
 *             if lai is NULL and f2 is not None:
 *                 ai_local = f2.result()
 *                 if ai_local.data is NULL:             # <<<<<<<<<<<<<<
 *                     raise OSError(
 *                         'getaddrinfo() returned empty list for local_addr')
 */
      __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_ai_local->data == NULL) != 0);
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/loop.pyx":1831
 *                 ai_local = f2.result()
 *                 if ai_local.data is NULL:
 *                     raise OSError(             # <<<<<<<<<<<<<<
 *                         'getaddrinfo() returned empty list for local_addr')
 *                 lai = ai_local.data
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1831, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(2, 1831, __pyx_L1_error)

        /* "uvloop/loop.pyx":1830
 *             if lai is NULL and f2 is not None:
 *                 ai_local = f2.result()
 *                 if ai_local.data is NULL:             # <<<<<<<<<<<<<<
 *                     raise OSError(
 *                         'getaddrinfo() returned empty list for local_addr')
 */
      }

      /* "uvloop/loop.pyx":1833
 *                     raise OSError(
 *                         'getaddrinfo() returned empty list for local_addr')
 *                 lai = ai_local.data             # <<<<<<<<<<<<<<
 * 
 *             exceptions = []
 */
      __pyx_t_14 = __pyx_cur_scope->__pyx_v_ai_local->data;
      __pyx_cur_scope->__pyx_v_lai = __pyx_t_14;

      /* "uvloop/loop.pyx":1828
 *                 rai = ai_remote.data
 * 
 *             if lai is NULL and f2 is not None:             # <<<<<<<<<<<<<<
 *                 ai_local = f2.result()
 *                 if ai_local.data is NULL:
 */
    }

    /* "uvloop/loop.pyx":1835
 *                 lai = ai_local.data
 * 
 *             exceptions = []             # <<<<<<<<<<<<<<
 *             rai_iter = rai
 *             while rai_iter is not NULL:
 */
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1835, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_cur_scope->__pyx_v_exceptions = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":1836
 * 
 *             exceptions = []
 *             rai_iter = rai             # <<<<<<<<<<<<<<
 *             while rai_iter is not NULL:
 *                 tr = None
 */
    __pyx_cur_scope->__pyx_v_rai_iter = __pyx_cur_scope->__pyx_v_rai;

    /* "uvloop/loop.pyx":1837
 *             exceptions = []
 *             rai_iter = rai
 *             while rai_iter is not NULL:             # <<<<<<<<<<<<<<
 *                 tr = None
 *                 try:
 */
    while (1) {
      __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_rai_iter != NULL) != 0);
      if (!__pyx_t_2) break;

      /* "uvloop/loop.pyx":1838
 *             rai_iter = rai
 *             while rai_iter is not NULL:
 *                 tr = None             # <<<<<<<<<<<<<<
 *                 try:
 *                     waiter = self._new_future()
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XGOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_tr, ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)Py_None));
      __Pyx_GIVEREF(Py_None);

      /* "uvloop/loop.pyx":1839
 *             while rai_iter is not NULL:
 *                 tr = None
 *                 try:             # <<<<<<<<<<<<<<
 *                     waiter = self._new_future()
 *                     tr = TCPTransport.new(self, protocol, None, waiter)
 */
      {
        __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        /*try:*/ {

          /* "uvloop/loop.pyx":1840
 *                 tr = None
 *                 try:
 *                     waiter = self._new_future()             # <<<<<<<<<<<<<<
 *                     tr = TCPTransport.new(self, protocol, None, waiter)
 * 
 */
          __pyx_t_4 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1840, __pyx_L38_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_waiter);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_waiter, __pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_4);
          __pyx_t_4 = 0;

          /* "uvloop/loop.pyx":1841
 *                 try:
 *                     waiter = self._new_future()
 *                     tr = TCPTransport.new(self, protocol, None, waiter)             # <<<<<<<<<<<<<<
 * 
 *                     if lai is not NULL:
 */
          __pyx_t_4 = ((PyObject *)__pyx_f_6uvloop_4loop_12TCPTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_waiter)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1841, __pyx_L38_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
          __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_tr, ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_t_4));
          __Pyx_GIVEREF(__pyx_t_4);
          __pyx_t_4 = 0;

          /* "uvloop/loop.pyx":1843
 *                     tr = TCPTransport.new(self, protocol, None, waiter)
 * 
 *                     if lai is not NULL:             # <<<<<<<<<<<<<<
 *                         lai_iter = lai
 *                         while lai_iter is not NULL:
 */
          __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_lai != NULL) != 0);
          if (__pyx_t_2) {

            /* "uvloop/loop.pyx":1844
 * 
 *                     if lai is not NULL:
 *                         lai_iter = lai             # <<<<<<<<<<<<<<
 *                         while lai_iter is not NULL:
 *                             try:
 */
            __pyx_cur_scope->__pyx_v_lai_iter = __pyx_cur_scope->__pyx_v_lai;

            /* "uvloop/loop.pyx":1845
 *                     if lai is not NULL:
 *                         lai_iter = lai
 *                         while lai_iter is not NULL:             # <<<<<<<<<<<<<<
 *                             try:
 *                                 tr.bind(lai_iter.ai_addr)
 */
            while (1) {
              __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_lai_iter != NULL) != 0);
              if (!__pyx_t_2) break;

              /* "uvloop/loop.pyx":1846
 *                         lai_iter = lai
 *                         while lai_iter is not NULL:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 tr.bind(lai_iter.ai_addr)
 *                                 break
 */
              {
                __Pyx_ExceptionSave(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_20);
                /*try:*/ {

                  /* "uvloop/loop.pyx":1847
 *                         while lai_iter is not NULL:
 *                             try:
 *                                 tr.bind(lai_iter.ai_addr)             # <<<<<<<<<<<<<<
 *                                 break
 *                             except OSError as exc:
 */
                  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->bind(__pyx_cur_scope->__pyx_v_tr, __pyx_cur_scope->__pyx_v_lai_iter->ai_addr, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1847, __pyx_L49_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                  /* "uvloop/loop.pyx":1848
 *                             try:
 *                                 tr.bind(lai_iter.ai_addr)
 *                                 break             # <<<<<<<<<<<<<<
 *                             except OSError as exc:
 *                                 exceptions.append(exc)
 */
                  goto __pyx_L54_try_break;

                  /* "uvloop/loop.pyx":1846
 *                         lai_iter = lai
 *                         while lai_iter is not NULL:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 tr.bind(lai_iter.ai_addr)
 *                                 break
 */
                }
                __pyx_L49_error:;
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

                /* "uvloop/loop.pyx":1849
 *                                 tr.bind(lai_iter.ai_addr)
 *                                 break
 *                             except OSError as exc:             # <<<<<<<<<<<<<<
 *                                 exceptions.append(exc)
 *                             lai_iter = lai_iter.ai_next
 */
                __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
                if (__pyx_t_9) {
                  __Pyx_AddTraceback("uvloop.loop.Loop.create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
                  if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(2, 1849, __pyx_L51_except_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_GOTREF(__pyx_t_6);
                  __Pyx_INCREF(__pyx_t_5);
                  __Pyx_GIVEREF(__pyx_t_5);
                  __pyx_cur_scope->__pyx_v_exc = __pyx_t_5;
                  /*try:*/ {

                    /* "uvloop/loop.pyx":1850
 *                                 break
 *                             except OSError as exc:
 *                                 exceptions.append(exc)             # <<<<<<<<<<<<<<
 *                             lai_iter = lai_iter.ai_next
 *                         else:
 */
                    __pyx_t_11 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_exceptions, __pyx_cur_scope->__pyx_v_exc); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 1850, __pyx_L62_error)
                  }

                  /* "uvloop/loop.pyx":1849
 *                                 tr.bind(lai_iter.ai_addr)
 *                                 break
 *                             except OSError as exc:             # <<<<<<<<<<<<<<
 *                                 exceptions.append(exc)
 *                             lai_iter = lai_iter.ai_next
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
                      __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
                      __pyx_cur_scope->__pyx_v_exc = NULL;
                      goto __pyx_L63;
                    }
                    __pyx_L62_error:;
                    /*exception exit:*/{
                      __Pyx_PyThreadState_assign
                      __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
                      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
                      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
                      __Pyx_XGOTREF(__pyx_t_22);
                      __Pyx_XGOTREF(__pyx_t_23);
                      __Pyx_XGOTREF(__pyx_t_24);
                      __Pyx_XGOTREF(__pyx_t_25);
                      __Pyx_XGOTREF(__pyx_t_26);
                      __Pyx_XGOTREF(__pyx_t_27);
                      __pyx_t_9 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
                      {
                        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
                        __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
                        __pyx_cur_scope->__pyx_v_exc = NULL;
                      }
                      if (PY_MAJOR_VERSION >= 3) {
                        __Pyx_XGIVEREF(__pyx_t_25);
                        __Pyx_XGIVEREF(__pyx_t_26);
                        __Pyx_XGIVEREF(__pyx_t_27);
                        __Pyx_ExceptionReset(__pyx_t_25, __pyx_t_26, __pyx_t_27);
                      }
                      __Pyx_XGIVEREF(__pyx_t_22);
                      __Pyx_XGIVEREF(__pyx_t_23);
                      __Pyx_XGIVEREF(__pyx_t_24);
                      __Pyx_ErrRestore(__pyx_t_22, __pyx_t_23, __pyx_t_24);
                      __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
                      __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_21;
                      goto __pyx_L51_except_error;
                    }
                    __pyx_L63:;
                  }
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                  goto __pyx_L50_exception_handled;
                }
                goto __pyx_L51_except_error;
                __pyx_L51_except_error:;

                /* "uvloop/loop.pyx":1846
 *                         lai_iter = lai
 *                         while lai_iter is not NULL:
 *                             try:             # <<<<<<<<<<<<<<
 *                                 tr.bind(lai_iter.ai_addr)
 *                                 break
 */
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
                goto __pyx_L38_error;
                __pyx_L54_try_break:;
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
                goto __pyx_L48_break;
                __pyx_L50_exception_handled:;
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
              }

              /* "uvloop/loop.pyx":1851
 *                             except OSError as exc:
 *                                 exceptions.append(exc)
 *                             lai_iter = lai_iter.ai_next             # <<<<<<<<<<<<<<
 *                         else:
 *                             tr._close()
 */
              __pyx_t_14 = __pyx_cur_scope->__pyx_v_lai_iter->ai_next;
              __pyx_cur_scope->__pyx_v_lai_iter = __pyx_t_14;
            }

            /* "uvloop/loop.pyx":1853
 *                             lai_iter = lai_iter.ai_next
 *                         else:
 *                             tr._close()             # <<<<<<<<<<<<<<
 *                             tr = None
 * 
 */
            /*else*/ {
              __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1853, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "uvloop/loop.pyx":1854
 *                         else:
 *                             tr._close()
 *                             tr = None             # <<<<<<<<<<<<<<
 * 
 *                             rai_iter = rai_iter.ai_next
 */
              __Pyx_INCREF(Py_None);
              __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
              __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_tr, ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)Py_None));
              __Pyx_GIVEREF(Py_None);

              /* "uvloop/loop.pyx":1856
 *                             tr = None
 * 
 *                             rai_iter = rai_iter.ai_next             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              __pyx_t_14 = __pyx_cur_scope->__pyx_v_rai_iter->ai_next;
              __pyx_cur_scope->__pyx_v_rai_iter = __pyx_t_14;

              /* "uvloop/loop.pyx":1857
 * 
 *                             rai_iter = rai_iter.ai_next
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                     tr.connect(rai_iter.ai_addr)
 */
              goto __pyx_L44_try_continue;
            }
            __pyx_L48_break:;

            /* "uvloop/loop.pyx":1843
 *                     tr = TCPTransport.new(self, protocol, None, waiter)
 * 
 *                     if lai is not NULL:             # <<<<<<<<<<<<<<
 *                         lai_iter = lai
 *                         while lai_iter is not NULL:
 */
          }

          /* "uvloop/loop.pyx":1859
 *                             continue
 * 
 *                     tr.connect(rai_iter.ai_addr)             # <<<<<<<<<<<<<<
 *                     await waiter
 * 
 */
          __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->connect(__pyx_cur_scope->__pyx_v_tr, __pyx_cur_scope->__pyx_v_rai_iter->ai_addr); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1859, __pyx_L38_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "uvloop/loop.pyx":1860
 * 
 *                     tr.connect(rai_iter.ai_addr)
 *                     await waiter             # <<<<<<<<<<<<<<
 * 
 *                 except OSError as exc:
 */
          __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
          __Pyx_XGOTREF(__pyx_r);
          if (likely(__pyx_r)) {
            __Pyx_XGIVEREF(__pyx_t_15);
            __pyx_cur_scope->__pyx_t_0 = __pyx_t_15;
            __Pyx_XGIVEREF(__pyx_t_16);
            __pyx_cur_scope->__pyx_t_1 = __pyx_t_16;
            __Pyx_XGIVEREF(__pyx_t_17);
            __pyx_cur_scope->__pyx_t_2 = __pyx_t_17;
            __Pyx_XGIVEREF(__pyx_r);
            __Pyx_RefNannyFinishContext();
            __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
            /* return from generator, awaiting value */
            __pyx_generator->resume_label = 3;
            return __pyx_r;
            __pyx_L68_resume_from_await:;
            __pyx_t_15 = __pyx_cur_scope->__pyx_t_0;
            __pyx_cur_scope->__pyx_t_0 = 0;
            __Pyx_XGOTREF(__pyx_t_15);
            __pyx_t_16 = __pyx_cur_scope->__pyx_t_1;
            __pyx_cur_scope->__pyx_t_1 = 0;
            __Pyx_XGOTREF(__pyx_t_16);
            __pyx_t_17 = __pyx_cur_scope->__pyx_t_2;
            __pyx_cur_scope->__pyx_t_2 = 0;
            __Pyx_XGOTREF(__pyx_t_17);
            if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1860, __pyx_L38_error)
          } else {
            PyObject* exc_type = __Pyx_PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
              else __PYX_ERR(2, 1860, __pyx_L38_error)
            }
          }

          /* "uvloop/loop.pyx":1839
 *             while rai_iter is not NULL:
 *                 tr = None
 *                 try:             # <<<<<<<<<<<<<<
 *                     waiter = self._new_future()
 *                     tr = TCPTransport.new(self, protocol, None, waiter)
 */
        }

        /* "uvloop/loop.pyx":1873
 *                     raise
 *                 else:
 *                     break             # <<<<<<<<<<<<<<
 * 
 *                 rai_iter = rai_iter.ai_next
 */
        /*else:*/ {
          goto __pyx_L43_try_break;
        }
        __pyx_L38_error:;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/loop.pyx":1862
 *                     await waiter
 * 
 *                 except OSError as exc:             # <<<<<<<<<<<<<<
 *                     if tr is not None:
 *                         tr._close()
 */
        __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
        if (__pyx_t_10) {
          __Pyx_AddTraceback("uvloop.loop.Loop.create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(2, 1862, __pyx_L40_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_exc);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_exc, __pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_5);
          /*try:*/ {

            /* "uvloop/loop.pyx":1863
 * 
 *                 except OSError as exc:
 *                     if tr is not None:             # <<<<<<<<<<<<<<
 *                         tr._close()
 *                         tr = None
 */
            __pyx_t_2 = (((PyObject *)__pyx_cur_scope->__pyx_v_tr) != Py_None);
            __pyx_t_1 = (__pyx_t_2 != 0);
            if (__pyx_t_1) {

              /* "uvloop/loop.pyx":1864
 *                 except OSError as exc:
 *                     if tr is not None:
 *                         tr._close()             # <<<<<<<<<<<<<<
 *                         tr = None
 *                     exceptions.append(exc)
 */
              __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1864, __pyx_L74_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

              /* "uvloop/loop.pyx":1865
 *                     if tr is not None:
 *                         tr._close()
 *                         tr = None             # <<<<<<<<<<<<<<
 *                     exceptions.append(exc)
 *                 except Exception:
 */
              __Pyx_INCREF(Py_None);
              __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
              __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_tr, ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)Py_None));
              __Pyx_GIVEREF(Py_None);

              /* "uvloop/loop.pyx":1863
 * 
 *                 except OSError as exc:
 *                     if tr is not None:             # <<<<<<<<<<<<<<
 *                         tr._close()
 *                         tr = None
 */
            }

            /* "uvloop/loop.pyx":1866
 *                         tr._close()
 *                         tr = None
 *                     exceptions.append(exc)             # <<<<<<<<<<<<<<
 *                 except Exception:
 *                     if tr is not None:
 */
            __pyx_t_11 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_exceptions, __pyx_cur_scope->__pyx_v_exc); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(2, 1866, __pyx_L74_error)
          }

          /* "uvloop/loop.pyx":1862
 *                     await waiter
 * 
 *                 except OSError as exc:             # <<<<<<<<<<<<<<
 *                     if tr is not None:
 *                         tr._close()
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
              __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
              __pyx_cur_scope->__pyx_v_exc = NULL;
              goto __pyx_L75;
            }
            __pyx_L74_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_assign
              __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_27 = 0; __pyx_t_26 = 0; __pyx_t_25 = 0;
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_27, &__pyx_t_26, &__pyx_t_25);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_27);
              __Pyx_XGOTREF(__pyx_t_26);
              __Pyx_XGOTREF(__pyx_t_25);
              __pyx_t_10 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_28 = __pyx_filename;
              {
                __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
                __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
                __pyx_cur_scope->__pyx_v_exc = NULL;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_27);
                __Pyx_XGIVEREF(__pyx_t_26);
                __Pyx_XGIVEREF(__pyx_t_25);
                __Pyx_ExceptionReset(__pyx_t_27, __pyx_t_26, __pyx_t_25);
              }
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_ErrRestore(__pyx_t_20, __pyx_t_19, __pyx_t_18);
              __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_27 = 0; __pyx_t_26 = 0; __pyx_t_25 = 0;
              __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_28;
              goto __pyx_L40_except_error;
            }
            __pyx_L75:;
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L39_exception_handled;
        }

        /* "uvloop/loop.pyx":1867
 *                         tr = None
 *                     exceptions.append(exc)
 *                 except Exception:             # <<<<<<<<<<<<<<
 *                     if tr is not None:
 *                         tr._close()
 */
        __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
        if (__pyx_t_9) {
          __Pyx_AddTraceback("uvloop.loop.Loop.create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(2, 1867, __pyx_L40_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GOTREF(__pyx_t_6);

          /* "uvloop/loop.pyx":1868
 *                     exceptions.append(exc)
 *                 except Exception:
 *                     if tr is not None:             # <<<<<<<<<<<<<<
 *                         tr._close()
 *                         tr = None
 */
          __pyx_t_1 = (((PyObject *)__pyx_cur_scope->__pyx_v_tr) != Py_None);
          __pyx_t_2 = (__pyx_t_1 != 0);
          if (__pyx_t_2) {

            /* "uvloop/loop.pyx":1869
 *                 except Exception:
 *                     if tr is not None:
 *                         tr._close()             # <<<<<<<<<<<<<<
 *                         tr = None
 *                     raise
 */
            __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1869, __pyx_L40_except_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "uvloop/loop.pyx":1870
 *                     if tr is not None:
 *                         tr._close()
 *                         tr = None             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
            __Pyx_INCREF(Py_None);
            __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
            __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_tr, ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)Py_None));
            __Pyx_GIVEREF(Py_None);

            /* "uvloop/loop.pyx":1868
 *                     exceptions.append(exc)
 *                 except Exception:
 *                     if tr is not None:             # <<<<<<<<<<<<<<
 *                         tr._close()
 *                         tr = None
 */
          }

          /* "uvloop/loop.pyx":1871
 *                         tr._close()
 *                         tr = None
 *                     raise             # <<<<<<<<<<<<<<
 *                 else:
 *                     break
 */
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_XGIVEREF(__pyx_t_6);
          __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_5, __pyx_t_6);
          __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; 
          __PYX_ERR(2, 1871, __pyx_L40_except_error)
        }
        goto __pyx_L40_except_error;
        __pyx_L40_except_error:;

        /* "uvloop/loop.pyx":1839
 *             while rai_iter is not NULL:
 *                 tr = None
 *                 try:             # <<<<<<<<<<<<<<
 *                     waiter = self._new_future()
 *                     tr = TCPTransport.new(self, protocol, None, waiter)
 */
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        goto __pyx_L1_error;
        __pyx_L43_try_break:;
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        goto __pyx_L37_break;
        __pyx_L44_try_continue:;
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        goto __pyx_L36_continue;
        __pyx_L39_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      }

      /* "uvloop/loop.pyx":1875
 *                     break
 * 
 *                 rai_iter = rai_iter.ai_next             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
      __pyx_t_14 = __pyx_cur_scope->__pyx_v_rai_iter->ai_next;
      __pyx_cur_scope->__pyx_v_rai_iter = __pyx_t_14;
      __pyx_L36_continue:;
    }

    /* "uvloop/loop.pyx":1879
 *             else:
 *                 # If they all have the same str(), raise one.
 *                 model = str(exceptions[0])             # <<<<<<<<<<<<<<
 *                 if all(str(exc) == model for exc in exceptions):
 *                     raise exceptions[0]
 */
    /*else*/ {
      __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_cur_scope->__pyx_v_exceptions, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1879, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1879, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_cur_scope->__pyx_v_model = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":1880
 *                 # If they all have the same str(), raise one.
 *                 model = str(exceptions[0])
 *                 if all(str(exc) == model for exc in exceptions):             # <<<<<<<<<<<<<<
 *                     raise exceptions[0]
 *                 # Raise a combined exception so the user can see all
 */
      __pyx_t_5 = __pyx_pf_6uvloop_4loop_4Loop_17create_connection_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_Generator_Next(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1880, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1880, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/loop.pyx":1881
 *                 model = str(exceptions[0])
 *                 if all(str(exc) == model for exc in exceptions):
 *                     raise exceptions[0]             # <<<<<<<<<<<<<<
 *                 # Raise a combined exception so the user can see all
 *                 # the various error messages.
 */
        __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_cur_scope->__pyx_v_exceptions, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1881, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(2, 1881, __pyx_L1_error)

        /* "uvloop/loop.pyx":1880
 *                 # If they all have the same str(), raise one.
 *                 model = str(exceptions[0])
 *                 if all(str(exc) == model for exc in exceptions):             # <<<<<<<<<<<<<<
 *                     raise exceptions[0]
 *                 # Raise a combined exception so the user can see all
 */
      }

      /* "uvloop/loop.pyx":1884
 *                 # Raise a combined exception so the user can see all
 *                 # the various error messages.
 *                 raise OSError('Multiple exceptions: {}'.format(             # <<<<<<<<<<<<<<
 *                     ', '.join(str(exc) for exc in exceptions)))
 *         else:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Multiple_exceptions, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "uvloop/loop.pyx":1885
 *                 # the various error messages.
 *                 raise OSError('Multiple exceptions: {}'.format(
 *                     ', '.join(str(exc) for exc in exceptions)))             # <<<<<<<<<<<<<<
 *         else:
 *             if sock is None:
 */
      __pyx_t_4 = __pyx_pf_6uvloop_4loop_4Loop_17create_connection_3genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_Generator_Next(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyUnicode_Join(__pyx_kp_u__71, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1884, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_4};
          __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1884, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_4};
          __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1884, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        {
          __pyx_t_29 = PyTuple_New(1+1); if (unlikely(!__pyx_t_29)) __PYX_ERR(2, 1884, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_29);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_29, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_29, 0+1, __pyx_t_4);
          __pyx_t_4 = 0;
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_29, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1884, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":1884
 *                 # Raise a combined exception so the user can see all
 *                 # the various error messages.
 *                 raise OSError('Multiple exceptions: {}'.format(             # <<<<<<<<<<<<<<
 *                     ', '.join(str(exc) for exc in exceptions)))
 *         else:
 */
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_OSError, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(2, 1884, __pyx_L1_error)
    }
    __pyx_L37_break:;

    /* "uvloop/loop.pyx":1774
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if host is not None or port is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
    goto __pyx_L16;
  }

  /* "uvloop/loop.pyx":1887
 *                     ', '.join(str(exc) for exc in exceptions)))
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host and port was not specified and no sock specified')
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_sock == Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":1888
 *         else:
 *             if sock is None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host and port was not specified and no sock specified')
 *             if not _is_sock_stream(sock.type):
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1888, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(2, 1888, __pyx_L1_error)

      /* "uvloop/loop.pyx":1887
 *                     ', '.join(str(exc) for exc in exceptions)))
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'host and port was not specified and no sock specified')
 */
    }

    /* "uvloop/loop.pyx":1890
 *                 raise ValueError(
 *                     'host and port was not specified and no sock specified')
 *             if not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A Stream Socket was expected, got {!r}'.format(sock))
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1890, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __pyx_f_6uvloop_4loop__is_sock_stream(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1890, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 1890, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = ((!__pyx_t_1) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/loop.pyx":1892
 *             if not _is_sock_stream(sock.type):
 *                 raise ValueError(
 *                     'A Stream Socket was expected, got {!r}'.format(sock))             # <<<<<<<<<<<<<<
 * 
 *             # libuv will set the socket to non-blocking mode, but
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_A_Stream_Socket_was_expected_got, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_29 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_29 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_29)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_29);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_29) {
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1892, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_29, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1892, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
          __Pyx_GOTREF(__pyx_t_6);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_29, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1892, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
          __Pyx_GOTREF(__pyx_t_6);
        } else
        #endif
        {
          __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1892, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_29); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_29); __pyx_t_29 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
          PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_cur_scope->__pyx_v_sock);
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1892, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":1891
 *                     'host and port was not specified and no sock specified')
 *             if not _is_sock_stream(sock.type):
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'A Stream Socket was expected, got {!r}'.format(sock))
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(2, 1891, __pyx_L1_error)

      /* "uvloop/loop.pyx":1890
 *                 raise ValueError(
 *                     'host and port was not specified and no sock specified')
 *             if not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A Stream Socket was expected, got {!r}'.format(sock))
 */
    }

    /* "uvloop/loop.pyx":1896
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *             waiter = self._new_future()
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__73, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1896, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":1898
 *             sock.setblocking(False)
 * 
 *             waiter = self._new_future()             # <<<<<<<<<<<<<<
 *             tr = TCPTransport.new(self, protocol, None, waiter)
 *             try:
 */
    __pyx_t_6 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_cur_scope->__pyx_v_waiter = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":1899
 * 
 *             waiter = self._new_future()
 *             tr = TCPTransport.new(self, protocol, None, waiter)             # <<<<<<<<<<<<<<
 *             try:
 *                 # libuv will make socket non-blocking
 */
    __pyx_t_6 = ((PyObject *)__pyx_f_6uvloop_4loop_12TCPTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_waiter)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1899, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_cur_scope->__pyx_v_tr = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":1900
 *             waiter = self._new_future()
 *             tr = TCPTransport.new(self, protocol, None, waiter)
 *             try:             # <<<<<<<<<<<<<<
 *                 # libuv will make socket non-blocking
 *                 tr._open(sock.fileno())
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_15);
      /*try:*/ {

        /* "uvloop/loop.pyx":1902
 *             try:
 *                 # libuv will make socket non-blocking
 *                 tr._open(sock.fileno())             # <<<<<<<<<<<<<<
 *                 tr._init_protocol()
 *                 await waiter
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1902, __pyx_L87_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (__pyx_t_4) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1902, __pyx_L87_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1902, __pyx_L87_error)
        }
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1902, __pyx_L87_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_tr), __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1902, __pyx_L87_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/loop.pyx":1903
 *                 # libuv will make socket non-blocking
 *                 tr._open(sock.fileno())
 *                 tr._init_protocol()             # <<<<<<<<<<<<<<
 *                 await waiter
 *             except Exception:
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1903, __pyx_L87_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/loop.pyx":1904
 *                 tr._open(sock.fileno())
 *                 tr._init_protocol()
 *                 await waiter             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 # It's OK to call `_close()` here, as opposed to
 */
        __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
        __Pyx_XGOTREF(__pyx_r);
        if (likely(__pyx_r)) {
          __Pyx_XGIVEREF(__pyx_t_15);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_15;
          __Pyx_XGIVEREF(__pyx_t_16);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_16;
          __Pyx_XGIVEREF(__pyx_t_17);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_17;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, awaiting value */
          __pyx_generator->resume_label = 4;
          return __pyx_r;
          __pyx_L93_resume_from_await:;
          __pyx_t_15 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_15);
          __pyx_t_16 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_16);
          __pyx_t_17 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_17);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1904, __pyx_L87_error)
        } else {
          PyObject* exc_type = __Pyx_PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
            else __PYX_ERR(2, 1904, __pyx_L87_error)
          }
        }

        /* "uvloop/loop.pyx":1900
 *             waiter = self._new_future()
 *             tr = TCPTransport.new(self, protocol, None, waiter)
 *             try:             # <<<<<<<<<<<<<<
 *                 # libuv will make socket non-blocking
 *                 tr._open(sock.fileno())
 */
      }
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      goto __pyx_L92_try_end;
      __pyx_L87_error:;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":1905
 *                 tr._init_protocol()
 *                 await waiter
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 # It's OK to call `_close()` here, as opposed to
 *                 # `_force_close()` or `close()` as we want to terminate the
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_9) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0) __PYX_ERR(2, 1905, __pyx_L89_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_4);

        /* "uvloop/loop.pyx":1911
 *                 # up in `Transport._call_connection_made()`, and calling
 *                 # `_close()` before it is fine.
 *                 tr._close()             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_29 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_29)) __PYX_ERR(2, 1911, __pyx_L89_except_error)
        __Pyx_GOTREF(__pyx_t_29);
        __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;

        /* "uvloop/loop.pyx":1912
 *                 # `_close()` before it is fine.
 *                 tr._close()
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *             tr._attach_fileobj(sock)
 */
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; 
        __PYX_ERR(2, 1912, __pyx_L89_except_error)
      }
      goto __pyx_L89_except_error;
      __pyx_L89_except_error:;

      /* "uvloop/loop.pyx":1900
 *             waiter = self._new_future()
 *             tr = TCPTransport.new(self, protocol, None, waiter)
 *             try:             # <<<<<<<<<<<<<<
 *                 # libuv will make socket non-blocking
 *                 tr._open(sock.fileno())
 */
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
      goto __pyx_L1_error;
      __pyx_L92_try_end:;
    }

    /* "uvloop/loop.pyx":1914
 *                 raise
 * 
 *             tr._attach_fileobj(sock)             # <<<<<<<<<<<<<<
 * 
 *         if ssl:
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._attach_fileobj(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_tr), __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L16:;

  /* "uvloop/loop.pyx":1916
 *             tr._attach_fileobj(sock)
 * 
 *         if ssl:             # <<<<<<<<<<<<<<
 *             try:
 *                 await ssl_waiter
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ssl); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1916, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1917
 * 
 *         if ssl:
 *             try:             # <<<<<<<<<<<<<<
 *                 await ssl_waiter
 *             except Exception:
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      /*try:*/ {

        /* "uvloop/loop.pyx":1918
 *         if ssl:
 *             try:
 *                 await ssl_waiter             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 tr._close()
 */
        __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_ssl_waiter);
        __Pyx_XGOTREF(__pyx_r);
        if (likely(__pyx_r)) {
          __Pyx_XGIVEREF(__pyx_t_15);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_15;
          __Pyx_XGIVEREF(__pyx_t_16);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_16;
          __Pyx_XGIVEREF(__pyx_t_17);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_17;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, awaiting value */
          __pyx_generator->resume_label = 5;
          return __pyx_r;
          __pyx_L103_resume_from_await:;
          __pyx_t_15 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_15);
          __pyx_t_16 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_16);
          __pyx_t_17 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_17);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1918, __pyx_L97_error)
        } else {
          PyObject* exc_type = __Pyx_PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
            else __PYX_ERR(2, 1918, __pyx_L97_error)
          }
        }

        /* "uvloop/loop.pyx":1917
 * 
 *         if ssl:
 *             try:             # <<<<<<<<<<<<<<
 *                 await ssl_waiter
 *             except Exception:
 */
      }
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
      goto __pyx_L102_try_end;
      __pyx_L97_error:;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":1919
 *             try:
 *                 await ssl_waiter
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 tr._close()
 *                 raise
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_9) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(2, 1919, __pyx_L99_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_6);

        /* "uvloop/loop.pyx":1920
 *                 await ssl_waiter
 *             except Exception:
 *                 tr._close()             # <<<<<<<<<<<<<<
 *                 raise
 *             return protocol._app_transport, app_protocol
 */
        __pyx_t_29 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_29)) __PYX_ERR(2, 1920, __pyx_L99_except_error)
        __Pyx_GOTREF(__pyx_t_29);
        __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;

        /* "uvloop/loop.pyx":1921
 *             except Exception:
 *                 tr._close()
 *                 raise             # <<<<<<<<<<<<<<
 *             return protocol._app_transport, app_protocol
 *         else:
 */
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_5, __pyx_t_6);
        __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; 
        __PYX_ERR(2, 1921, __pyx_L99_except_error)
      }
      goto __pyx_L99_except_error;
      __pyx_L99_except_error:;

      /* "uvloop/loop.pyx":1917
 * 
 *         if ssl:
 *             try:             # <<<<<<<<<<<<<<
 *                 await ssl_waiter
 *             except Exception:
 */
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
      goto __pyx_L1_error;
      __pyx_L102_try_end:;
    }

    /* "uvloop/loop.pyx":1922
 *                 tr._close()
 *                 raise
 *             return protocol._app_transport, app_protocol             # <<<<<<<<<<<<<<
 *         else:
 *             return tr, protocol
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_protocol, __pyx_n_s_app_transport); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_app_protocol);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_cur_scope->__pyx_v_app_protocol);
    __pyx_t_6 = 0;
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":1916
 *             tr._attach_fileobj(sock)
 * 
 *         if ssl:             # <<<<<<<<<<<<<<
 *             try:
 *                 await ssl_waiter
 */
  }

  /* "uvloop/loop.pyx":1924
 *             return protocol._app_transport, app_protocol
 *         else:
 *             return tr, protocol             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_tr));
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_cur_scope->__pyx_v_protocol);
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":1709
 * 
 *     @cython.iterable_coroutine
 *     async def create_connection(self, protocol_factory, host=None, port=None, *,             # <<<<<<<<<<<<<<
 *                                 ssl=None, family=0, proto=0, flags=0, sock=None,
 *                                 local_addr=None, server_hostname=None,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_AddTraceback("create_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_63generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":1927
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_server(self, protocol_factory, path=None,             # <<<<<<<<<<<<<<
 *                                  *, backlog=100, sock=None, ssl=None,
 *                                  ssl_handshake_timeout=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_62create_unix_server(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_61create_unix_server[] = "Loop.create_unix_server(self, protocol_factory, path=None, *, backlog=100, sock=None, ssl=None, ssl_handshake_timeout=None)\nA coroutine which creates a UNIX Domain Socket server.\n\n        The return value is a Server object, which can be used to stop\n        the service.\n\n        path is a str, representing a file systsem path to bind the\n        server socket to.\n\n        sock can optionally be specified in order to use a preexisting\n        socket object.\n\n        backlog is the maximum number of queued connections passed to\n        listen() (defaults to 100).\n\n        ssl can be set to an SSLContext to enable SSL over the\n        accepted connections.\n\n        ssl_handshake_timeout is the time in seconds that an SSL server\n        will wait for completion of the SSL handshake before aborting the\n        connection. Default is 60s.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_62create_unix_server(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_backlog = 0;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_ssl = 0;
  PyObject *__pyx_v_ssl_handshake_timeout = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_unix_server (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_path,&__pyx_n_s_backlog,&__pyx_n_s_sock,&__pyx_n_s_ssl,&__pyx_n_s_ssl_handshake_timeout,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)__pyx_int_100);

    /* "uvloop/loop.pyx":1928
 *     @cython.iterable_coroutine
 *     async def create_unix_server(self, protocol_factory, path=None,
 *                                  *, backlog=100, sock=None, ssl=None,             # <<<<<<<<<<<<<<
 *                                  ssl_handshake_timeout=None):
 *         """A coroutine which creates a UNIX Domain Socket server.
 */
    values[3] = ((PyObject *)Py_None);
    values[4] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":1929
 *     async def create_unix_server(self, protocol_factory, path=None,
 *                                  *, backlog=100, sock=None, ssl=None,
 *                                  ssl_handshake_timeout=None):             # <<<<<<<<<<<<<<
 *         """A coroutine which creates a UNIX Domain Socket server.
 * 
 */
    values[5] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_path);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (kw_args > 0 && likely(kw_args <= 4)) {
        Py_ssize_t index;
        for (index = 2; index < 6 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_unix_server") < 0)) __PYX_ERR(2, 1927, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_path = values[1];
    __pyx_v_backlog = values[2];
    __pyx_v_sock = values[3];
    __pyx_v_ssl = values[4];
    __pyx_v_ssl_handshake_timeout = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_unix_server", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 1927, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_61create_unix_server(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_path, __pyx_v_backlog, __pyx_v_sock, __pyx_v_ssl, __pyx_v_ssl_handshake_timeout);

  /* "uvloop/loop.pyx":1927
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_server(self, protocol_factory, path=None,             # <<<<<<<<<<<<<<
 *                                  *, backlog=100, sock=None, ssl=None,
 *                                  ssl_handshake_timeout=None):
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_61create_unix_server(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_path, PyObject *__pyx_v_backlog, PyObject *__pyx_v_sock, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_unix_server", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_12_create_unix_server(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_12_create_unix_server, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 1927, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_path = __pyx_v_path;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
  __pyx_cur_scope->__pyx_v_backlog = __pyx_v_backlog;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_backlog);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_backlog);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_ssl = __pyx_v_ssl;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl);
  __pyx_cur_scope->__pyx_v_ssl_handshake_timeout = __pyx_v_ssl_handshake_timeout;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_63generator5, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_create_unix_server, __pyx_n_s_Loop_create_unix_server, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 1927, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_63generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  char const *__pyx_t_22;
  int __pyx_t_23;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_unix_server", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 1927, __pyx_L1_error)

  /* "uvloop/loop.pyx":1953
 *         cdef:
 *             UnixServer pipe
 *             Server server = Server(self)             # <<<<<<<<<<<<<<
 * 
 *         if ssl is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6uvloop_4loop_Server), ((PyObject *)__pyx_cur_scope->__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_server = ((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":1955
 *             Server server = Server(self)
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_ssl != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":1956
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 */
    __pyx_t_1 = __pyx_v_6uvloop_4loop_ssl_SSLContext;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_ssl, __pyx_t_1); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 1956, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/loop.pyx":1957
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')             # <<<<<<<<<<<<<<
 *         else:
 *             if ssl_handshake_timeout is not None:
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__74, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1957, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 1957, __pyx_L1_error)

      /* "uvloop/loop.pyx":1956
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 */
    }

    /* "uvloop/loop.pyx":1955
 *             Server server = Server(self)
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":1959
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_ssl_handshake_timeout != Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":1960
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__75, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1960, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 1960, __pyx_L1_error)

      /* "uvloop/loop.pyx":1959
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    }
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":1963
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if path is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
  __pyx_t_3 = (__pyx_cur_scope->__pyx_v_path != Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":1964
 * 
 *         if path is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'path and sock can not be specified at the same time')
 */
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":1965
 *         if path is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'path and sock can not be specified at the same time')
 *             orig_path = path
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__76, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1965, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 1965, __pyx_L1_error)

      /* "uvloop/loop.pyx":1964
 * 
 *         if path is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'path and sock can not be specified at the same time')
 */
    }

    /* "uvloop/loop.pyx":1967
 *                 raise ValueError(
 *                     'path and sock can not be specified at the same time')
 *             orig_path = path             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
    __pyx_cur_scope->__pyx_v_orig_path = __pyx_cur_scope->__pyx_v_path;

    /* "uvloop/loop.pyx":1969
 *             orig_path = path
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/loop.pyx":1972
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 *                 fspath = type(path).__fspath__             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 pass
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_cur_scope->__pyx_v_path)), __pyx_n_s_fspath); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1972, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_cur_scope->__pyx_v_fspath = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "uvloop/loop.pyx":1969
 *             orig_path = path
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
      }

      /* "uvloop/loop.pyx":1976
 *                 pass
 *             else:
 *                 path = fspath(path)             # <<<<<<<<<<<<<<
 * 
 *             if isinstance(path, str):
 */
      /*else:*/ {
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fspath);
        __pyx_t_7 = __pyx_cur_scope->__pyx_v_fspath; __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (!__pyx_t_8) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_cur_scope->__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1976, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_1);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_path};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1976, __pyx_L11_except_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_path};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1976, __pyx_L11_except_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          {
            __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1976, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
            PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_cur_scope->__pyx_v_path);
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1976, __pyx_L11_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_path);
        __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_path, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_1 = 0;
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L14_try_end;
      __pyx_L9_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":1973
 *                 # available on Python 3.5.
 *                 fspath = type(path).__fspath__
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 pass
 *             else:
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
      if (__pyx_t_10) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L10_exception_handled;
      }
      goto __pyx_L11_except_error;
      __pyx_L11_except_error:;

      /* "uvloop/loop.pyx":1969
 *             orig_path = path
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L10_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_L14_try_end:;
    }

    /* "uvloop/loop.pyx":1978
 *                 path = fspath(path)
 * 
 *             if isinstance(path, str):             # <<<<<<<<<<<<<<
 *                 path = PyUnicode_EncodeFSDefault(path)
 * 
 */
    __pyx_t_3 = PyUnicode_Check(__pyx_cur_scope->__pyx_v_path); 
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":1979
 * 
 *             if isinstance(path, str):
 *                 path = PyUnicode_EncodeFSDefault(path)             # <<<<<<<<<<<<<<
 * 
 *             # Check for abstract socket.
 */
      __pyx_t_1 = PyUnicode_EncodeFSDefault(__pyx_cur_scope->__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_path);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_path, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":1978
 *                 path = fspath(path)
 * 
 *             if isinstance(path, str):             # <<<<<<<<<<<<<<
 *                 path = PyUnicode_EncodeFSDefault(path)
 * 
 */
    }

    /* "uvloop/loop.pyx":1982
 * 
 *             # Check for abstract socket.
 *             if path[0] != 0:             # <<<<<<<<<<<<<<
 *                 try:
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_path, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1982, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = PyObject_RichCompare(__pyx_t_1, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1982, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1982, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":1983
 *             # Check for abstract socket.
 *             if path[0] != 0:
 *                 try:             # <<<<<<<<<<<<<<
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):
 *                         os_remove(path)
 */
      {
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        /*try:*/ {

          /* "uvloop/loop.pyx":1984
 *             if path[0] != 0:
 *                 try:
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):             # <<<<<<<<<<<<<<
 *                         os_remove(path)
 *                 except FileNotFoundError:
 */
          __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_stat);
          __pyx_t_9 = __pyx_v_6uvloop_4loop_os_stat; __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_8) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_cur_scope->__pyx_v_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1984, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_1);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_path};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_path};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_1);
            } else
            #endif
            {
              __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8); __pyx_t_8 = NULL;
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
              PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_cur_scope->__pyx_v_path);
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_st_mode); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1984, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_INCREF(__pyx_v_6uvloop_4loop_stat_S_ISSOCK);
          __pyx_t_1 = __pyx_v_6uvloop_4loop_stat_S_ISSOCK; __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1984, __pyx_L17_error)
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_9};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_9};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_GIVEREF(__pyx_t_9);
              PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_9);
              __pyx_t_9 = 0;
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1984, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 1984, __pyx_L17_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (__pyx_t_2) {

            /* "uvloop/loop.pyx":1985
 *                 try:
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):
 *                         os_remove(path)             # <<<<<<<<<<<<<<
 *                 except FileNotFoundError:
 *                     pass
 */
            __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_remove);
            __pyx_t_1 = __pyx_v_6uvloop_4loop_os_remove; __pyx_t_8 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
              }
            }
            if (!__pyx_t_8) {
              __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_cur_scope->__pyx_v_path); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1985, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_7);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_1)) {
                PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_path};
                __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1985, __pyx_L17_error)
                __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_GOTREF(__pyx_t_7);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
                PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_path};
                __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1985, __pyx_L17_error)
                __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_GOTREF(__pyx_t_7);
              } else
              #endif
              {
                __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 1985, __pyx_L17_error)
                __Pyx_GOTREF(__pyx_t_9);
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
                __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
                __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
                PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_cur_scope->__pyx_v_path);
                __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1985, __pyx_L17_error)
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "uvloop/loop.pyx":1984
 *             if path[0] != 0:
 *                 try:
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):             # <<<<<<<<<<<<<<
 *                         os_remove(path)
 *                 except FileNotFoundError:
 */
          }

          /* "uvloop/loop.pyx":1983
 *             # Check for abstract socket.
 *             if path[0] != 0:
 *                 try:             # <<<<<<<<<<<<<<
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):
 *                         os_remove(path)
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L22_try_end;
        __pyx_L17_error:;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "uvloop/loop.pyx":1986
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):
 *                         os_remove(path)
 *                 except FileNotFoundError:             # <<<<<<<<<<<<<<
 *                     pass
 *                 except OSError as err:
 */
        __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_1, &__pyx_t_9);
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FileNotFoundError); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1986, __pyx_L19_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_7, __pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_ErrRestore(__pyx_t_7, __pyx_t_1, __pyx_t_9);
        __pyx_t_7 = 0; __pyx_t_1 = 0; __pyx_t_9 = 0;
        if (__pyx_t_10) {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L18_exception_handled;
        }

        /* "uvloop/loop.pyx":1988
 *                 except FileNotFoundError:
 *                     pass
 *                 except OSError as err:             # <<<<<<<<<<<<<<
 *                     # Directory may have permissions only to create socket.
 *                     aio_logger.error(
 */
        __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
        if (__pyx_t_10) {
          __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(2, 1988, __pyx_L19_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_1);
          __pyx_cur_scope->__pyx_v_err = __pyx_t_1;
          /*try:*/ {

            /* "uvloop/loop.pyx":1990
 *                 except OSError as err:
 *                     # Directory may have permissions only to create socket.
 *                     aio_logger.error(             # <<<<<<<<<<<<<<
 *                         'Unable to check or remove stale UNIX socket %r: %r',
 *                         orig_path, err)
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1990, __pyx_L29_error)
            __Pyx_GOTREF(__pyx_t_11);

            /* "uvloop/loop.pyx":1992
 *                     aio_logger.error(
 *                         'Unable to check or remove stale UNIX socket %r: %r',
 *                         orig_path, err)             # <<<<<<<<<<<<<<
 * 
 *             # We use Python sockets to create a UNIX server socket because
 */
            __pyx_t_12 = NULL;
            __pyx_t_10 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_11, function);
                __pyx_t_10 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_11)) {
              PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u_Unable_to_check_or_remove_stale, __pyx_cur_scope->__pyx_v_orig_path, __pyx_cur_scope->__pyx_v_err};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_10, 3+__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1990, __pyx_L29_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
              PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u_Unable_to_check_or_remove_stale, __pyx_cur_scope->__pyx_v_orig_path, __pyx_cur_scope->__pyx_v_err};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_10, 3+__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1990, __pyx_L29_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            {
              __pyx_t_13 = PyTuple_New(3+__pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 1990, __pyx_L29_error)
              __Pyx_GOTREF(__pyx_t_13);
              if (__pyx_t_12) {
                __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
              }
              __Pyx_INCREF(__pyx_kp_u_Unable_to_check_or_remove_stale);
              __Pyx_GIVEREF(__pyx_kp_u_Unable_to_check_or_remove_stale);
              PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_10, __pyx_kp_u_Unable_to_check_or_remove_stale);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_orig_path);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_orig_path);
              PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_10, __pyx_cur_scope->__pyx_v_orig_path);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_err);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_err);
              PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_10, __pyx_cur_scope->__pyx_v_err);
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1990, __pyx_L29_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }

          /* "uvloop/loop.pyx":1988
 *                 except FileNotFoundError:
 *                     pass
 *                 except OSError as err:             # <<<<<<<<<<<<<<
 *                     # Directory may have permissions only to create socket.
 *                     aio_logger.error(
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_err);
              __Pyx_DECREF(__pyx_cur_scope->__pyx_v_err);
              __pyx_cur_scope->__pyx_v_err = NULL;
              goto __pyx_L30;
            }
            __pyx_L29_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_assign
              __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_16);
              __Pyx_XGOTREF(__pyx_t_17);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              __pyx_t_10 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
              {
                __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_err);
                __Pyx_DECREF(__pyx_cur_scope->__pyx_v_err);
                __pyx_cur_scope->__pyx_v_err = NULL;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
              }
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
              __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
              __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
              goto __pyx_L19_except_error;
            }
            __pyx_L30:;
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          goto __pyx_L18_exception_handled;
        }
        goto __pyx_L19_except_error;
        __pyx_L19_except_error:;

        /* "uvloop/loop.pyx":1983
 *             # Check for abstract socket.
 *             if path[0] != 0:
 *                 try:             # <<<<<<<<<<<<<<
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):
 *                         os_remove(path)
 */
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        goto __pyx_L1_error;
        __pyx_L18_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        __pyx_L22_try_end:;
      }

      /* "uvloop/loop.pyx":1982
 * 
 *             # Check for abstract socket.
 *             if path[0] != 0:             # <<<<<<<<<<<<<<
 *                 try:
 *                     if stat_S_ISSOCK(os_stat(path).st_mode):
 */
    }

    /* "uvloop/loop.pyx":1998
 *             # they were bound to.  This is different from asyncio, which
 *             # doesn't cleanup the socket path.
 *             sock = socket_socket(uv.AF_UNIX)             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1998, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_socket);
    __pyx_t_9 = __pyx_v_6uvloop_4loop_socket_socket; __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1998, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_7);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_1};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1998, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_1};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1998, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 1998, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_11, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1998, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_sock);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_sock, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":2000
 *             sock = socket_socket(uv.AF_UNIX)
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 sock.bind(path)
 *             except OSError as exc:
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/loop.pyx":2001
 * 
 *             try:
 *                 sock.bind(path)             # <<<<<<<<<<<<<<
 *             except OSError as exc:
 *                 sock.close()
 */
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_bind); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2001, __pyx_L35_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_11 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_11)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_11);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
          }
        }
        if (!__pyx_t_11) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_cur_scope->__pyx_v_path); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2001, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_7);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_9)) {
            PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_cur_scope->__pyx_v_path};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2001, __pyx_L35_error)
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
            PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_cur_scope->__pyx_v_path};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2001, __pyx_L35_error)
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          {
            __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2001, __pyx_L35_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_11); __pyx_t_11 = NULL;
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
            PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_cur_scope->__pyx_v_path);
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_1, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2001, __pyx_L35_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "uvloop/loop.pyx":2000
 *             sock = socket_socket(uv.AF_UNIX)
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 sock.bind(path)
 *             except OSError as exc:
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L40_try_end;
      __pyx_L35_error:;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":2002
 *             try:
 *                 sock.bind(path)
 *             except OSError as exc:             # <<<<<<<<<<<<<<
 *                 sock.close()
 *                 if exc.errno == errno.EADDRINUSE:
 */
      __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
      if (__pyx_t_14) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_9, &__pyx_t_1) < 0) __PYX_ERR(2, 2002, __pyx_L37_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_9);
        __pyx_cur_scope->__pyx_v_exc = __pyx_t_9;
        /*try:*/ {

          /* "uvloop/loop.pyx":2003
 *                 sock.bind(path)
 *             except OSError as exc:
 *                 sock.close()             # <<<<<<<<<<<<<<
 *                 if exc.errno == errno.EADDRINUSE:
 *                     # Let's improve the error message by adding
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_close); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2003, __pyx_L46_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
            }
          }
          if (__pyx_t_13) {
            __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_13); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2003, __pyx_L46_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          } else {
            __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2003, __pyx_L46_error)
          }
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "uvloop/loop.pyx":2004
 *             except OSError as exc:
 *                 sock.close()
 *                 if exc.errno == errno.EADDRINUSE:             # <<<<<<<<<<<<<<
 *                     # Let's improve the error message by adding
 *                     # with what exact address it occurs.
 */
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_exc, __pyx_n_s_errno); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2004, __pyx_L46_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_8 = __Pyx_PyInt_From_int(EADDRINUSE); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2004, __pyx_L46_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_13 = PyObject_RichCompare(__pyx_t_11, __pyx_t_8, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2004, __pyx_L46_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2004, __pyx_L46_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(__pyx_t_2)) {

            /* "uvloop/loop.pyx":2007
 *                     # Let's improve the error message by adding
 *                     # with what exact address it occurs.
 *                     msg = 'Address {!r} is already in use'.format(orig_path)             # <<<<<<<<<<<<<<
 *                     raise OSError(errno.EADDRINUSE, msg) from None
 *                 else:
 */
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Address_r_is_already_in_use, __pyx_n_s_format); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2007, __pyx_L46_error)
            __Pyx_GOTREF(__pyx_t_8);
            __pyx_t_11 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_11)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_11);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
              }
            }
            if (!__pyx_t_11) {
              __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_cur_scope->__pyx_v_orig_path); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2007, __pyx_L46_error)
              __Pyx_GOTREF(__pyx_t_13);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_8)) {
                PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_cur_scope->__pyx_v_orig_path};
                __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2007, __pyx_L46_error)
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_GOTREF(__pyx_t_13);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
                PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_cur_scope->__pyx_v_orig_path};
                __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2007, __pyx_L46_error)
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_GOTREF(__pyx_t_13);
              } else
              #endif
              {
                __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2007, __pyx_L46_error)
                __Pyx_GOTREF(__pyx_t_12);
                __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
                __Pyx_INCREF(__pyx_cur_scope->__pyx_v_orig_path);
                __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_orig_path);
                PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_cur_scope->__pyx_v_orig_path);
                __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_12, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2007, __pyx_L46_error)
                __Pyx_GOTREF(__pyx_t_13);
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GIVEREF(__pyx_t_13);
            __pyx_cur_scope->__pyx_v_msg = __pyx_t_13;
            __pyx_t_13 = 0;

            /* "uvloop/loop.pyx":2008
 *                     # with what exact address it occurs.
 *                     msg = 'Address {!r} is already in use'.format(orig_path)
 *                     raise OSError(errno.EADDRINUSE, msg) from None             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise
 */
            __pyx_t_13 = __Pyx_PyInt_From_int(EADDRINUSE); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2008, __pyx_L46_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2008, __pyx_L46_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_13);
            PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_13);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_msg);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_msg);
            PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_cur_scope->__pyx_v_msg);
            __pyx_t_13 = 0;
            __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_t_8, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2008, __pyx_L46_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_Raise(__pyx_t_13, 0, 0, Py_None);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __PYX_ERR(2, 2008, __pyx_L46_error)

            /* "uvloop/loop.pyx":2004
 *             except OSError as exc:
 *                 sock.close()
 *                 if exc.errno == errno.EADDRINUSE:             # <<<<<<<<<<<<<<
 *                     # Let's improve the error message by adding
 *                     # with what exact address it occurs.
 */
          }

          /* "uvloop/loop.pyx":2010
 *                     raise OSError(errno.EADDRINUSE, msg) from None
 *                 else:
 *                     raise             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 sock.close()
 */
          /*else*/ {
            __Pyx_GIVEREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_9);
            __Pyx_XGIVEREF(__pyx_t_1);
            __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_9, __pyx_t_1);
            __pyx_t_7 = 0; __pyx_t_9 = 0; __pyx_t_1 = 0; 
            __PYX_ERR(2, 2010, __pyx_L46_error)
          }
        }

        /* "uvloop/loop.pyx":2002
 *             try:
 *                 sock.bind(path)
 *             except OSError as exc:             # <<<<<<<<<<<<<<
 *                 sock.close()
 *                 if exc.errno == errno.EADDRINUSE:
 */
        /*finally:*/ {
          __pyx_L46_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_assign
            __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_17, &__pyx_t_16);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_16);
            __pyx_t_14 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
            {
              __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
              __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
              __pyx_cur_scope->__pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_17, __pyx_t_16);
            }
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_21, __pyx_t_20, __pyx_t_19);
            __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0;
            __pyx_lineno = __pyx_t_14; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_22;
            goto __pyx_L37_except_error;
          }
        }
      }

      /* "uvloop/loop.pyx":2011
 *                 else:
 *                     raise
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 sock.close()
 *                 raise
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_9, &__pyx_t_7) < 0) __PYX_ERR(2, 2011, __pyx_L37_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_7);

        /* "uvloop/loop.pyx":2012
 *                     raise
 *             except Exception:
 *                 sock.close()             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_close); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2012, __pyx_L37_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (__pyx_t_12) {
          __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2012, __pyx_L37_except_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        } else {
          __pyx_t_13 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2012, __pyx_L37_except_error)
        }
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "uvloop/loop.pyx":2013
 *             except Exception:
 *                 sock.close()
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_9, __pyx_t_7);
        __pyx_t_1 = 0; __pyx_t_9 = 0; __pyx_t_7 = 0; 
        __PYX_ERR(2, 2013, __pyx_L37_except_error)
      }
      goto __pyx_L37_except_error;
      __pyx_L37_except_error:;

      /* "uvloop/loop.pyx":2000
 *             sock = socket_socket(uv.AF_UNIX)
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 sock.bind(path)
 *             except OSError as exc:
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L40_try_end:;
    }

    /* "uvloop/loop.pyx":1963
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if path is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
    goto __pyx_L7;
  }

  /* "uvloop/loop.pyx":2016
 * 
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'path was not specified, and no sock specified')
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_cur_scope->__pyx_v_sock == Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":2017
 *         else:
 *             if sock is None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'path was not specified, and no sock specified')
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__77, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2017, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(2, 2017, __pyx_L1_error)

      /* "uvloop/loop.pyx":2016
 * 
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'path was not specified, and no sock specified')
 */
    }

    /* "uvloop/loop.pyx":2020
 *                     'path was not specified, and no sock specified')
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = PyObject_RichCompare(__pyx_t_7, __pyx_t_9, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2020, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2020, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (!__pyx_t_2) {
    } else {
      __pyx_t_3 = __pyx_t_2;
      goto __pyx_L57_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __pyx_f_6uvloop_4loop__is_sock_stream(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2020, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2020, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_23 = ((!__pyx_t_2) != 0);
    __pyx_t_3 = __pyx_t_23;
    __pyx_L57_bool_binop_done:;
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/loop.pyx":2023
 *                 raise ValueError(
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 *                     .format(sock))             # <<<<<<<<<<<<<<
 * 
 *             # libuv will set the socket to non-blocking mode, but
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_A_UNIX_Domain_Stream_Socket_was, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2023, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2023, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2023, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2023, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2023, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
          PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_cur_scope->__pyx_v_sock);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_13, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2023, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":2021
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 *                     .format(sock))
 */
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2021, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 2021, __pyx_L1_error)

      /* "uvloop/loop.pyx":2020
 *                     'path was not specified, and no sock specified')
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 */
    }

    /* "uvloop/loop.pyx":2027
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *         pipe = UnixServer.new(
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__78, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2027, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_L7:;

  /* "uvloop/loop.pyx":2029
 *             sock.setblocking(False)
 * 
 *         pipe = UnixServer.new(             # <<<<<<<<<<<<<<
 *             self, protocol_factory, server, ssl, ssl_handshake_timeout)
 * 
 */
  __pyx_t_9 = ((PyObject *)__pyx_f_6uvloop_4loop_10UnixServer_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol_factory, __pyx_cur_scope->__pyx_v_server, __pyx_cur_scope->__pyx_v_ssl, __pyx_cur_scope->__pyx_v_ssl_handshake_timeout)); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2029, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_9);
  __pyx_cur_scope->__pyx_v_pipe = ((struct __pyx_obj_6uvloop_4loop_UnixServer *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":2032
 *             self, protocol_factory, server, ssl, ssl_handshake_timeout)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             pipe._open(sock.fileno())
 *         except Exception:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/loop.pyx":2033
 * 
 *         try:
 *             pipe._open(sock.fileno())             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pipe._close()
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2033, __pyx_L59_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_13 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (__pyx_t_13) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2033, __pyx_L59_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      } else {
        __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2033, __pyx_L59_error)
      }
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_t_9); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2033, __pyx_L59_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_cur_scope->__pyx_v_pipe->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_pipe), __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2033, __pyx_L59_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/loop.pyx":2032
 *             self, protocol_factory, server, ssl, ssl_handshake_timeout)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             pipe._open(sock.fileno())
 *         except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L64_try_end;
    __pyx_L59_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":2034
 *         try:
 *             pipe._open(sock.fileno())
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pipe._close()
 *             sock.close()
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_1, &__pyx_t_13) < 0) __PYX_ERR(2, 2034, __pyx_L61_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_13);

      /* "uvloop/loop.pyx":2035
 *             pipe._open(sock.fileno())
 *         except Exception:
 *             pipe._close()             # <<<<<<<<<<<<<<
 *             sock.close()
 *             raise
 */
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_cur_scope->__pyx_v_pipe->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_pipe)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2035, __pyx_L61_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":2036
 *         except Exception:
 *             pipe._close()
 *             sock.close()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_close); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2036, __pyx_L61_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      if (__pyx_t_12) {
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2036, __pyx_L61_except_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else {
        __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2036, __pyx_L61_except_error)
      }
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":2037
 *             pipe._close()
 *             sock.close()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
      __Pyx_GIVEREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_1, __pyx_t_13);
      __pyx_t_9 = 0; __pyx_t_1 = 0; __pyx_t_13 = 0; 
      __PYX_ERR(2, 2037, __pyx_L61_except_error)
    }
    goto __pyx_L61_except_error;
    __pyx_L61_except_error:;

    /* "uvloop/loop.pyx":2032
 *             self, protocol_factory, server, ssl, ssl_handshake_timeout)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             pipe._open(sock.fileno())
 *         except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L64_try_end:;
  }

  /* "uvloop/loop.pyx":2039
 *             raise
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             pipe.listen(backlog)
 *         except Exception:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/loop.pyx":2040
 * 
 *         try:
 *             pipe.listen(backlog)             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pipe._close()
 */
      __pyx_t_13 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_cur_scope->__pyx_v_pipe->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.listen(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_cur_scope->__pyx_v_pipe), __pyx_cur_scope->__pyx_v_backlog); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2040, __pyx_L67_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "uvloop/loop.pyx":2039
 *             raise
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             pipe.listen(backlog)
 *         except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L72_try_end;
    __pyx_L67_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "uvloop/loop.pyx":2041
 *         try:
 *             pipe.listen(backlog)
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pipe._close()
 *             raise
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_1, &__pyx_t_9) < 0) __PYX_ERR(2, 2041, __pyx_L69_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_9);

      /* "uvloop/loop.pyx":2042
 *             pipe.listen(backlog)
 *         except Exception:
 *             pipe._close()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_cur_scope->__pyx_v_pipe->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_pipe)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2042, __pyx_L69_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":2043
 *         except Exception:
 *             pipe._close()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         pipe._attach_fileobj(sock)
 */
      __Pyx_GIVEREF(__pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestoreWithState(__pyx_t_13, __pyx_t_1, __pyx_t_9);
      __pyx_t_13 = 0; __pyx_t_1 = 0; __pyx_t_9 = 0; 
      __PYX_ERR(2, 2043, __pyx_L69_except_error)
    }
    goto __pyx_L69_except_error;
    __pyx_L69_except_error:;

    /* "uvloop/loop.pyx":2039
 *             raise
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             pipe.listen(backlog)
 *         except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L72_try_end:;
  }

  /* "uvloop/loop.pyx":2045
 *             raise
 * 
 *         pipe._attach_fileobj(sock)             # <<<<<<<<<<<<<<
 *         server._add_server(pipe)
 *         return server
 */
  __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_cur_scope->__pyx_v_pipe->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._attach_fileobj(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_pipe), __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":2046
 * 
 *         pipe._attach_fileobj(sock)
 *         server._add_server(pipe)             # <<<<<<<<<<<<<<
 *         return server
 * 
 */
  __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_cur_scope->__pyx_v_server->__pyx_vtab)->_add_server(__pyx_cur_scope->__pyx_v_server, ((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_cur_scope->__pyx_v_pipe)); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/loop.pyx":2047
 *         pipe._attach_fileobj(sock)
 *         server._add_server(pipe)
 *         return server             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(((PyObject *)__pyx_cur_scope->__pyx_v_server));
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":1927
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_server(self, protocol_factory, path=None,             # <<<<<<<<<<<<<<
 *                                  *, backlog=100, sock=None, ssl=None,
 *                                  ssl_handshake_timeout=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("create_unix_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_66generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2050
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_connection(self, protocol_factory, path=None, *,             # <<<<<<<<<<<<<<
 *                                      ssl=None, sock=None,
 *                                      server_hostname=None,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_65create_unix_connection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_64create_unix_connection[] = "Loop.create_unix_connection(self, protocol_factory, path=None, *, ssl=None, sock=None, server_hostname=None, ssl_handshake_timeout=None)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_65create_unix_connection(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_ssl = 0;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_server_hostname = 0;
  PyObject *__pyx_v_ssl_handshake_timeout = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_unix_connection (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_path,&__pyx_n_s_ssl,&__pyx_n_s_sock,&__pyx_n_s_server_hostname,&__pyx_n_s_ssl_handshake_timeout,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[1] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2051
 *     @cython.iterable_coroutine
 *     async def create_unix_connection(self, protocol_factory, path=None, *,
 *                                      ssl=None, sock=None,             # <<<<<<<<<<<<<<
 *                                      server_hostname=None,
 *                                      ssl_handshake_timeout=None):
 */
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2052
 *     async def create_unix_connection(self, protocol_factory, path=None, *,
 *                                      ssl=None, sock=None,
 *                                      server_hostname=None,             # <<<<<<<<<<<<<<
 *                                      ssl_handshake_timeout=None):
 * 
 */
    values[4] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2053
 *                                      ssl=None, sock=None,
 *                                      server_hostname=None,
 *                                      ssl_handshake_timeout=None):             # <<<<<<<<<<<<<<
 * 
 *         cdef:
 */
    values[5] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_path);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (kw_args > 0 && likely(kw_args <= 4)) {
        Py_ssize_t index;
        for (index = 2; index < 6 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_unix_connection") < 0)) __PYX_ERR(2, 2050, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_path = values[1];
    __pyx_v_ssl = values[2];
    __pyx_v_sock = values[3];
    __pyx_v_server_hostname = values[4];
    __pyx_v_ssl_handshake_timeout = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_unix_connection", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2050, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_64create_unix_connection(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_path, __pyx_v_ssl, __pyx_v_sock, __pyx_v_server_hostname, __pyx_v_ssl_handshake_timeout);

  /* "uvloop/loop.pyx":2050
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_connection(self, protocol_factory, path=None, *,             # <<<<<<<<<<<<<<
 *                                      ssl=None, sock=None,
 *                                      server_hostname=None,
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_64create_unix_connection(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_path, PyObject *__pyx_v_ssl, PyObject *__pyx_v_sock, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_unix_connection", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2050, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_path = __pyx_v_path;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
  __pyx_cur_scope->__pyx_v_ssl = __pyx_v_ssl;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_server_hostname = __pyx_v_server_hostname;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_hostname);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_hostname);
  __pyx_cur_scope->__pyx_v_ssl_handshake_timeout = __pyx_v_ssl_handshake_timeout;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_66generator6, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_create_unix_connection, __pyx_n_s_Loop_create_unix_connection, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2050, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_66generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_unix_connection", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L23_resume_from_await;
    case 2: goto __pyx_L36_resume_from_await;
    case 3: goto __pyx_L46_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2050, __pyx_L1_error)

  /* "uvloop/loop.pyx":2061
 *             object ssl_waiter
 * 
 *         app_protocol = protocol = protocol_factory()             # <<<<<<<<<<<<<<
 *         ssl_waiter = None
 *         if ssl:
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_protocol_factory; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2061, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2061, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_app_protocol = __pyx_t_1;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_protocol = __pyx_t_1;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2062
 * 
 *         app_protocol = protocol = protocol_factory()
 *         ssl_waiter = None             # <<<<<<<<<<<<<<
 *         if ssl:
 *             if server_hostname is None:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_cur_scope->__pyx_v_ssl_waiter = Py_None;

  /* "uvloop/loop.pyx":2063
 *         app_protocol = protocol = protocol_factory()
 *         ssl_waiter = None
 *         if ssl:             # <<<<<<<<<<<<<<
 *             if server_hostname is None:
 *                 raise ValueError('You must set server_hostname '
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ssl); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 2063, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "uvloop/loop.pyx":2064
 *         ssl_waiter = None
 *         if ssl:
 *             if server_hostname is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('You must set server_hostname '
 *                                  'when using ssl without a host')
 */
    __pyx_t_4 = (__pyx_cur_scope->__pyx_v_server_hostname == Py_None);
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":2065
 *         if ssl:
 *             if server_hostname is None:
 *                 raise ValueError('You must set server_hostname '             # <<<<<<<<<<<<<<
 *                                  'when using ssl without a host')
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__79, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2065, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 2065, __pyx_L1_error)

      /* "uvloop/loop.pyx":2064
 *         ssl_waiter = None
 *         if ssl:
 *             if server_hostname is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('You must set server_hostname '
 *                                  'when using ssl without a host')
 */
    }

    /* "uvloop/loop.pyx":2068
 *                                  'when using ssl without a host')
 * 
 *             ssl_waiter = self._new_future()             # <<<<<<<<<<<<<<
 *             sslcontext = None if isinstance(ssl, bool) else ssl
 *             protocol = SSLProtocol(
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_ssl_waiter);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_ssl_waiter, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2069
 * 
 *             ssl_waiter = self._new_future()
 *             sslcontext = None if isinstance(ssl, bool) else ssl             # <<<<<<<<<<<<<<
 *             protocol = SSLProtocol(
 *                 self, app_protocol, sslcontext, ssl_waiter,
 */
    __pyx_t_2 = ((PyObject*)&PyBool_Type);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_ssl, __pyx_t_2); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(2, 2069, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if ((__pyx_t_5 != 0)) {
      __Pyx_INCREF(Py_None);
      __pyx_t_1 = Py_None;
    } else {
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
      __pyx_t_1 = __pyx_cur_scope->__pyx_v_ssl;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_v_sslcontext = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2070
 *             ssl_waiter = self._new_future()
 *             sslcontext = None if isinstance(ssl, bool) else ssl
 *             protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_SSLProtocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "uvloop/loop.pyx":2072
 *             protocol = SSLProtocol(
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,             # <<<<<<<<<<<<<<
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *         else:
 */
    __pyx_t_2 = PyTuple_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_app_protocol);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sslcontext);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sslcontext);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_cur_scope->__pyx_v_sslcontext);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_waiter);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_waiter);
    PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_cur_scope->__pyx_v_ssl_waiter);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    PyTuple_SET_ITEM(__pyx_t_2, 4, Py_False);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_server_hostname);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_server_hostname);
    PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_cur_scope->__pyx_v_server_hostname);

    /* "uvloop/loop.pyx":2073
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,
 *                 ssl_handshake_timeout=ssl_handshake_timeout)             # <<<<<<<<<<<<<<
 *         else:
 *             if server_hostname is not None:
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2073, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ssl_handshake_timeout, __pyx_cur_scope->__pyx_v_ssl_handshake_timeout) < 0) __PYX_ERR(2, 2073, __pyx_L1_error)

    /* "uvloop/loop.pyx":2070
 *             ssl_waiter = self._new_future()
 *             sslcontext = None if isinstance(ssl, bool) else ssl
 *             protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self, app_protocol, sslcontext, ssl_waiter,
 *                 False, server_hostname,
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_protocol);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_protocol, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":2063
 *         app_protocol = protocol = protocol_factory()
 *         ssl_waiter = None
 *         if ssl:             # <<<<<<<<<<<<<<
 *             if server_hostname is None:
 *                 raise ValueError('You must set server_hostname '
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":2075
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *         else:
 *             if server_hostname is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 */
  /*else*/ {
    __pyx_t_5 = (__pyx_cur_scope->__pyx_v_server_hostname != Py_None);
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (unlikely(__pyx_t_4)) {

      /* "uvloop/loop.pyx":2076
 *         else:
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')             # <<<<<<<<<<<<<<
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__80, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2076, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 2076, __pyx_L1_error)

      /* "uvloop/loop.pyx":2075
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *         else:
 *             if server_hostname is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 */
    }

    /* "uvloop/loop.pyx":2077
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    __pyx_t_4 = (__pyx_cur_scope->__pyx_v_ssl_handshake_timeout != Py_None);
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":2078
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__81, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2078, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 2078, __pyx_L1_error)

      /* "uvloop/loop.pyx":2077
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    }
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":2081
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if path is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
  __pyx_t_5 = (__pyx_cur_scope->__pyx_v_path != Py_None);
  __pyx_t_4 = (__pyx_t_5 != 0);
  if (__pyx_t_4) {

    /* "uvloop/loop.pyx":2082
 * 
 *         if path is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'path and sock can not be specified at the same time')
 */
    __pyx_t_4 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":2083
 *         if path is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'path and sock can not be specified at the same time')
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__82, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2083, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 2083, __pyx_L1_error)

      /* "uvloop/loop.pyx":2082
 * 
 *         if path is not None:
 *             if sock is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'path and sock can not be specified at the same time')
 */
    }

    /* "uvloop/loop.pyx":2086
 *                     'path and sock can not be specified at the same time')
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "uvloop/loop.pyx":2089
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 *                 fspath = type(path).__fspath__             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 pass
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_cur_scope->__pyx_v_path)), __pyx_n_s_fspath); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2089, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_cur_scope->__pyx_v_fspath = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "uvloop/loop.pyx":2086
 *                     'path and sock can not be specified at the same time')
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
      }

      /* "uvloop/loop.pyx":2093
 *                 pass
 *             else:
 *                 path = fspath(path)             # <<<<<<<<<<<<<<
 * 
 *             if isinstance(path, str):
 */
      /*else:*/ {
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fspath);
        __pyx_t_3 = __pyx_cur_scope->__pyx_v_fspath; __pyx_t_2 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_2) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_path); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2093, __pyx_L12_except_error)
          __Pyx_GOTREF(__pyx_t_6);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_path};
            __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2093, __pyx_L12_except_error)
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_path};
            __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2093, __pyx_L12_except_error)
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else
          #endif
          {
            __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2093, __pyx_L12_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2); __pyx_t_2 = NULL;
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_path);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_path);
            PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_cur_scope->__pyx_v_path);
            __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2093, __pyx_L12_except_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_path);
        __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_path, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_t_6 = 0;
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L15_try_end;
      __pyx_L10_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":2090
 *                 # available on Python 3.5.
 *                 fspath = type(path).__fspath__
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 pass
 *             else:
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
      if (__pyx_t_10) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L11_exception_handled;
      }
      goto __pyx_L12_except_error;
      __pyx_L12_except_error:;

      /* "uvloop/loop.pyx":2086
 *                     'path and sock can not be specified at the same time')
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L11_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_L15_try_end:;
    }

    /* "uvloop/loop.pyx":2095
 *                 path = fspath(path)
 * 
 *             if isinstance(path, str):             # <<<<<<<<<<<<<<
 *                 path = PyUnicode_EncodeFSDefault(path)
 * 
 */
    __pyx_t_5 = PyUnicode_Check(__pyx_cur_scope->__pyx_v_path); 
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (__pyx_t_4) {

      /* "uvloop/loop.pyx":2096
 * 
 *             if isinstance(path, str):
 *                 path = PyUnicode_EncodeFSDefault(path)             # <<<<<<<<<<<<<<
 * 
 *             waiter = self._new_future()
 */
      __pyx_t_6 = PyUnicode_EncodeFSDefault(__pyx_cur_scope->__pyx_v_path); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2096, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_path);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_path, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":2095
 *                 path = fspath(path)
 * 
 *             if isinstance(path, str):             # <<<<<<<<<<<<<<
 *                 path = PyUnicode_EncodeFSDefault(path)
 * 
 */
    }

    /* "uvloop/loop.pyx":2098
 *                 path = PyUnicode_EncodeFSDefault(path)
 * 
 *             waiter = self._new_future()             # <<<<<<<<<<<<<<
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             tr.connect(path)
 */
    __pyx_t_6 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2098, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_cur_scope->__pyx_v_waiter = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":2099
 * 
 *             waiter = self._new_future()
 *             tr = UnixTransport.new(self, protocol, None, waiter)             # <<<<<<<<<<<<<<
 *             tr.connect(path)
 *             try:
 */
    __pyx_t_6 = ((PyObject *)__pyx_f_6uvloop_4loop_13UnixTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_waiter)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2099, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_cur_scope->__pyx_v_tr = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":2100
 *             waiter = self._new_future()
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             tr.connect(path)             # <<<<<<<<<<<<<<
 *             try:
 *                 await waiter
 */
    __pyx_t_11 = __Pyx_PyObject_AsWritableString(__pyx_cur_scope->__pyx_v_path); if (unlikely((!__pyx_t_11) && PyErr_Occurred())) __PYX_ERR(2, 2100, __pyx_L1_error)
    __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->connect(__pyx_cur_scope->__pyx_v_tr, __pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":2101
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             tr.connect(path)
 *             try:             # <<<<<<<<<<<<<<
 *                 await waiter
 *             except Exception:
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_8, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "uvloop/loop.pyx":2102
 *             tr.connect(path)
 *             try:
 *                 await waiter             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 tr._close()
 */
        __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
        __Pyx_XGOTREF(__pyx_r);
        if (likely(__pyx_r)) {
          __Pyx_XGIVEREF(__pyx_t_7);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_7;
          __Pyx_XGIVEREF(__pyx_t_8);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_8;
          __Pyx_XGIVEREF(__pyx_t_9);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_9;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, awaiting value */
          __pyx_generator->resume_label = 1;
          return __pyx_r;
          __pyx_L23_resume_from_await:;
          __pyx_t_7 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_7);
          __pyx_t_8 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_8);
          __pyx_t_9 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_9);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2102, __pyx_L17_error)
        } else {
          PyObject* exc_type = __Pyx_PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
            else __PYX_ERR(2, 2102, __pyx_L17_error)
          }
        }

        /* "uvloop/loop.pyx":2101
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             tr.connect(path)
 *             try:             # <<<<<<<<<<<<<<
 *                 await waiter
 *             except Exception:
 */
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L22_try_end;
      __pyx_L17_error:;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":2103
 *             try:
 *                 await waiter
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 tr._close()
 *                 raise
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_3, &__pyx_t_1) < 0) __PYX_ERR(2, 2103, __pyx_L19_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_1);

        /* "uvloop/loop.pyx":2104
 *                 await waiter
 *             except Exception:
 *                 tr._close()             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2104, __pyx_L19_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":2105
 *             except Exception:
 *                 tr._close()
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_1);
        __Pyx_ErrRestoreWithState(__pyx_t_6, __pyx_t_3, __pyx_t_1);
        __pyx_t_6 = 0; __pyx_t_3 = 0; __pyx_t_1 = 0; 
        __PYX_ERR(2, 2105, __pyx_L19_except_error)
      }
      goto __pyx_L19_except_error;
      __pyx_L19_except_error:;

      /* "uvloop/loop.pyx":2101
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             tr.connect(path)
 *             try:             # <<<<<<<<<<<<<<
 *                 await waiter
 *             except Exception:
 */
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L22_try_end:;
    }

    /* "uvloop/loop.pyx":2081
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if path is not None:             # <<<<<<<<<<<<<<
 *             if sock is not None:
 *                 raise ValueError(
 */
    goto __pyx_L8;
  }

  /* "uvloop/loop.pyx":2108
 * 
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('no path and sock were specified')
 * 
 */
  /*else*/ {
    __pyx_t_4 = (__pyx_cur_scope->__pyx_v_sock == Py_None);
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":2109
 *         else:
 *             if sock is None:
 *                 raise ValueError('no path and sock were specified')             # <<<<<<<<<<<<<<
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__83, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 2109, __pyx_L1_error)

      /* "uvloop/loop.pyx":2108
 * 
 *         else:
 *             if sock is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('no path and sock were specified')
 * 
 */
    }

    /* "uvloop/loop.pyx":2111
 *                 raise ValueError('no path and sock were specified')
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 2111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (!__pyx_t_4) {
    } else {
      __pyx_t_5 = __pyx_t_4;
      goto __pyx_L28_bool_binop_done;
    }
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __pyx_f_6uvloop_4loop__is_sock_stream(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 2111, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_12 = ((!__pyx_t_4) != 0);
    __pyx_t_5 = __pyx_t_12;
    __pyx_L28_bool_binop_done:;
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/loop.pyx":2114
 *                 raise ValueError(
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 *                     .format(sock))             # <<<<<<<<<<<<<<
 * 
 *             # libuv will set the socket to non-blocking mode, but
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_A_UNIX_Domain_Stream_Socket_was, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_1) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2114, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2114, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2114, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
          PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_cur_scope->__pyx_v_sock);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2114, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":2112
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 *                     .format(sock))
 */
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(2, 2112, __pyx_L1_error)

      /* "uvloop/loop.pyx":2111
 *                 raise ValueError('no path and sock were specified')
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A UNIX Domain Stream Socket was expected, got {!r}'
 */
    }

    /* "uvloop/loop.pyx":2118
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *             waiter = self._new_future()
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__84, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2120
 *             sock.setblocking(False)
 * 
 *             waiter = self._new_future()             # <<<<<<<<<<<<<<
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             try:
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_v_waiter = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2121
 * 
 *             waiter = self._new_future()
 *             tr = UnixTransport.new(self, protocol, None, waiter)             # <<<<<<<<<<<<<<
 *             try:
 *                 tr._open(sock.fileno())
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_6uvloop_4loop_13UnixTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_waiter)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_cur_scope->__pyx_v_tr = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2122
 *             waiter = self._new_future()
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             try:             # <<<<<<<<<<<<<<
 *                 tr._open(sock.fileno())
 *                 tr._init_protocol()
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "uvloop/loop.pyx":2123
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             try:
 *                 tr._open(sock.fileno())             # <<<<<<<<<<<<<<
 *                 tr._init_protocol()
 *                 await waiter
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2123, __pyx_L30_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_2 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (__pyx_t_2) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2123, __pyx_L30_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        } else {
          __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2123, __pyx_L30_error)
        }
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2123, __pyx_L30_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_tr), __pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2123, __pyx_L30_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/loop.pyx":2124
 *             try:
 *                 tr._open(sock.fileno())
 *                 tr._init_protocol()             # <<<<<<<<<<<<<<
 *                 await waiter
 *             except Exception:
 */
        __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2124, __pyx_L30_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/loop.pyx":2125
 *                 tr._open(sock.fileno())
 *                 tr._init_protocol()
 *                 await waiter             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 tr._close()
 */
        __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
        __Pyx_XGOTREF(__pyx_r);
        if (likely(__pyx_r)) {
          __Pyx_XGIVEREF(__pyx_t_7);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_7;
          __Pyx_XGIVEREF(__pyx_t_8);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_8;
          __Pyx_XGIVEREF(__pyx_t_9);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_9;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, awaiting value */
          __pyx_generator->resume_label = 2;
          return __pyx_r;
          __pyx_L36_resume_from_await:;
          __pyx_t_7 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_7);
          __pyx_t_8 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_8);
          __pyx_t_9 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_9);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2125, __pyx_L30_error)
        } else {
          PyObject* exc_type = __Pyx_PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
            else __PYX_ERR(2, 2125, __pyx_L30_error)
          }
        }

        /* "uvloop/loop.pyx":2122
 *             waiter = self._new_future()
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             try:             # <<<<<<<<<<<<<<
 *                 tr._open(sock.fileno())
 *                 tr._init_protocol()
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L35_try_end;
      __pyx_L30_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2126
 *                 tr._init_protocol()
 *                 await waiter
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 tr._close()
 *                 raise
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_6, &__pyx_t_2) < 0) __PYX_ERR(2, 2126, __pyx_L32_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_2);

        /* "uvloop/loop.pyx":2127
 *                 await waiter
 *             except Exception:
 *                 tr._close()             # <<<<<<<<<<<<<<
 *                 raise
 * 
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2127, __pyx_L32_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "uvloop/loop.pyx":2128
 *             except Exception:
 *                 tr._close()
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *             tr._attach_fileobj(sock)
 */
        __Pyx_GIVEREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_2);
        __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_6, __pyx_t_2);
        __pyx_t_3 = 0; __pyx_t_6 = 0; __pyx_t_2 = 0; 
        __PYX_ERR(2, 2128, __pyx_L32_except_error)
      }
      goto __pyx_L32_except_error;
      __pyx_L32_except_error:;

      /* "uvloop/loop.pyx":2122
 *             waiter = self._new_future()
 *             tr = UnixTransport.new(self, protocol, None, waiter)
 *             try:             # <<<<<<<<<<<<<<
 *                 tr._open(sock.fileno())
 *                 tr._init_protocol()
 */
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L35_try_end:;
    }

    /* "uvloop/loop.pyx":2130
 *                 raise
 * 
 *             tr._attach_fileobj(sock)             # <<<<<<<<<<<<<<
 * 
 *         if ssl:
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._attach_fileobj(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_tr), __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L8:;

  /* "uvloop/loop.pyx":2132
 *             tr._attach_fileobj(sock)
 * 
 *         if ssl:             # <<<<<<<<<<<<<<
 *             try:
 *                 await ssl_waiter
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ssl); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(2, 2132, __pyx_L1_error)
  if (__pyx_t_5) {

    /* "uvloop/loop.pyx":2133
 * 
 *         if ssl:
 *             try:             # <<<<<<<<<<<<<<
 *                 await ssl_waiter
 *             except Exception:
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_8, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "uvloop/loop.pyx":2134
 *         if ssl:
 *             try:
 *                 await ssl_waiter             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 tr._close()
 */
        __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_ssl_waiter);
        __Pyx_XGOTREF(__pyx_r);
        if (likely(__pyx_r)) {
          __Pyx_XGIVEREF(__pyx_t_7);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_7;
          __Pyx_XGIVEREF(__pyx_t_8);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_8;
          __Pyx_XGIVEREF(__pyx_t_9);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_9;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, awaiting value */
          __pyx_generator->resume_label = 3;
          return __pyx_r;
          __pyx_L46_resume_from_await:;
          __pyx_t_7 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_7);
          __pyx_t_8 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_8);
          __pyx_t_9 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_9);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2134, __pyx_L40_error)
        } else {
          PyObject* exc_type = __Pyx_PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
            else __PYX_ERR(2, 2134, __pyx_L40_error)
          }
        }

        /* "uvloop/loop.pyx":2133
 * 
 *         if ssl:
 *             try:             # <<<<<<<<<<<<<<
 *                 await ssl_waiter
 *             except Exception:
 */
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L45_try_end;
      __pyx_L40_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":2135
 *             try:
 *                 await ssl_waiter
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 tr._close()
 *                 raise
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop.create_unix_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_6, &__pyx_t_3) < 0) __PYX_ERR(2, 2135, __pyx_L42_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_3);

        /* "uvloop/loop.pyx":2136
 *                 await ssl_waiter
 *             except Exception:
 *                 tr._close()             # <<<<<<<<<<<<<<
 *                 raise
 *             return protocol._app_transport, app_protocol
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_cur_scope->__pyx_v_tr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_tr)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2136, __pyx_L42_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "uvloop/loop.pyx":2137
 *             except Exception:
 *                 tr._close()
 *                 raise             # <<<<<<<<<<<<<<
 *             return protocol._app_transport, app_protocol
 *         else:
 */
        __Pyx_GIVEREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_6, __pyx_t_3);
        __pyx_t_2 = 0; __pyx_t_6 = 0; __pyx_t_3 = 0; 
        __PYX_ERR(2, 2137, __pyx_L42_except_error)
      }
      goto __pyx_L42_except_error;
      __pyx_L42_except_error:;

      /* "uvloop/loop.pyx":2133
 * 
 *         if ssl:
 *             try:             # <<<<<<<<<<<<<<
 *                 await ssl_waiter
 *             except Exception:
 */
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L45_try_end:;
    }

    /* "uvloop/loop.pyx":2138
 *                 tr._close()
 *                 raise
 *             return protocol._app_transport, app_protocol             # <<<<<<<<<<<<<<
 *         else:
 *             return tr, protocol
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_protocol, __pyx_n_s_app_transport); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_app_protocol);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_cur_scope->__pyx_v_app_protocol);
    __pyx_t_3 = 0;
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":2132
 *             tr._attach_fileobj(sock)
 * 
 *         if ssl:             # <<<<<<<<<<<<<<
 *             try:
 *                 await ssl_waiter
 */
  }

  /* "uvloop/loop.pyx":2140
 *             return protocol._app_transport, app_protocol
 *         else:
 *             return tr, protocol             # <<<<<<<<<<<<<<
 * 
 *     def default_exception_handler(self, context):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_tr));
    PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_tr));
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_cur_scope->__pyx_v_protocol);
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = 0;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2050
 * 
 *     @cython.iterable_coroutine
 *     async def create_unix_connection(self, protocol_factory, path=None, *,             # <<<<<<<<<<<<<<
 *                                      ssl=None, sock=None,
 *                                      server_hostname=None,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("create_unix_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2142
 *             return tr, protocol
 * 
 *     def default_exception_handler(self, context):             # <<<<<<<<<<<<<<
 *         """Default exception handler.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_68default_exception_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_context); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_67default_exception_handler[] = "Loop.default_exception_handler(self, context)\nDefault exception handler.\n\n        This is called when an exception occurs and no exception\n        handler is set, and can be called by a custom exception\n        handler that wants to defer to the default behavior.\n\n        The context parameter has the same meaning as in\n        `call_exception_handler()`.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_68default_exception_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_context) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("default_exception_handler (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_67default_exception_handler(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_context));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_67default_exception_handler(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_context) {
  PyObject *__pyx_v_message = NULL;
  PyObject *__pyx_v_exception = NULL;
  PyObject *__pyx_v_exc_info = NULL;
  PyObject *__pyx_v_log_lines = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_tb = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  __Pyx_RefNannySetupContext("default_exception_handler", 0);

  /* "uvloop/loop.pyx":2152
 *         `call_exception_handler()`.
 *         """
 *         message = context.get('message')             # <<<<<<<<<<<<<<
 *         if not message:
 *             message = 'Unhandled exception in event loop'
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__85, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_message = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2153
 *         """
 *         message = context.get('message')
 *         if not message:             # <<<<<<<<<<<<<<
 *             message = 'Unhandled exception in event loop'
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_message); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 2153, __pyx_L1_error)
  __pyx_t_4 = ((!__pyx_t_3) != 0);
  if (__pyx_t_4) {

    /* "uvloop/loop.pyx":2154
 *         message = context.get('message')
 *         if not message:
 *             message = 'Unhandled exception in event loop'             # <<<<<<<<<<<<<<
 * 
 *         exception = context.get('exception')
 */
    __Pyx_INCREF(__pyx_kp_u_Unhandled_exception_in_event_loo);
    __Pyx_DECREF_SET(__pyx_v_message, __pyx_kp_u_Unhandled_exception_in_event_loo);

    /* "uvloop/loop.pyx":2153
 *         """
 *         message = context.get('message')
 *         if not message:             # <<<<<<<<<<<<<<
 *             message = 'Unhandled exception in event loop'
 * 
 */
  }

  /* "uvloop/loop.pyx":2156
 *             message = 'Unhandled exception in event loop'
 * 
 *         exception = context.get('exception')             # <<<<<<<<<<<<<<
 *         if exception is not None:
 *             exc_info = (type(exception), exception, exception.__traceback__)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_exception = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2157
 * 
 *         exception = context.get('exception')
 *         if exception is not None:             # <<<<<<<<<<<<<<
 *             exc_info = (type(exception), exception, exception.__traceback__)
 *         else:
 */
  __pyx_t_4 = (__pyx_v_exception != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "uvloop/loop.pyx":2158
 *         exception = context.get('exception')
 *         if exception is not None:
 *             exc_info = (type(exception), exception, exception.__traceback__)             # <<<<<<<<<<<<<<
 *         else:
 *             exc_info = False
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_n_s_traceback); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_exception)));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_exception)));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(__pyx_v_exception)));
    __Pyx_INCREF(__pyx_v_exception);
    __Pyx_GIVEREF(__pyx_v_exception);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_exception);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_v_exc_info = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":2157
 * 
 *         exception = context.get('exception')
 *         if exception is not None:             # <<<<<<<<<<<<<<
 *             exc_info = (type(exception), exception, exception.__traceback__)
 *         else:
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":2160
 *             exc_info = (type(exception), exception, exception.__traceback__)
 *         else:
 *             exc_info = False             # <<<<<<<<<<<<<<
 * 
 *         log_lines = [message]
 */
  /*else*/ {
    __Pyx_INCREF(Py_False);
    __pyx_v_exc_info = Py_False;
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":2162
 *             exc_info = False
 * 
 *         log_lines = [message]             # <<<<<<<<<<<<<<
 *         for key in sorted(context):
 *             if key in {'message', 'exception'}:
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_message);
  __Pyx_GIVEREF(__pyx_v_message);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_message);
  __pyx_v_log_lines = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2163
 * 
 *         log_lines = [message]
 *         for key in sorted(context):             # <<<<<<<<<<<<<<
 *             if key in {'message', 'exception'}:
 *                 continue
 */
  __pyx_t_1 = PySequence_List(__pyx_v_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_5 = PyList_Sort(__pyx_t_2); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(2, 2163, __pyx_L1_error)
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(2, 2163, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(2, 2163, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":2164
 *         log_lines = [message]
 *         for key in sorted(context):
 *             if key in {'message', 'exception'}:             # <<<<<<<<<<<<<<
 *                 continue
 *             value = context[key]
 */
    __Pyx_INCREF(__pyx_v_key);
    __pyx_t_2 = __pyx_v_key;
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_message, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 2164, __pyx_L1_error)
    if (!__pyx_t_4) {
    } else {
      __pyx_t_3 = __pyx_t_4;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_exception, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 2164, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_4;
    __pyx_L8_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = (__pyx_t_3 != 0);
    if (__pyx_t_4) {

      /* "uvloop/loop.pyx":2165
 *         for key in sorted(context):
 *             if key in {'message', 'exception'}:
 *                 continue             # <<<<<<<<<<<<<<
 *             value = context[key]
 *             if key == 'source_traceback':
 */
      goto __pyx_L5_continue;

      /* "uvloop/loop.pyx":2164
 *         log_lines = [message]
 *         for key in sorted(context):
 *             if key in {'message', 'exception'}:             # <<<<<<<<<<<<<<
 *                 continue
 *             value = context[key]
 */
    }

    /* "uvloop/loop.pyx":2166
 *             if key in {'message', 'exception'}:
 *                 continue
 *             value = context[key]             # <<<<<<<<<<<<<<
 *             if key == 'source_traceback':
 *                 tb = ''.join(tb_format_list(value))
 */
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_context, __pyx_v_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":2167
 *                 continue
 *             value = context[key]
 *             if key == 'source_traceback':             # <<<<<<<<<<<<<<
 *                 tb = ''.join(tb_format_list(value))
 *                 value = 'Object created at (most recent call last):\n'
 */
    __pyx_t_4 = (__Pyx_PyUnicode_Equals(__pyx_v_key, __pyx_n_u_source_traceback, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 2167, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "uvloop/loop.pyx":2168
 *             value = context[key]
 *             if key == 'source_traceback':
 *                 tb = ''.join(tb_format_list(value))             # <<<<<<<<<<<<<<
 *                 value = 'Object created at (most recent call last):\n'
 *                 value += tb.rstrip()
 */
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_tb_format_list);
      __pyx_t_7 = __pyx_v_6uvloop_4loop_tb_format_list; __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_8) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2168, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_value};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2168, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_value};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2168, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2168, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
          __Pyx_INCREF(__pyx_v_value);
          __Pyx_GIVEREF(__pyx_v_value);
          PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_value);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2168, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyUnicode_Join(__pyx_kp_u__7, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2168, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_tb, ((PyObject*)__pyx_t_7));
      __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":2169
 *             if key == 'source_traceback':
 *                 tb = ''.join(tb_format_list(value))
 *                 value = 'Object created at (most recent call last):\n'             # <<<<<<<<<<<<<<
 *                 value += tb.rstrip()
 *             else:
 */
      __Pyx_INCREF(__pyx_kp_u_Object_created_at_most_recent_ca);
      __Pyx_DECREF_SET(__pyx_v_value, __pyx_kp_u_Object_created_at_most_recent_ca);

      /* "uvloop/loop.pyx":2170
 *                 tb = ''.join(tb_format_list(value))
 *                 value = 'Object created at (most recent call last):\n'
 *                 value += tb.rstrip()             # <<<<<<<<<<<<<<
 *             else:
 *                 try:
 */
      __pyx_t_7 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyUnicode_Type_rstrip, __pyx_v_tb); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_value, __pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2170, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":2167
 *                 continue
 *             value = context[key]
 *             if key == 'source_traceback':             # <<<<<<<<<<<<<<
 *                 tb = ''.join(tb_format_list(value))
 *                 value = 'Object created at (most recent call last):\n'
 */
      goto __pyx_L10;
    }

    /* "uvloop/loop.pyx":2172
 *                 value += tb.rstrip()
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = repr(value)
 *                 except Exception as ex:
 */
    /*else*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        /*try:*/ {

          /* "uvloop/loop.pyx":2173
 *             else:
 *                 try:
 *                     value = repr(value)             # <<<<<<<<<<<<<<
 *                 except Exception as ex:
 *                     value = ('Exception in __repr__ {!r}; '
 */
          __pyx_t_2 = PyObject_Repr(__pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2173, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "uvloop/loop.pyx":2172
 *                 value += tb.rstrip()
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = repr(value)
 *                 except Exception as ex:
 */
        }
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L18_try_end;
        __pyx_L11_error:;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/loop.pyx":2174
 *                 try:
 *                     value = repr(value)
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     value = ('Exception in __repr__ {!r}; '
 *                              'value type: {!r}'.format(ex, type(value)))
 */
        __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
        if (__pyx_t_13) {
          __Pyx_AddTraceback("uvloop.loop.Loop.default_exception_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(2, 2174, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __pyx_v_ex = __pyx_t_7;
          /*try:*/ {

            /* "uvloop/loop.pyx":2176
 *                 except Exception as ex:
 *                     value = ('Exception in __repr__ {!r}; '
 *                              'value type: {!r}'.format(ex, type(value)))             # <<<<<<<<<<<<<<
 *             log_lines.append('{}: {}'.format(key, value))
 * 
 */
            __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Exception_in___repr___r_value_ty, __pyx_n_s_format); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 2176, __pyx_L24_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_15 = NULL;
            __pyx_t_13 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
              __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
              if (likely(__pyx_t_15)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                __Pyx_INCREF(__pyx_t_15);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_14, function);
                __pyx_t_13 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_ex, ((PyObject *)Py_TYPE(__pyx_v_value))};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_14, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2176, __pyx_L24_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_14)) {
              PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_ex, ((PyObject *)Py_TYPE(__pyx_v_value))};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_14, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2176, __pyx_L24_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            {
              __pyx_t_16 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_16)) __PYX_ERR(2, 2176, __pyx_L24_error)
              __Pyx_GOTREF(__pyx_t_16);
              if (__pyx_t_15) {
                __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_15); __pyx_t_15 = NULL;
              }
              __Pyx_INCREF(__pyx_v_ex);
              __Pyx_GIVEREF(__pyx_v_ex);
              PyTuple_SET_ITEM(__pyx_t_16, 0+__pyx_t_13, __pyx_v_ex);
              __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_value)));
              __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_value)));
              PyTuple_SET_ITEM(__pyx_t_16, 1+__pyx_t_13, ((PyObject *)Py_TYPE(__pyx_v_value)));
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_16, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2176, __pyx_L24_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            }
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_8);
            __pyx_t_8 = 0;
          }

          /* "uvloop/loop.pyx":2174
 *                 try:
 *                     value = repr(value)
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     value = ('Exception in __repr__ {!r}; '
 *                              'value type: {!r}'.format(ex, type(value)))
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
              goto __pyx_L25;
            }
            __pyx_L24_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_23);
              __Pyx_XGOTREF(__pyx_t_24);
              __pyx_t_13 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_ex);
                __pyx_v_ex = NULL;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_22);
                __Pyx_XGIVEREF(__pyx_t_23);
                __Pyx_XGIVEREF(__pyx_t_24);
                __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
              }
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
              __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
              __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
              goto __pyx_L13_except_error;
            }
            __pyx_L25:;
          }
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L12_exception_handled;
        }
        goto __pyx_L13_except_error;
        __pyx_L13_except_error:;

        /* "uvloop/loop.pyx":2172
 *                 value += tb.rstrip()
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     value = repr(value)
 *                 except Exception as ex:
 */
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
        goto __pyx_L1_error;
        __pyx_L12_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
        __pyx_L18_try_end:;
      }
    }
    __pyx_L10:;

    /* "uvloop/loop.pyx":2177
 *                     value = ('Exception in __repr__ {!r}; '
 *                              'value type: {!r}'.format(ex, type(value)))
 *             log_lines.append('{}: {}'.format(key, value))             # <<<<<<<<<<<<<<
 * 
 *         aio_logger.error('\n'.join(log_lines), exc_info=exc_info)
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u__87, __pyx_n_s_format); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = NULL;
    __pyx_t_17 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_17 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_key, __pyx_v_value};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_17, 2+__pyx_t_17); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2177, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_key, __pyx_v_value};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_17, 2+__pyx_t_17); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2177, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_17); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2177, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_2) {
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2); __pyx_t_2 = NULL;
      }
      __Pyx_INCREF(__pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_17, __pyx_v_key);
      __Pyx_INCREF(__pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_17, __pyx_v_value);
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2177, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_log_lines, __pyx_t_9); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(2, 2177, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":2163
 * 
 *         log_lines = [message]
 *         for key in sorted(context):             # <<<<<<<<<<<<<<
 *             if key in {'message', 'exception'}:
 *                 continue
 */
    __pyx_L5_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2179
 *             log_lines.append('{}: {}'.format(key, value))
 * 
 *         aio_logger.error('\n'.join(log_lines), exc_info=exc_info)             # <<<<<<<<<<<<<<
 * 
 *     def get_exception_handler(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__88, __pyx_v_log_lines); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9);
  __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_exc_info, __pyx_v_exc_info) < 0) __PYX_ERR(2, 2179, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "uvloop/loop.pyx":2142
 *             return tr, protocol
 * 
 *     def default_exception_handler(self, context):             # <<<<<<<<<<<<<<
 *         """Default exception handler.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("uvloop.loop.Loop.default_exception_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_message);
  __Pyx_XDECREF(__pyx_v_exception);
  __Pyx_XDECREF(__pyx_v_exc_info);
  __Pyx_XDECREF(__pyx_v_log_lines);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_tb);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2181
 *         aio_logger.error('\n'.join(log_lines), exc_info=exc_info)
 * 
 *     def get_exception_handler(self):             # <<<<<<<<<<<<<<
 *         """Return an exception handler, or None if the default one is in use.
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_70get_exception_handler(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_69get_exception_handler[] = "Loop.get_exception_handler(self)\nReturn an exception handler, or None if the default one is in use.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_70get_exception_handler(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_exception_handler (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_69get_exception_handler(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_69get_exception_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_exception_handler", 0);

  /* "uvloop/loop.pyx":2184
 *         """Return an exception handler, or None if the default one is in use.
 *         """
 *         return self._exception_handler             # <<<<<<<<<<<<<<
 * 
 *     def set_exception_handler(self, handler):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_exception_handler);
  __pyx_r = __pyx_v_self->_exception_handler;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":2181
 *         aio_logger.error('\n'.join(log_lines), exc_info=exc_info)
 * 
 *     def get_exception_handler(self):             # <<<<<<<<<<<<<<
 *         """Return an exception handler, or None if the default one is in use.
 *         """
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2186
 *         return self._exception_handler
 * 
 *     def set_exception_handler(self, handler):             # <<<<<<<<<<<<<<
 *         """Set handler as the new event loop exception handler.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_72set_exception_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_handler); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_71set_exception_handler[] = "Loop.set_exception_handler(self, handler)\nSet handler as the new event loop exception handler.\n\n        If handler is None, the default exception handler will\n        be set.\n\n        If handler is a callable object, it should have a\n        signature matching '(loop, context)', where 'loop'\n        will be a reference to the active event loop, 'context'\n        will be a dict object (see `call_exception_handler()`\n        documentation for details about context).\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_72set_exception_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_handler) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_exception_handler (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_71set_exception_handler(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_handler));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_71set_exception_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_handler) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("set_exception_handler", 0);

  /* "uvloop/loop.pyx":2198
 *         documentation for details about context).
 *         """
 *         if handler is not None and not callable(handler):             # <<<<<<<<<<<<<<
 *             raise TypeError('A callable object or None is expected, '
 *                             'got {!r}'.format(handler))
 */
  __pyx_t_2 = (__pyx_v_handler != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyCallable_Check(__pyx_v_handler); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(2, 2198, __pyx_L1_error)
  __pyx_t_2 = ((!(__pyx_t_3 != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2200
 *         if handler is not None and not callable(handler):
 *             raise TypeError('A callable object or None is expected, '
 *                             'got {!r}'.format(handler))             # <<<<<<<<<<<<<<
 *         self._exception_handler = handler
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_A_callable_object_or_None_is_exp, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_handler); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2200, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_handler};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2200, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_handler};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2200, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_handler);
        __Pyx_GIVEREF(__pyx_v_handler);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_handler);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2200, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":2199
 *         """
 *         if handler is not None and not callable(handler):
 *             raise TypeError('A callable object or None is expected, '             # <<<<<<<<<<<<<<
 *                             'got {!r}'.format(handler))
 *         self._exception_handler = handler
 */
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(2, 2199, __pyx_L1_error)

    /* "uvloop/loop.pyx":2198
 *         documentation for details about context).
 *         """
 *         if handler is not None and not callable(handler):             # <<<<<<<<<<<<<<
 *             raise TypeError('A callable object or None is expected, '
 *                             'got {!r}'.format(handler))
 */
  }

  /* "uvloop/loop.pyx":2201
 *             raise TypeError('A callable object or None is expected, '
 *                             'got {!r}'.format(handler))
 *         self._exception_handler = handler             # <<<<<<<<<<<<<<
 * 
 *     def call_exception_handler(self, context):
 */
  __Pyx_INCREF(__pyx_v_handler);
  __Pyx_GIVEREF(__pyx_v_handler);
  __Pyx_GOTREF(__pyx_v_self->_exception_handler);
  __Pyx_DECREF(__pyx_v_self->_exception_handler);
  __pyx_v_self->_exception_handler = __pyx_v_handler;

  /* "uvloop/loop.pyx":2186
 *         return self._exception_handler
 * 
 *     def set_exception_handler(self, handler):             # <<<<<<<<<<<<<<
 *         """Set handler as the new event loop exception handler.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop.set_exception_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2203
 *         self._exception_handler = handler
 * 
 *     def call_exception_handler(self, context):             # <<<<<<<<<<<<<<
 *         """Call the current event loop's exception handler.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_74call_exception_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_context); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_73call_exception_handler[] = "Loop.call_exception_handler(self, context)\nCall the current event loop's exception handler.\n\n        The context argument is a dict containing the following keys:\n\n        - 'message': Error message;\n        - 'exception' (optional): Exception object;\n        - 'future' (optional): Future instance;\n        - 'handle' (optional): Handle instance;\n        - 'protocol' (optional): Protocol instance;\n        - 'transport' (optional): Transport instance;\n        - 'socket' (optional): Socket instance.\n\n        New keys maybe introduced in the future.\n\n        Note: do not overload this method in an event loop subclass.\n        For custom exception handling, use the\n        `set_exception_handler()` method.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_74call_exception_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_context) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_exception_handler (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_73call_exception_handler(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_context));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_73call_exception_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_context) {
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_t_19;
  char const *__pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  __Pyx_RefNannySetupContext("call_exception_handler", 0);

  /* "uvloop/loop.pyx":2222
 *         `set_exception_handler()` method.
 *         """
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._debug_exception_handler_cnt += 1
 * 
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2223
 *         """
 *         if UVLOOP_DEBUG:
 *             self._debug_exception_handler_cnt += 1             # <<<<<<<<<<<<<<
 * 
 *         if self._exception_handler is None:
 */
    __pyx_v_self->_debug_exception_handler_cnt = (__pyx_v_self->_debug_exception_handler_cnt + 1);

    /* "uvloop/loop.pyx":2222
 *         `set_exception_handler()` method.
 *         """
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._debug_exception_handler_cnt += 1
 * 
 */
  }

  /* "uvloop/loop.pyx":2225
 *             self._debug_exception_handler_cnt += 1
 * 
 *         if self._exception_handler is None:             # <<<<<<<<<<<<<<
 *             try:
 *                 self.default_exception_handler(context)
 */
  __pyx_t_1 = (__pyx_v_self->_exception_handler == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2226
 * 
 *         if self._exception_handler is None:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.default_exception_handler(context)
 *             except Exception:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/loop.pyx":2227
 *         if self._exception_handler is None:
 *             try:
 *                 self.default_exception_handler(context)             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 # Second protection layer for unexpected errors
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_default_exception_handler); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2227, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (!__pyx_t_8) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_context); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2227, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_6);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_context};
            __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2227, __pyx_L5_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_context};
            __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2227, __pyx_L5_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else
          #endif
          {
            __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2227, __pyx_L5_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
            __Pyx_INCREF(__pyx_v_context);
            __Pyx_GIVEREF(__pyx_v_context);
            PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_context);
            __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2227, __pyx_L5_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/loop.pyx":2226
 * 
 *         if self._exception_handler is None:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.default_exception_handler(context)
 *             except Exception:
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L10_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":2228
 *             try:
 *                 self.default_exception_handler(context)
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 # Second protection layer for unexpected errors
 *                 # in the default implementation, as well as for subclassed
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop.call_exception_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(2, 2228, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_9);

        /* "uvloop/loop.pyx":2232
 *                 # in the default implementation, as well as for subclassed
 *                 # event loops with overloaded "default_exception_handler".
 *                 aio_logger.error('Exception in default exception handler',             # <<<<<<<<<<<<<<
 *                                  exc_info=True)
 *         else:
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2232, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_8);

        /* "uvloop/loop.pyx":2233
 *                 # event loops with overloaded "default_exception_handler".
 *                 aio_logger.error('Exception in default exception handler',
 *                                  exc_info=True)             # <<<<<<<<<<<<<<
 *         else:
 *             try:
 */
        __pyx_t_11 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2233, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_exc_info, Py_True) < 0) __PYX_ERR(2, 2233, __pyx_L7_except_error)

        /* "uvloop/loop.pyx":2232
 *                 # in the default implementation, as well as for subclassed
 *                 # event loops with overloaded "default_exception_handler".
 *                 aio_logger.error('Exception in default exception handler',             # <<<<<<<<<<<<<<
 *                                  exc_info=True)
 *         else:
 */
        __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__89, __pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2232, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "uvloop/loop.pyx":2226
 * 
 *         if self._exception_handler is None:
 *             try:             # <<<<<<<<<<<<<<
 *                 self.default_exception_handler(context)
 *             except Exception:
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_L10_try_end:;
    }

    /* "uvloop/loop.pyx":2225
 *             self._debug_exception_handler_cnt += 1
 * 
 *         if self._exception_handler is None:             # <<<<<<<<<<<<<<
 *             try:
 *                 self.default_exception_handler(context)
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":2235
 *                                  exc_info=True)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self._exception_handler(self, context)
 *             except Exception as exc:
 */
  /*else*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_3);
      /*try:*/ {

        /* "uvloop/loop.pyx":2236
 *         else:
 *             try:
 *                 self._exception_handler(self, context)             # <<<<<<<<<<<<<<
 *             except Exception as exc:
 *                 # Exception in the user set custom exception handler.
 */
        __Pyx_INCREF(__pyx_v_self->_exception_handler);
        __pyx_t_7 = __pyx_v_self->_exception_handler; __pyx_t_6 = NULL;
        __pyx_t_10 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_10 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_self), __pyx_v_context};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2236, __pyx_L13_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[3] = {__pyx_t_6, ((PyObject *)__pyx_v_self), __pyx_v_context};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2236, __pyx_L13_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2236, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__pyx_t_6) {
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_10, ((PyObject *)__pyx_v_self));
          __Pyx_INCREF(__pyx_v_context);
          __Pyx_GIVEREF(__pyx_v_context);
          PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_10, __pyx_v_context);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2236, __pyx_L13_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "uvloop/loop.pyx":2235
 *                                  exc_info=True)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self._exception_handler(self, context)
 *             except Exception as exc:
 */
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L18_try_end;
      __pyx_L13_error:;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/loop.pyx":2237
 *             try:
 *                 self._exception_handler(self, context)
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 # Exception in the user set custom exception handler.
 *                 try:
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.Loop.call_exception_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_7, &__pyx_t_12) < 0) __PYX_ERR(2, 2237, __pyx_L15_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_exc = __pyx_t_7;
        /*try:*/ {

          /* "uvloop/loop.pyx":2239
 *             except Exception as exc:
 *                 # Exception in the user set custom exception handler.
 *                 try:             # <<<<<<<<<<<<<<
 *                     # Let's try default handler.
 *                     self.default_exception_handler({
 */
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            /*try:*/ {

              /* "uvloop/loop.pyx":2241
 *                 try:
 *                     # Let's try default handler.
 *                     self.default_exception_handler({             # <<<<<<<<<<<<<<
 *                         'message': 'Unhandled error in exception handler',
 *                         'exception': exc,
 */
              __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_default_exception_handler); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2241, __pyx_L26_error)
              __Pyx_GOTREF(__pyx_t_11);

              /* "uvloop/loop.pyx":2242
 *                     # Let's try default handler.
 *                     self.default_exception_handler({
 *                         'message': 'Unhandled error in exception handler',             # <<<<<<<<<<<<<<
 *                         'exception': exc,
 *                         'context': context,
 */
              __pyx_t_8 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2242, __pyx_L26_error)
              __Pyx_GOTREF(__pyx_t_8);
              if (PyDict_SetItem(__pyx_t_8, __pyx_n_u_message, __pyx_kp_u_Unhandled_error_in_exception_han) < 0) __PYX_ERR(2, 2242, __pyx_L26_error)

              /* "uvloop/loop.pyx":2243
 *                     self.default_exception_handler({
 *                         'message': 'Unhandled error in exception handler',
 *                         'exception': exc,             # <<<<<<<<<<<<<<
 *                         'context': context,
 *                     })
 */
              if (PyDict_SetItem(__pyx_t_8, __pyx_n_u_exception, __pyx_v_exc) < 0) __PYX_ERR(2, 2242, __pyx_L26_error)

              /* "uvloop/loop.pyx":2244
 *                         'message': 'Unhandled error in exception handler',
 *                         'exception': exc,
 *                         'context': context,             # <<<<<<<<<<<<<<
 *                     })
 *                 except Exception:
 */
              if (PyDict_SetItem(__pyx_t_8, __pyx_n_u_context, __pyx_v_context) < 0) __PYX_ERR(2, 2242, __pyx_L26_error)
              __pyx_t_16 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
                __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_11);
                if (likely(__pyx_t_16)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
                  __Pyx_INCREF(__pyx_t_16);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_11, function);
                }
              }
              if (!__pyx_t_16) {
                __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2241, __pyx_L26_error)
                __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_GOTREF(__pyx_t_6);
              } else {
                #if CYTHON_FAST_PYCALL
                if (PyFunction_Check(__pyx_t_11)) {
                  PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_t_8};
                  __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2241, __pyx_L26_error)
                  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                  __Pyx_GOTREF(__pyx_t_6);
                  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                } else
                #endif
                #if CYTHON_FAST_PYCCALL
                if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
                  PyObject *__pyx_temp[2] = {__pyx_t_16, __pyx_t_8};
                  __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2241, __pyx_L26_error)
                  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                  __Pyx_GOTREF(__pyx_t_6);
                  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                } else
                #endif
                {
                  __pyx_t_17 = PyTuple_New(1+1); if (unlikely(!__pyx_t_17)) __PYX_ERR(2, 2241, __pyx_L26_error)
                  __Pyx_GOTREF(__pyx_t_17);
                  __Pyx_GIVEREF(__pyx_t_16); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_16); __pyx_t_16 = NULL;
                  __Pyx_GIVEREF(__pyx_t_8);
                  PyTuple_SET_ITEM(__pyx_t_17, 0+1, __pyx_t_8);
                  __pyx_t_8 = 0;
                  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2241, __pyx_L26_error)
                  __Pyx_GOTREF(__pyx_t_6);
                  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                }
              }
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "uvloop/loop.pyx":2239
 *             except Exception as exc:
 *                 # Exception in the user set custom exception handler.
 *                 try:             # <<<<<<<<<<<<<<
 *                     # Let's try default handler.
 *                     self.default_exception_handler({
 */
            }
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            goto __pyx_L33_try_end;
            __pyx_L26_error:;
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "uvloop/loop.pyx":2246
 *                         'context': context,
 *                     })
 *                 except Exception:             # <<<<<<<<<<<<<<
 *                     # Guard 'default_exception_handler' in case it is
 *                     # overloaded.
 */
            __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
            if (__pyx_t_10) {
              __Pyx_AddTraceback("uvloop.loop.Loop.call_exception_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_11, &__pyx_t_17) < 0) __PYX_ERR(2, 2246, __pyx_L28_except_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_GOTREF(__pyx_t_17);

              /* "uvloop/loop.pyx":2249
 *                     # Guard 'default_exception_handler' in case it is
 *                     # overloaded.
 *                     aio_logger.error('Exception in default exception handler '             # <<<<<<<<<<<<<<
 *                                      'while handling an unexpected error '
 *                                      'in custom exception handler',
 */
              __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2249, __pyx_L28_except_error)
              __Pyx_GOTREF(__pyx_t_8);

              /* "uvloop/loop.pyx":2252
 *                                      'while handling an unexpected error '
 *                                      'in custom exception handler',
 *                                      exc_info=True)             # <<<<<<<<<<<<<<
 * 
 *     def add_reader(self, fileobj, callback, *args):
 */
              __pyx_t_16 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(2, 2252, __pyx_L28_except_error)
              __Pyx_GOTREF(__pyx_t_16);
              if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_exc_info, Py_True) < 0) __PYX_ERR(2, 2252, __pyx_L28_except_error)

              /* "uvloop/loop.pyx":2249
 *                     # Guard 'default_exception_handler' in case it is
 *                     # overloaded.
 *                     aio_logger.error('Exception in default exception handler '             # <<<<<<<<<<<<<<
 *                                      'while handling an unexpected error '
 *                                      'in custom exception handler',
 */
              __pyx_t_18 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__90, __pyx_t_16); if (unlikely(!__pyx_t_18)) __PYX_ERR(2, 2249, __pyx_L28_except_error)
              __Pyx_GOTREF(__pyx_t_18);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
              goto __pyx_L27_exception_handled;
            }
            goto __pyx_L28_except_error;
            __pyx_L28_except_error:;

            /* "uvloop/loop.pyx":2239
 *             except Exception as exc:
 *                 # Exception in the user set custom exception handler.
 *                 try:             # <<<<<<<<<<<<<<
 *                     # Let's try default handler.
 *                     self.default_exception_handler({
 */
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
            goto __pyx_L24_error;
            __pyx_L27_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
            __pyx_L33_try_end:;
          }
        }

        /* "uvloop/loop.pyx":2237
 *             try:
 *                 self._exception_handler(self, context)
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 # Exception in the user set custom exception handler.
 *                 try:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            goto __pyx_L25;
          }
          __pyx_L24_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_23);
            __pyx_t_10 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
            }
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_ErrRestore(__pyx_t_15, __pyx_t_14, __pyx_t_13);
            __pyx_t_15 = 0; __pyx_t_14 = 0; __pyx_t_13 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
            __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
            goto __pyx_L15_except_error;
          }
          __pyx_L25:;
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L14_exception_handled;
      }
      goto __pyx_L15_except_error;
      __pyx_L15_except_error:;

      /* "uvloop/loop.pyx":2235
 *                                  exc_info=True)
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 self._exception_handler(self, context)
 *             except Exception as exc:
 */
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
      goto __pyx_L1_error;
      __pyx_L14_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
      __pyx_L18_try_end:;
    }
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":2203
 *         self._exception_handler = handler
 * 
 *     def call_exception_handler(self, context):             # <<<<<<<<<<<<<<
 *         """Call the current event loop's exception handler.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("uvloop.loop.Loop.call_exception_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2254
 *                                      exc_info=True)
 * 
 *     def add_reader(self, fileobj, callback, *args):             # <<<<<<<<<<<<<<
 *         """Add a reader callback."""
 *         if len(args) == 0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_76add_reader(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_75add_reader[] = "Loop.add_reader(self, fileobj, callback, *args)\nAdd a reader callback.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_76add_reader(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fileobj = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_reader (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fileobj,&__pyx_n_s_callback,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fileobj)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_reader", 0, 2, 2, 1); __PYX_ERR(2, 2254, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "add_reader") < 0)) __PYX_ERR(2, 2254, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_fileobj = values[0];
    __pyx_v_callback = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_reader", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2254, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.add_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_75add_reader(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_fileobj, __pyx_v_callback, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_75add_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, PyObject *__pyx_v_callback, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("add_reader", 0);
  __Pyx_INCREF(__pyx_v_args);

  /* "uvloop/loop.pyx":2256
 *     def add_reader(self, fileobj, callback, *args):
 *         """Add a reader callback."""
 *         if len(args) == 0:             # <<<<<<<<<<<<<<
 *             args = None
 *         self._add_reader(fileobj, new_Handle(self, callback, args, None))
 */
  __pyx_t_1 = PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 2256, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 == 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2257
 *         """Add a reader callback."""
 *         if len(args) == 0:
 *             args = None             # <<<<<<<<<<<<<<
 *         self._add_reader(fileobj, new_Handle(self, callback, args, None))
 * 
 */
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)Py_None));

    /* "uvloop/loop.pyx":2256
 *     def add_reader(self, fileobj, callback, *args):
 *         """Add a reader callback."""
 *         if len(args) == 0:             # <<<<<<<<<<<<<<
 *             args = None
 *         self._add_reader(fileobj, new_Handle(self, callback, args, None))
 */
  }

  /* "uvloop/loop.pyx":2258
 *         if len(args) == 0:
 *             args = None
 *         self._add_reader(fileobj, new_Handle(self, callback, args, None))             # <<<<<<<<<<<<<<
 * 
 *     def remove_reader(self, fileobj):
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_new_Handle(__pyx_v_self, __pyx_v_callback, __pyx_v_args, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 2258, __pyx_L1_error)
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_add_reader(__pyx_v_self, __pyx_v_fileobj, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_3)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2258, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2254
 *                                      exc_info=True)
 * 
 *     def add_reader(self, fileobj, callback, *args):             # <<<<<<<<<<<<<<
 *         """Add a reader callback."""
 *         if len(args) == 0:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop.add_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2260
 *         self._add_reader(fileobj, new_Handle(self, callback, args, None))
 * 
 *     def remove_reader(self, fileobj):             # <<<<<<<<<<<<<<
 *         """Remove a reader callback."""
 *         self._remove_reader(fileobj)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_78remove_reader(PyObject *__pyx_v_self, PyObject *__pyx_v_fileobj); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_77remove_reader[] = "Loop.remove_reader(self, fileobj)\nRemove a reader callback.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_78remove_reader(PyObject *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_reader (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_77remove_reader(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_fileobj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_77remove_reader(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("remove_reader", 0);

  /* "uvloop/loop.pyx":2262
 *     def remove_reader(self, fileobj):
 *         """Remove a reader callback."""
 *         self._remove_reader(fileobj)             # <<<<<<<<<<<<<<
 * 
 *     def add_writer(self, fileobj, callback, *args):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_reader(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2260
 *         self._add_reader(fileobj, new_Handle(self, callback, args, None))
 * 
 *     def remove_reader(self, fileobj):             # <<<<<<<<<<<<<<
 *         """Remove a reader callback."""
 *         self._remove_reader(fileobj)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.remove_reader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2264
 *         self._remove_reader(fileobj)
 * 
 *     def add_writer(self, fileobj, callback, *args):             # <<<<<<<<<<<<<<
 *         """Add a writer callback.."""
 *         if len(args) == 0:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_80add_writer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_79add_writer[] = "Loop.add_writer(self, fileobj, callback, *args)\nAdd a writer callback..";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_80add_writer(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fileobj = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_writer (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fileobj,&__pyx_n_s_callback,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fileobj)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_writer", 0, 2, 2, 1); __PYX_ERR(2, 2264, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "add_writer") < 0)) __PYX_ERR(2, 2264, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_fileobj = values[0];
    __pyx_v_callback = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_writer", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2264, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.add_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_79add_writer(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_fileobj, __pyx_v_callback, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_79add_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj, PyObject *__pyx_v_callback, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("add_writer", 0);
  __Pyx_INCREF(__pyx_v_args);

  /* "uvloop/loop.pyx":2266
 *     def add_writer(self, fileobj, callback, *args):
 *         """Add a writer callback.."""
 *         if len(args) == 0:             # <<<<<<<<<<<<<<
 *             args = None
 *         self._add_writer(fileobj, new_Handle(self, callback, args, None))
 */
  __pyx_t_1 = PyTuple_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 2266, __pyx_L1_error)
  __pyx_t_2 = ((__pyx_t_1 == 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2267
 *         """Add a writer callback.."""
 *         if len(args) == 0:
 *             args = None             # <<<<<<<<<<<<<<
 *         self._add_writer(fileobj, new_Handle(self, callback, args, None))
 * 
 */
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)Py_None));

    /* "uvloop/loop.pyx":2266
 *     def add_writer(self, fileobj, callback, *args):
 *         """Add a writer callback.."""
 *         if len(args) == 0:             # <<<<<<<<<<<<<<
 *             args = None
 *         self._add_writer(fileobj, new_Handle(self, callback, args, None))
 */
  }

  /* "uvloop/loop.pyx":2268
 *         if len(args) == 0:
 *             args = None
 *         self._add_writer(fileobj, new_Handle(self, callback, args, None))             # <<<<<<<<<<<<<<
 * 
 *     def remove_writer(self, fileobj):
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_new_Handle(__pyx_v_self, __pyx_v_callback, __pyx_v_args, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 2268, __pyx_L1_error)
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_add_writer(__pyx_v_self, __pyx_v_fileobj, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_3)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2268, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2264
 *         self._remove_reader(fileobj)
 * 
 *     def add_writer(self, fileobj, callback, *args):             # <<<<<<<<<<<<<<
 *         """Add a writer callback.."""
 *         if len(args) == 0:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Loop.add_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2270
 *         self._add_writer(fileobj, new_Handle(self, callback, args, None))
 * 
 *     def remove_writer(self, fileobj):             # <<<<<<<<<<<<<<
 *         """Remove a writer callback."""
 *         self._remove_writer(fileobj)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_82remove_writer(PyObject *__pyx_v_self, PyObject *__pyx_v_fileobj); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_81remove_writer[] = "Loop.remove_writer(self, fileobj)\nRemove a writer callback.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_82remove_writer(PyObject *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_writer (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_81remove_writer(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_fileobj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_81remove_writer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_fileobj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("remove_writer", 0);

  /* "uvloop/loop.pyx":2272
 *     def remove_writer(self, fileobj):
 *         """Remove a writer callback."""
 *         self._remove_writer(fileobj)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_remove_writer(__pyx_v_self, __pyx_v_fileobj); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2270
 *         self._add_writer(fileobj, new_Handle(self, callback, args, None))
 * 
 *     def remove_writer(self, fileobj):             # <<<<<<<<<<<<<<
 *         """Remove a writer callback."""
 *         self._remove_writer(fileobj)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.remove_writer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_85generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2275
 * 
 *     @cython.iterable_coroutine
 *     async def sock_recv(self, sock, n):             # <<<<<<<<<<<<<<
 *         """Receive data from the socket.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_84sock_recv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_83sock_recv[] = "Loop.sock_recv(self, sock, n)\nReceive data from the socket.\n\n        The return value is a bytes object representing the data received.\n        The maximum amount of data to be received at once is specified by\n        nbytes.\n\n        This method is a coroutine.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_84sock_recv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_n = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_recv (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sock,&__pyx_n_s_n,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sock)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_n)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("sock_recv", 1, 2, 2, 1); __PYX_ERR(2, 2275, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "sock_recv") < 0)) __PYX_ERR(2, 2275, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_sock = values[0];
    __pyx_v_n = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sock_recv", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2275, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_recv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_83sock_recv(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_sock, __pyx_v_n);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_83sock_recv(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_n) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_recv", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_14_sock_recv(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_14_sock_recv, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2275, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_n = __pyx_v_n;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_n);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_n);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_85generator7, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_sock_recv, __pyx_n_s_Loop_sock_recv, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2275, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_recv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_85generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_recv", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2275, __pyx_L1_error)

  /* "uvloop/loop.pyx":2287
 *             Handle handle
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_self->_debug != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_gettimeout); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2287, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2287, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2287, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2288
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__91, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 2288, __pyx_L1_error)

    /* "uvloop/loop.pyx":2287
 *             Handle handle
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  }

  /* "uvloop/loop.pyx":2290
 *             raise ValueError("the socket must be non-blocking")
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)             # <<<<<<<<<<<<<<
 *         handle = new_MethodHandle3(
 *             self,
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_SyncSocketReaderFuture); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2290, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2290, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_cur_scope->__pyx_v_sock);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_fut = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2291
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 *         handle = new_MethodHandle3(             # <<<<<<<<<<<<<<
 *             self,
 *             "Loop._sock_recv",
 */
  __pyx_t_4 = __pyx_f_6uvloop_4loop_new_MethodHandle3(__pyx_cur_scope->__pyx_v_self, __pyx_kp_u_Loop__sock_recv, ((__pyx_t_6uvloop_4loop_method3_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_recv), ((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_cur_scope->__pyx_v_fut, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_n); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 2291, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2298
 *             fut, sock, n)
 * 
 *         self._add_reader(sock, handle)             # <<<<<<<<<<<<<<
 *         return await fut
 * 
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_add_reader(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_handle); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2299
 * 
 *         self._add_reader(sock, handle)
 *         return await fut             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_fut);
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L7_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2299, __pyx_L1_error)
    __pyx_t_4 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_4);
  } else {
    __pyx_t_4 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_4) < 0) __PYX_ERR(2, 2299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2275
 * 
 *     @cython.iterable_coroutine
 *     async def sock_recv(self, sock, n):             # <<<<<<<<<<<<<<
 *         """Receive data from the socket.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("sock_recv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_88generator8(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2302
 * 
 *     @cython.iterable_coroutine
 *     async def sock_recv_into(self, sock, buf):             # <<<<<<<<<<<<<<
 *         """Receive data from the socket.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_87sock_recv_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_86sock_recv_into[] = "Loop.sock_recv_into(self, sock, buf)\nReceive data from the socket.\n\n        The received data is written into *buf* (a writable buffer).\n        The return value is the number of bytes written.\n\n        This method is a coroutine.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_87sock_recv_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_buf = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_recv_into (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sock,&__pyx_n_s_buf,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sock)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_buf)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("sock_recv_into", 1, 2, 2, 1); __PYX_ERR(2, 2302, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "sock_recv_into") < 0)) __PYX_ERR(2, 2302, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_sock = values[0];
    __pyx_v_buf = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sock_recv_into", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2302, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_recv_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_86sock_recv_into(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_sock, __pyx_v_buf);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_86sock_recv_into(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_buf) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_recv_into", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2302, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_buf = __pyx_v_buf;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_buf);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_buf);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_88generator8, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_sock_recv_into, __pyx_n_s_Loop_sock_recv_into, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2302, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_recv_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_88generator8(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_recv_into", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2302, __pyx_L1_error)

  /* "uvloop/loop.pyx":2313
 *             Handle handle
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_self->_debug != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_gettimeout); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2313, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2313, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2313, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2313, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2314
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__92, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 2314, __pyx_L1_error)

    /* "uvloop/loop.pyx":2313
 *             Handle handle
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  }

  /* "uvloop/loop.pyx":2316
 *             raise ValueError("the socket must be non-blocking")
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)             # <<<<<<<<<<<<<<
 *         handle = new_MethodHandle3(
 *             self,
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_SyncSocketReaderFuture); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2316, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2316, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_cur_scope->__pyx_v_sock);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2316, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_fut = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2317
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 *         handle = new_MethodHandle3(             # <<<<<<<<<<<<<<
 *             self,
 *             "Loop._sock_recv_into",
 */
  __pyx_t_4 = __pyx_f_6uvloop_4loop_new_MethodHandle3(__pyx_cur_scope->__pyx_v_self, __pyx_kp_u_Loop__sock_recv_into, ((__pyx_t_6uvloop_4loop_method3_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_recv_into), ((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_cur_scope->__pyx_v_fut, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_buf); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 2317, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2324
 *             fut, sock, buf)
 * 
 *         self._add_reader(sock, handle)             # <<<<<<<<<<<<<<
 *         return await fut
 * 
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_add_reader(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_handle); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2325
 * 
 *         self._add_reader(sock, handle)
 *         return await fut             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_fut);
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L7_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2325, __pyx_L1_error)
    __pyx_t_4 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_4);
  } else {
    __pyx_t_4 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_4) < 0) __PYX_ERR(2, 2325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2302
 * 
 *     @cython.iterable_coroutine
 *     async def sock_recv_into(self, sock, buf):             # <<<<<<<<<<<<<<
 *         """Receive data from the socket.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("sock_recv_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_91generator9(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2328
 * 
 *     @cython.iterable_coroutine
 *     async def sock_sendall(self, sock, data):             # <<<<<<<<<<<<<<
 *         """Send data to the socket.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_90sock_sendall(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_89sock_sendall[] = "Loop.sock_sendall(self, sock, data)\nSend data to the socket.\n\n        The socket must be connected to a remote socket. This method continues\n        to send data from data until either all data has been sent or an\n        error occurs. None is returned on success. On error, an exception is\n        raised, and there is no way to determine how much data, if any, was\n        successfully processed by the receiving end of the connection.\n\n        This method is a coroutine.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_90sock_sendall(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_sendall (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sock,&__pyx_n_s_data,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sock)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("sock_sendall", 1, 2, 2, 1); __PYX_ERR(2, 2328, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "sock_sendall") < 0)) __PYX_ERR(2, 2328, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_sock = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sock_sendall", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2328, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_sendall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_89sock_sendall(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_sock, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_89sock_sendall(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_data) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_sendall", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_16_sock_sendall(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_16_sock_sendall, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2328, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_data = __pyx_v_data;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_data);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_data);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_91generator9, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_sock_sendall, __pyx_n_s_Loop_sock_sendall, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2328, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_sendall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_91generator9(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_sendall", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L20_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2328, __pyx_L1_error)

  /* "uvloop/loop.pyx":2343
 *             ssize_t n
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_self->_debug != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_gettimeout); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2343, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2343, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2343, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2344
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         if not data:
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__93, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 2344, __pyx_L1_error)

    /* "uvloop/loop.pyx":2343
 *             ssize_t n
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  }

  /* "uvloop/loop.pyx":2346
 *             raise ValueError("the socket must be non-blocking")
 * 
 *         if not data:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_data); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2346, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2347
 * 
 *         if not data:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         socket_inc_io_ref(sock)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":2346
 *             raise ValueError("the socket must be non-blocking")
 * 
 *         if not data:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/loop.pyx":2349
 *             return
 * 
 *         socket_inc_io_ref(sock)             # <<<<<<<<<<<<<<
 *         try:
 *             try:
 */
  __pyx_t_4 = __pyx_f_6uvloop_4loop_socket_inc_io_ref(__pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2350
 * 
 *         socket_inc_io_ref(sock)
 *         try:             # <<<<<<<<<<<<<<
 *             try:
 *                 n = sock.send(data)
 */
  /*try:*/ {

    /* "uvloop/loop.pyx":2351
 *         socket_inc_io_ref(sock)
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 n = sock.send(data)
 *             except (BlockingIOError, InterruptedError):
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "uvloop/loop.pyx":2352
 *         try:
 *             try:
 *                 n = sock.send(data)             # <<<<<<<<<<<<<<
 *             except (BlockingIOError, InterruptedError):
 *                 pass
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_send); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2352, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_5) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_data); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2352, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_4);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_data};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2352, __pyx_L11_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_data};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2352, __pyx_L11_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          {
            __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2352, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_5); __pyx_t_5 = NULL;
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_data);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_data);
            PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_cur_scope->__pyx_v_data);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2352, __pyx_L11_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_10 = PyInt_AsSsize_t(__pyx_t_4); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2352, __pyx_L11_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_cur_scope->__pyx_v_n = __pyx_t_10;

        /* "uvloop/loop.pyx":2351
 *         socket_inc_io_ref(sock)
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 n = sock.send(data)
 *             except (BlockingIOError, InterruptedError):
 */
      }

      /* "uvloop/loop.pyx":2356
 *                 pass
 *             else:
 *                 if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                     # This can be a partial success, i.e. only part
 *                     # of the data was sent
 */
      /*else:*/ {
        __pyx_t_2 = (UVLOOP_DEBUG != 0);
        if (__pyx_t_2) {

          /* "uvloop/loop.pyx":2359
 *                     # This can be a partial success, i.e. only part
 *                     # of the data was sent
 *                     self._sock_try_write_total += 1             # <<<<<<<<<<<<<<
 * 
 *                 if n == len(data):
 */
          __pyx_cur_scope->__pyx_v_self->_sock_try_write_total = (__pyx_cur_scope->__pyx_v_self->_sock_try_write_total + 1);

          /* "uvloop/loop.pyx":2356
 *                 pass
 *             else:
 *                 if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                     # This can be a partial success, i.e. only part
 *                     # of the data was sent
 */
        }

        /* "uvloop/loop.pyx":2361
 *                     self._sock_try_write_total += 1
 * 
 *                 if n == len(data):             # <<<<<<<<<<<<<<
 *                     return
 *                 if not isinstance(data, memoryview):
 */
        __pyx_t_11 = PyObject_Length(__pyx_cur_scope->__pyx_v_data); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 2361, __pyx_L13_except_error)
        __pyx_t_2 = ((__pyx_cur_scope->__pyx_v_n == __pyx_t_11) != 0);
        if (__pyx_t_2) {

          /* "uvloop/loop.pyx":2362
 * 
 *                 if n == len(data):
 *                     return             # <<<<<<<<<<<<<<
 *                 if not isinstance(data, memoryview):
 *                     data = memoryview(data)
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_r = NULL;
          goto __pyx_L14_except_return;

          /* "uvloop/loop.pyx":2361
 *                     self._sock_try_write_total += 1
 * 
 *                 if n == len(data):             # <<<<<<<<<<<<<<
 *                     return
 *                 if not isinstance(data, memoryview):
 */
        }

        /* "uvloop/loop.pyx":2363
 *                 if n == len(data):
 *                     return
 *                 if not isinstance(data, memoryview):             # <<<<<<<<<<<<<<
 *                     data = memoryview(data)
 *                 data = data[n:]
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2363, __pyx_L13_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_data, __pyx_t_4); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 2363, __pyx_L13_except_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_1 = ((!(__pyx_t_2 != 0)) != 0);
        if (__pyx_t_1) {

          /* "uvloop/loop.pyx":2364
 *                     return
 *                 if not isinstance(data, memoryview):
 *                     data = memoryview(data)             # <<<<<<<<<<<<<<
 *                 data = data[n:]
 * 
 */
          __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2364, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_cur_scope->__pyx_v_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2364, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_data);
          __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_data, __pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_3);
          __pyx_t_3 = 0;

          /* "uvloop/loop.pyx":2363
 *                 if n == len(data):
 *                     return
 *                 if not isinstance(data, memoryview):             # <<<<<<<<<<<<<<
 *                     data = memoryview(data)
 *                 data = data[n:]
 */
        }

        /* "uvloop/loop.pyx":2365
 *                 if not isinstance(data, memoryview):
 *                     data = memoryview(data)
 *                 data = data[n:]             # <<<<<<<<<<<<<<
 * 
 *             fut = _SyncSocketWriterFuture(sock, self)
 */
        __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_data, __pyx_cur_scope->__pyx_v_n, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2365, __pyx_L13_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_data);
        __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_data, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __pyx_t_3 = 0;
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L16_try_end;
      __pyx_L11_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":2353
 *             try:
 *                 n = sock.send(data)
 *             except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *                 pass
 *             else:
 */
      __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_4, &__pyx_t_9);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2353, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2353, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_5) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_3, __pyx_t_12);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_ErrRestore(__pyx_t_3, __pyx_t_4, __pyx_t_9);
      __pyx_t_3 = 0; __pyx_t_4 = 0; __pyx_t_9 = 0;
      if (__pyx_t_13) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L12_exception_handled;
      }
      goto __pyx_L13_except_error;
      __pyx_L13_except_error:;

      /* "uvloop/loop.pyx":2351
 *         socket_inc_io_ref(sock)
 *         try:
 *             try:             # <<<<<<<<<<<<<<
 *                 n = sock.send(data)
 *             except (BlockingIOError, InterruptedError):
 */
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L9_error;
      __pyx_L14_except_return:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L8_return;
      __pyx_L12_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L16_try_end:;
    }

    /* "uvloop/loop.pyx":2367
 *                 data = data[n:]
 * 
 *             fut = _SyncSocketWriterFuture(sock, self)             # <<<<<<<<<<<<<<
 *             handle = new_MethodHandle3(
 *                 self,
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_SyncSocketWriterFuture); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2367, __pyx_L9_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = NULL;
    __pyx_t_13 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_13 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2367, __pyx_L9_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2367, __pyx_L9_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    {
      __pyx_t_12 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2367, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_12);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
      PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_13, __pyx_cur_scope->__pyx_v_sock);
      __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
      __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
      PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_13, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_12, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2367, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GIVEREF(__pyx_t_9);
    __pyx_cur_scope->__pyx_v_fut = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":2368
 * 
 *             fut = _SyncSocketWriterFuture(sock, self)
 *             handle = new_MethodHandle3(             # <<<<<<<<<<<<<<
 *                 self,
 *                 "Loop._sock_sendall",
 */
    __pyx_t_9 = __pyx_f_6uvloop_4loop_new_MethodHandle3(__pyx_cur_scope->__pyx_v_self, __pyx_kp_u_Loop__sock_sendall, ((__pyx_t_6uvloop_4loop_method3_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_sendall), ((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_cur_scope->__pyx_v_fut, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_data); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2368, __pyx_L9_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 2368, __pyx_L9_error)
    __Pyx_GIVEREF(__pyx_t_9);
    __pyx_cur_scope->__pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_9);
    __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":2375
 *                 fut, sock, data)
 * 
 *             self._add_writer(sock, handle)             # <<<<<<<<<<<<<<
 *             return await fut
 *         finally:
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_add_writer(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_handle); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2375, __pyx_L9_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":2376
 * 
 *             self._add_writer(sock, handle)
 *             return await fut             # <<<<<<<<<<<<<<
 *         finally:
 *             socket_dec_io_ref(sock)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_fut);
    __Pyx_XGOTREF(__pyx_r);
    if (likely(__pyx_r)) {
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, awaiting value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L20_resume_from_await:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2376, __pyx_L9_error)
      __pyx_t_9 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_9);
    } else {
      __pyx_t_9 = NULL;
      if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_9) < 0) __PYX_ERR(2, 2376, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_9);
    }
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = 0;
    goto __pyx_L8_return;
  }

  /* "uvloop/loop.pyx":2378
 *             return await fut
 *         finally:
 *             socket_dec_io_ref(sock)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  /*finally:*/ {
    __pyx_L9_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_assign
      __pyx_t_8 = 0; __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6) < 0)) __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      __pyx_t_13 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
      {
        __pyx_t_9 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2378, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      }
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ErrRestore(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      __pyx_t_8 = 0; __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
      goto __pyx_L1_error;
      __pyx_L22_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L8_return: {
      __Pyx_PyThreadState_assign
      __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_17, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_17, &__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __pyx_t_19 = __pyx_r;
      __pyx_r = 0;
      __pyx_t_9 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2378, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_19;
      __pyx_t_19 = 0;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      }
      __Pyx_XGIVEREF(__pyx_t_18);
      __Pyx_XGIVEREF(__pyx_t_17);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ErrRestore(__pyx_t_18, __pyx_t_17, __pyx_t_16);
      __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0;
      goto __pyx_L0;
    }
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2328
 * 
 *     @cython.iterable_coroutine
 *     async def sock_sendall(self, sock, data):             # <<<<<<<<<<<<<<
 *         """Send data to the socket.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("sock_sendall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_94generator10(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2381
 * 
 *     @cython.iterable_coroutine
 *     async def sock_accept(self, sock):             # <<<<<<<<<<<<<<
 *         """Accept a connection.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_93sock_accept(PyObject *__pyx_v_self, PyObject *__pyx_v_sock); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_92sock_accept[] = "Loop.sock_accept(self, sock)\nAccept a connection.\n\n        The socket must be bound to an address and listening for connections.\n        The return value is a pair (conn, address) where conn is a new socket\n        object usable to send and receive data on the connection, and address\n        is the address bound to the socket on the other end of the connection.\n\n        This method is a coroutine.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_93sock_accept(PyObject *__pyx_v_self, PyObject *__pyx_v_sock) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_accept (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_92sock_accept(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_sock));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_92sock_accept(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_accept", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_17_sock_accept(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_17_sock_accept, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2381, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_94generator10, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_sock_accept, __pyx_n_s_Loop_sock_accept, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2381, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_accept", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_94generator10(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_accept", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2381, __pyx_L1_error)

  /* "uvloop/loop.pyx":2394
 *             Handle handle
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_self->_debug != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_gettimeout); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2394, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2394, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2394, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2394, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2395
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__94, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 2395, __pyx_L1_error)

    /* "uvloop/loop.pyx":2394
 *             Handle handle
 * 
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  }

  /* "uvloop/loop.pyx":2397
 *             raise ValueError("the socket must be non-blocking")
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)             # <<<<<<<<<<<<<<
 *         handle = new_MethodHandle2(
 *             self,
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_SyncSocketReaderFuture); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2397, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock, ((PyObject *)__pyx_cur_scope->__pyx_v_self)};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2397, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_cur_scope->__pyx_v_sock);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2397, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_fut = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2398
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 *         handle = new_MethodHandle2(             # <<<<<<<<<<<<<<
 *             self,
 *             "Loop._sock_accept",
 */
  __pyx_t_4 = __pyx_f_6uvloop_4loop_new_MethodHandle2(__pyx_cur_scope->__pyx_v_self, __pyx_kp_u_Loop__sock_accept, ((__pyx_t_6uvloop_4loop_method2_t)((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_accept), ((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_cur_scope->__pyx_v_fut, __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 2398, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2405
 *             fut, sock)
 * 
 *         self._add_reader(sock, handle)             # <<<<<<<<<<<<<<
 *         return await fut
 * 
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_add_reader(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_handle); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2406
 * 
 *         self._add_reader(sock, handle)
 *         return await fut             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_fut);
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L7_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2406, __pyx_L1_error)
    __pyx_t_4 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_4);
  } else {
    __pyx_t_4 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_4) < 0) __PYX_ERR(2, 2406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2381
 * 
 *     @cython.iterable_coroutine
 *     async def sock_accept(self, sock):             # <<<<<<<<<<<<<<
 *         """Accept a connection.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("sock_accept", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_97generator11(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2409
 * 
 *     @cython.iterable_coroutine
 *     async def sock_connect(self, sock, address):             # <<<<<<<<<<<<<<
 *         """Connect to a remote socket at address.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_96sock_connect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_95sock_connect[] = "Loop.sock_connect(self, sock, address)\nConnect to a remote socket at address.\n\n        This method is a coroutine.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_96sock_connect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_address = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_connect (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sock,&__pyx_n_s_address,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sock)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_address)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("sock_connect", 1, 2, 2, 1); __PYX_ERR(2, 2409, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "sock_connect") < 0)) __PYX_ERR(2, 2409, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_sock = values[0];
    __pyx_v_address = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sock_connect", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2409, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_95sock_connect(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_sock, __pyx_v_address);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_95sock_connect(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_address) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_connect", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_18_sock_connect(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_18_sock_connect, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2409, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_address = __pyx_v_address;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_address);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_address);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_97generator11, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_sock_connect, __pyx_n_s_Loop_sock_connect, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2409, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.sock_connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_97generator11(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_t_11;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sock_connect", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L11_resume_from_await;
    case 2: goto __pyx_L15_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2409, __pyx_L1_error)

  /* "uvloop/loop.pyx":2414
 *         This method is a coroutine.
 *         """
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_self->_debug != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_gettimeout); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2414, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2414, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2415
 *         """
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         socket_inc_io_ref(sock)
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__95, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 2415, __pyx_L1_error)

    /* "uvloop/loop.pyx":2414
 *         This method is a coroutine.
 *         """
 *         if self._debug and sock.gettimeout() != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("the socket must be non-blocking")
 * 
 */
  }

  /* "uvloop/loop.pyx":2417
 *             raise ValueError("the socket must be non-blocking")
 * 
 *         socket_inc_io_ref(sock)             # <<<<<<<<<<<<<<
 *         try:
 *             if sock.family == uv.AF_UNIX:
 */
  __pyx_t_4 = __pyx_f_6uvloop_4loop_socket_inc_io_ref(__pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2417, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2418
 * 
 *         socket_inc_io_ref(sock)
 *         try:             # <<<<<<<<<<<<<<
 *             if sock.family == uv.AF_UNIX:
 *                 fut = self._sock_connect(sock, address)
 */
  /*try:*/ {

    /* "uvloop/loop.pyx":2419
 *         socket_inc_io_ref(sock)
 *         try:
 *             if sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *                 fut = self._sock_connect(sock, address)
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2419, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2419, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2419, __pyx_L8_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2419, __pyx_L8_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":2420
 *         try:
 *             if sock.family == uv.AF_UNIX:
 *                 fut = self._sock_connect(sock, address)             # <<<<<<<<<<<<<<
 *             else:
 *                 addrs = await self.getaddrinfo(
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_connect(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_address); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2420, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_cur_scope->__pyx_v_fut = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":2419
 *         socket_inc_io_ref(sock)
 *         try:
 *             if sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *                 fut = self._sock_connect(sock, address)
 *             else:
 */
      goto __pyx_L10;
    }

    /* "uvloop/loop.pyx":2422
 *                 fut = self._sock_connect(sock, address)
 *             else:
 *                 addrs = await self.getaddrinfo(             # <<<<<<<<<<<<<<
 *                     *address[:2], family=sock.family)
 * 
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_getaddrinfo); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2422, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "uvloop/loop.pyx":2423
 *             else:
 *                 addrs = await self.getaddrinfo(
 *                     *address[:2], family=sock.family)             # <<<<<<<<<<<<<<
 * 
 *                 _, _, _, _, address = addrs[0]
 */
      __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_address, 0, 2, NULL, NULL, &__pyx_slice__96, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2423, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/loop.pyx":2422
 *                 fut = self._sock_connect(sock, address)
 *             else:
 *                 addrs = await self.getaddrinfo(             # <<<<<<<<<<<<<<
 *                     *address[:2], family=sock.family)
 * 
 */
      __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2422, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2423
 *             else:
 *                 addrs = await self.getaddrinfo(
 *                     *address[:2], family=sock.family)             # <<<<<<<<<<<<<<
 * 
 *                 _, _, _, _, address = addrs[0]
 */
      __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2423, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2423, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_family, __pyx_t_6) < 0) __PYX_ERR(2, 2423, __pyx_L8_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":2422
 *                 fut = self._sock_connect(sock, address)
 *             else:
 *                 addrs = await self.getaddrinfo(             # <<<<<<<<<<<<<<
 *                     *address[:2], family=sock.family)
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2422, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L11_resume_from_await:;
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2422, __pyx_L8_error)
        __pyx_t_6 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_6);
      } else {
        __pyx_t_6 = NULL;
        if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_6) < 0) __PYX_ERR(2, 2422, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_GIVEREF(__pyx_t_6);
      __pyx_cur_scope->__pyx_v_addrs = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "uvloop/loop.pyx":2425
 *                     *address[:2], family=sock.family)
 * 
 *                 _, _, _, _, address = addrs[0]             # <<<<<<<<<<<<<<
 *                 fut = self._sock_connect(sock, address)
 *             if fut is not None:
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_addrs, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2425, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_6);
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 5)) {
          if (size > 5) __Pyx_RaiseTooManyValuesError(5);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(2, 2425, __pyx_L8_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 3); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 4); 
        } else {
          __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 2); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 3); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 4); 
        }
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        #else
        {
          Py_ssize_t i;
          PyObject** temps[5] = {&__pyx_t_3,&__pyx_t_4,&__pyx_t_5,&__pyx_t_7,&__pyx_t_8};
          for (i=0; i < 5; i++) {
            PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(2, 2425, __pyx_L8_error)
            __Pyx_GOTREF(item);
            *(temps[i]) = item;
          }
        }
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        PyObject** temps[5] = {&__pyx_t_3,&__pyx_t_4,&__pyx_t_5,&__pyx_t_7,&__pyx_t_8};
        __pyx_t_9 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2425, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
        for (index=0; index < 5; index++) {
          PyObject* item = __pyx_t_10(__pyx_t_9); if (unlikely(!item)) goto __pyx_L12_unpacking_failed;
          __Pyx_GOTREF(item);
          *(temps[index]) = item;
        }
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 5) < 0) __PYX_ERR(2, 2425, __pyx_L8_error)
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L13_unpacking_done;
        __pyx_L12_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(2, 2425, __pyx_L8_error)
        __pyx_L13_unpacking_done:;
      }
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v__ = __pyx_t_3;
      __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v__);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v__, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v__);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v__, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v__);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v__, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_address);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_address, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_8);
      __pyx_t_8 = 0;

      /* "uvloop/loop.pyx":2426
 * 
 *                 _, _, _, _, address = addrs[0]
 *                 fut = self._sock_connect(sock, address)             # <<<<<<<<<<<<<<
 *             if fut is not None:
 *                 await fut
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_connect(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_address); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2426, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      __pyx_cur_scope->__pyx_v_fut = __pyx_t_6;
      __pyx_t_6 = 0;
    }
    __pyx_L10:;

    /* "uvloop/loop.pyx":2427
 *                 _, _, _, _, address = addrs[0]
 *                 fut = self._sock_connect(sock, address)
 *             if fut is not None:             # <<<<<<<<<<<<<<
 *                 await fut
 *         finally:
 */
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_fut != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":2428
 *                 fut = self._sock_connect(sock, address)
 *             if fut is not None:
 *                 await fut             # <<<<<<<<<<<<<<
 *         finally:
 *             socket_dec_io_ref(sock)
 */
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_fut);
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 2;
        return __pyx_r;
        __pyx_L15_resume_from_await:;
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2428, __pyx_L8_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 2428, __pyx_L8_error)
        }
      }

      /* "uvloop/loop.pyx":2427
 *                 _, _, _, _, address = addrs[0]
 *                 fut = self._sock_connect(sock, address)
 *             if fut is not None:             # <<<<<<<<<<<<<<
 *                 await fut
 *         finally:
 */
    }
  }

  /* "uvloop/loop.pyx":2430
 *                 await fut
 *         finally:
 *             socket_dec_io_ref(sock)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_6 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2430, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L9;
    }
    __pyx_L8_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_assign
      __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_19);
      __pyx_t_11 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
      {
        __pyx_t_6 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2430, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
      }
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
      __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
      goto __pyx_L1_error;
      __pyx_L17_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
      }
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L9:;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2409
 * 
 *     @cython.iterable_coroutine
 *     async def sock_connect(self, sock, address):             # <<<<<<<<<<<<<<
 *         """Connect to a remote socket at address.
 * 
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("sock_connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_100generator12(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2433
 * 
 *     @cython.iterable_coroutine
 *     async def connect_accepted_socket(self, protocol_factory, sock, *,             # <<<<<<<<<<<<<<
 *                                       ssl=None, ssl_handshake_timeout=None):
 *         """Handle an accepted connection.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_99connect_accepted_socket(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_98connect_accepted_socket[] = "Loop.connect_accepted_socket(self, protocol_factory, sock, *, ssl=None, ssl_handshake_timeout=None)\nHandle an accepted connection.\n\n        This is used by servers that accept connections outside of\n        asyncio but that use asyncio to handle connections.\n\n        This method is a coroutine.  When completed, the coroutine\n        returns a (transport, protocol) pair.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_99connect_accepted_socket(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_ssl = 0;
  PyObject *__pyx_v_ssl_handshake_timeout = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_accepted_socket (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_sock,&__pyx_n_s_ssl,&__pyx_n_s_ssl_handshake_timeout,0};
    PyObject* values[4] = {0,0,0,0};

    /* "uvloop/loop.pyx":2434
 *     @cython.iterable_coroutine
 *     async def connect_accepted_socket(self, protocol_factory, sock, *,
 *                                       ssl=None, ssl_handshake_timeout=None):             # <<<<<<<<<<<<<<
 *         """Handle an accepted connection.
 * 
 */
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sock)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("connect_accepted_socket", 1, 2, 2, 1); __PYX_ERR(2, 2433, __pyx_L3_error)
        }
      }
      if (kw_args > 0 && likely(kw_args <= 2)) {
        Py_ssize_t index;
        for (index = 2; index < 4 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "connect_accepted_socket") < 0)) __PYX_ERR(2, 2433, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_sock = values[1];
    __pyx_v_ssl = values[2];
    __pyx_v_ssl_handshake_timeout = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connect_accepted_socket", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2433, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.connect_accepted_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_98connect_accepted_socket(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_sock, __pyx_v_ssl, __pyx_v_ssl_handshake_timeout);

  /* "uvloop/loop.pyx":2433
 * 
 *     @cython.iterable_coroutine
 *     async def connect_accepted_socket(self, protocol_factory, sock, *,             # <<<<<<<<<<<<<<
 *                                       ssl=None, ssl_handshake_timeout=None):
 *         """Handle an accepted connection.
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_98connect_accepted_socket(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_sock, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_accepted_socket", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2433, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  __pyx_cur_scope->__pyx_v_ssl = __pyx_v_ssl;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl);
  __pyx_cur_scope->__pyx_v_ssl_handshake_timeout = __pyx_v_ssl_handshake_timeout;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl_handshake_timeout);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_100generator12, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_connect_accepted_socket, __pyx_n_s_Loop_connect_accepted_socket, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2433, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.connect_accepted_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_100generator12(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_accepted_socket", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L19_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2433, __pyx_L1_error)

  /* "uvloop/loop.pyx":2445
 * 
 *         cdef:
 *             UVStream transport = None             # <<<<<<<<<<<<<<
 * 
 *         if ssl is not None:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_cur_scope->__pyx_v_transport = ((struct __pyx_obj_6uvloop_4loop_UVStream *)Py_None);

  /* "uvloop/loop.pyx":2447
 *             UVStream transport = None
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_ssl != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2448
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 */
    __pyx_t_3 = __pyx_v_6uvloop_4loop_ssl_SSLContext;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = PyObject_IsInstance(__pyx_cur_scope->__pyx_v_ssl, __pyx_t_3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(2, 2448, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = ((!(__pyx_t_2 != 0)) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":2449
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')             # <<<<<<<<<<<<<<
 *         else:
 *             if ssl_handshake_timeout is not None:
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__97, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2449, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 2449, __pyx_L1_error)

      /* "uvloop/loop.pyx":2448
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 */
    }

    /* "uvloop/loop.pyx":2447
 *             UVStream transport = None
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":2451
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_cur_scope->__pyx_v_ssl_handshake_timeout != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/loop.pyx":2452
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__98, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 2452, __pyx_L1_error)

      /* "uvloop/loop.pyx":2451
 *                 raise TypeError('ssl argument must be an SSLContext or None')
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    }
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":2455
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'A Stream Socket was expected, got {!r}'.format(sock))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_6uvloop_4loop__is_sock_stream(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = ((!__pyx_t_2) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2457
 *         if not _is_sock_stream(sock.type):
 *             raise ValueError(
 *                 'A Stream Socket was expected, got {!r}'.format(sock))             # <<<<<<<<<<<<<<
 * 
 *         app_protocol = protocol_factory()
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_A_Stream_Socket_was_expected_got, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2457, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2457, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2457, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2457, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_cur_scope->__pyx_v_sock);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2457, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2456
 * 
 *         if not _is_sock_stream(sock.type):
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'A Stream Socket was expected, got {!r}'.format(sock))
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 2456, __pyx_L1_error)

    /* "uvloop/loop.pyx":2455
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         if not _is_sock_stream(sock.type):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'A Stream Socket was expected, got {!r}'.format(sock))
 */
  }

  /* "uvloop/loop.pyx":2459
 *                 'A Stream Socket was expected, got {!r}'.format(sock))
 * 
 *         app_protocol = protocol_factory()             # <<<<<<<<<<<<<<
 *         waiter = self._new_future()
 *         transport_waiter = None
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_protocol_factory; __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2459, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2459, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_app_protocol = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":2460
 * 
 *         app_protocol = protocol_factory()
 *         waiter = self._new_future()             # <<<<<<<<<<<<<<
 *         transport_waiter = None
 * 
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_waiter = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":2461
 *         app_protocol = protocol_factory()
 *         waiter = self._new_future()
 *         transport_waiter = None             # <<<<<<<<<<<<<<
 * 
 *         if ssl is None:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_cur_scope->__pyx_v_transport_waiter = Py_None;

  /* "uvloop/loop.pyx":2463
 *         transport_waiter = None
 * 
 *         if ssl is None:             # <<<<<<<<<<<<<<
 *             protocol = app_protocol
 *             transport_waiter = waiter
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_ssl == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2464
 * 
 *         if ssl is None:
 *             protocol = app_protocol             # <<<<<<<<<<<<<<
 *             transport_waiter = waiter
 *         else:
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_app_protocol);
    __pyx_cur_scope->__pyx_v_protocol = __pyx_cur_scope->__pyx_v_app_protocol;

    /* "uvloop/loop.pyx":2465
 *         if ssl is None:
 *             protocol = app_protocol
 *             transport_waiter = waiter             # <<<<<<<<<<<<<<
 *         else:
 *             protocol = SSLProtocol(
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_waiter);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_transport_waiter);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_transport_waiter, __pyx_cur_scope->__pyx_v_waiter);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_waiter);

    /* "uvloop/loop.pyx":2463
 *         transport_waiter = None
 * 
 *         if ssl is None:             # <<<<<<<<<<<<<<
 *             protocol = app_protocol
 *             transport_waiter = waiter
 */
    goto __pyx_L8;
  }

  /* "uvloop/loop.pyx":2467
 *             transport_waiter = waiter
 *         else:
 *             protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self, app_protocol, ssl, waiter,
 *                 server_side=True,
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_SSLProtocol); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/loop.pyx":2468
 *         else:
 *             protocol = SSLProtocol(
 *                 self, app_protocol, ssl, waiter,             # <<<<<<<<<<<<<<
 *                 server_side=True,
 *                 server_hostname=None,
 */
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_self));
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_app_protocol);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_app_protocol);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_ssl);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_ssl);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_cur_scope->__pyx_v_ssl);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_waiter);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_waiter);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_cur_scope->__pyx_v_waiter);

    /* "uvloop/loop.pyx":2469
 *             protocol = SSLProtocol(
 *                 self, app_protocol, ssl, waiter,
 *                 server_side=True,             # <<<<<<<<<<<<<<
 *                 server_hostname=None,
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 */
    __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2469, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_server_side, Py_True) < 0) __PYX_ERR(2, 2469, __pyx_L1_error)

    /* "uvloop/loop.pyx":2470
 *                 self, app_protocol, ssl, waiter,
 *                 server_side=True,
 *                 server_hostname=None,             # <<<<<<<<<<<<<<
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *             transport_waiter = None
 */
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_server_hostname, Py_None) < 0) __PYX_ERR(2, 2469, __pyx_L1_error)

    /* "uvloop/loop.pyx":2471
 *                 server_side=True,
 *                 server_hostname=None,
 *                 ssl_handshake_timeout=ssl_handshake_timeout)             # <<<<<<<<<<<<<<
 *             transport_waiter = None
 * 
 */
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_ssl_handshake_timeout, __pyx_cur_scope->__pyx_v_ssl_handshake_timeout) < 0) __PYX_ERR(2, 2469, __pyx_L1_error)

    /* "uvloop/loop.pyx":2467
 *             transport_waiter = waiter
 *         else:
 *             protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self, app_protocol, ssl, waiter,
 *                 server_side=True,
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_cur_scope->__pyx_v_protocol = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":2472
 *                 server_hostname=None,
 *                 ssl_handshake_timeout=ssl_handshake_timeout)
 *             transport_waiter = None             # <<<<<<<<<<<<<<
 * 
 *         if sock.family == uv.AF_UNIX:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_transport_waiter);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_transport_waiter, Py_None);
    __Pyx_GIVEREF(Py_None);
  }
  __pyx_L8:;

  /* "uvloop/loop.pyx":2474
 *             transport_waiter = None
 * 
 *         if sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *             transport = <UVStream>UnixTransport.new(
 *                 self, protocol, None, transport_waiter)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2475
 * 
 *         if sock.family == uv.AF_UNIX:
 *             transport = <UVStream>UnixTransport.new(             # <<<<<<<<<<<<<<
 *                 self, protocol, None, transport_waiter)
 *         elif sock.family in (uv.AF_INET, uv.AF_INET6):
 */
    __pyx_t_4 = ((PyObject *)__pyx_f_6uvloop_4loop_13UnixTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_transport_waiter)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2475, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __pyx_t_4;
    __Pyx_INCREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_transport));
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_transport, ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_6));
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":2474
 *             transport_waiter = None
 * 
 *         if sock.family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *             transport = <UVStream>UnixTransport.new(
 *                 self, protocol, None, transport_waiter)
 */
    goto __pyx_L9;
  }

  /* "uvloop/loop.pyx":2477
 *             transport = <UVStream>UnixTransport.new(
 *                 self, protocol, None, transport_waiter)
 *         elif sock.family in (uv.AF_INET, uv.AF_INET6):             # <<<<<<<<<<<<<<
 *             transport = <UVStream>TCPTransport.new(
 *                 self, protocol, None, transport_waiter)
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_family); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyInt_From_int(AF_INET); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_6, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!__pyx_t_1) {
  } else {
    __pyx_t_2 = __pyx_t_1;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyInt_From_int(AF_INET6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_6, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __pyx_t_1;
  __pyx_L10_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2478
 *                 self, protocol, None, transport_waiter)
 *         elif sock.family in (uv.AF_INET, uv.AF_INET6):
 *             transport = <UVStream>TCPTransport.new(             # <<<<<<<<<<<<<<
 *                 self, protocol, None, transport_waiter)
 * 
 */
    __pyx_t_6 = ((PyObject *)__pyx_f_6uvloop_4loop_12TCPTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_transport_waiter)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2478, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __pyx_t_6;
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_transport));
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_transport, ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_4));
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":2477
 *             transport = <UVStream>UnixTransport.new(
 *                 self, protocol, None, transport_waiter)
 *         elif sock.family in (uv.AF_INET, uv.AF_INET6):             # <<<<<<<<<<<<<<
 *             transport = <UVStream>TCPTransport.new(
 *                 self, protocol, None, transport_waiter)
 */
  }
  __pyx_L9:;

  /* "uvloop/loop.pyx":2481
 *                 self, protocol, None, transport_waiter)
 * 
 *         if transport is None:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'invalid socket family, expected AF_UNIX, AF_INET or AF_INET6')
 */
  __pyx_t_1 = (((PyObject *)__pyx_cur_scope->__pyx_v_transport) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":2482
 * 
 *         if transport is None:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'invalid socket family, expected AF_UNIX, AF_INET or AF_INET6')
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__99, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2482, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(2, 2482, __pyx_L1_error)

    /* "uvloop/loop.pyx":2481
 *                 self, protocol, None, transport_waiter)
 * 
 *         if transport is None:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'invalid socket family, expected AF_UNIX, AF_INET or AF_INET6')
 */
  }

  /* "uvloop/loop.pyx":2485
 *                 'invalid socket family, expected AF_UNIX, AF_INET or AF_INET6')
 * 
 *         transport._open(sock.fileno())             # <<<<<<<<<<<<<<
 *         transport._init_protocol()
 *         transport._attach_fileobj(sock)
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2485, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2485, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_cur_scope->__pyx_v_transport->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_transport), __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2486
 * 
 *         transport._open(sock.fileno())
 *         transport._init_protocol()             # <<<<<<<<<<<<<<
 *         transport._attach_fileobj(sock)
 * 
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_cur_scope->__pyx_v_transport->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_transport)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2487
 *         transport._open(sock.fileno())
 *         transport._init_protocol()
 *         transport._attach_fileobj(sock)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_cur_scope->__pyx_v_transport->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._attach_fileobj(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_transport), __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2489
 *         transport._attach_fileobj(sock)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "uvloop/loop.pyx":2490
 * 
 *         try:
 *             await waiter             # <<<<<<<<<<<<<<
 *         except Exception:
 *             transport._close()
 */
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_t_8);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_8;
        __Pyx_XGIVEREF(__pyx_t_9);
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_9;
        __Pyx_XGIVEREF(__pyx_t_10);
        __pyx_cur_scope->__pyx_t_2 = __pyx_t_10;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L19_resume_from_await:;
        __pyx_t_8 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_8);
        __pyx_t_9 = __pyx_cur_scope->__pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = 0;
        __Pyx_XGOTREF(__pyx_t_9);
        __pyx_t_10 = __pyx_cur_scope->__pyx_t_2;
        __pyx_cur_scope->__pyx_t_2 = 0;
        __Pyx_XGOTREF(__pyx_t_10);
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2490, __pyx_L13_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 2490, __pyx_L13_error)
        }
      }

      /* "uvloop/loop.pyx":2489
 *         transport._attach_fileobj(sock)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L18_try_end;
    __pyx_L13_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":2491
 *         try:
 *             await waiter
 *         except Exception:             # <<<<<<<<<<<<<<
 *             transport._close()
 *             raise
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("uvloop.loop.Loop.connect_accepted_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5) < 0) __PYX_ERR(2, 2491, __pyx_L15_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_5);

      /* "uvloop/loop.pyx":2492
 *             await waiter
 *         except Exception:
 *             transport._close()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_cur_scope->__pyx_v_transport->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_transport)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2492, __pyx_L15_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2493
 *         except Exception:
 *             transport._close()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         if ssl:
 */
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_6, __pyx_t_5);
      __pyx_t_4 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; 
      __PYX_ERR(2, 2493, __pyx_L15_except_error)
    }
    goto __pyx_L15_except_error;
    __pyx_L15_except_error:;

    /* "uvloop/loop.pyx":2489
 *         transport._attach_fileobj(sock)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L18_try_end:;
  }

  /* "uvloop/loop.pyx":2495
 *             raise
 * 
 *         if ssl:             # <<<<<<<<<<<<<<
 *             return protocol._app_transport, protocol
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ssl); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2495, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2496
 * 
 *         if ssl:
 *             return protocol._app_transport, protocol             # <<<<<<<<<<<<<<
 *         else:
 *             return transport, protocol
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_protocol, __pyx_n_s_app_transport); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2496, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_cur_scope->__pyx_v_protocol);
    __pyx_t_5 = 0;
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":2495
 *             raise
 * 
 *         if ssl:             # <<<<<<<<<<<<<<
 *             return protocol._app_transport, protocol
 *         else:
 */
  }

  /* "uvloop/loop.pyx":2498
 *             return protocol._app_transport, protocol
 *         else:
 *             return transport, protocol             # <<<<<<<<<<<<<<
 * 
 *     def run_in_executor(self, executor, func, *args):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_transport));
    __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_transport));
    PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_transport));
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
    __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_cur_scope->__pyx_v_protocol);
    __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = 0;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2433
 * 
 *     @cython.iterable_coroutine
 *     async def connect_accepted_socket(self, protocol_factory, sock, *,             # <<<<<<<<<<<<<<
 *                                       ssl=None, ssl_handshake_timeout=None):
 *         """Handle an accepted connection.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("connect_accepted_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2500
 *             return transport, protocol
 * 
 *     def run_in_executor(self, executor, func, *args):             # <<<<<<<<<<<<<<
 *         if aio_iscoroutine(func) or aio_iscoroutinefunction(func):
 *             raise TypeError("coroutines cannot be used with run_in_executor()")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_102run_in_executor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_101run_in_executor[] = "Loop.run_in_executor(self, executor, func, *args)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_102run_in_executor(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_executor = 0;
  PyObject *__pyx_v_func = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("run_in_executor (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_executor,&__pyx_n_s_func,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_executor)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_func)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("run_in_executor", 0, 2, 2, 1); __PYX_ERR(2, 2500, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "run_in_executor") < 0)) __PYX_ERR(2, 2500, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_executor = values[0];
    __pyx_v_func = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("run_in_executor", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2500, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.run_in_executor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_101run_in_executor(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_executor, __pyx_v_func, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_101run_in_executor(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_executor, PyObject *__pyx_v_func, PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("run_in_executor", 0);
  __Pyx_INCREF(__pyx_v_executor);

  /* "uvloop/loop.pyx":2501
 * 
 *     def run_in_executor(self, executor, func, *args):
 *         if aio_iscoroutine(func) or aio_iscoroutinefunction(func):             # <<<<<<<<<<<<<<
 *             raise TypeError("coroutines cannot be used with run_in_executor()")
 * 
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_iscoroutine);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_iscoroutine; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_func); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_func};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_func};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_func);
      __Pyx_GIVEREF(__pyx_v_func);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_func);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 2501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_iscoroutinefunction);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_iscoroutinefunction; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_func); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_func};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_func};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_func);
      __Pyx_GIVEREF(__pyx_v_func);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_func);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2501, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 2501, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2502
 *     def run_in_executor(self, executor, func, *args):
 *         if aio_iscoroutine(func) or aio_iscoroutinefunction(func):
 *             raise TypeError("coroutines cannot be used with run_in_executor()")             # <<<<<<<<<<<<<<
 * 
 *         self._check_closed()
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__100, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2502, __pyx_L1_error)

    /* "uvloop/loop.pyx":2501
 * 
 *     def run_in_executor(self, executor, func, *args):
 *         if aio_iscoroutine(func) or aio_iscoroutinefunction(func):             # <<<<<<<<<<<<<<
 *             raise TypeError("coroutines cannot be used with run_in_executor()")
 * 
 */
  }

  /* "uvloop/loop.pyx":2504
 *             raise TypeError("coroutines cannot be used with run_in_executor()")
 * 
 *         self._check_closed()             # <<<<<<<<<<<<<<
 * 
 *         if executor is None:
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2506
 *         self._check_closed()
 * 
 *         if executor is None:             # <<<<<<<<<<<<<<
 *             executor = self._default_executor
 *             if executor is None:
 */
  __pyx_t_1 = (__pyx_v_executor == Py_None);
  __pyx_t_6 = (__pyx_t_1 != 0);
  if (__pyx_t_6) {

    /* "uvloop/loop.pyx":2507
 * 
 *         if executor is None:
 *             executor = self._default_executor             # <<<<<<<<<<<<<<
 *             if executor is None:
 *                 executor = cc_ThreadPoolExecutor()
 */
    __pyx_t_2 = __pyx_v_self->_default_executor;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_executor, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":2508
 *         if executor is None:
 *             executor = self._default_executor
 *             if executor is None:             # <<<<<<<<<<<<<<
 *                 executor = cc_ThreadPoolExecutor()
 *                 self._default_executor = executor
 */
    __pyx_t_6 = (__pyx_v_executor == Py_None);
    __pyx_t_1 = (__pyx_t_6 != 0);
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":2509
 *             executor = self._default_executor
 *             if executor is None:
 *                 executor = cc_ThreadPoolExecutor()             # <<<<<<<<<<<<<<
 *                 self._default_executor = executor
 * 
 */
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_cc_ThreadPoolExecutor);
      __pyx_t_3 = __pyx_v_6uvloop_4loop_cc_ThreadPoolExecutor; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2509, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2509, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_executor, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":2510
 *             if executor is None:
 *                 executor = cc_ThreadPoolExecutor()
 *                 self._default_executor = executor             # <<<<<<<<<<<<<<
 * 
 *         return aio_wrap_future(executor.submit(func, *args), loop=self)
 */
      __Pyx_INCREF(__pyx_v_executor);
      __Pyx_GIVEREF(__pyx_v_executor);
      __Pyx_GOTREF(__pyx_v_self->_default_executor);
      __Pyx_DECREF(__pyx_v_self->_default_executor);
      __pyx_v_self->_default_executor = __pyx_v_executor;

      /* "uvloop/loop.pyx":2508
 *         if executor is None:
 *             executor = self._default_executor
 *             if executor is None:             # <<<<<<<<<<<<<<
 *                 executor = cc_ThreadPoolExecutor()
 *                 self._default_executor = executor
 */
    }

    /* "uvloop/loop.pyx":2506
 *         self._check_closed()
 * 
 *         if executor is None:             # <<<<<<<<<<<<<<
 *             executor = self._default_executor
 *             if executor is None:
 */
  }

  /* "uvloop/loop.pyx":2512
 *                 self._default_executor = executor
 * 
 *         return aio_wrap_future(executor.submit(func, *args), loop=self)             # <<<<<<<<<<<<<<
 * 
 *     def set_default_executor(self, executor):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_executor, __pyx_n_s_submit); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_func);
  __Pyx_GIVEREF(__pyx_v_func);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_func);
  __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_v_args); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loop, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(2, 2512, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_wrap_future, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":2500
 *             return transport, protocol
 * 
 *     def run_in_executor(self, executor, func, *args):             # <<<<<<<<<<<<<<
 *         if aio_iscoroutine(func) or aio_iscoroutinefunction(func):
 *             raise TypeError("coroutines cannot be used with run_in_executor()")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.Loop.run_in_executor", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_executor);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2514
 *         return aio_wrap_future(executor.submit(func, *args), loop=self)
 * 
 *     def set_default_executor(self, executor):             # <<<<<<<<<<<<<<
 *         self._default_executor = executor
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_104set_default_executor(PyObject *__pyx_v_self, PyObject *__pyx_v_executor); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_103set_default_executor[] = "Loop.set_default_executor(self, executor)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_104set_default_executor(PyObject *__pyx_v_self, PyObject *__pyx_v_executor) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_default_executor (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_103set_default_executor(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_executor));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_103set_default_executor(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_executor) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_default_executor", 0);

  /* "uvloop/loop.pyx":2515
 * 
 *     def set_default_executor(self, executor):
 *         self._default_executor = executor             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_INCREF(__pyx_v_executor);
  __Pyx_GIVEREF(__pyx_v_executor);
  __Pyx_GOTREF(__pyx_v_self->_default_executor);
  __Pyx_DECREF(__pyx_v_self->_default_executor);
  __pyx_v_self->_default_executor = __pyx_v_executor;

  /* "uvloop/loop.pyx":2514
 *         return aio_wrap_future(executor.submit(func, *args), loop=self)
 * 
 *     def set_default_executor(self, executor):             # <<<<<<<<<<<<<<
 *         self._default_executor = executor
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_107generator13(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2518
 * 
 *     @cython.iterable_coroutine
 *     async def __subprocess_run(self, protocol_factory, args,             # <<<<<<<<<<<<<<
 *                                stdin=subprocess_PIPE,
 *                                stdout=subprocess_PIPE,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_106__subprocess_run(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_105__subprocess_run[] = "Loop.__subprocess_run(self, protocol_factory, args, stdin=subprocess_PIPE, stdout=subprocess_PIPE, stderr=subprocess_PIPE, universal_newlines=False, shell=True, bufsize=0, preexec_fn=None, close_fds=None, cwd=None, env=None, startupinfo=None, creationflags=0, restore_signals=True, start_new_session=False, executable=None, pass_fds=(), __uvloop_sleep_after_fork=False)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_106__subprocess_run(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_stdin = 0;
  PyObject *__pyx_v_stdout = 0;
  PyObject *__pyx_v_stderr = 0;
  PyObject *__pyx_v_universal_newlines = 0;
  CYTHON_UNUSED PyObject *__pyx_v_shell = 0;
  PyObject *__pyx_v_bufsize = 0;
  PyObject *__pyx_v_preexec_fn = 0;
  CYTHON_UNUSED PyObject *__pyx_v_close_fds = 0;
  PyObject *__pyx_v_cwd = 0;
  PyObject *__pyx_v_env = 0;
  PyObject *__pyx_v_startupinfo = 0;
  PyObject *__pyx_v_creationflags = 0;
  PyObject *__pyx_v_restore_signals = 0;
  PyObject *__pyx_v_start_new_session = 0;
  PyObject *__pyx_v_executable = 0;
  PyObject *__pyx_v_pass_fds = 0;
  PyObject *__pyx_v___uvloop_sleep_after_fork = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__subprocess_run (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_args,&__pyx_n_s_stdin,&__pyx_n_s_stdout,&__pyx_n_s_stderr,&__pyx_n_s_universal_newlines,&__pyx_n_s_shell,&__pyx_n_s_bufsize,&__pyx_n_s_preexec_fn,&__pyx_n_s_close_fds,&__pyx_n_s_cwd,&__pyx_n_s_env,&__pyx_n_s_startupinfo,&__pyx_n_s_creationflags,&__pyx_n_s_restore_signals,&__pyx_n_s_start_new_session,&__pyx_n_s_executable,&__pyx_n_s_pass_fds,&__pyx_n_s_uvloop_sleep_after_fork,0};
    PyObject* values[19] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    values[2] = __pyx_k__101;
    values[3] = __pyx_k__102;
    values[4] = __pyx_k__103;

    /* "uvloop/loop.pyx":2522
 *                                stdout=subprocess_PIPE,
 *                                stderr=subprocess_PIPE,
 *                                universal_newlines=False,             # <<<<<<<<<<<<<<
 *                                shell=True,
 *                                bufsize=0,
 */
    values[5] = ((PyObject *)Py_False);

    /* "uvloop/loop.pyx":2523
 *                                stderr=subprocess_PIPE,
 *                                universal_newlines=False,
 *                                shell=True,             # <<<<<<<<<<<<<<
 *                                bufsize=0,
 *                                preexec_fn=None,
 */
    values[6] = ((PyObject *)Py_True);
    values[7] = ((PyObject *)__pyx_int_0);

    /* "uvloop/loop.pyx":2525
 *                                shell=True,
 *                                bufsize=0,
 *                                preexec_fn=None,             # <<<<<<<<<<<<<<
 *                                close_fds=None,
 *                                cwd=None,
 */
    values[8] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2526
 *                                bufsize=0,
 *                                preexec_fn=None,
 *                                close_fds=None,             # <<<<<<<<<<<<<<
 *                                cwd=None,
 *                                env=None,
 */
    values[9] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2527
 *                                preexec_fn=None,
 *                                close_fds=None,
 *                                cwd=None,             # <<<<<<<<<<<<<<
 *                                env=None,
 *                                startupinfo=None,
 */
    values[10] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2528
 *                                close_fds=None,
 *                                cwd=None,
 *                                env=None,             # <<<<<<<<<<<<<<
 *                                startupinfo=None,
 *                                creationflags=0,
 */
    values[11] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2529
 *                                cwd=None,
 *                                env=None,
 *                                startupinfo=None,             # <<<<<<<<<<<<<<
 *                                creationflags=0,
 *                                restore_signals=True,
 */
    values[12] = ((PyObject *)Py_None);
    values[13] = ((PyObject *)__pyx_int_0);

    /* "uvloop/loop.pyx":2531
 *                                startupinfo=None,
 *                                creationflags=0,
 *                                restore_signals=True,             # <<<<<<<<<<<<<<
 *                                start_new_session=False,
 *                                executable=None,
 */
    values[14] = ((PyObject *)Py_True);

    /* "uvloop/loop.pyx":2532
 *                                creationflags=0,
 *                                restore_signals=True,
 *                                start_new_session=False,             # <<<<<<<<<<<<<<
 *                                executable=None,
 *                                pass_fds=(),
 */
    values[15] = ((PyObject *)Py_False);

    /* "uvloop/loop.pyx":2533
 *                                restore_signals=True,
 *                                start_new_session=False,
 *                                executable=None,             # <<<<<<<<<<<<<<
 *                                pass_fds=(),
 * 
 */
    values[16] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2534
 *                                start_new_session=False,
 *                                executable=None,
 *                                pass_fds=(),             # <<<<<<<<<<<<<<
 * 
 *                                # For tests only! Do not use in your code. Ever.
 */
    values[17] = ((PyObject *)__pyx_empty_tuple);

    /* "uvloop/loop.pyx":2537
 * 
 *                                # For tests only! Do not use in your code. Ever.
 *                                __uvloop_sleep_after_fork=False             # <<<<<<<<<<<<<<
 *                             ):
 * 
 */
    values[18] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_args)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__subprocess_run", 0, 2, 19, 1); __PYX_ERR(2, 2518, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_stdin);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_stdout);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_stderr);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_universal_newlines);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_shell);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_bufsize);
          if (value) { values[7] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_preexec_fn);
          if (value) { values[8] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_close_fds);
          if (value) { values[9] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cwd);
          if (value) { values[10] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_env);
          if (value) { values[11] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_startupinfo);
          if (value) { values[12] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_creationflags);
          if (value) { values[13] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_restore_signals);
          if (value) { values[14] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start_new_session);
          if (value) { values[15] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_executable);
          if (value) { values[16] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 17:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pass_fds);
          if (value) { values[17] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 18:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_uvloop_sleep_after_fork);
          if (value) { values[18] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__subprocess_run") < 0)) __PYX_ERR(2, 2518, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_args = values[1];
    __pyx_v_stdin = values[2];
    __pyx_v_stdout = values[3];
    __pyx_v_stderr = values[4];
    __pyx_v_universal_newlines = values[5];
    __pyx_v_shell = values[6];
    __pyx_v_bufsize = values[7];
    __pyx_v_preexec_fn = values[8];
    __pyx_v_close_fds = values[9];
    __pyx_v_cwd = values[10];
    __pyx_v_env = values[11];
    __pyx_v_startupinfo = values[12];
    __pyx_v_creationflags = values[13];
    __pyx_v_restore_signals = values[14];
    __pyx_v_start_new_session = values[15];
    __pyx_v_executable = values[16];
    __pyx_v_pass_fds = values[17];
    __pyx_v___uvloop_sleep_after_fork = values[18];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__subprocess_run", 0, 2, 19, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2518, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.__subprocess_run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_105__subprocess_run(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_args, __pyx_v_stdin, __pyx_v_stdout, __pyx_v_stderr, __pyx_v_universal_newlines, __pyx_v_shell, __pyx_v_bufsize, __pyx_v_preexec_fn, __pyx_v_close_fds, __pyx_v_cwd, __pyx_v_env, __pyx_v_startupinfo, __pyx_v_creationflags, __pyx_v_restore_signals, __pyx_v_start_new_session, __pyx_v_executable, __pyx_v_pass_fds, __pyx_v___uvloop_sleep_after_fork);

  /* "uvloop/loop.pyx":2518
 * 
 *     @cython.iterable_coroutine
 *     async def __subprocess_run(self, protocol_factory, args,             # <<<<<<<<<<<<<<
 *                                stdin=subprocess_PIPE,
 *                                stdout=subprocess_PIPE,
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_105__subprocess_run(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_args, PyObject *__pyx_v_stdin, PyObject *__pyx_v_stdout, PyObject *__pyx_v_stderr, PyObject *__pyx_v_universal_newlines, CYTHON_UNUSED PyObject *__pyx_v_shell, PyObject *__pyx_v_bufsize, PyObject *__pyx_v_preexec_fn, CYTHON_UNUSED PyObject *__pyx_v_close_fds, PyObject *__pyx_v_cwd, PyObject *__pyx_v_env, PyObject *__pyx_v_startupinfo, PyObject *__pyx_v_creationflags, PyObject *__pyx_v_restore_signals, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v_executable, PyObject *__pyx_v_pass_fds, PyObject *__pyx_v___uvloop_sleep_after_fork) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__subprocess_run", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_20___subprocess_run(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_20___subprocess_run, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2518, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_args = __pyx_v_args;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_args);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_args);
  __pyx_cur_scope->__pyx_v_stdin = __pyx_v_stdin;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_stdin);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_stdin);
  __pyx_cur_scope->__pyx_v_stdout = __pyx_v_stdout;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_stdout);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_stdout);
  __pyx_cur_scope->__pyx_v_stderr = __pyx_v_stderr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_stderr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_stderr);
  __pyx_cur_scope->__pyx_v_universal_newlines = __pyx_v_universal_newlines;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_universal_newlines);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_universal_newlines);
  __pyx_cur_scope->__pyx_v_shell = __pyx_v_shell;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_shell);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_shell);
  __pyx_cur_scope->__pyx_v_bufsize = __pyx_v_bufsize;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_bufsize);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_bufsize);
  __pyx_cur_scope->__pyx_v_preexec_fn = __pyx_v_preexec_fn;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_preexec_fn);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_preexec_fn);
  __pyx_cur_scope->__pyx_v_close_fds = __pyx_v_close_fds;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_close_fds);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_close_fds);
  __pyx_cur_scope->__pyx_v_cwd = __pyx_v_cwd;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_cwd);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_cwd);
  __pyx_cur_scope->__pyx_v_env = __pyx_v_env;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_env);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_env);
  __pyx_cur_scope->__pyx_v_startupinfo = __pyx_v_startupinfo;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_startupinfo);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_startupinfo);
  __pyx_cur_scope->__pyx_v_creationflags = __pyx_v_creationflags;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_creationflags);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_creationflags);
  __pyx_cur_scope->__pyx_v_restore_signals = __pyx_v_restore_signals;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_restore_signals);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_restore_signals);
  __pyx_cur_scope->__pyx_v_start_new_session = __pyx_v_start_new_session;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_start_new_session);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_start_new_session);
  __pyx_cur_scope->__pyx_v_executable = __pyx_v_executable;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_executable);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_executable);
  __pyx_cur_scope->__pyx_v_pass_fds = __pyx_v_pass_fds;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_pass_fds);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_pass_fds);
  __pyx_cur_scope->__pyx_v___uvloop_sleep_after_fork = __pyx_v___uvloop_sleep_after_fork;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v___uvloop_sleep_after_fork);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v___uvloop_sleep_after_fork);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_107generator13, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_subprocess_run, __pyx_n_s_Loop___subprocess_run, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2518, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.__subprocess_run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_107generator13(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__subprocess_run", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L16_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2518, __pyx_L1_error)

  /* "uvloop/loop.pyx":2544
 * 
 *         cdef:
 *             int debug_flags = 0             # <<<<<<<<<<<<<<
 * 
 *         if universal_newlines:
 */
  __pyx_cur_scope->__pyx_v_debug_flags = 0;

  /* "uvloop/loop.pyx":2546
 *             int debug_flags = 0
 * 
 *         if universal_newlines:             # <<<<<<<<<<<<<<
 *             raise ValueError("universal_newlines must be False")
 *         if bufsize != 0:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_universal_newlines); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2546, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2547
 * 
 *         if universal_newlines:
 *             raise ValueError("universal_newlines must be False")             # <<<<<<<<<<<<<<
 *         if bufsize != 0:
 *             raise ValueError("bufsize must be 0")
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__104, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2547, __pyx_L1_error)

    /* "uvloop/loop.pyx":2546
 *             int debug_flags = 0
 * 
 *         if universal_newlines:             # <<<<<<<<<<<<<<
 *             raise ValueError("universal_newlines must be False")
 *         if bufsize != 0:
 */
  }

  /* "uvloop/loop.pyx":2548
 *         if universal_newlines:
 *             raise ValueError("universal_newlines must be False")
 *         if bufsize != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("bufsize must be 0")
 *         if startupinfo is not None:
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_bufsize, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2548, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2548, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2549
 *             raise ValueError("universal_newlines must be False")
 *         if bufsize != 0:
 *             raise ValueError("bufsize must be 0")             # <<<<<<<<<<<<<<
 *         if startupinfo is not None:
 *             raise ValueError('startupinfo is not supported')
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__105, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2549, __pyx_L1_error)

    /* "uvloop/loop.pyx":2548
 *         if universal_newlines:
 *             raise ValueError("universal_newlines must be False")
 *         if bufsize != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError("bufsize must be 0")
 *         if startupinfo is not None:
 */
  }

  /* "uvloop/loop.pyx":2550
 *         if bufsize != 0:
 *             raise ValueError("bufsize must be 0")
 *         if startupinfo is not None:             # <<<<<<<<<<<<<<
 *             raise ValueError('startupinfo is not supported')
 *         if creationflags != 0:
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_startupinfo != Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/loop.pyx":2551
 *             raise ValueError("bufsize must be 0")
 *         if startupinfo is not None:
 *             raise ValueError('startupinfo is not supported')             # <<<<<<<<<<<<<<
 *         if creationflags != 0:
 *             raise ValueError('creationflags is not supported')
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__106, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2551, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2551, __pyx_L1_error)

    /* "uvloop/loop.pyx":2550
 *         if bufsize != 0:
 *             raise ValueError("bufsize must be 0")
 *         if startupinfo is not None:             # <<<<<<<<<<<<<<
 *             raise ValueError('startupinfo is not supported')
 *         if creationflags != 0:
 */
  }

  /* "uvloop/loop.pyx":2552
 *         if startupinfo is not None:
 *             raise ValueError('startupinfo is not supported')
 *         if creationflags != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError('creationflags is not supported')
 * 
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_creationflags, __pyx_int_0, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2552, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(2, 2552, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/loop.pyx":2553
 *             raise ValueError('startupinfo is not supported')
 *         if creationflags != 0:
 *             raise ValueError('creationflags is not supported')             # <<<<<<<<<<<<<<
 * 
 *         if executable is not None:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__107, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2553, __pyx_L1_error)

    /* "uvloop/loop.pyx":2552
 *         if startupinfo is not None:
 *             raise ValueError('startupinfo is not supported')
 *         if creationflags != 0:             # <<<<<<<<<<<<<<
 *             raise ValueError('creationflags is not supported')
 * 
 */
  }

  /* "uvloop/loop.pyx":2555
 *             raise ValueError('creationflags is not supported')
 * 
 *         if executable is not None:             # <<<<<<<<<<<<<<
 *             args[0] = executable
 * 
 */
  __pyx_t_3 = (__pyx_cur_scope->__pyx_v_executable != Py_None);
  __pyx_t_1 = (__pyx_t_3 != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2556
 * 
 *         if executable is not None:
 *             args[0] = executable             # <<<<<<<<<<<<<<
 * 
 *         if __uvloop_sleep_after_fork:
 */
    if (unlikely(__Pyx_SetItemInt(__pyx_cur_scope->__pyx_v_args, 0, __pyx_cur_scope->__pyx_v_executable, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0)) __PYX_ERR(2, 2556, __pyx_L1_error)

    /* "uvloop/loop.pyx":2555
 *             raise ValueError('creationflags is not supported')
 * 
 *         if executable is not None:             # <<<<<<<<<<<<<<
 *             args[0] = executable
 * 
 */
  }

  /* "uvloop/loop.pyx":2558
 *             args[0] = executable
 * 
 *         if __uvloop_sleep_after_fork:             # <<<<<<<<<<<<<<
 *             debug_flags |= __PROCESS_DEBUG_SLEEP_AFTER_FORK
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v___uvloop_sleep_after_fork); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2558, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2559
 * 
 *         if __uvloop_sleep_after_fork:
 *             debug_flags |= __PROCESS_DEBUG_SLEEP_AFTER_FORK             # <<<<<<<<<<<<<<
 * 
 *         waiter = self._new_future()
 */
    __pyx_cur_scope->__pyx_v_debug_flags = (__pyx_cur_scope->__pyx_v_debug_flags | 1);

    /* "uvloop/loop.pyx":2558
 *             args[0] = executable
 * 
 *         if __uvloop_sleep_after_fork:             # <<<<<<<<<<<<<<
 *             debug_flags |= __PROCESS_DEBUG_SLEEP_AFTER_FORK
 * 
 */
  }

  /* "uvloop/loop.pyx":2561
 *             debug_flags |= __PROCESS_DEBUG_SLEEP_AFTER_FORK
 * 
 *         waiter = self._new_future()             # <<<<<<<<<<<<<<
 *         protocol = protocol_factory()
 *         proc = UVProcessTransport.new(self, protocol,
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_waiter = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2562
 * 
 *         waiter = self._new_future()
 *         protocol = protocol_factory()             # <<<<<<<<<<<<<<
 *         proc = UVProcessTransport.new(self, protocol,
 *                                       args, env, cwd, start_new_session,
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_protocol_factory; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2562, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2562, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_protocol = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2567
 *                                       stdin, stdout, stderr, pass_fds,
 *                                       waiter,
 *                                       debug_flags,             # <<<<<<<<<<<<<<
 *                                       preexec_fn,
 *                                       restore_signals)
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_cur_scope->__pyx_v_debug_flags); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/loop.pyx":2563
 *         waiter = self._new_future()
 *         protocol = protocol_factory()
 *         proc = UVProcessTransport.new(self, protocol,             # <<<<<<<<<<<<<<
 *                                       args, env, cwd, start_new_session,
 *                                       stdin, stdout, stderr, pass_fds,
 */
  __pyx_t_4 = ((PyObject *)__pyx_f_6uvloop_4loop_18UVProcessTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_protocol, __pyx_cur_scope->__pyx_v_args, __pyx_cur_scope->__pyx_v_env, __pyx_cur_scope->__pyx_v_cwd, __pyx_cur_scope->__pyx_v_start_new_session, __pyx_cur_scope->__pyx_v_stdin, __pyx_cur_scope->__pyx_v_stdout, __pyx_cur_scope->__pyx_v_stderr, __pyx_cur_scope->__pyx_v_pass_fds, __pyx_cur_scope->__pyx_v_waiter, __pyx_t_2, __pyx_cur_scope->__pyx_v_preexec_fn, __pyx_cur_scope->__pyx_v_restore_signals)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_proc = ((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2571
 *                                       restore_signals)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "uvloop/loop.pyx":2572
 * 
 *         try:
 *             await waiter             # <<<<<<<<<<<<<<
 *         except Exception:
 *             proc.close()
 */
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_t_6);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_6;
        __Pyx_XGIVEREF(__pyx_t_7);
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_7;
        __Pyx_XGIVEREF(__pyx_t_8);
        __pyx_cur_scope->__pyx_t_2 = __pyx_t_8;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L16_resume_from_await:;
        __pyx_t_6 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_6);
        __pyx_t_7 = __pyx_cur_scope->__pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = 0;
        __Pyx_XGOTREF(__pyx_t_7);
        __pyx_t_8 = __pyx_cur_scope->__pyx_t_2;
        __pyx_cur_scope->__pyx_t_2 = 0;
        __Pyx_XGOTREF(__pyx_t_8);
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2572, __pyx_L10_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 2572, __pyx_L10_error)
        }
      }

      /* "uvloop/loop.pyx":2571
 *                                       restore_signals)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L15_try_end;
    __pyx_L10_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":2573
 *         try:
 *             await waiter
 *         except Exception:             # <<<<<<<<<<<<<<
 *             proc.close()
 *             raise
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("uvloop.loop.Loop.__subprocess_run", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_2, &__pyx_t_5) < 0) __PYX_ERR(2, 2573, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_5);

      /* "uvloop/loop.pyx":2574
 *             await waiter
 *         except Exception:
 *             proc.close()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_proc), __pyx_n_s_close); if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2574, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      if (__pyx_t_12) {
        __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2574, __pyx_L12_except_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else {
        __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2574, __pyx_L12_except_error)
      }
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "uvloop/loop.pyx":2575
 *         except Exception:
 *             proc.close()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         return proc, protocol
 */
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_2, __pyx_t_5);
      __pyx_t_4 = 0; __pyx_t_2 = 0; __pyx_t_5 = 0; 
      __PYX_ERR(2, 2575, __pyx_L12_except_error)
    }
    goto __pyx_L12_except_error;
    __pyx_L12_except_error:;

    /* "uvloop/loop.pyx":2571
 *                                       restore_signals)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L15_try_end:;
  }

  /* "uvloop/loop.pyx":2577
 *             raise
 * 
 *         return proc, protocol             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_proc));
  __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_proc));
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_proc));
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_cur_scope->__pyx_v_protocol);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2518
 * 
 *     @cython.iterable_coroutine
 *     async def __subprocess_run(self, protocol_factory, args,             # <<<<<<<<<<<<<<
 *                                stdin=subprocess_PIPE,
 *                                stdout=subprocess_PIPE,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("__subprocess_run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_110generator14(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2580
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_shell(self, protocol_factory, cmd, *,             # <<<<<<<<<<<<<<
 *                                shell=True,
 *                                **kwargs):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_109subprocess_shell(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_108subprocess_shell[] = "Loop.subprocess_shell(self, protocol_factory, cmd, *, shell=True, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_109subprocess_shell(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_cmd = 0;
  PyObject *__pyx_v_shell = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subprocess_shell (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_cmd,&__pyx_n_s_shell,0};
    PyObject* values[3] = {0,0,0};

    /* "uvloop/loop.pyx":2581
 *     @cython.iterable_coroutine
 *     async def subprocess_shell(self, protocol_factory, cmd, *,
 *                                shell=True,             # <<<<<<<<<<<<<<
 *                                **kwargs):
 * 
 */
    values[2] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cmd)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("subprocess_shell", 1, 2, 2, 1); __PYX_ERR(2, 2580, __pyx_L3_error)
        }
      }
      if (kw_args == 1) {
        const Py_ssize_t index = 2;
        PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
        if (value) { values[index] = value; kw_args--; }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, pos_args, "subprocess_shell") < 0)) __PYX_ERR(2, 2580, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_cmd = values[1];
    __pyx_v_shell = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("subprocess_shell", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2580, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_CLEAR(__pyx_v_kwargs);
  __Pyx_AddTraceback("uvloop.loop.Loop.subprocess_shell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_108subprocess_shell(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_cmd, __pyx_v_shell, __pyx_v_kwargs);

  /* "uvloop/loop.pyx":2580
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_shell(self, protocol_factory, cmd, *,             # <<<<<<<<<<<<<<
 *                                shell=True,
 *                                **kwargs):
 */

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_108subprocess_shell(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_cmd, PyObject *__pyx_v_shell, PyObject *__pyx_v_kwargs) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subprocess_shell", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2580, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_cmd = __pyx_v_cmd;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_cmd);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_cmd);
  __pyx_cur_scope->__pyx_v_shell = __pyx_v_shell;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_shell);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_shell);
  __pyx_cur_scope->__pyx_v_kwargs = __pyx_v_kwargs;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_kwargs);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_kwargs);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_110generator14, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_subprocess_shell, __pyx_n_s_Loop_subprocess_shell, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2580, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.subprocess_shell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_110generator14(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subprocess_shell", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2580, __pyx_L1_error)

  /* "uvloop/loop.pyx":2584
 *                                **kwargs):
 * 
 *         if not shell:             # <<<<<<<<<<<<<<
 *             raise ValueError("shell must be True")
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_shell); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2584, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/loop.pyx":2585
 * 
 *         if not shell:
 *             raise ValueError("shell must be True")             # <<<<<<<<<<<<<<
 * 
 *         args = [cmd]
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__108, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 2585, __pyx_L1_error)

    /* "uvloop/loop.pyx":2584
 *                                **kwargs):
 * 
 *         if not shell:             # <<<<<<<<<<<<<<
 *             raise ValueError("shell must be True")
 * 
 */
  }

  /* "uvloop/loop.pyx":2587
 *             raise ValueError("shell must be True")
 * 
 *         args = [cmd]             # <<<<<<<<<<<<<<
 *         if shell:
 *             args = [b'/bin/sh', b'-c'] + args
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_cmd);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_cmd);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_cmd);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_args = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":2588
 * 
 *         args = [cmd]
 *         if shell:             # <<<<<<<<<<<<<<
 *             args = [b'/bin/sh', b'-c'] + args
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_shell); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2588, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2589
 *         args = [cmd]
 *         if shell:
 *             args = [b'/bin/sh', b'-c'] + args             # <<<<<<<<<<<<<<
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=True,
 */
    __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_kp_b_bin_sh);
    __Pyx_GIVEREF(__pyx_kp_b_bin_sh);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_kp_b_bin_sh);
    __Pyx_INCREF(__pyx_kp_b_c);
    __Pyx_GIVEREF(__pyx_kp_b_c);
    PyList_SET_ITEM(__pyx_t_3, 1, __pyx_kp_b_c);
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_cur_scope->__pyx_v_args); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_args);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_args, ((PyObject*)__pyx_t_4));
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":2588
 * 
 *         args = [cmd]
 *         if shell:             # <<<<<<<<<<<<<<
 *             args = [b'/bin/sh', b'-c'] + args
 * 
 */
  }

  /* "uvloop/loop.pyx":2591
 *             args = [b'/bin/sh', b'-c'] + args
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=True,             # <<<<<<<<<<<<<<
 *                                            **kwargs)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_subprocess_run); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_args);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_args);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_args);
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_shell, Py_True) < 0) __PYX_ERR(2, 2591, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "uvloop/loop.pyx":2592
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=True,
 *                                            **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  if (__Pyx_MergeKeywords(__pyx_t_5, __pyx_cur_scope->__pyx_v_kwargs) < 0) __PYX_ERR(2, 2592, __pyx_L1_error)

  /* "uvloop/loop.pyx":2591
 *             args = [b'/bin/sh', b'-c'] + args
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=True,             # <<<<<<<<<<<<<<
 *                                            **kwargs)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2591, __pyx_L1_error)
    __pyx_t_6 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_6);
  } else {
    __pyx_t_6 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_6) < 0) __PYX_ERR(2, 2591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2580
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_shell(self, protocol_factory, cmd, *,             # <<<<<<<<<<<<<<
 *                                shell=True,
 *                                **kwargs):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("subprocess_shell", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_113generator15(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2595
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_exec(self,  protocol_factory, program, *args,             # <<<<<<<<<<<<<<
 *                               shell=False, **kwargs):
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_112subprocess_exec(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_111subprocess_exec[] = "Loop.subprocess_exec(self, protocol_factory, program, *args, shell=False, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_112subprocess_exec(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_program = 0;
  PyObject *__pyx_v_shell = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subprocess_exec (wrapper)", 0);
  __pyx_v_kwargs = PyDict_New(); if (unlikely(!__pyx_v_kwargs)) return NULL;
  __Pyx_GOTREF(__pyx_v_kwargs);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_DECREF(__pyx_v_kwargs); __pyx_v_kwargs = 0;
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_program,&__pyx_n_s_shell,0};
    PyObject* values[3] = {0,0,0};

    /* "uvloop/loop.pyx":2596
 *     @cython.iterable_coroutine
 *     async def subprocess_exec(self,  protocol_factory, program, *args,
 *                               shell=False, **kwargs):             # <<<<<<<<<<<<<<
 * 
 *         if shell:
 */
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_program)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("subprocess_exec", 0, 2, 2, 1); __PYX_ERR(2, 2595, __pyx_L3_error)
        }
      }
      if (kw_args == 1) {
        const Py_ssize_t index = 2;
        PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
        if (value) { values[index] = value; kw_args--; }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, __pyx_v_kwargs, values, used_pos_args, "subprocess_exec") < 0)) __PYX_ERR(2, 2595, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_program = values[1];
    __pyx_v_shell = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("subprocess_exec", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2595, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_CLEAR(__pyx_v_args);
  __Pyx_CLEAR(__pyx_v_kwargs);
  __Pyx_AddTraceback("uvloop.loop.Loop.subprocess_exec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_111subprocess_exec(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_program, __pyx_v_shell, __pyx_v_args, __pyx_v_kwargs);

  /* "uvloop/loop.pyx":2595
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_exec(self,  protocol_factory, program, *args,             # <<<<<<<<<<<<<<
 *                               shell=False, **kwargs):
 * 
 */

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_111subprocess_exec(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_program, PyObject *__pyx_v_shell, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subprocess_exec", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2595, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_program = __pyx_v_program;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_program);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_program);
  __pyx_cur_scope->__pyx_v_shell = __pyx_v_shell;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_shell);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_shell);
  __pyx_cur_scope->__pyx_v_args = __pyx_v_args;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_args);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_args);
  __pyx_cur_scope->__pyx_v_kwargs = __pyx_v_kwargs;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_kwargs);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_kwargs);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_113generator15, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_subprocess_exec, __pyx_n_s_Loop_subprocess_exec, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2595, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.subprocess_exec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_113generator15(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("subprocess_exec", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L5_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2595, __pyx_L1_error)

  /* "uvloop/loop.pyx":2598
 *                               shell=False, **kwargs):
 * 
 *         if shell:             # <<<<<<<<<<<<<<
 *             raise ValueError("shell must be False")
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_shell); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2598, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2599
 * 
 *         if shell:
 *             raise ValueError("shell must be False")             # <<<<<<<<<<<<<<
 * 
 *         args = list((program,) + args)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__109, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2599, __pyx_L1_error)

    /* "uvloop/loop.pyx":2598
 *                               shell=False, **kwargs):
 * 
 *         if shell:             # <<<<<<<<<<<<<<
 *             raise ValueError("shell must be False")
 * 
 */
  }

  /* "uvloop/loop.pyx":2601
 *             raise ValueError("shell must be False")
 * 
 *         args = list((program,) + args)             # <<<<<<<<<<<<<<
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=False,
 */
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_program);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_program);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_cur_scope->__pyx_v_program);
  __pyx_t_3 = PyNumber_Add(__pyx_t_2, __pyx_cur_scope->__pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PySequence_List(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_args);
  __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_args, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2603
 *         args = list((program,) + args)
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=False,             # <<<<<<<<<<<<<<
 *                                            **kwargs)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_subprocess_run); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_args);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_args);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_args);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_shell, Py_False) < 0) __PYX_ERR(2, 2603, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":2604
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=False,
 *                                            **kwargs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  if (__Pyx_MergeKeywords(__pyx_t_4, __pyx_cur_scope->__pyx_v_kwargs) < 0) __PYX_ERR(2, 2604, __pyx_L1_error)

  /* "uvloop/loop.pyx":2603
 *         args = list((program,) + args)
 * 
 *         return await self.__subprocess_run(protocol_factory, args, shell=False,             # <<<<<<<<<<<<<<
 *                                            **kwargs)
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L5_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2603, __pyx_L1_error)
    __pyx_t_5 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_5);
  } else {
    __pyx_t_5 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_5) < 0) __PYX_ERR(2, 2603, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2595
 * 
 *     @cython.iterable_coroutine
 *     async def subprocess_exec(self,  protocol_factory, program, *args,             # <<<<<<<<<<<<<<
 *                               shell=False, **kwargs):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("subprocess_exec", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_116generator16(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2607
 * 
 *     @cython.iterable_coroutine
 *     async def connect_read_pipe(self, proto_factory, pipe):             # <<<<<<<<<<<<<<
 *         """Register read pipe in event loop. Set the pipe to non-blocking mode.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_115connect_read_pipe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_114connect_read_pipe[] = "Loop.connect_read_pipe(self, proto_factory, pipe)\nRegister read pipe in event loop. Set the pipe to non-blocking mode.\n\n        protocol_factory should instantiate object with Protocol interface.\n        pipe is a file-like object.\n        Return pair (transport, protocol), where transport supports the\n        ReadTransport interface.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_115connect_read_pipe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_proto_factory = 0;
  PyObject *__pyx_v_pipe = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_read_pipe (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_proto_factory,&__pyx_n_s_pipe,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_proto_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pipe)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("connect_read_pipe", 1, 2, 2, 1); __PYX_ERR(2, 2607, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "connect_read_pipe") < 0)) __PYX_ERR(2, 2607, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_proto_factory = values[0];
    __pyx_v_pipe = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connect_read_pipe", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2607, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.connect_read_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_114connect_read_pipe(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_proto_factory, __pyx_v_pipe);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_114connect_read_pipe(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_proto_factory, PyObject *__pyx_v_pipe) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_read_pipe", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2607, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_proto_factory = __pyx_v_proto_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto_factory);
  __pyx_cur_scope->__pyx_v_pipe = __pyx_v_pipe;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_pipe);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_pipe);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_116generator16, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_connect_read_pipe, __pyx_n_s_Loop_connect_read_pipe, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2607, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.connect_read_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_116generator16(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_read_pipe", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L10_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2607, __pyx_L1_error)

  /* "uvloop/loop.pyx":2617
 *             ReadUnixTransport transp
 * 
 *         waiter = self._new_future()             # <<<<<<<<<<<<<<
 *         proto = proto_factory()
 *         transp = ReadUnixTransport.new(self, proto, None, waiter)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_waiter = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2618
 * 
 *         waiter = self._new_future()
 *         proto = proto_factory()             # <<<<<<<<<<<<<<
 *         transp = ReadUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto_factory);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_proto_factory; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2618, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2618, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_proto = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2619
 *         waiter = self._new_future()
 *         proto = proto_factory()
 *         transp = ReadUnixTransport.new(self, proto, None, waiter)             # <<<<<<<<<<<<<<
 *         transp._add_extra_info('pipe', pipe)
 *         try:
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_6uvloop_4loop_17ReadUnixTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_proto, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_waiter)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_transp = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2620
 *         proto = proto_factory()
 *         transp = ReadUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)             # <<<<<<<<<<<<<<
 *         try:
 *             transp._open(pipe.fileno())
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._add_extra_info(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_transp), __pyx_n_u_pipe, __pyx_cur_scope->__pyx_v_pipe); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2621
 *         transp = ReadUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 *         try:             # <<<<<<<<<<<<<<
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/loop.pyx":2622
 *         transp._add_extra_info('pipe', pipe)
 *         try:
 *             transp._open(pipe.fileno())             # <<<<<<<<<<<<<<
 *             transp._init_protocol()
 *             await waiter
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_pipe, __pyx_n_s_fileno); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2622, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (__pyx_t_3) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2622, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2622, __pyx_L4_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2622, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_transp), __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2622, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":2623
 *         try:
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_transp)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2623, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":2624
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 *             await waiter             # <<<<<<<<<<<<<<
 *         except Exception:
 *             transp._close()
 */
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_t_4);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_4;
        __Pyx_XGIVEREF(__pyx_t_5);
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_5;
        __Pyx_XGIVEREF(__pyx_t_6);
        __pyx_cur_scope->__pyx_t_2 = __pyx_t_6;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L10_resume_from_await:;
        __pyx_t_4 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_4);
        __pyx_t_5 = __pyx_cur_scope->__pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = 0;
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __pyx_cur_scope->__pyx_t_2;
        __pyx_cur_scope->__pyx_t_2 = 0;
        __Pyx_XGOTREF(__pyx_t_6);
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2624, __pyx_L4_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 2624, __pyx_L4_error)
        }
      }

      /* "uvloop/loop.pyx":2621
 *         transp = ReadUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 *         try:             # <<<<<<<<<<<<<<
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2625
 *             transp._init_protocol()
 *             await waiter
 *         except Exception:             # <<<<<<<<<<<<<<
 *             transp._close()
 *             raise
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("uvloop.loop.Loop.connect_read_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(2, 2625, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/loop.pyx":2626
 *             await waiter
 *         except Exception:
 *             transp._close()             # <<<<<<<<<<<<<<
 *             raise
 *         transp._attach_fileobj(pipe)
 */
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_transp)); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2626, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/loop.pyx":2627
 *         except Exception:
 *             transp._close()
 *             raise             # <<<<<<<<<<<<<<
 *         transp._attach_fileobj(pipe)
 *         return transp, proto
 */
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      __pyx_t_1 = 0; __pyx_t_2 = 0; __pyx_t_3 = 0; 
      __PYX_ERR(2, 2627, __pyx_L6_except_error)
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/loop.pyx":2621
 *         transp = ReadUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 *         try:             # <<<<<<<<<<<<<<
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_end:;
  }

  /* "uvloop/loop.pyx":2628
 *             transp._close()
 *             raise
 *         transp._attach_fileobj(pipe)             # <<<<<<<<<<<<<<
 *         return transp, proto
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._attach_fileobj(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_transp), __pyx_cur_scope->__pyx_v_pipe); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":2629
 *             raise
 *         transp._attach_fileobj(pipe)
 *         return transp, proto             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_transp));
  __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_transp));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_transp));
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_proto);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2607
 * 
 *     @cython.iterable_coroutine
 *     async def connect_read_pipe(self, proto_factory, pipe):             # <<<<<<<<<<<<<<
 *         """Register read pipe in event loop. Set the pipe to non-blocking mode.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("connect_read_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_119generator17(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2632
 * 
 *     @cython.iterable_coroutine
 *     async def connect_write_pipe(self, proto_factory, pipe):             # <<<<<<<<<<<<<<
 *         """Register write pipe in event loop.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_118connect_write_pipe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_117connect_write_pipe[] = "Loop.connect_write_pipe(self, proto_factory, pipe)\nRegister write pipe in event loop.\n\n        protocol_factory should instantiate object with BaseProtocol interface.\n        Pipe is file-like object already switched to nonblocking.\n        Return pair (transport, protocol), where transport support\n        WriteTransport interface.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_118connect_write_pipe(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_proto_factory = 0;
  PyObject *__pyx_v_pipe = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_write_pipe (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_proto_factory,&__pyx_n_s_pipe,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_proto_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pipe)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("connect_write_pipe", 1, 2, 2, 1); __PYX_ERR(2, 2632, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "connect_write_pipe") < 0)) __PYX_ERR(2, 2632, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_proto_factory = values[0];
    __pyx_v_pipe = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connect_write_pipe", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2632, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.connect_write_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_117connect_write_pipe(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_proto_factory, __pyx_v_pipe);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_117connect_write_pipe(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_proto_factory, PyObject *__pyx_v_pipe) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_write_pipe", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2632, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_proto_factory = __pyx_v_proto_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto_factory);
  __pyx_cur_scope->__pyx_v_pipe = __pyx_v_pipe;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_pipe);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_pipe);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_119generator17, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_connect_write_pipe, __pyx_n_s_Loop_connect_write_pipe, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2632, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.connect_write_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_119generator17(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_write_pipe", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L10_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2632, __pyx_L1_error)

  /* "uvloop/loop.pyx":2642
 *             WriteUnixTransport transp
 * 
 *         waiter = self._new_future()             # <<<<<<<<<<<<<<
 *         proto = proto_factory()
 *         transp = WriteUnixTransport.new(self, proto, None, waiter)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_waiter = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2643
 * 
 *         waiter = self._new_future()
 *         proto = proto_factory()             # <<<<<<<<<<<<<<
 *         transp = WriteUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto_factory);
  __pyx_t_2 = __pyx_cur_scope->__pyx_v_proto_factory; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2643, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2643, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_proto = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2644
 *         waiter = self._new_future()
 *         proto = proto_factory()
 *         transp = WriteUnixTransport.new(self, proto, None, waiter)             # <<<<<<<<<<<<<<
 *         transp._add_extra_info('pipe', pipe)
 *         try:
 */
  __pyx_t_1 = ((PyObject *)__pyx_f_6uvloop_4loop_18WriteUnixTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_proto, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_cur_scope->__pyx_v_waiter)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_transp = ((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2645
 *         proto = proto_factory()
 *         transp = WriteUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)             # <<<<<<<<<<<<<<
 *         try:
 *             transp._open(pipe.fileno())
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._add_extra_info(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_transp), __pyx_n_u_pipe, __pyx_cur_scope->__pyx_v_pipe); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2646
 *         transp = WriteUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 *         try:             # <<<<<<<<<<<<<<
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/loop.pyx":2647
 *         transp._add_extra_info('pipe', pipe)
 *         try:
 *             transp._open(pipe.fileno())             # <<<<<<<<<<<<<<
 *             transp._init_protocol()
 *             await waiter
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_pipe, __pyx_n_s_fileno); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2647, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (__pyx_t_3) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2647, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2647, __pyx_L4_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2647, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_transp), __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2647, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":2648
 *         try:
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_transp)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2648, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/loop.pyx":2649
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 *             await waiter             # <<<<<<<<<<<<<<
 *         except Exception:
 *             transp._close()
 */
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_t_4);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_4;
        __Pyx_XGIVEREF(__pyx_t_5);
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_5;
        __Pyx_XGIVEREF(__pyx_t_6);
        __pyx_cur_scope->__pyx_t_2 = __pyx_t_6;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L10_resume_from_await:;
        __pyx_t_4 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_4);
        __pyx_t_5 = __pyx_cur_scope->__pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = 0;
        __Pyx_XGOTREF(__pyx_t_5);
        __pyx_t_6 = __pyx_cur_scope->__pyx_t_2;
        __pyx_cur_scope->__pyx_t_2 = 0;
        __Pyx_XGOTREF(__pyx_t_6);
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2649, __pyx_L4_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 2649, __pyx_L4_error)
        }
      }

      /* "uvloop/loop.pyx":2646
 *         transp = WriteUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 *         try:             # <<<<<<<<<<<<<<
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2650
 *             transp._init_protocol()
 *             await waiter
 *         except Exception:             # <<<<<<<<<<<<<<
 *             transp._close()
 *             raise
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_7) {
      __Pyx_AddTraceback("uvloop.loop.Loop.connect_write_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(2, 2650, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/loop.pyx":2651
 *             await waiter
 *         except Exception:
 *             transp._close()             # <<<<<<<<<<<<<<
 *             raise
 *         transp._attach_fileobj(pipe)
 */
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_cur_scope->__pyx_v_transp)); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2651, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/loop.pyx":2652
 *         except Exception:
 *             transp._close()
 *             raise             # <<<<<<<<<<<<<<
 *         transp._attach_fileobj(pipe)
 *         return transp, proto
 */
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_2, __pyx_t_3);
      __pyx_t_1 = 0; __pyx_t_2 = 0; __pyx_t_3 = 0; 
      __PYX_ERR(2, 2652, __pyx_L6_except_error)
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/loop.pyx":2646
 *         transp = WriteUnixTransport.new(self, proto, None, waiter)
 *         transp._add_extra_info('pipe', pipe)
 *         try:             # <<<<<<<<<<<<<<
 *             transp._open(pipe.fileno())
 *             transp._init_protocol()
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L9_try_end:;
  }

  /* "uvloop/loop.pyx":2653
 *             transp._close()
 *             raise
 *         transp._attach_fileobj(pipe)             # <<<<<<<<<<<<<<
 *         return transp, proto
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_cur_scope->__pyx_v_transp->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._attach_fileobj(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_cur_scope->__pyx_v_transp), __pyx_cur_scope->__pyx_v_pipe); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/loop.pyx":2654
 *             raise
 *         transp._attach_fileobj(pipe)
 *         return transp, proto             # <<<<<<<<<<<<<<
 * 
 *     def add_signal_handler(self, sig, callback, *args):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_transp));
  __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_transp));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_transp));
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_proto);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2632
 * 
 *     @cython.iterable_coroutine
 *     async def connect_write_pipe(self, proto_factory, pipe):             # <<<<<<<<<<<<<<
 *         """Register write pipe in event loop.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("connect_write_pipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2656
 *         return transp, proto
 * 
 *     def add_signal_handler(self, sig, callback, *args):             # <<<<<<<<<<<<<<
 *         """Add a handler for a signal.  UNIX only.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_121add_signal_handler(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_120add_signal_handler[] = "Loop.add_signal_handler(self, sig, callback, *args)\nAdd a handler for a signal.  UNIX only.\n\n        Raise ValueError if the signal number is invalid or uncatchable.\n        Raise RuntimeError if there is a problem setting up the handler.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_121add_signal_handler(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_sig = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_signal_handler (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 2) {
    __pyx_v_args = PyTuple_GetSlice(__pyx_args, 2, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v_args)) {
      __Pyx_RefNannyFinishContext();
      return NULL;
    }
    __Pyx_GOTREF(__pyx_v_args);
  } else {
    __pyx_v_args = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_sig,&__pyx_n_s_callback,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sig)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("add_signal_handler", 0, 2, 2, 1); __PYX_ERR(2, 2656, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 2) ? pos_args : 2;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "add_signal_handler") < 0)) __PYX_ERR(2, 2656, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_sig = values[0];
    __pyx_v_callback = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_signal_handler", 0, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2656, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v_args); __pyx_v_args = 0;
  __Pyx_AddTraceback("uvloop.loop.Loop.add_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_120add_signal_handler(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_sig, __pyx_v_callback, __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_120add_signal_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig, PyObject *__pyx_v_callback, PyObject *__pyx_v_args) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h = 0;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_nexc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  char const *__pyx_t_26;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  char const *__pyx_t_30;
  __Pyx_RefNannySetupContext("add_signal_handler", 0);

  /* "uvloop/loop.pyx":2665
 *             Handle h
 * 
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             self._setup_signals()
 *             if not self._listening_signals:
 */
  __pyx_t_1 = ((!(__pyx_v_self->_listening_signals != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2666
 * 
 *         if not self._listening_signals:
 *             self._setup_signals()             # <<<<<<<<<<<<<<
 *             if not self._listening_signals:
 *                 raise ValueError('set_wakeup_fd only works in main thread')
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_setup_signals(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2666, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":2667
 *         if not self._listening_signals:
 *             self._setup_signals()
 *             if not self._listening_signals:             # <<<<<<<<<<<<<<
 *                 raise ValueError('set_wakeup_fd only works in main thread')
 * 
 */
    __pyx_t_1 = ((!(__pyx_v_self->_listening_signals != 0)) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":2668
 *             self._setup_signals()
 *             if not self._listening_signals:
 *                 raise ValueError('set_wakeup_fd only works in main thread')             # <<<<<<<<<<<<<<
 * 
 *         if (aio_iscoroutine(callback)
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__110, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2668, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 2668, __pyx_L1_error)

      /* "uvloop/loop.pyx":2667
 *         if not self._listening_signals:
 *             self._setup_signals()
 *             if not self._listening_signals:             # <<<<<<<<<<<<<<
 *                 raise ValueError('set_wakeup_fd only works in main thread')
 * 
 */
    }

    /* "uvloop/loop.pyx":2665
 *             Handle h
 * 
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             self._setup_signals()
 *             if not self._listening_signals:
 */
  }

  /* "uvloop/loop.pyx":2670
 *                 raise ValueError('set_wakeup_fd only works in main thread')
 * 
 *         if (aio_iscoroutine(callback)             # <<<<<<<<<<<<<<
 *                 or aio_iscoroutinefunction(callback)):
 *             raise TypeError(
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_iscoroutine);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_iscoroutine; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_callback); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2670, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_callback};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2670, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_callback};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2670, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_INCREF(__pyx_v_callback);
      __Pyx_GIVEREF(__pyx_v_callback);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_callback);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2670, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 2670, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }

  /* "uvloop/loop.pyx":2671
 * 
 *         if (aio_iscoroutine(callback)
 *                 or aio_iscoroutinefunction(callback)):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 "coroutines cannot be used with add_signal_handler()")
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_iscoroutinefunction);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_iscoroutinefunction; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_callback); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2671, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_callback};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2671, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_callback};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2671, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5); __pyx_t_5 = NULL;
      __Pyx_INCREF(__pyx_v_callback);
      __Pyx_GIVEREF(__pyx_v_callback);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_callback);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2671, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 2671, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;

  /* "uvloop/loop.pyx":2670
 *                 raise ValueError('set_wakeup_fd only works in main thread')
 * 
 *         if (aio_iscoroutine(callback)             # <<<<<<<<<<<<<<
 *                 or aio_iscoroutinefunction(callback)):
 *             raise TypeError(
 */
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":2672
 *         if (aio_iscoroutine(callback)
 *                 or aio_iscoroutinefunction(callback)):
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 "coroutines cannot be used with add_signal_handler()")
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__111, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2672, __pyx_L1_error)

    /* "uvloop/loop.pyx":2670
 *                 raise ValueError('set_wakeup_fd only works in main thread')
 * 
 *         if (aio_iscoroutine(callback)             # <<<<<<<<<<<<<<
 *                 or aio_iscoroutinefunction(callback)):
 *             raise TypeError(
 */
  }

  /* "uvloop/loop.pyx":2675
 *                 "coroutines cannot be used with add_signal_handler()")
 * 
 *         if sig == uv.SIGCHLD:             # <<<<<<<<<<<<<<
 *             if (hasattr(callback, '__self__') and
 *                     isinstance(callback.__self__, aio_AbstractChildWatcher)):
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(SIGCHLD); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_sig, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2675, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2675, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2676
 * 
 *         if sig == uv.SIGCHLD:
 *             if (hasattr(callback, '__self__') and             # <<<<<<<<<<<<<<
 *                     isinstance(callback.__self__, aio_AbstractChildWatcher)):
 * 
 */
    __pyx_t_6 = __Pyx_HasAttr(__pyx_v_callback, __pyx_n_u_self); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(2, 2676, __pyx_L1_error)
    __pyx_t_7 = (__pyx_t_6 != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_1 = __pyx_t_7;
      goto __pyx_L10_bool_binop_done;
    }

    /* "uvloop/loop.pyx":2677
 *         if sig == uv.SIGCHLD:
 *             if (hasattr(callback, '__self__') and
 *                     isinstance(callback.__self__, aio_AbstractChildWatcher)):             # <<<<<<<<<<<<<<
 * 
 *                 _warn_with_source(
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_callback, __pyx_n_s_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_v_6uvloop_4loop_aio_AbstractChildWatcher;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_7 = PyObject_IsInstance(__pyx_t_3, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(2, 2677, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = (__pyx_t_7 != 0);
    __pyx_t_1 = __pyx_t_6;
    __pyx_L10_bool_binop_done:;

    /* "uvloop/loop.pyx":2676
 * 
 *         if sig == uv.SIGCHLD:
 *             if (hasattr(callback, '__self__') and             # <<<<<<<<<<<<<<
 *                     isinstance(callback.__self__, aio_AbstractChildWatcher)):
 * 
 */
    if (__pyx_t_1) {

      /* "uvloop/loop.pyx":2679
 *                     isinstance(callback.__self__, aio_AbstractChildWatcher)):
 * 
 *                 _warn_with_source(             # <<<<<<<<<<<<<<
 *                     "!!! asyncio is trying to install its ChildWatcher for "
 *                     "SIGCHLD signal !!!\n\nThis is probably because a uvloop "
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop__warn_with_source(__pyx_kp_u_asyncio_is_trying_to_install_it, __pyx_builtin_RuntimeWarning, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2679, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":2692
 *                 # in our README.  Need to start a deprecation period
 *                 # at some point to turn this warning into an error.
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             raise RuntimeError(
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/loop.pyx":2676
 * 
 *         if sig == uv.SIGCHLD:
 *             if (hasattr(callback, '__self__') and             # <<<<<<<<<<<<<<
 *                     isinstance(callback.__self__, aio_AbstractChildWatcher)):
 * 
 */
    }

    /* "uvloop/loop.pyx":2694
 *                 return
 * 
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'cannot add a signal handler for SIGCHLD: it is used '
 *                 'by the event loop to track subprocesses')
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__112, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2694, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2694, __pyx_L1_error)

    /* "uvloop/loop.pyx":2675
 *                 "coroutines cannot be used with add_signal_handler()")
 * 
 *         if sig == uv.SIGCHLD:             # <<<<<<<<<<<<<<
 *             if (hasattr(callback, '__self__') and
 *                     isinstance(callback.__self__, aio_AbstractChildWatcher)):
 */
  }

  /* "uvloop/loop.pyx":2698
 *                 'by the event loop to track subprocesses')
 * 
 *         self._check_signal(sig)             # <<<<<<<<<<<<<<
 *         self._check_closed()
 *         try:
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__check_signal(__pyx_v_self, __pyx_v_sig); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2699
 * 
 *         self._check_signal(sig)
 *         self._check_closed()             # <<<<<<<<<<<<<<
 *         try:
 *             # set_wakeup_fd() raises ValueError if this is not the
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__check_closed(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2700
 *         self._check_signal(sig)
 *         self._check_closed()
 *         try:             # <<<<<<<<<<<<<<
 *             # set_wakeup_fd() raises ValueError if this is not the
 *             # main thread.  By calling it early we ensure that an
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "uvloop/loop.pyx":2705
 *             # event loop running in another thread cannot add a signal
 *             # handler.
 *             _set_signal_wakeup_fd(self._csock.fileno())             # <<<<<<<<<<<<<<
 *         except (ValueError, OSError) as exc:
 *             raise RuntimeError(str(exc))
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_csock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2705, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2705, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2705, __pyx_L12_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __pyx_f_6uvloop_4loop__set_signal_wakeup_fd(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2705, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2700
 *         self._check_signal(sig)
 *         self._check_closed()
 *         try:             # <<<<<<<<<<<<<<
 *             # set_wakeup_fd() raises ValueError if this is not the
 *             # main thread.  By calling it early we ensure that an
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L17_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2706
 *             # handler.
 *             _set_signal_wakeup_fd(self._csock.fileno())
 *         except (ValueError, OSError) as exc:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(str(exc))
 * 
 */
    __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
    if (__pyx_t_11) {
      __Pyx_AddTraceback("uvloop.loop.Loop.add_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_4) < 0) __PYX_ERR(2, 2706, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      /*try:*/ {

        /* "uvloop/loop.pyx":2707
 *             _set_signal_wakeup_fd(self._csock.fileno())
 *         except (ValueError, OSError) as exc:
 *             raise RuntimeError(str(exc))             # <<<<<<<<<<<<<<
 * 
 *         h = new_Handle(self, callback, args or None, None)
 */
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_exc); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2707, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_5); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2707, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_Raise(__pyx_t_12, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __PYX_ERR(2, 2707, __pyx_L23_error)
      }

      /* "uvloop/loop.pyx":2706
 *             # handler.
 *             _set_signal_wakeup_fd(self._csock.fileno())
 *         except (ValueError, OSError) as exc:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(str(exc))
 * 
 */
      /*finally:*/ {
        __pyx_L23_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_11 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L14_except_error;
        }
      }
    }
    goto __pyx_L14_except_error;
    __pyx_L14_except_error:;

    /* "uvloop/loop.pyx":2700
 *         self._check_signal(sig)
 *         self._check_closed()
 *         try:             # <<<<<<<<<<<<<<
 *             # set_wakeup_fd() raises ValueError if this is not the
 *             # main thread.  By calling it early we ensure that an
 */
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L1_error;
    __pyx_L17_try_end:;
  }

  /* "uvloop/loop.pyx":2709
 *             raise RuntimeError(str(exc))
 * 
 *         h = new_Handle(self, callback, args or None, None)             # <<<<<<<<<<<<<<
 *         self._signal_handlers[sig] = h
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_args); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2709, __pyx_L1_error)
  if (!__pyx_t_1) {
  } else {
    __Pyx_INCREF(__pyx_v_args);
    __pyx_t_4 = __pyx_v_args;
    goto __pyx_L29_bool_binop_done;
  }
  __Pyx_INCREF(Py_None);
  __pyx_t_4 = Py_None;
  __pyx_L29_bool_binop_done:;
  __pyx_t_2 = __pyx_f_6uvloop_4loop_new_Handle(__pyx_v_self, __pyx_v_callback, __pyx_t_4, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2709, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(2, 2709, __pyx_L1_error)
  __pyx_v_h = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":2710
 * 
 *         h = new_Handle(self, callback, args or None, None)
 *         self._signal_handlers[sig] = h             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  if (unlikely(__pyx_v_self->_signal_handlers == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(2, 2710, __pyx_L1_error)
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->_signal_handlers, __pyx_v_sig, ((PyObject *)__pyx_v_h)) < 0)) __PYX_ERR(2, 2710, __pyx_L1_error)

  /* "uvloop/loop.pyx":2712
 *         self._signal_handlers[sig] = h
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             # Register a dummy signal handler to ask Python to write the signal
 *             # number in the wakeup file descriptor.
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "uvloop/loop.pyx":2715
 *             # Register a dummy signal handler to ask Python to write the signal
 *             # number in the wakeup file descriptor.
 *             signal_signal(sig, self.__sighandler)             # <<<<<<<<<<<<<<
 * 
 *             # Set SA_RESTART to limit EINTR occurrences.
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sighandler); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2715, __pyx_L31_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_signal_signal);
      __pyx_t_3 = __pyx_v_6uvloop_4loop_signal_signal; __pyx_t_12 = NULL;
      __pyx_t_13 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_13 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_v_sig, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2715, __pyx_L31_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_v_sig, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2715, __pyx_L31_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2715, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (__pyx_t_12) {
          __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_12); __pyx_t_12 = NULL;
        }
        __Pyx_INCREF(__pyx_v_sig);
        __Pyx_GIVEREF(__pyx_v_sig);
        PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_13, __pyx_v_sig);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_13, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2715, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":2718
 * 
 *             # Set SA_RESTART to limit EINTR occurrences.
 *             signal_siginterrupt(sig, False)             # <<<<<<<<<<<<<<
 *         except OSError as exc:
 *             del self._signal_handlers[sig]
 */
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_signal_siginterrupt);
      __pyx_t_3 = __pyx_v_6uvloop_4loop_signal_siginterrupt; __pyx_t_5 = NULL;
      __pyx_t_13 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_13 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sig, Py_False};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2718, __pyx_L31_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_sig, Py_False};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2718, __pyx_L31_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2718, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_sig);
        __Pyx_GIVEREF(__pyx_v_sig);
        PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_13, __pyx_v_sig);
        __Pyx_INCREF(Py_False);
        __Pyx_GIVEREF(Py_False);
        PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_13, Py_False);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2718, __pyx_L31_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/loop.pyx":2712
 *         self._signal_handlers[sig] = h
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             # Register a dummy signal handler to ask Python to write the signal
 *             # number in the wakeup file descriptor.
 */
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L36_try_end;
    __pyx_L31_error:;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/loop.pyx":2719
 *             # Set SA_RESTART to limit EINTR occurrences.
 *             signal_siginterrupt(sig, False)
 *         except OSError as exc:             # <<<<<<<<<<<<<<
 *             del self._signal_handlers[sig]
 *             if not self._signal_handlers:
 */
    __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
    if (__pyx_t_13) {
      __Pyx_AddTraceback("uvloop.loop.Loop.add_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(2, 2719, __pyx_L33_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_exc = __pyx_t_3;
      /*try:*/ {

        /* "uvloop/loop.pyx":2720
 *             signal_siginterrupt(sig, False)
 *         except OSError as exc:
 *             del self._signal_handlers[sig]             # <<<<<<<<<<<<<<
 *             if not self._signal_handlers:
 *                 try:
 */
        if (unlikely(__pyx_v_self->_signal_handlers == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(2, 2720, __pyx_L42_error)
        }
        if (unlikely(PyDict_DelItem(__pyx_v_self->_signal_handlers, __pyx_v_sig) < 0)) __PYX_ERR(2, 2720, __pyx_L42_error)

        /* "uvloop/loop.pyx":2721
 *         except OSError as exc:
 *             del self._signal_handlers[sig]
 *             if not self._signal_handlers:             # <<<<<<<<<<<<<<
 *                 try:
 *                     signal_set_wakeup_fd(-1)
 */
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_signal_handlers); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2721, __pyx_L42_error)
        __pyx_t_6 = ((!__pyx_t_1) != 0);
        if (__pyx_t_6) {

          /* "uvloop/loop.pyx":2722
 *             del self._signal_handlers[sig]
 *             if not self._signal_handlers:
 *                 try:             # <<<<<<<<<<<<<<
 *                     signal_set_wakeup_fd(-1)
 *                 except (ValueError, OSError) as nexc:
 */
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_18);
            /*try:*/ {

              /* "uvloop/loop.pyx":2723
 *             if not self._signal_handlers:
 *                 try:
 *                     signal_set_wakeup_fd(-1)             # <<<<<<<<<<<<<<
 *                 except (ValueError, OSError) as nexc:
 *                     aio_logger.info('set_wakeup_fd(-1) failed: %s', nexc)
 */
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_signal_set_wakeup_fd, __pyx_tuple__113, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2723, __pyx_L45_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "uvloop/loop.pyx":2722
 *             del self._signal_handlers[sig]
 *             if not self._signal_handlers:
 *                 try:             # <<<<<<<<<<<<<<
 *                     signal_set_wakeup_fd(-1)
 *                 except (ValueError, OSError) as nexc:
 */
            }
            __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            goto __pyx_L52_try_end;
            __pyx_L45_error:;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "uvloop/loop.pyx":2724
 *                 try:
 *                     signal_set_wakeup_fd(-1)
 *                 except (ValueError, OSError) as nexc:             # <<<<<<<<<<<<<<
 *                     aio_logger.info('set_wakeup_fd(-1) failed: %s', nexc)
 * 
 */
            __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
            if (__pyx_t_13) {
              __Pyx_AddTraceback("uvloop.loop.Loop.add_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_12, &__pyx_t_21) < 0) __PYX_ERR(2, 2724, __pyx_L47_except_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GOTREF(__pyx_t_21);
              __Pyx_INCREF(__pyx_t_12);
              __pyx_v_nexc = __pyx_t_12;
              /*try:*/ {

                /* "uvloop/loop.pyx":2725
 *                     signal_set_wakeup_fd(-1)
 *                 except (ValueError, OSError) as nexc:
 *                     aio_logger.info('set_wakeup_fd(-1) failed: %s', nexc)             # <<<<<<<<<<<<<<
 * 
 *             if exc.errno == errno_EINVAL:
 */
                __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_info); if (unlikely(!__pyx_t_23)) __PYX_ERR(2, 2725, __pyx_L58_error)
                __Pyx_GOTREF(__pyx_t_23);
                __pyx_t_24 = NULL;
                __pyx_t_13 = 0;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_23))) {
                  __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_23);
                  if (likely(__pyx_t_24)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
                    __Pyx_INCREF(__pyx_t_24);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_23, function);
                    __pyx_t_13 = 1;
                  }
                }
                #if CYTHON_FAST_PYCALL
                if (PyFunction_Check(__pyx_t_23)) {
                  PyObject *__pyx_temp[3] = {__pyx_t_24, __pyx_kp_u_set_wakeup_fd_1_failed_s, __pyx_v_nexc};
                  __pyx_t_22 = __Pyx_PyFunction_FastCall(__pyx_t_23, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_22)) __PYX_ERR(2, 2725, __pyx_L58_error)
                  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                  __Pyx_GOTREF(__pyx_t_22);
                } else
                #endif
                #if CYTHON_FAST_PYCCALL
                if (__Pyx_PyFastCFunction_Check(__pyx_t_23)) {
                  PyObject *__pyx_temp[3] = {__pyx_t_24, __pyx_kp_u_set_wakeup_fd_1_failed_s, __pyx_v_nexc};
                  __pyx_t_22 = __Pyx_PyCFunction_FastCall(__pyx_t_23, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_22)) __PYX_ERR(2, 2725, __pyx_L58_error)
                  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                  __Pyx_GOTREF(__pyx_t_22);
                } else
                #endif
                {
                  __pyx_t_25 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_25)) __PYX_ERR(2, 2725, __pyx_L58_error)
                  __Pyx_GOTREF(__pyx_t_25);
                  if (__pyx_t_24) {
                    __Pyx_GIVEREF(__pyx_t_24); PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_t_24); __pyx_t_24 = NULL;
                  }
                  __Pyx_INCREF(__pyx_kp_u_set_wakeup_fd_1_failed_s);
                  __Pyx_GIVEREF(__pyx_kp_u_set_wakeup_fd_1_failed_s);
                  PyTuple_SET_ITEM(__pyx_t_25, 0+__pyx_t_13, __pyx_kp_u_set_wakeup_fd_1_failed_s);
                  __Pyx_INCREF(__pyx_v_nexc);
                  __Pyx_GIVEREF(__pyx_v_nexc);
                  PyTuple_SET_ITEM(__pyx_t_25, 1+__pyx_t_13, __pyx_v_nexc);
                  __pyx_t_22 = __Pyx_PyObject_Call(__pyx_t_23, __pyx_t_25, NULL); if (unlikely(!__pyx_t_22)) __PYX_ERR(2, 2725, __pyx_L58_error)
                  __Pyx_GOTREF(__pyx_t_22);
                  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
                }
                __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
                __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
              }

              /* "uvloop/loop.pyx":2724
 *                 try:
 *                     signal_set_wakeup_fd(-1)
 *                 except (ValueError, OSError) as nexc:             # <<<<<<<<<<<<<<
 *                     aio_logger.info('set_wakeup_fd(-1) failed: %s', nexc)
 * 
 */
              /*finally:*/ {
                /*normal exit:*/{
                  __Pyx_DECREF(__pyx_v_nexc);
                  __pyx_v_nexc = NULL;
                  goto __pyx_L59;
                }
                __pyx_L58_error:;
                /*exception exit:*/{
                  __Pyx_PyThreadState_declare
                  __Pyx_PyThreadState_assign
                  __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0;
                  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
                  __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
                  __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
                  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
                  if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_27, &__pyx_t_28, &__pyx_t_29);
                  if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
                  __Pyx_XGOTREF(__pyx_t_17);
                  __Pyx_XGOTREF(__pyx_t_16);
                  __Pyx_XGOTREF(__pyx_t_15);
                  __Pyx_XGOTREF(__pyx_t_27);
                  __Pyx_XGOTREF(__pyx_t_28);
                  __Pyx_XGOTREF(__pyx_t_29);
                  __pyx_t_13 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_26 = __pyx_filename;
                  {
                    __Pyx_DECREF(__pyx_v_nexc);
                    __pyx_v_nexc = NULL;
                  }
                  if (PY_MAJOR_VERSION >= 3) {
                    __Pyx_XGIVEREF(__pyx_t_27);
                    __Pyx_XGIVEREF(__pyx_t_28);
                    __Pyx_XGIVEREF(__pyx_t_29);
                    __Pyx_ExceptionReset(__pyx_t_27, __pyx_t_28, __pyx_t_29);
                  }
                  __Pyx_XGIVEREF(__pyx_t_17);
                  __Pyx_XGIVEREF(__pyx_t_16);
                  __Pyx_XGIVEREF(__pyx_t_15);
                  __Pyx_ErrRestore(__pyx_t_17, __pyx_t_16, __pyx_t_15);
                  __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0;
                  __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_26;
                  goto __pyx_L47_except_error;
                }
                __pyx_L59:;
              }
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
              goto __pyx_L46_exception_handled;
            }
            goto __pyx_L47_except_error;
            __pyx_L47_except_error:;

            /* "uvloop/loop.pyx":2722
 *             del self._signal_handlers[sig]
 *             if not self._signal_handlers:
 *                 try:             # <<<<<<<<<<<<<<
 *                     signal_set_wakeup_fd(-1)
 *                 except (ValueError, OSError) as nexc:
 */
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_19, __pyx_t_18);
            goto __pyx_L42_error;
            __pyx_L46_exception_handled:;
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_19, __pyx_t_18);
            __pyx_L52_try_end:;
          }

          /* "uvloop/loop.pyx":2721
 *         except OSError as exc:
 *             del self._signal_handlers[sig]
 *             if not self._signal_handlers:             # <<<<<<<<<<<<<<
 *                 try:
 *                     signal_set_wakeup_fd(-1)
 */
        }

        /* "uvloop/loop.pyx":2727
 *                     aio_logger.info('set_wakeup_fd(-1) failed: %s', nexc)
 * 
 *             if exc.errno == errno_EINVAL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 *             else:
 */
        __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_errno); if (unlikely(!__pyx_t_21)) __PYX_ERR(2, 2727, __pyx_L42_error)
        __Pyx_GOTREF(__pyx_t_21);
        __pyx_t_12 = PyObject_RichCompare(__pyx_t_21, __pyx_v_6uvloop_4loop_errno_EINVAL, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2727, __pyx_L42_error)
        __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 2727, __pyx_L42_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(__pyx_t_6)) {

          /* "uvloop/loop.pyx":2728
 * 
 *             if exc.errno == errno_EINVAL:
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))             # <<<<<<<<<<<<<<
 *             else:
 *                 raise
 */
          __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_sig_cannot_be_caught, __pyx_n_s_format); if (unlikely(!__pyx_t_21)) __PYX_ERR(2, 2728, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_21);
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_21))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_21);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_21, function);
            }
          }
          if (!__pyx_t_5) {
            __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_v_sig); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2728, __pyx_L42_error)
            __Pyx_GOTREF(__pyx_t_12);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_21)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_sig};
              __pyx_t_12 = __Pyx_PyFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2728, __pyx_L42_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_12);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_21)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_sig};
              __pyx_t_12 = __Pyx_PyCFunction_FastCall(__pyx_t_21, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2728, __pyx_L42_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_12);
            } else
            #endif
            {
              __pyx_t_22 = PyTuple_New(1+1); if (unlikely(!__pyx_t_22)) __PYX_ERR(2, 2728, __pyx_L42_error)
              __Pyx_GOTREF(__pyx_t_22);
              __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_5); __pyx_t_5 = NULL;
              __Pyx_INCREF(__pyx_v_sig);
              __Pyx_GIVEREF(__pyx_v_sig);
              PyTuple_SET_ITEM(__pyx_t_22, 0+1, __pyx_v_sig);
              __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_t_22, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2728, __pyx_L42_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
          __pyx_t_21 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_12); if (unlikely(!__pyx_t_21)) __PYX_ERR(2, 2728, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_21);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_Raise(__pyx_t_21, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
          __PYX_ERR(2, 2728, __pyx_L42_error)

          /* "uvloop/loop.pyx":2727
 *                     aio_logger.info('set_wakeup_fd(-1) failed: %s', nexc)
 * 
 *             if exc.errno == errno_EINVAL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 *             else:
 */
        }

        /* "uvloop/loop.pyx":2730
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 *             else:
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *     def remove_signal_handler(self, sig):
 */
        /*else*/ {
          __Pyx_GIVEREF(__pyx_t_2);
          __Pyx_GIVEREF(__pyx_t_3);
          __Pyx_XGIVEREF(__pyx_t_4);
          __Pyx_ErrRestoreWithState(__pyx_t_2, __pyx_t_3, __pyx_t_4);
          __pyx_t_2 = 0; __pyx_t_3 = 0; __pyx_t_4 = 0; 
          __PYX_ERR(2, 2730, __pyx_L42_error)
        }
      }

      /* "uvloop/loop.pyx":2719
 *             # Set SA_RESTART to limit EINTR occurrences.
 *             signal_siginterrupt(sig, False)
 *         except OSError as exc:             # <<<<<<<<<<<<<<
 *             del self._signal_handlers[sig]
 *             if not self._signal_handlers:
 */
      /*finally:*/ {
        __pyx_L42_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0; __pyx_t_27 = 0;
          __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
          __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
          __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_29, &__pyx_t_28, &__pyx_t_27);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_29);
          __Pyx_XGOTREF(__pyx_t_28);
          __Pyx_XGOTREF(__pyx_t_27);
          __pyx_t_11 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_30 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_29);
            __Pyx_XGIVEREF(__pyx_t_28);
            __Pyx_XGIVEREF(__pyx_t_27);
            __Pyx_ExceptionReset(__pyx_t_29, __pyx_t_28, __pyx_t_27);
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_29 = 0; __pyx_t_28 = 0; __pyx_t_27 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_30;
          goto __pyx_L33_except_error;
        }
      }
    }
    goto __pyx_L33_except_error;
    __pyx_L33_except_error:;

    /* "uvloop/loop.pyx":2712
 *         self._signal_handlers[sig] = h
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             # Register a dummy signal handler to ask Python to write the signal
 *             # number in the wakeup file descriptor.
 */
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L36_try_end:;
  }

  /* "uvloop/loop.pyx":2656
 *         return transp, proto
 * 
 *     def add_signal_handler(self, sig, callback, *args):             # <<<<<<<<<<<<<<
 *         """Add a handler for a signal.  UNIX only.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_AddTraceback("uvloop.loop.Loop.add_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_h);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_nexc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2732
 *                 raise
 * 
 *     def remove_signal_handler(self, sig):             # <<<<<<<<<<<<<<
 *         """Remove a handler for a signal.  UNIX only.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_123remove_signal_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_sig); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_122remove_signal_handler[] = "Loop.remove_signal_handler(self, sig)\nRemove a handler for a signal.  UNIX only.\n\n        Return True if a signal handler was removed, False if not.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_123remove_signal_handler(PyObject *__pyx_v_self, PyObject *__pyx_v_sig) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_signal_handler (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_122remove_signal_handler(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_sig));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_122remove_signal_handler(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_sig) {
  PyObject *__pyx_v_handler = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_t_21;
  __Pyx_RefNannySetupContext("remove_signal_handler", 0);

  /* "uvloop/loop.pyx":2737
 *         Return True if a signal handler was removed, False if not.
 *         """
 *         self._check_signal(sig)             # <<<<<<<<<<<<<<
 * 
 *         if not self._listening_signals:
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__check_signal(__pyx_v_self, __pyx_v_sig); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2739
 *         self._check_signal(sig)
 * 
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_2 = ((!(__pyx_v_self->_listening_signals != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2740
 * 
 *         if not self._listening_signals:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":2739
 *         self._check_signal(sig)
 * 
 *         if not self._listening_signals:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "uvloop/loop.pyx":2742
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             del self._signal_handlers[sig]
 *         except KeyError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "uvloop/loop.pyx":2743
 * 
 *         try:
 *             del self._signal_handlers[sig]             # <<<<<<<<<<<<<<
 *         except KeyError:
 *             return False
 */
      if (unlikely(__pyx_v_self->_signal_handlers == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(2, 2743, __pyx_L4_error)
      }
      if (unlikely(PyDict_DelItem(__pyx_v_self->_signal_handlers, __pyx_v_sig) < 0)) __PYX_ERR(2, 2743, __pyx_L4_error)

      /* "uvloop/loop.pyx":2742
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             del self._signal_handlers[sig]
 *         except KeyError:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2744
 *         try:
 *             del self._signal_handlers[sig]
 *         except KeyError:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.Loop.remove_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(2, 2744, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);

      /* "uvloop/loop.pyx":2745
 *             del self._signal_handlers[sig]
 *         except KeyError:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         if sig == uv.SIGINT:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L7_except_return;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/loop.pyx":2742
 *             return False
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             del self._signal_handlers[sig]
 *         except KeyError:
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L7_except_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L0;
    __pyx_L9_try_end:;
  }

  /* "uvloop/loop.pyx":2747
 *             return False
 * 
 *         if sig == uv.SIGINT:             # <<<<<<<<<<<<<<
 *             handler = signal_default_int_handler
 *         else:
 */
  __pyx_t_8 = __Pyx_PyInt_From_int(SIGINT); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = PyObject_RichCompare(__pyx_v_sig, __pyx_t_8, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2747, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2748
 * 
 *         if sig == uv.SIGINT:
 *             handler = signal_default_int_handler             # <<<<<<<<<<<<<<
 *         else:
 *             handler = signal_SIG_DFL
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_signal_default_int_handler);
    __pyx_v_handler = __pyx_v_6uvloop_4loop_signal_default_int_handler;

    /* "uvloop/loop.pyx":2747
 *             return False
 * 
 *         if sig == uv.SIGINT:             # <<<<<<<<<<<<<<
 *             handler = signal_default_int_handler
 *         else:
 */
    goto __pyx_L12;
  }

  /* "uvloop/loop.pyx":2750
 *             handler = signal_default_int_handler
 *         else:
 *             handler = signal_SIG_DFL             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_signal_SIG_DFL);
    __pyx_v_handler = __pyx_v_6uvloop_4loop_signal_SIG_DFL;
  }
  __pyx_L12:;

  /* "uvloop/loop.pyx":2752
 *             handler = signal_SIG_DFL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             signal_signal(sig, handler)
 *         except OSError as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/loop.pyx":2753
 * 
 *         try:
 *             signal_signal(sig, handler)             # <<<<<<<<<<<<<<
 *         except OSError as exc:
 *             if exc.errno == errno_EINVAL:
 */
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_signal_signal);
      __pyx_t_8 = __pyx_v_6uvloop_4loop_signal_signal; __pyx_t_1 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_6 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_sig, __pyx_v_handler};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2753, __pyx_L13_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_sig, __pyx_v_handler};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2753, __pyx_L13_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2753, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(__pyx_v_sig);
        __Pyx_GIVEREF(__pyx_v_sig);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_6, __pyx_v_sig);
        __Pyx_INCREF(__pyx_v_handler);
        __Pyx_GIVEREF(__pyx_v_handler);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_6, __pyx_v_handler);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2753, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/loop.pyx":2752
 *             handler = signal_SIG_DFL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             signal_signal(sig, handler)
 *         except OSError as exc:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L18_try_end;
    __pyx_L13_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/loop.pyx":2754
 *         try:
 *             signal_signal(sig, handler)
 *         except OSError as exc:             # <<<<<<<<<<<<<<
 *             if exc.errno == errno_EINVAL:
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.Loop.remove_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(2, 2754, __pyx_L15_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_v_exc = __pyx_t_8;
      /*try:*/ {

        /* "uvloop/loop.pyx":2755
 *             signal_signal(sig, handler)
 *         except OSError as exc:
 *             if exc.errno == errno_EINVAL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 *             else:
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_errno); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2755, __pyx_L24_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = PyObject_RichCompare(__pyx_t_1, __pyx_v_6uvloop_4loop_errno_EINVAL, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2755, __pyx_L24_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2755, __pyx_L24_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(__pyx_t_2)) {

          /* "uvloop/loop.pyx":2756
 *         except OSError as exc:
 *             if exc.errno == errno_EINVAL:
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))             # <<<<<<<<<<<<<<
 *             else:
 *                 raise
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_sig_cannot_be_caught, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2756, __pyx_L24_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_sig); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2756, __pyx_L24_error)
            __Pyx_GOTREF(__pyx_t_10);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_sig};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2756, __pyx_L24_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_10);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_sig};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2756, __pyx_L24_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_10);
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2756, __pyx_L24_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_INCREF(__pyx_v_sig);
              __Pyx_GIVEREF(__pyx_v_sig);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_v_sig);
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_12, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2756, __pyx_L24_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2756, __pyx_L24_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_Raise(__pyx_t_1, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __PYX_ERR(2, 2756, __pyx_L24_error)

          /* "uvloop/loop.pyx":2755
 *             signal_signal(sig, handler)
 *         except OSError as exc:
 *             if exc.errno == errno_EINVAL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 *             else:
 */
        }

        /* "uvloop/loop.pyx":2758
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 *             else:
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *         if not self._signal_handlers:
 */
        /*else*/ {
          __Pyx_GIVEREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_8, __pyx_t_9);
          __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; 
          __PYX_ERR(2, 2758, __pyx_L24_error)
        }
      }

      /* "uvloop/loop.pyx":2754
 *         try:
 *             signal_signal(sig, handler)
 *         except OSError as exc:             # <<<<<<<<<<<<<<
 *             if exc.errno == errno_EINVAL:
 *                 raise RuntimeError('sig {} cannot be caught'.format(sig))
 */
      /*finally:*/ {
        __pyx_L24_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __pyx_t_6 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          }
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
          goto __pyx_L15_except_error;
        }
      }
    }
    goto __pyx_L15_except_error;
    __pyx_L15_except_error:;

    /* "uvloop/loop.pyx":2752
 *             handler = signal_SIG_DFL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             signal_signal(sig, handler)
 *         except OSError as exc:
 */
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L18_try_end:;
  }

  /* "uvloop/loop.pyx":2760
 *                 raise
 * 
 *         if not self._signal_handlers:             # <<<<<<<<<<<<<<
 *             self._shutdown_signals()
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->_signal_handlers); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2760, __pyx_L1_error)
  __pyx_t_21 = ((!__pyx_t_2) != 0);
  if (__pyx_t_21) {

    /* "uvloop/loop.pyx":2761
 * 
 *         if not self._signal_handlers:
 *             self._shutdown_signals()             # <<<<<<<<<<<<<<
 * 
 *         return True
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_vtab)->_shutdown_signals(__pyx_v_self); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/loop.pyx":2760
 *                 raise
 * 
 *         if not self._signal_handlers:             # <<<<<<<<<<<<<<
 *             self._shutdown_signals()
 * 
 */
  }

  /* "uvloop/loop.pyx":2763
 *             self._shutdown_signals()
 * 
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "uvloop/loop.pyx":2732
 *                 raise
 * 
 *     def remove_signal_handler(self, sig):             # <<<<<<<<<<<<<<
 *         """Remove a handler for a signal.  UNIX only.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.Loop.remove_signal_handler", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_126generator18(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2766
 * 
 *     @cython.iterable_coroutine
 *     async def create_datagram_endpoint(self, protocol_factory,             # <<<<<<<<<<<<<<
 *                                        local_addr=None, remote_addr=None, *,
 *                                        family=0, proto=0, flags=0,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_125create_datagram_endpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_124create_datagram_endpoint[] = "Loop.create_datagram_endpoint(self, protocol_factory, local_addr=None, remote_addr=None, *, family=0, proto=0, flags=0, reuse_address=None, reuse_port=None, allow_broadcast=None, sock=None)\nA coroutine which creates a datagram endpoint.\n\n        This method will try to establish the endpoint in the background.\n        When successful, the coroutine returns a (transport, protocol) pair.\n\n        protocol_factory must be a callable returning a protocol instance.\n\n        socket family AF_INET or socket.AF_INET6 depending on host (or\n        family if specified), socket type SOCK_DGRAM.\n\n        reuse_address tells the kernel to reuse a local socket in\n        TIME_WAIT state, without waiting for its natural timeout to\n        expire. If not specified it will automatically be set to True on\n        UNIX.\n\n        reuse_port tells the kernel to allow this endpoint to be bound to\n        the same port as other existing endpoints are bound to, so long as\n        they all set this flag when being created. This option is not\n        supported on Windows and some UNIX's. If the\n        :py:data:`~socket.SO_REUSEPORT` constant is not defined then this\n        capability is unsupported.\n\n        allow_broadcast tells the kernel to allow this endpoint to send\n        messages to the broadcast address.\n\n        sock can optionally be specified in order to use a preexisting\n        socket object.\n        ";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_125create_datagram_endpoint(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_protocol_factory = 0;
  PyObject *__pyx_v_local_addr = 0;
  PyObject *__pyx_v_remote_addr = 0;
  PyObject *__pyx_v_family = 0;
  PyObject *__pyx_v_proto = 0;
  PyObject *__pyx_v_flags = 0;
  PyObject *__pyx_v_reuse_address = 0;
  PyObject *__pyx_v_reuse_port = 0;
  PyObject *__pyx_v_allow_broadcast = 0;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_datagram_endpoint (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_protocol_factory,&__pyx_n_s_local_addr,&__pyx_n_s_remote_addr,&__pyx_n_s_family,&__pyx_n_s_proto,&__pyx_n_s_flags,&__pyx_n_s_reuse_address,&__pyx_n_s_reuse_port,&__pyx_n_s_allow_broadcast,&__pyx_n_s_sock,0};
    PyObject* values[10] = {0,0,0,0,0,0,0,0,0,0};

    /* "uvloop/loop.pyx":2767
 *     @cython.iterable_coroutine
 *     async def create_datagram_endpoint(self, protocol_factory,
 *                                        local_addr=None, remote_addr=None, *,             # <<<<<<<<<<<<<<
 *                                        family=0, proto=0, flags=0,
 *                                        reuse_address=None, reuse_port=None,
 */
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)__pyx_int_0);
    values[4] = ((PyObject *)__pyx_int_0);
    values[5] = ((PyObject *)__pyx_int_0);

    /* "uvloop/loop.pyx":2769
 *                                        local_addr=None, remote_addr=None, *,
 *                                        family=0, proto=0, flags=0,
 *                                        reuse_address=None, reuse_port=None,             # <<<<<<<<<<<<<<
 *                                        allow_broadcast=None, sock=None):
 *         """A coroutine which creates a datagram endpoint.
 */
    values[6] = ((PyObject *)Py_None);
    values[7] = ((PyObject *)Py_None);

    /* "uvloop/loop.pyx":2770
 *                                        family=0, proto=0, flags=0,
 *                                        reuse_address=None, reuse_port=None,
 *                                        allow_broadcast=None, sock=None):             # <<<<<<<<<<<<<<
 *         """A coroutine which creates a datagram endpoint.
 * 
 */
    values[8] = ((PyObject *)Py_None);
    values[9] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol_factory)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_local_addr);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_remote_addr);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (kw_args > 0 && likely(kw_args <= 7)) {
        Py_ssize_t index;
        for (index = 3; index < 10 && kw_args > 0; index++) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, *__pyx_pyargnames[index]);
          if (value) { values[index] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_datagram_endpoint") < 0)) __PYX_ERR(2, 2766, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_protocol_factory = values[0];
    __pyx_v_local_addr = values[1];
    __pyx_v_remote_addr = values[2];
    __pyx_v_family = values[3];
    __pyx_v_proto = values[4];
    __pyx_v_flags = values[5];
    __pyx_v_reuse_address = values[6];
    __pyx_v_reuse_port = values[7];
    __pyx_v_allow_broadcast = values[8];
    __pyx_v_sock = values[9];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_datagram_endpoint", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2766, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_datagram_endpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_124create_datagram_endpoint(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), __pyx_v_protocol_factory, __pyx_v_local_addr, __pyx_v_remote_addr, __pyx_v_family, __pyx_v_proto, __pyx_v_flags, __pyx_v_reuse_address, __pyx_v_reuse_port, __pyx_v_allow_broadcast, __pyx_v_sock);

  /* "uvloop/loop.pyx":2766
 * 
 *     @cython.iterable_coroutine
 *     async def create_datagram_endpoint(self, protocol_factory,             # <<<<<<<<<<<<<<
 *                                        local_addr=None, remote_addr=None, *,
 *                                        family=0, proto=0, flags=0,
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_24create_datagram_endpoint_2generator24(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2816
 *                             allow_broadcast=allow_broadcast)
 *                 problems = ', '.join(
 *                     '{}={}'.format(k, v) for k, v in opts.items() if v)             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'socket modifier keyword arguments can not be used '
 */

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_24create_datagram_endpoint_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_26_genexpr(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_26_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2816, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_24create_datagram_endpoint_2generator24, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_create_datagram_endpoint_locals, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2816, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_datagram_endpoint.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_24create_datagram_endpoint_2generator24(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  __pyx_t_2 = 0;
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_opts)) { __Pyx_RaiseClosureNameError("opts"); __PYX_ERR(2, 2816, __pyx_L1_error) }
  if (unlikely(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_opts == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
    __PYX_ERR(2, 2816, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_opts, 1, __pyx_n_s_items, (&__pyx_t_3), (&__pyx_t_4)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_1);
  __pyx_t_1 = __pyx_t_5;
  __pyx_t_5 = 0;
  while (1) {
    __pyx_t_7 = __Pyx_dict_iter_next(__pyx_t_1, __pyx_t_3, &__pyx_t_2, &__pyx_t_5, &__pyx_t_6, NULL, __pyx_t_4);
    if (unlikely(__pyx_t_7 == 0)) break;
    if (unlikely(__pyx_t_7 == -1)) __PYX_ERR(2, 2816, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_k);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_k, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_v);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_v, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_v); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(2, 2816, __pyx_L1_error)
    if (__pyx_t_8) {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u__114, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_cur_scope->__pyx_v_k, __pyx_cur_scope->__pyx_v_v};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2816, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_cur_scope->__pyx_v_k, __pyx_cur_scope->__pyx_v_v};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2816, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2816, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_k);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_k);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_7, __pyx_cur_scope->__pyx_v_k);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_v);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_v);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_7, __pyx_cur_scope->__pyx_v_v);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2816, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_6))) __PYX_ERR(2, 2816, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2766
 * 
 *     @cython.iterable_coroutine
 *     async def create_datagram_endpoint(self, protocol_factory,             # <<<<<<<<<<<<<<
 *                                        local_addr=None, remote_addr=None, *,
 *                                        family=0, proto=0, flags=0,
 */

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_124create_datagram_endpoint(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_protocol_factory, PyObject *__pyx_v_local_addr, PyObject *__pyx_v_remote_addr, PyObject *__pyx_v_family, PyObject *__pyx_v_proto, PyObject *__pyx_v_flags, PyObject *__pyx_v_reuse_address, PyObject *__pyx_v_reuse_port, PyObject *__pyx_v_allow_broadcast, PyObject *__pyx_v_sock) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_datagram_endpoint", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2766, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __pyx_cur_scope->__pyx_v_protocol_factory = __pyx_v_protocol_factory;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_cur_scope->__pyx_v_local_addr = __pyx_v_local_addr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_local_addr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_local_addr);
  __pyx_cur_scope->__pyx_v_remote_addr = __pyx_v_remote_addr;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_remote_addr);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_remote_addr);
  __pyx_cur_scope->__pyx_v_family = __pyx_v_family;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_family);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_family);
  __pyx_cur_scope->__pyx_v_proto = __pyx_v_proto;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto);
  __pyx_cur_scope->__pyx_v_flags = __pyx_v_flags;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_flags);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_flags);
  __pyx_cur_scope->__pyx_v_reuse_address = __pyx_v_reuse_address;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_reuse_address);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_reuse_address);
  __pyx_cur_scope->__pyx_v_reuse_port = __pyx_v_reuse_port;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_reuse_port);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_reuse_port);
  __pyx_cur_scope->__pyx_v_allow_broadcast = __pyx_v_allow_broadcast;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_allow_broadcast);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_allow_broadcast);
  __pyx_cur_scope->__pyx_v_sock = __pyx_v_sock;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_126generator18, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_create_datagram_endpoint, __pyx_n_s_Loop_create_datagram_endpoint, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2766, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.create_datagram_endpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_126generator18(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *(*__pyx_t_16)(PyObject *);
  int __pyx_t_17;
  int __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_t_22;
  char const *__pyx_t_23;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_datagram_endpoint", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L29_resume_from_await;
    case 2: goto __pyx_L65_resume_from_await;
    case 3: goto __pyx_L88_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2766, __pyx_L1_error)

  /* "uvloop/loop.pyx":2800
 *         """
 *         cdef:
 *             UDPTransport udp = None             # <<<<<<<<<<<<<<
 *             system.sockaddr_storage rai
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __pyx_cur_scope->__pyx_v_udp = ((struct __pyx_obj_6uvloop_4loop_UDPTransport *)Py_None);

  /* "uvloop/loop.pyx":2803
 *             system.sockaddr_storage rai
 * 
 *         if sock is not None:             # <<<<<<<<<<<<<<
 *             if not _is_sock_dgram(sock.type):
 *                 raise ValueError(
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2804
 * 
 *         if sock is not None:
 *             if not _is_sock_dgram(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A UDP Socket was expected, got {!r}'.format(sock))
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __pyx_f_6uvloop_4loop__is_sock_dgram(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2804, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2804, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = ((!__pyx_t_2) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":2806
 *             if not _is_sock_dgram(sock.type):
 *                 raise ValueError(
 *                     'A UDP Socket was expected, got {!r}'.format(sock))             # <<<<<<<<<<<<<<
 *             if (local_addr or remote_addr or
 *                     family or proto or flags or
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_A_UDP_Socket_was_expected_got_r, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2806, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_cur_scope->__pyx_v_sock); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2806, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2806, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_cur_scope->__pyx_v_sock};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2806, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2806, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_cur_scope->__pyx_v_sock);
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2806, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2805
 *         if sock is not None:
 *             if not _is_sock_dgram(sock.type):
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'A UDP Socket was expected, got {!r}'.format(sock))
 *             if (local_addr or remote_addr or
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2805, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 2805, __pyx_L1_error)

      /* "uvloop/loop.pyx":2804
 * 
 *         if sock is not None:
 *             if not _is_sock_dgram(sock.type):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'A UDP Socket was expected, got {!r}'.format(sock))
 */
    }

    /* "uvloop/loop.pyx":2807
 *                 raise ValueError(
 *                     'A UDP Socket was expected, got {!r}'.format(sock))
 *             if (local_addr or remote_addr or             # <<<<<<<<<<<<<<
 *                     family or proto or flags or
 *                     reuse_address or reuse_port or allow_broadcast):
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_local_addr); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2807, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_remote_addr); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2807, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }

    /* "uvloop/loop.pyx":2808
 *                     'A UDP Socket was expected, got {!r}'.format(sock))
 *             if (local_addr or remote_addr or
 *                     family or proto or flags or             # <<<<<<<<<<<<<<
 *                     reuse_address or reuse_port or allow_broadcast):
 *                 # show the problematic kwargs in exception msg
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_family); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2808, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_proto); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2808, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_flags); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2808, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }

    /* "uvloop/loop.pyx":2809
 *             if (local_addr or remote_addr or
 *                     family or proto or flags or
 *                     reuse_address or reuse_port or allow_broadcast):             # <<<<<<<<<<<<<<
 *                 # show the problematic kwargs in exception msg
 *                 opts = dict(local_addr=local_addr, remote_addr=remote_addr,
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_reuse_address); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2809, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_reuse_port); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2809, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_allow_broadcast); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2809, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L7_bool_binop_done:;

    /* "uvloop/loop.pyx":2807
 *                 raise ValueError(
 *                     'A UDP Socket was expected, got {!r}'.format(sock))
 *             if (local_addr or remote_addr or             # <<<<<<<<<<<<<<
 *                     family or proto or flags or
 *                     reuse_address or reuse_port or allow_broadcast):
 */
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/loop.pyx":2811
 *                     reuse_address or reuse_port or allow_broadcast):
 *                 # show the problematic kwargs in exception msg
 *                 opts = dict(local_addr=local_addr, remote_addr=remote_addr,             # <<<<<<<<<<<<<<
 *                             family=family, proto=proto, flags=flags,
 *                             reuse_address=reuse_address, reuse_port=reuse_port,
 */
      __pyx_t_3 = __Pyx_PyDict_NewPresized(8); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2811, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_local_addr, __pyx_cur_scope->__pyx_v_local_addr) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_remote_addr, __pyx_cur_scope->__pyx_v_remote_addr) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)

      /* "uvloop/loop.pyx":2812
 *                 # show the problematic kwargs in exception msg
 *                 opts = dict(local_addr=local_addr, remote_addr=remote_addr,
 *                             family=family, proto=proto, flags=flags,             # <<<<<<<<<<<<<<
 *                             reuse_address=reuse_address, reuse_port=reuse_port,
 *                             allow_broadcast=allow_broadcast)
 */
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_family, __pyx_cur_scope->__pyx_v_family) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_proto, __pyx_cur_scope->__pyx_v_proto) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_flags, __pyx_cur_scope->__pyx_v_flags) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)

      /* "uvloop/loop.pyx":2813
 *                 opts = dict(local_addr=local_addr, remote_addr=remote_addr,
 *                             family=family, proto=proto, flags=flags,
 *                             reuse_address=reuse_address, reuse_port=reuse_port,             # <<<<<<<<<<<<<<
 *                             allow_broadcast=allow_broadcast)
 *                 problems = ', '.join(
 */
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_reuse_address, __pyx_cur_scope->__pyx_v_reuse_address) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_reuse_port, __pyx_cur_scope->__pyx_v_reuse_port) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)

      /* "uvloop/loop.pyx":2814
 *                             family=family, proto=proto, flags=flags,
 *                             reuse_address=reuse_address, reuse_port=reuse_port,
 *                             allow_broadcast=allow_broadcast)             # <<<<<<<<<<<<<<
 *                 problems = ', '.join(
 *                     '{}={}'.format(k, v) for k, v in opts.items() if v)
 */
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_allow_broadcast, __pyx_cur_scope->__pyx_v_allow_broadcast) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v_opts = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2816
 *                             allow_broadcast=allow_broadcast)
 *                 problems = ', '.join(
 *                     '{}={}'.format(k, v) for k, v in opts.items() if v)             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'socket modifier keyword arguments can not be used '
 */
      __pyx_t_3 = __pyx_pf_6uvloop_4loop_4Loop_24create_datagram_endpoint_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2816, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/loop.pyx":2815
 *                             reuse_address=reuse_address, reuse_port=reuse_port,
 *                             allow_broadcast=allow_broadcast)
 *                 problems = ', '.join(             # <<<<<<<<<<<<<<
 *                     '{}={}'.format(k, v) for k, v in opts.items() if v)
 *                 raise ValueError(
 */
      __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2815, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyUnicode_Join(__pyx_kp_u__71, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2815, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v_problems = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2819
 *                 raise ValueError(
 *                     'socket modifier keyword arguments can not be used '
 *                     'when sock is specified. ({})'.format(problems))             # <<<<<<<<<<<<<<
 *             sock.setblocking(False)
 *             udp = UDPTransport.new(self, sock, None)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_socket_modifier_keyword_argument, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_cur_scope->__pyx_v_problems); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2819, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_problems};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2819, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_cur_scope->__pyx_v_problems};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2819, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2819, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_problems);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_problems);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_cur_scope->__pyx_v_problems);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2819, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":2817
 *                 problems = ', '.join(
 *                     '{}={}'.format(k, v) for k, v in opts.items() if v)
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'socket modifier keyword arguments can not be used '
 *                     'when sock is specified. ({})'.format(problems))
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2817, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(2, 2817, __pyx_L1_error)

      /* "uvloop/loop.pyx":2807
 *                 raise ValueError(
 *                     'A UDP Socket was expected, got {!r}'.format(sock))
 *             if (local_addr or remote_addr or             # <<<<<<<<<<<<<<
 *                     family or proto or flags or
 *                     reuse_address or reuse_port or allow_broadcast):
 */
    }

    /* "uvloop/loop.pyx":2820
 *                     'socket modifier keyword arguments can not be used '
 *                     'when sock is specified. ({})'.format(problems))
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 *             udp = UDPTransport.new(self, sock, None)
 *         else:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__115, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2820, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2821
 *                     'when sock is specified. ({})'.format(problems))
 *             sock.setblocking(False)
 *             udp = UDPTransport.new(self, sock, None)             # <<<<<<<<<<<<<<
 *         else:
 *             if not (local_addr or remote_addr):
 */
    __pyx_t_3 = ((PyObject *)__pyx_f_6uvloop_4loop_12UDPTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, Py_None)); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2821, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_udp));
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_udp, ((struct __pyx_obj_6uvloop_4loop_UDPTransport *)__pyx_t_3));
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2803
 *             system.sockaddr_storage rai
 * 
 *         if sock is not None:             # <<<<<<<<<<<<<<
 *             if not _is_sock_dgram(sock.type):
 *                 raise ValueError(
 */
    goto __pyx_L4;
  }

  /* "uvloop/loop.pyx":2823
 *             udp = UDPTransport.new(self, sock, None)
 *         else:
 *             if not (local_addr or remote_addr):             # <<<<<<<<<<<<<<
 *                 if family == 0:
 *                     raise ValueError('unexpected address family')
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_local_addr); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2823, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L16_bool_binop_done;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_remote_addr); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2823, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L16_bool_binop_done:;
    __pyx_t_2 = ((!__pyx_t_1) != 0);
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":2824
 *         else:
 *             if not (local_addr or remote_addr):
 *                 if family == 0:             # <<<<<<<<<<<<<<
 *                     raise ValueError('unexpected address family')
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 */
      __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_cur_scope->__pyx_v_family, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2824, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2824, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/loop.pyx":2825
 *             if not (local_addr or remote_addr):
 *                 if family == 0:
 *                     raise ValueError('unexpected address family')             # <<<<<<<<<<<<<<
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 *             elif family == uv.AF_UNIX:
 */
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__116, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(2, 2825, __pyx_L1_error)

        /* "uvloop/loop.pyx":2824
 *         else:
 *             if not (local_addr or remote_addr):
 *                 if family == 0:             # <<<<<<<<<<<<<<
 *                     raise ValueError('unexpected address family')
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 */
      }

      /* "uvloop/loop.pyx":2826
 *                 if family == 0:
 *                     raise ValueError('unexpected address family')
 *                 addr_pairs_info = (((family, proto), (None, None)),)             # <<<<<<<<<<<<<<
 *             elif family == uv.AF_UNIX:
 *                 for addr in (local_addr, remote_addr):
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2826, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_family);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_family);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_family);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_proto);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2826, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
      __Pyx_INCREF(__pyx_tuple__117);
      __Pyx_GIVEREF(__pyx_tuple__117);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_tuple__117);
      __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2826, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v_addr_pairs_info = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2823
 *             udp = UDPTransport.new(self, sock, None)
 *         else:
 *             if not (local_addr or remote_addr):             # <<<<<<<<<<<<<<
 *                 if family == 0:
 *                     raise ValueError('unexpected address family')
 */
      goto __pyx_L15;
    }

    /* "uvloop/loop.pyx":2827
 *                     raise ValueError('unexpected address family')
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 *             elif family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *                 for addr in (local_addr, remote_addr):
 *                     if addr is not None and not isinstance(addr, str):
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_cur_scope->__pyx_v_family, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2827, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2827, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "uvloop/loop.pyx":2828
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 *             elif family == uv.AF_UNIX:
 *                 for addr in (local_addr, remote_addr):             # <<<<<<<<<<<<<<
 *                     if addr is not None and not isinstance(addr, str):
 *                         raise TypeError('string is expected')
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_local_addr);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_local_addr);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_cur_scope->__pyx_v_local_addr);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_remote_addr);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_remote_addr);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_remote_addr);
      __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      for (;;) {
        if (__pyx_t_7 >= 2) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_4); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(2, 2828, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2828, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_addr);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_addr, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;

        /* "uvloop/loop.pyx":2829
 *             elif family == uv.AF_UNIX:
 *                 for addr in (local_addr, remote_addr):
 *                     if addr is not None and not isinstance(addr, str):             # <<<<<<<<<<<<<<
 *                         raise TypeError('string is expected')
 *                 addr_pairs_info = (((family, proto),
 */
        __pyx_t_1 = (__pyx_cur_scope->__pyx_v_addr != Py_None);
        __pyx_t_8 = (__pyx_t_1 != 0);
        if (__pyx_t_8) {
        } else {
          __pyx_t_2 = __pyx_t_8;
          goto __pyx_L22_bool_binop_done;
        }
        __pyx_t_8 = PyUnicode_Check(__pyx_cur_scope->__pyx_v_addr); 
        __pyx_t_1 = ((!(__pyx_t_8 != 0)) != 0);
        __pyx_t_2 = __pyx_t_1;
        __pyx_L22_bool_binop_done:;
        if (unlikely(__pyx_t_2)) {

          /* "uvloop/loop.pyx":2830
 *                 for addr in (local_addr, remote_addr):
 *                     if addr is not None and not isinstance(addr, str):
 *                         raise TypeError('string is expected')             # <<<<<<<<<<<<<<
 *                 addr_pairs_info = (((family, proto),
 *                                     (local_addr, remote_addr)), )
 */
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__118, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2830, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_Raise(__pyx_t_4, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __PYX_ERR(2, 2830, __pyx_L1_error)

          /* "uvloop/loop.pyx":2829
 *             elif family == uv.AF_UNIX:
 *                 for addr in (local_addr, remote_addr):
 *                     if addr is not None and not isinstance(addr, str):             # <<<<<<<<<<<<<<
 *                         raise TypeError('string is expected')
 *                 addr_pairs_info = (((family, proto),
 */
        }

        /* "uvloop/loop.pyx":2828
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 *             elif family == uv.AF_UNIX:
 *                 for addr in (local_addr, remote_addr):             # <<<<<<<<<<<<<<
 *                     if addr is not None and not isinstance(addr, str):
 *                         raise TypeError('string is expected')
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/loop.pyx":2831
 *                     if addr is not None and not isinstance(addr, str):
 *                         raise TypeError('string is expected')
 *                 addr_pairs_info = (((family, proto),             # <<<<<<<<<<<<<<
 *                                     (local_addr, remote_addr)), )
 *             else:
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_family);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_family);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_cur_scope->__pyx_v_family);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_proto);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_proto);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_cur_scope->__pyx_v_proto);

      /* "uvloop/loop.pyx":2832
 *                         raise TypeError('string is expected')
 *                 addr_pairs_info = (((family, proto),
 *                                     (local_addr, remote_addr)), )             # <<<<<<<<<<<<<<
 *             else:
 *                 # join address by (family, protocol)
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2832, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_local_addr);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_local_addr);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_cur_scope->__pyx_v_local_addr);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_remote_addr);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_remote_addr);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_remote_addr);

      /* "uvloop/loop.pyx":2831
 *                     if addr is not None and not isinstance(addr, str):
 *                         raise TypeError('string is expected')
 *                 addr_pairs_info = (((family, proto),             # <<<<<<<<<<<<<<
 *                                     (local_addr, remote_addr)), )
 *             else:
 */
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
      __pyx_t_3 = 0;
      __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2831, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_cur_scope->__pyx_v_addr_pairs_info = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":2827
 *                     raise ValueError('unexpected address family')
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 *             elif family == uv.AF_UNIX:             # <<<<<<<<<<<<<<
 *                 for addr in (local_addr, remote_addr):
 *                     if addr is not None and not isinstance(addr, str):
 */
      goto __pyx_L15;
    }

    /* "uvloop/loop.pyx":2835
 *             else:
 *                 # join address by (family, protocol)
 *                 addr_infos = col_OrderedDict()             # <<<<<<<<<<<<<<
 *                 for idx, addr in ((0, local_addr), (1, remote_addr)):
 *                     if addr is not None:
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_col_OrderedDict);
      __pyx_t_5 = __pyx_v_6uvloop_4loop_col_OrderedDict; __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_3) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2835, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2835, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_cur_scope->__pyx_v_addr_infos = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":2836
 *                 # join address by (family, protocol)
 *                 addr_infos = col_OrderedDict()
 *                 for idx, addr in ((0, local_addr), (1, remote_addr)):             # <<<<<<<<<<<<<<
 *                     if addr is not None:
 *                         assert isinstance(addr, tuple) and len(addr) == 2, (
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_int_0);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_local_addr);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_local_addr);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_cur_scope->__pyx_v_local_addr);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_GIVEREF(__pyx_int_1);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_int_1);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_remote_addr);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_remote_addr);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_cur_scope->__pyx_v_remote_addr);
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2836, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_5 = __pyx_t_3; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      for (;;) {
        if (__pyx_t_7 >= 2) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(2, 2836, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2836, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        if (likely(__pyx_t_3 != Py_None)) {
          PyObject* sequence = __pyx_t_3;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(2, 2836, __pyx_L1_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          #else
          __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2836, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2836, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else {
          __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(2, 2836, __pyx_L1_error)
        }
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_idx);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_idx, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_addr);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_addr, __pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_6);
        __pyx_t_6 = 0;

        /* "uvloop/loop.pyx":2837
 *                 addr_infos = col_OrderedDict()
 *                 for idx, addr in ((0, local_addr), (1, remote_addr)):
 *                     if addr is not None:             # <<<<<<<<<<<<<<
 *                         assert isinstance(addr, tuple) and len(addr) == 2, (
 *                             '2-tuple is expected')
 */
        __pyx_t_2 = (__pyx_cur_scope->__pyx_v_addr != Py_None);
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "uvloop/loop.pyx":2838
 *                 for idx, addr in ((0, local_addr), (1, remote_addr)):
 *                     if addr is not None:
 *                         assert isinstance(addr, tuple) and len(addr) == 2, (             # <<<<<<<<<<<<<<
 *                             '2-tuple is expected')
 * 
 */
          #ifndef CYTHON_WITHOUT_ASSERTIONS
          if (unlikely(!Py_OptimizeFlag)) {
            __pyx_t_2 = PyTuple_Check(__pyx_cur_scope->__pyx_v_addr); 
            __pyx_t_8 = (__pyx_t_2 != 0);
            if (__pyx_t_8) {
            } else {
              __pyx_t_1 = __pyx_t_8;
              goto __pyx_L27_bool_binop_done;
            }
            __pyx_t_9 = PyObject_Length(__pyx_cur_scope->__pyx_v_addr); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(2, 2838, __pyx_L1_error)
            __pyx_t_8 = ((__pyx_t_9 == 2) != 0);
            __pyx_t_1 = __pyx_t_8;
            __pyx_L27_bool_binop_done:;
            if (unlikely(!__pyx_t_1)) {
              PyErr_SetObject(PyExc_AssertionError, __pyx_kp_u_2_tuple_is_expected);
              __PYX_ERR(2, 2838, __pyx_L1_error)
            }
          }
          #endif

          /* "uvloop/loop.pyx":2841
 *                             '2-tuple is expected')
 * 
 *                         infos = await self.getaddrinfo(             # <<<<<<<<<<<<<<
 *                             *addr[:2], family=family, type=uv.SOCK_DGRAM,
 *                             proto=proto, flags=flags)
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_getaddrinfo); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2841, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);

          /* "uvloop/loop.pyx":2842
 * 
 *                         infos = await self.getaddrinfo(
 *                             *addr[:2], family=family, type=uv.SOCK_DGRAM,             # <<<<<<<<<<<<<<
 *                             proto=proto, flags=flags)
 * 
 */
          __pyx_t_6 = __Pyx_PyObject_GetSlice(__pyx_cur_scope->__pyx_v_addr, 0, 2, NULL, NULL, &__pyx_slice__119, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2842, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);

          /* "uvloop/loop.pyx":2841
 *                             '2-tuple is expected')
 * 
 *                         infos = await self.getaddrinfo(             # <<<<<<<<<<<<<<
 *                             *addr[:2], family=family, type=uv.SOCK_DGRAM,
 *                             proto=proto, flags=flags)
 */
          __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2841, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "uvloop/loop.pyx":2842
 * 
 *                         infos = await self.getaddrinfo(
 *                             *addr[:2], family=family, type=uv.SOCK_DGRAM,             # <<<<<<<<<<<<<<
 *                             proto=proto, flags=flags)
 * 
 */
          __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2842, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_family, __pyx_cur_scope->__pyx_v_family) < 0) __PYX_ERR(2, 2842, __pyx_L1_error)
          __pyx_t_10 = __Pyx_PyInt_From_int(SOCK_DGRAM); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2842, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_type, __pyx_t_10) < 0) __PYX_ERR(2, 2842, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "uvloop/loop.pyx":2843
 *                         infos = await self.getaddrinfo(
 *                             *addr[:2], family=family, type=uv.SOCK_DGRAM,
 *                             proto=proto, flags=flags)             # <<<<<<<<<<<<<<
 * 
 *                         if not infos:
 */
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_proto, __pyx_cur_scope->__pyx_v_proto) < 0) __PYX_ERR(2, 2842, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_flags, __pyx_cur_scope->__pyx_v_flags) < 0) __PYX_ERR(2, 2842, __pyx_L1_error)

          /* "uvloop/loop.pyx":2841
 *                             '2-tuple is expected')
 * 
 *                         infos = await self.getaddrinfo(             # <<<<<<<<<<<<<<
 *                             *addr[:2], family=family, type=uv.SOCK_DGRAM,
 *                             proto=proto, flags=flags)
 */
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2841, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_10);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XGOTREF(__pyx_r);
          if (likely(__pyx_r)) {
            __Pyx_XGIVEREF(__pyx_t_5);
            __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
            __pyx_cur_scope->__pyx_t_1 = __pyx_t_7;
            __Pyx_XGIVEREF(__pyx_r);
            __Pyx_RefNannyFinishContext();
            __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
            /* return from generator, awaiting value */
            __pyx_generator->resume_label = 1;
            return __pyx_r;
            __pyx_L29_resume_from_await:;
            __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
            __pyx_cur_scope->__pyx_t_0 = 0;
            __Pyx_XGOTREF(__pyx_t_5);
            __pyx_t_7 = __pyx_cur_scope->__pyx_t_1;
            if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2841, __pyx_L1_error)
            __pyx_t_10 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_10);
          } else {
            __pyx_t_10 = NULL;
            if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_10) < 0) __PYX_ERR(2, 2841, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
          }
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_infos);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_infos, __pyx_t_10);
          __Pyx_GIVEREF(__pyx_t_10);
          __pyx_t_10 = 0;

          /* "uvloop/loop.pyx":2845
 *                             proto=proto, flags=flags)
 * 
 *                         if not infos:             # <<<<<<<<<<<<<<
 *                             raise OSError('getaddrinfo() returned empty list')
 * 
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_infos); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2845, __pyx_L1_error)
          __pyx_t_8 = ((!__pyx_t_1) != 0);
          if (unlikely(__pyx_t_8)) {

            /* "uvloop/loop.pyx":2846
 * 
 *                         if not infos:
 *                             raise OSError('getaddrinfo() returned empty list')             # <<<<<<<<<<<<<<
 * 
 *                         for fam, _, pro, _, address in infos:
 */
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2846, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_Raise(__pyx_t_10, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __PYX_ERR(2, 2846, __pyx_L1_error)

            /* "uvloop/loop.pyx":2845
 *                             proto=proto, flags=flags)
 * 
 *                         if not infos:             # <<<<<<<<<<<<<<
 *                             raise OSError('getaddrinfo() returned empty list')
 * 
 */
          }

          /* "uvloop/loop.pyx":2848
 *                             raise OSError('getaddrinfo() returned empty list')
 * 
 *                         for fam, _, pro, _, address in infos:             # <<<<<<<<<<<<<<
 *                             key = (fam, pro)
 *                             if key not in addr_infos:
 */
          if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_infos)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_infos)) {
            __pyx_t_10 = __pyx_cur_scope->__pyx_v_infos; __Pyx_INCREF(__pyx_t_10); __pyx_t_9 = 0;
            __pyx_t_11 = NULL;
          } else {
            __pyx_t_9 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_infos); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2848, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_11 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2848, __pyx_L1_error)
          }
          for (;;) {
            if (likely(!__pyx_t_11)) {
              if (likely(PyList_CheckExact(__pyx_t_10))) {
                if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_10)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_6 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_9); __Pyx_INCREF(__pyx_t_6); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(2, 2848, __pyx_L1_error)
                #else
                __pyx_t_6 = PySequence_ITEM(__pyx_t_10, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2848, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_6);
                #endif
              } else {
                if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_9); __Pyx_INCREF(__pyx_t_6); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(2, 2848, __pyx_L1_error)
                #else
                __pyx_t_6 = PySequence_ITEM(__pyx_t_10, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2848, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_6);
                #endif
              }
            } else {
              __pyx_t_6 = __pyx_t_11(__pyx_t_10);
              if (unlikely(!__pyx_t_6)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(2, 2848, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_6);
            }
            if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
              PyObject* sequence = __pyx_t_6;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 5)) {
                if (size > 5) __Pyx_RaiseTooManyValuesError(5);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(2, 2848, __pyx_L1_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
                __pyx_t_12 = PyTuple_GET_ITEM(sequence, 2); 
                __pyx_t_13 = PyTuple_GET_ITEM(sequence, 3); 
                __pyx_t_14 = PyTuple_GET_ITEM(sequence, 4); 
              } else {
                __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
                __pyx_t_12 = PyList_GET_ITEM(sequence, 2); 
                __pyx_t_13 = PyList_GET_ITEM(sequence, 3); 
                __pyx_t_14 = PyList_GET_ITEM(sequence, 4); 
              }
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_14);
              #else
              {
                Py_ssize_t i;
                PyObject** temps[5] = {&__pyx_t_4,&__pyx_t_3,&__pyx_t_12,&__pyx_t_13,&__pyx_t_14};
                for (i=0; i < 5; i++) {
                  PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(2, 2848, __pyx_L1_error)
                  __Pyx_GOTREF(item);
                  *(temps[i]) = item;
                }
              }
              #endif
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else {
              Py_ssize_t index = -1;
              PyObject** temps[5] = {&__pyx_t_4,&__pyx_t_3,&__pyx_t_12,&__pyx_t_13,&__pyx_t_14};
              __pyx_t_15 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(2, 2848, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              __pyx_t_16 = Py_TYPE(__pyx_t_15)->tp_iternext;
              for (index=0; index < 5; index++) {
                PyObject* item = __pyx_t_16(__pyx_t_15); if (unlikely(!item)) goto __pyx_L33_unpacking_failed;
                __Pyx_GOTREF(item);
                *(temps[index]) = item;
              }
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_15), 5) < 0) __PYX_ERR(2, 2848, __pyx_L1_error)
              __pyx_t_16 = NULL;
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              goto __pyx_L34_unpacking_done;
              __pyx_L33_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              __pyx_t_16 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(2, 2848, __pyx_L1_error)
              __pyx_L34_unpacking_done:;
            }
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_fam);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_fam, __pyx_t_4);
            __Pyx_GIVEREF(__pyx_t_4);
            __pyx_t_4 = 0;
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v__);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v__, __pyx_t_3);
            __Pyx_GIVEREF(__pyx_t_3);
            __pyx_t_3 = 0;
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_pro);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_pro, __pyx_t_12);
            __Pyx_GIVEREF(__pyx_t_12);
            __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_cur_scope->__pyx_v__);
            __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v__, __pyx_t_13);
            __Pyx_GIVEREF(__pyx_t_13);
            __pyx_t_13 = 0;
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_address);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_address, __pyx_t_14);
            __Pyx_GIVEREF(__pyx_t_14);
            __pyx_t_14 = 0;

            /* "uvloop/loop.pyx":2849
 * 
 *                         for fam, _, pro, _, address in infos:
 *                             key = (fam, pro)             # <<<<<<<<<<<<<<
 *                             if key not in addr_infos:
 *                                 addr_infos[key] = [None, None]
 */
            __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2849, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_fam);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_fam);
            PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_cur_scope->__pyx_v_fam);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_pro);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_pro);
            PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_cur_scope->__pyx_v_pro);
            __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_key);
            __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_key, ((PyObject*)__pyx_t_6));
            __Pyx_GIVEREF(__pyx_t_6);
            __pyx_t_6 = 0;

            /* "uvloop/loop.pyx":2850
 *                         for fam, _, pro, _, address in infos:
 *                             key = (fam, pro)
 *                             if key not in addr_infos:             # <<<<<<<<<<<<<<
 *                                 addr_infos[key] = [None, None]
 *                             addr_infos[key][idx] = address
 */
            __pyx_t_8 = (__Pyx_PySequence_ContainsTF(__pyx_cur_scope->__pyx_v_key, __pyx_cur_scope->__pyx_v_addr_infos, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(2, 2850, __pyx_L1_error)
            __pyx_t_1 = (__pyx_t_8 != 0);
            if (__pyx_t_1) {

              /* "uvloop/loop.pyx":2851
 *                             key = (fam, pro)
 *                             if key not in addr_infos:
 *                                 addr_infos[key] = [None, None]             # <<<<<<<<<<<<<<
 *                             addr_infos[key][idx] = address
 * 
 */
              __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2851, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_INCREF(Py_None);
              __Pyx_GIVEREF(Py_None);
              PyList_SET_ITEM(__pyx_t_6, 0, Py_None);
              __Pyx_INCREF(Py_None);
              __Pyx_GIVEREF(Py_None);
              PyList_SET_ITEM(__pyx_t_6, 1, Py_None);
              if (unlikely(PyObject_SetItem(__pyx_cur_scope->__pyx_v_addr_infos, __pyx_cur_scope->__pyx_v_key, __pyx_t_6) < 0)) __PYX_ERR(2, 2851, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

              /* "uvloop/loop.pyx":2850
 *                         for fam, _, pro, _, address in infos:
 *                             key = (fam, pro)
 *                             if key not in addr_infos:             # <<<<<<<<<<<<<<
 *                                 addr_infos[key] = [None, None]
 *                             addr_infos[key][idx] = address
 */
            }

            /* "uvloop/loop.pyx":2852
 *                             if key not in addr_infos:
 *                                 addr_infos[key] = [None, None]
 *                             addr_infos[key][idx] = address             # <<<<<<<<<<<<<<
 * 
 *                 # each addr has to have info for each (family, proto) pair
 */
            __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_cur_scope->__pyx_v_addr_infos, __pyx_cur_scope->__pyx_v_key); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2852, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            if (unlikely(PyObject_SetItem(__pyx_t_6, __pyx_cur_scope->__pyx_v_idx, __pyx_cur_scope->__pyx_v_address) < 0)) __PYX_ERR(2, 2852, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "uvloop/loop.pyx":2848
 *                             raise OSError('getaddrinfo() returned empty list')
 * 
 *                         for fam, _, pro, _, address in infos:             # <<<<<<<<<<<<<<
 *                             key = (fam, pro)
 *                             if key not in addr_infos:
 */
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "uvloop/loop.pyx":2837
 *                 addr_infos = col_OrderedDict()
 *                 for idx, addr in ((0, local_addr), (1, remote_addr)):
 *                     if addr is not None:             # <<<<<<<<<<<<<<
 *                         assert isinstance(addr, tuple) and len(addr) == 2, (
 *                             '2-tuple is expected')
 */
        }

        /* "uvloop/loop.pyx":2836
 *                 # join address by (family, protocol)
 *                 addr_infos = col_OrderedDict()
 *                 for idx, addr in ((0, local_addr), (1, remote_addr)):             # <<<<<<<<<<<<<<
 *                     if addr is not None:
 *                         assert isinstance(addr, tuple) and len(addr) == 2, (
 */
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":2855
 * 
 *                 # each addr has to have info for each (family, proto) pair
 *                 addr_pairs_info = [             # <<<<<<<<<<<<<<
 *                     (key, addr_pair) for key, addr_pair in addr_infos.items()
 *                     if not ((local_addr and addr_pair[0] is None) or
 */
      { /* enter inner scope */
        __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2855, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);

        /* "uvloop/loop.pyx":2856
 *                 # each addr has to have info for each (family, proto) pair
 *                 addr_pairs_info = [
 *                     (key, addr_pair) for key, addr_pair in addr_infos.items()             # <<<<<<<<<<<<<<
 *                     if not ((local_addr and addr_pair[0] is None) or
 *                             (remote_addr and addr_pair[1] is None))]
 */
        __pyx_t_7 = 0;
        if (unlikely(__pyx_cur_scope->__pyx_v_addr_infos == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "items");
          __PYX_ERR(2, 2856, __pyx_L1_error)
        }
        __pyx_t_6 = __Pyx_dict_iterator(__pyx_cur_scope->__pyx_v_addr_infos, 0, __pyx_n_s_items, (&__pyx_t_9), (&__pyx_t_17)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2856, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_10);
        __pyx_t_10 = __pyx_t_6;
        __pyx_t_6 = 0;
        while (1) {
          __pyx_t_18 = __Pyx_dict_iter_next(__pyx_t_10, __pyx_t_9, &__pyx_t_7, &__pyx_t_6, &__pyx_t_14, NULL, __pyx_t_17);
          if (unlikely(__pyx_t_18 == 0)) break;
          if (unlikely(__pyx_t_18 == -1)) __PYX_ERR(2, 2856, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_key);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_key, __pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          __pyx_t_6 = 0;
          __Pyx_XGOTREF(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_addr_pair);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_addr_pair, __pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_14);
          __pyx_t_14 = 0;

          /* "uvloop/loop.pyx":2857
 *                 addr_pairs_info = [
 *                     (key, addr_pair) for key, addr_pair in addr_infos.items()
 *                     if not ((local_addr and addr_pair[0] is None) or             # <<<<<<<<<<<<<<
 *                             (remote_addr and addr_pair[1] is None))]
 * 
 */
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_local_addr); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(2, 2857, __pyx_L1_error)
          if (!__pyx_t_8) {
            goto __pyx_L40_next_or;
          } else {
          }
          __pyx_t_14 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_addr_pair, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 2857, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_8 = (__pyx_t_14 == Py_None);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_2 = (__pyx_t_8 != 0);
          if (!__pyx_t_2) {
          } else {
            __pyx_t_1 = __pyx_t_2;
            goto __pyx_L39_bool_binop_done;
          }
          __pyx_L40_next_or:;

          /* "uvloop/loop.pyx":2858
 *                     (key, addr_pair) for key, addr_pair in addr_infos.items()
 *                     if not ((local_addr and addr_pair[0] is None) or
 *                             (remote_addr and addr_pair[1] is None))]             # <<<<<<<<<<<<<<
 * 
 *                 if not addr_pairs_info:
 */
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_remote_addr); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 2858, __pyx_L1_error)
          if (__pyx_t_2) {
          } else {
            __pyx_t_1 = __pyx_t_2;
            goto __pyx_L39_bool_binop_done;
          }
          __pyx_t_14 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_addr_pair, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 2858, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_2 = (__pyx_t_14 == Py_None);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_8 = (__pyx_t_2 != 0);
          __pyx_t_1 = __pyx_t_8;
          __pyx_L39_bool_binop_done:;

          /* "uvloop/loop.pyx":2857
 *                 addr_pairs_info = [
 *                     (key, addr_pair) for key, addr_pair in addr_infos.items()
 *                     if not ((local_addr and addr_pair[0] is None) or             # <<<<<<<<<<<<<<
 *                             (remote_addr and addr_pair[1] is None))]
 * 
 */
          __pyx_t_8 = ((!__pyx_t_1) != 0);
          if (__pyx_t_8) {

            /* "uvloop/loop.pyx":2856
 *                 # each addr has to have info for each (family, proto) pair
 *                 addr_pairs_info = [
 *                     (key, addr_pair) for key, addr_pair in addr_infos.items()             # <<<<<<<<<<<<<<
 *                     if not ((local_addr and addr_pair[0] is None) or
 *                             (remote_addr and addr_pair[1] is None))]
 */
            __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 2856, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_key);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_key);
            PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_cur_scope->__pyx_8genexpr4__pyx_v_key);
            __Pyx_INCREF(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_addr_pair);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_8genexpr4__pyx_v_addr_pair);
            PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_cur_scope->__pyx_8genexpr4__pyx_v_addr_pair);
            if (unlikely(__Pyx_ListComp_Append(__pyx_t_5, (PyObject*)__pyx_t_14))) __PYX_ERR(2, 2855, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

            /* "uvloop/loop.pyx":2857
 *                 addr_pairs_info = [
 *                     (key, addr_pair) for key, addr_pair in addr_infos.items()
 *                     if not ((local_addr and addr_pair[0] is None) or             # <<<<<<<<<<<<<<
 *                             (remote_addr and addr_pair[1] is None))]
 * 
 */
          }
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } /* exit inner scope */
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_cur_scope->__pyx_v_addr_pairs_info = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "uvloop/loop.pyx":2860
 *                             (remote_addr and addr_pair[1] is None))]
 * 
 *                 if not addr_pairs_info:             # <<<<<<<<<<<<<<
 *                     raise ValueError('can not get address information')
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_addr_pairs_info); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(2, 2860, __pyx_L1_error)
      __pyx_t_1 = ((!__pyx_t_8) != 0);
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/loop.pyx":2861
 * 
 *                 if not addr_pairs_info:
 *                     raise ValueError('can not get address information')             # <<<<<<<<<<<<<<
 * 
 *             exceptions = []
 */
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__121, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2861, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __PYX_ERR(2, 2861, __pyx_L1_error)

        /* "uvloop/loop.pyx":2860
 *                             (remote_addr and addr_pair[1] is None))]
 * 
 *                 if not addr_pairs_info:             # <<<<<<<<<<<<<<
 *                     raise ValueError('can not get address information')
 * 
 */
      }
    }
    __pyx_L15:;

    /* "uvloop/loop.pyx":2863
 *                     raise ValueError('can not get address information')
 * 
 *             exceptions = []             # <<<<<<<<<<<<<<
 *             for ((family, proto),
 *                  (local_address, remote_address)) in addr_pairs_info:
 */
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_cur_scope->__pyx_v_exceptions = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":2865
 *             exceptions = []
 *             for ((family, proto),
 *                  (local_address, remote_address)) in addr_pairs_info:             # <<<<<<<<<<<<<<
 *                 sock = None
 *                 r_addr = None
 */
    if (likely(PyList_CheckExact(__pyx_cur_scope->__pyx_v_addr_pairs_info)) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_addr_pairs_info)) {
      __pyx_t_5 = __pyx_cur_scope->__pyx_v_addr_pairs_info; __Pyx_INCREF(__pyx_t_5); __pyx_t_9 = 0;
      __pyx_t_11 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_addr_pairs_info); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2865, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(2, 2865, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_11)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_10 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_9); __Pyx_INCREF(__pyx_t_10); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(2, 2865, __pyx_L1_error)
          #else
          __pyx_t_10 = PySequence_ITEM(__pyx_t_5, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2865, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
        } else {
          if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_9); __Pyx_INCREF(__pyx_t_10); __pyx_t_9++; if (unlikely(0 < 0)) __PYX_ERR(2, 2865, __pyx_L1_error)
          #else
          __pyx_t_10 = PySequence_ITEM(__pyx_t_5, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2865, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
        }
      } else {
        __pyx_t_10 = __pyx_t_11(__pyx_t_5);
        if (unlikely(!__pyx_t_10)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(2, 2865, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_10);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_10))) || (PyList_CheckExact(__pyx_t_10))) {
        PyObject* sequence = __pyx_t_10;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(2, 2864, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_14 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_14 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_14 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 2864, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2864, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_13 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2864, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_16 = Py_TYPE(__pyx_t_13)->tp_iternext;
        index = 0; __pyx_t_14 = __pyx_t_16(__pyx_t_13); if (unlikely(!__pyx_t_14)) goto __pyx_L46_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_14);
        index = 1; __pyx_t_6 = __pyx_t_16(__pyx_t_13); if (unlikely(!__pyx_t_6)) goto __pyx_L46_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_13), 2) < 0) __PYX_ERR(2, 2864, __pyx_L1_error)
        __pyx_t_16 = NULL;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L47_unpacking_done;
        __pyx_L46_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_16 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(2, 2864, __pyx_L1_error)
        __pyx_L47_unpacking_done:;
      }

      /* "uvloop/loop.pyx":2864
 * 
 *             exceptions = []
 *             for ((family, proto),             # <<<<<<<<<<<<<<
 *                  (local_address, remote_address)) in addr_pairs_info:
 *                 sock = None
 */
      if ((likely(PyTuple_CheckExact(__pyx_t_14))) || (PyList_CheckExact(__pyx_t_14))) {
        PyObject* sequence = __pyx_t_14;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(2, 2864, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_13 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_13 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_12);
        #else
        __pyx_t_13 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2864, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_12 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2864, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_3 = PyObject_GetIter(__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2864, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_16 = Py_TYPE(__pyx_t_3)->tp_iternext;
        index = 0; __pyx_t_13 = __pyx_t_16(__pyx_t_3); if (unlikely(!__pyx_t_13)) goto __pyx_L48_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_13);
        index = 1; __pyx_t_12 = __pyx_t_16(__pyx_t_3); if (unlikely(!__pyx_t_12)) goto __pyx_L48_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_3), 2) < 0) __PYX_ERR(2, 2864, __pyx_L1_error)
        __pyx_t_16 = NULL;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L49_unpacking_done;
        __pyx_L48_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_16 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(2, 2864, __pyx_L1_error)
        __pyx_L49_unpacking_done:;
      }
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_family);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_family, __pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_13);
      __pyx_t_13 = 0;
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_proto);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_proto, __pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_12);
      __pyx_t_12 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(2, 2865, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_13 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_12 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_13 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_13);
        #else
        __pyx_t_12 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2865, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2865, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_3 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2865, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_16 = Py_TYPE(__pyx_t_3)->tp_iternext;
        index = 0; __pyx_t_12 = __pyx_t_16(__pyx_t_3); if (unlikely(!__pyx_t_12)) goto __pyx_L50_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        index = 1; __pyx_t_13 = __pyx_t_16(__pyx_t_3); if (unlikely(!__pyx_t_13)) goto __pyx_L50_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_13);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_3), 2) < 0) __PYX_ERR(2, 2865, __pyx_L1_error)
        __pyx_t_16 = NULL;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L51_unpacking_done;
        __pyx_L50_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_16 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(2, 2865, __pyx_L1_error)
        __pyx_L51_unpacking_done:;
      }

      /* "uvloop/loop.pyx":2865
 *             exceptions = []
 *             for ((family, proto),
 *                  (local_address, remote_address)) in addr_pairs_info:             # <<<<<<<<<<<<<<
 *                 sock = None
 *                 r_addr = None
 */
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_local_address);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_local_address, __pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_12);
      __pyx_t_12 = 0;
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_remote_address);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_remote_address, __pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_13);
      __pyx_t_13 = 0;

      /* "uvloop/loop.pyx":2866
 *             for ((family, proto),
 *                  (local_address, remote_address)) in addr_pairs_info:
 *                 sock = None             # <<<<<<<<<<<<<<
 *                 r_addr = None
 *                 try:
 */
      __Pyx_INCREF(Py_None);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_sock);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_sock, Py_None);
      __Pyx_GIVEREF(Py_None);

      /* "uvloop/loop.pyx":2867
 *                  (local_address, remote_address)) in addr_pairs_info:
 *                 sock = None
 *                 r_addr = None             # <<<<<<<<<<<<<<
 *                 try:
 *                     sock = socket_socket(
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_r_addr);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_r_addr, Py_None);
      __Pyx_GIVEREF(Py_None);

      /* "uvloop/loop.pyx":2868
 *                 sock = None
 *                 r_addr = None
 *                 try:             # <<<<<<<<<<<<<<
 *                     sock = socket_socket(
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)
 */
      {
        __Pyx_ExceptionSave(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_21);
        /*try:*/ {

          /* "uvloop/loop.pyx":2870
 *                 try:
 *                     sock = socket_socket(
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)             # <<<<<<<<<<<<<<
 *                     if reuse_address:
 *                         sock.setsockopt(
 */
          __pyx_t_10 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2870, __pyx_L52_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_family, __pyx_cur_scope->__pyx_v_family) < 0) __PYX_ERR(2, 2870, __pyx_L52_error)
          __pyx_t_6 = __Pyx_PyInt_From_int(SOCK_DGRAM); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2870, __pyx_L52_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_type, __pyx_t_6) < 0) __PYX_ERR(2, 2870, __pyx_L52_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_proto, __pyx_cur_scope->__pyx_v_proto) < 0) __PYX_ERR(2, 2870, __pyx_L52_error)

          /* "uvloop/loop.pyx":2869
 *                 r_addr = None
 *                 try:
 *                     sock = socket_socket(             # <<<<<<<<<<<<<<
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)
 *                     if reuse_address:
 */
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_socket_socket, __pyx_empty_tuple, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2869, __pyx_L52_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_sock);
          __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_sock, __pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          __pyx_t_6 = 0;

          /* "uvloop/loop.pyx":2871
 *                     sock = socket_socket(
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)
 *                     if reuse_address:             # <<<<<<<<<<<<<<
 *                         sock.setsockopt(
 *                             uv.SOL_SOCKET, uv.SO_REUSEADDR, 1)
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_reuse_address); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2871, __pyx_L52_error)
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":2872
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)
 *                     if reuse_address:
 *                         sock.setsockopt(             # <<<<<<<<<<<<<<
 *                             uv.SOL_SOCKET, uv.SO_REUSEADDR, 1)
 *                     if reuse_port:
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setsockopt); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2872, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_10);

            /* "uvloop/loop.pyx":2873
 *                     if reuse_address:
 *                         sock.setsockopt(
 *                             uv.SOL_SOCKET, uv.SO_REUSEADDR, 1)             # <<<<<<<<<<<<<<
 *                     if reuse_port:
 *                         self._sock_set_reuseport(sock.fileno())
 */
            __pyx_t_14 = __Pyx_PyInt_From_int(SOL_SOCKET); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 2873, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_13 = __Pyx_PyInt_From_int(SO_REUSEADDR); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2873, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_12 = NULL;
            __pyx_t_17 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
                __pyx_t_17 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_t_14, __pyx_t_13, __pyx_int_1};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_17, 3+__pyx_t_17); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2872, __pyx_L52_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_t_14, __pyx_t_13, __pyx_int_1};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_17, 3+__pyx_t_17); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2872, __pyx_L52_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            } else
            #endif
            {
              __pyx_t_3 = PyTuple_New(3+__pyx_t_17); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2872, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_3);
              if (__pyx_t_12) {
                __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_12); __pyx_t_12 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_14);
              PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_17, __pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_13);
              PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_17, __pyx_t_13);
              __Pyx_INCREF(__pyx_int_1);
              __Pyx_GIVEREF(__pyx_int_1);
              PyTuple_SET_ITEM(__pyx_t_3, 2+__pyx_t_17, __pyx_int_1);
              __pyx_t_14 = 0;
              __pyx_t_13 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2872, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "uvloop/loop.pyx":2871
 *                     sock = socket_socket(
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)
 *                     if reuse_address:             # <<<<<<<<<<<<<<
 *                         sock.setsockopt(
 *                             uv.SOL_SOCKET, uv.SO_REUSEADDR, 1)
 */
          }

          /* "uvloop/loop.pyx":2874
 *                         sock.setsockopt(
 *                             uv.SOL_SOCKET, uv.SO_REUSEADDR, 1)
 *                     if reuse_port:             # <<<<<<<<<<<<<<
 *                         self._sock_set_reuseport(sock.fileno())
 *                     if allow_broadcast:
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_reuse_port); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2874, __pyx_L52_error)
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":2875
 *                             uv.SOL_SOCKET, uv.SO_REUSEADDR, 1)
 *                     if reuse_port:
 *                         self._sock_set_reuseport(sock.fileno())             # <<<<<<<<<<<<<<
 *                     if allow_broadcast:
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2875, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_3 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_3)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
              }
            }
            if (__pyx_t_3) {
              __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2875, __pyx_L52_error)
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            } else {
              __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2875, __pyx_L52_error)
            }
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_t_17 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2875, __pyx_L52_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_cur_scope->__pyx_v_self->__pyx_vtab)->_sock_set_reuseport(__pyx_cur_scope->__pyx_v_self, __pyx_t_17); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2875, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "uvloop/loop.pyx":2874
 *                         sock.setsockopt(
 *                             uv.SOL_SOCKET, uv.SO_REUSEADDR, 1)
 *                     if reuse_port:             # <<<<<<<<<<<<<<
 *                         self._sock_set_reuseport(sock.fileno())
 *                     if allow_broadcast:
 */
          }

          /* "uvloop/loop.pyx":2876
 *                     if reuse_port:
 *                         self._sock_set_reuseport(sock.fileno())
 *                     if allow_broadcast:             # <<<<<<<<<<<<<<
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)
 *                     sock.setblocking(False)
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_allow_broadcast); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2876, __pyx_L52_error)
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":2877
 *                         self._sock_set_reuseport(sock.fileno())
 *                     if allow_broadcast:
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)             # <<<<<<<<<<<<<<
 *                     sock.setblocking(False)
 *                     if local_addr:
 */
            __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setsockopt); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2877, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_3 = __Pyx_PyInt_From_int(SOL_SOCKET); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2877, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_SO_BROADCAST); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2877, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_14 = NULL;
            __pyx_t_17 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
              __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_10);
              if (likely(__pyx_t_14)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                __Pyx_INCREF(__pyx_t_14);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_10, function);
                __pyx_t_17 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_14, __pyx_t_3, __pyx_t_13, __pyx_int_1};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_17, 3+__pyx_t_17); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2877, __pyx_L52_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[4] = {__pyx_t_14, __pyx_t_3, __pyx_t_13, __pyx_int_1};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_17, 3+__pyx_t_17); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2877, __pyx_L52_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(3+__pyx_t_17); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2877, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_12);
              if (__pyx_t_14) {
                __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_14); __pyx_t_14 = NULL;
              }
              __Pyx_GIVEREF(__pyx_t_3);
              PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_17, __pyx_t_3);
              __Pyx_GIVEREF(__pyx_t_13);
              PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_17, __pyx_t_13);
              __Pyx_INCREF(__pyx_int_1);
              __Pyx_GIVEREF(__pyx_int_1);
              PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_17, __pyx_int_1);
              __pyx_t_3 = 0;
              __pyx_t_13 = 0;
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2877, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "uvloop/loop.pyx":2876
 *                     if reuse_port:
 *                         self._sock_set_reuseport(sock.fileno())
 *                     if allow_broadcast:             # <<<<<<<<<<<<<<
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)
 *                     sock.setblocking(False)
 */
          }

          /* "uvloop/loop.pyx":2878
 *                     if allow_broadcast:
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)
 *                     sock.setblocking(False)             # <<<<<<<<<<<<<<
 *                     if local_addr:
 *                         sock.bind(local_address)
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_setblocking); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2878, __pyx_L52_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__122, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2878, __pyx_L52_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "uvloop/loop.pyx":2879
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)
 *                     sock.setblocking(False)
 *                     if local_addr:             # <<<<<<<<<<<<<<
 *                         sock.bind(local_address)
 *                     if remote_addr:
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_local_addr); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2879, __pyx_L52_error)
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":2880
 *                     sock.setblocking(False)
 *                     if local_addr:
 *                         sock.bind(local_address)             # <<<<<<<<<<<<<<
 *                     if remote_addr:
 *                         await self.sock_connect(sock, remote_address)
 */
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_bind); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2880, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_12 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_6, function);
              }
            }
            if (!__pyx_t_12) {
              __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_cur_scope->__pyx_v_local_address); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2880, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_10);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_6)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_cur_scope->__pyx_v_local_address};
                __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2880, __pyx_L52_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_10);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_cur_scope->__pyx_v_local_address};
                __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2880, __pyx_L52_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_10);
              } else
              #endif
              {
                __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2880, __pyx_L52_error)
                __Pyx_GOTREF(__pyx_t_13);
                __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
                __Pyx_INCREF(__pyx_cur_scope->__pyx_v_local_address);
                __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_local_address);
                PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_cur_scope->__pyx_v_local_address);
                __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2880, __pyx_L52_error)
                __Pyx_GOTREF(__pyx_t_10);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "uvloop/loop.pyx":2879
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)
 *                     sock.setblocking(False)
 *                     if local_addr:             # <<<<<<<<<<<<<<
 *                         sock.bind(local_address)
 *                     if remote_addr:
 */
          }

          /* "uvloop/loop.pyx":2881
 *                     if local_addr:
 *                         sock.bind(local_address)
 *                     if remote_addr:             # <<<<<<<<<<<<<<
 *                         await self.sock_connect(sock, remote_address)
 *                         r_addr = remote_address
 */
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_remote_addr); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(2, 2881, __pyx_L52_error)
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":2882
 *                         sock.bind(local_address)
 *                     if remote_addr:
 *                         await self.sock_connect(sock, remote_address)             # <<<<<<<<<<<<<<
 *                         r_addr = remote_address
 *                 except OSError as exc:
 */
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_sock_connect); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2882, __pyx_L52_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_13 = NULL;
            __pyx_t_17 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
              __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_6);
              if (likely(__pyx_t_13)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_6, function);
                __pyx_t_17 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_remote_address};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_17, 2+__pyx_t_17); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2882, __pyx_L52_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_10);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_remote_address};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_17, 2+__pyx_t_17); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2882, __pyx_L52_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_10);
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(2+__pyx_t_17); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2882, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_12);
              if (__pyx_t_13) {
                __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_13); __pyx_t_13 = NULL;
              }
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_sock);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_sock);
              PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_17, __pyx_cur_scope->__pyx_v_sock);
              __Pyx_INCREF(__pyx_cur_scope->__pyx_v_remote_address);
              __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_remote_address);
              PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_17, __pyx_cur_scope->__pyx_v_remote_address);
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_12, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2882, __pyx_L52_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_t_10);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XGOTREF(__pyx_r);
            if (likely(__pyx_r)) {
              __Pyx_XGIVEREF(__pyx_t_5);
              __pyx_cur_scope->__pyx_t_0 = __pyx_t_5;
              __pyx_cur_scope->__pyx_t_1 = __pyx_t_9;
              __pyx_cur_scope->__pyx_t_2 = __pyx_t_11;
              __Pyx_XGIVEREF(__pyx_t_19);
              __pyx_cur_scope->__pyx_t_3 = __pyx_t_19;
              __Pyx_XGIVEREF(__pyx_t_20);
              __pyx_cur_scope->__pyx_t_4 = __pyx_t_20;
              __Pyx_XGIVEREF(__pyx_t_21);
              __pyx_cur_scope->__pyx_t_5 = __pyx_t_21;
              __Pyx_XGIVEREF(__pyx_r);
              __Pyx_RefNannyFinishContext();
              __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
              /* return from generator, awaiting value */
              __pyx_generator->resume_label = 2;
              return __pyx_r;
              __pyx_L65_resume_from_await:;
              __pyx_t_5 = __pyx_cur_scope->__pyx_t_0;
              __pyx_cur_scope->__pyx_t_0 = 0;
              __Pyx_XGOTREF(__pyx_t_5);
              __pyx_t_9 = __pyx_cur_scope->__pyx_t_1;
              __pyx_t_11 = __pyx_cur_scope->__pyx_t_2;
              __pyx_t_19 = __pyx_cur_scope->__pyx_t_3;
              __pyx_cur_scope->__pyx_t_3 = 0;
              __Pyx_XGOTREF(__pyx_t_19);
              __pyx_t_20 = __pyx_cur_scope->__pyx_t_4;
              __pyx_cur_scope->__pyx_t_4 = 0;
              __Pyx_XGOTREF(__pyx_t_20);
              __pyx_t_21 = __pyx_cur_scope->__pyx_t_5;
              __pyx_cur_scope->__pyx_t_5 = 0;
              __Pyx_XGOTREF(__pyx_t_21);
              if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2882, __pyx_L52_error)
            } else {
              PyObject* exc_type = __Pyx_PyErr_Occurred();
              if (exc_type) {
                if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
                else __PYX_ERR(2, 2882, __pyx_L52_error)
              }
            }

            /* "uvloop/loop.pyx":2883
 *                     if remote_addr:
 *                         await self.sock_connect(sock, remote_address)
 *                         r_addr = remote_address             # <<<<<<<<<<<<<<
 *                 except OSError as exc:
 *                     if sock is not None:
 */
            __Pyx_INCREF(__pyx_cur_scope->__pyx_v_remote_address);
            __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_r_addr);
            __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_r_addr, __pyx_cur_scope->__pyx_v_remote_address);
            __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_remote_address);

            /* "uvloop/loop.pyx":2881
 *                     if local_addr:
 *                         sock.bind(local_address)
 *                     if remote_addr:             # <<<<<<<<<<<<<<
 *                         await self.sock_connect(sock, remote_address)
 *                         r_addr = remote_address
 */
          }

          /* "uvloop/loop.pyx":2868
 *                 sock = None
 *                 r_addr = None
 *                 try:             # <<<<<<<<<<<<<<
 *                     sock = socket_socket(
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)
 */
        }

        /* "uvloop/loop.pyx":2893
 *                     raise
 *                 else:
 *                     break             # <<<<<<<<<<<<<<
 *             else:
 *                 raise exceptions[0]
 */
        /*else:*/ {
          goto __pyx_L57_try_break;
        }
        __pyx_L52_error:;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "uvloop/loop.pyx":2884
 *                         await self.sock_connect(sock, remote_address)
 *                         r_addr = remote_address
 *                 except OSError as exc:             # <<<<<<<<<<<<<<
 *                     if sock is not None:
 *                         sock.close()
 */
        __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
        if (__pyx_t_17) {
          __Pyx_AddTraceback("uvloop.loop.Loop.create_datagram_endpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_10, &__pyx_t_6, &__pyx_t_12) < 0) __PYX_ERR(2, 2884, __pyx_L54_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_6);
          __pyx_cur_scope->__pyx_v_exc = __pyx_t_6;
          /*try:*/ {

            /* "uvloop/loop.pyx":2885
 *                         r_addr = remote_address
 *                 except OSError as exc:
 *                     if sock is not None:             # <<<<<<<<<<<<<<
 *                         sock.close()
 *                     exceptions.append(exc)
 */
            __pyx_t_1 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
            __pyx_t_8 = (__pyx_t_1 != 0);
            if (__pyx_t_8) {

              /* "uvloop/loop.pyx":2886
 *                 except OSError as exc:
 *                     if sock is not None:
 *                         sock.close()             # <<<<<<<<<<<<<<
 *                     exceptions.append(exc)
 *                 except Exception:
 */
              __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2886, __pyx_L71_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_14 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
                __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_3);
                if (likely(__pyx_t_14)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                  __Pyx_INCREF(__pyx_t_14);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_3, function);
                }
              }
              if (__pyx_t_14) {
                __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2886, __pyx_L71_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              } else {
                __pyx_t_13 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2886, __pyx_L71_error)
              }
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

              /* "uvloop/loop.pyx":2885
 *                         r_addr = remote_address
 *                 except OSError as exc:
 *                     if sock is not None:             # <<<<<<<<<<<<<<
 *                         sock.close()
 *                     exceptions.append(exc)
 */
            }

            /* "uvloop/loop.pyx":2887
 *                     if sock is not None:
 *                         sock.close()
 *                     exceptions.append(exc)             # <<<<<<<<<<<<<<
 *                 except Exception:
 *                     if sock is not None:
 */
            __pyx_t_22 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_exceptions, __pyx_cur_scope->__pyx_v_exc); if (unlikely(__pyx_t_22 == ((int)-1))) __PYX_ERR(2, 2887, __pyx_L71_error)
          }

          /* "uvloop/loop.pyx":2884
 *                         await self.sock_connect(sock, remote_address)
 *                         r_addr = remote_address
 *                 except OSError as exc:             # <<<<<<<<<<<<<<
 *                     if sock is not None:
 *                         sock.close()
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
              __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
              __pyx_cur_scope->__pyx_v_exc = NULL;
              goto __pyx_L72;
            }
            __pyx_L71_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_assign
              __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0;
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_27, &__pyx_t_28, &__pyx_t_29);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_24, &__pyx_t_25, &__pyx_t_26) < 0)) __Pyx_ErrFetch(&__pyx_t_24, &__pyx_t_25, &__pyx_t_26);
              __Pyx_XGOTREF(__pyx_t_24);
              __Pyx_XGOTREF(__pyx_t_25);
              __Pyx_XGOTREF(__pyx_t_26);
              __Pyx_XGOTREF(__pyx_t_27);
              __Pyx_XGOTREF(__pyx_t_28);
              __Pyx_XGOTREF(__pyx_t_29);
              __pyx_t_17 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_23 = __pyx_filename;
              {
                __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_exc);
                __Pyx_DECREF(__pyx_cur_scope->__pyx_v_exc);
                __pyx_cur_scope->__pyx_v_exc = NULL;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_27);
                __Pyx_XGIVEREF(__pyx_t_28);
                __Pyx_XGIVEREF(__pyx_t_29);
                __Pyx_ExceptionReset(__pyx_t_27, __pyx_t_28, __pyx_t_29);
              }
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_25);
              __Pyx_XGIVEREF(__pyx_t_26);
              __Pyx_ErrRestore(__pyx_t_24, __pyx_t_25, __pyx_t_26);
              __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0;
              __pyx_lineno = __pyx_t_17; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_23;
              goto __pyx_L54_except_error;
            }
            __pyx_L72:;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          goto __pyx_L53_exception_handled;
        }

        /* "uvloop/loop.pyx":2888
 *                         sock.close()
 *                     exceptions.append(exc)
 *                 except Exception:             # <<<<<<<<<<<<<<
 *                     if sock is not None:
 *                         sock.close()
 */
        __pyx_t_18 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
        if (__pyx_t_18) {
          __Pyx_AddTraceback("uvloop.loop.Loop.create_datagram_endpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_6, &__pyx_t_10) < 0) __PYX_ERR(2, 2888, __pyx_L54_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GOTREF(__pyx_t_10);

          /* "uvloop/loop.pyx":2889
 *                     exceptions.append(exc)
 *                 except Exception:
 *                     if sock is not None:             # <<<<<<<<<<<<<<
 *                         sock.close()
 *                     raise
 */
          __pyx_t_8 = (__pyx_cur_scope->__pyx_v_sock != Py_None);
          __pyx_t_1 = (__pyx_t_8 != 0);
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":2890
 *                 except Exception:
 *                     if sock is not None:
 *                         sock.close()             # <<<<<<<<<<<<<<
 *                     raise
 *                 else:
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_sock, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2890, __pyx_L54_except_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_14 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_14)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_14);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
              }
            }
            if (__pyx_t_14) {
              __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2890, __pyx_L54_except_error)
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            } else {
              __pyx_t_13 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2890, __pyx_L54_except_error)
            }
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

            /* "uvloop/loop.pyx":2889
 *                     exceptions.append(exc)
 *                 except Exception:
 *                     if sock is not None:             # <<<<<<<<<<<<<<
 *                         sock.close()
 *                     raise
 */
          }

          /* "uvloop/loop.pyx":2891
 *                     if sock is not None:
 *                         sock.close()
 *                     raise             # <<<<<<<<<<<<<<
 *                 else:
 *                     break
 */
          __Pyx_GIVEREF(__pyx_t_12);
          __Pyx_GIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestoreWithState(__pyx_t_12, __pyx_t_6, __pyx_t_10);
          __pyx_t_12 = 0; __pyx_t_6 = 0; __pyx_t_10 = 0; 
          __PYX_ERR(2, 2891, __pyx_L54_except_error)
        }
        goto __pyx_L54_except_error;
        __pyx_L54_except_error:;

        /* "uvloop/loop.pyx":2868
 *                 sock = None
 *                 r_addr = None
 *                 try:             # <<<<<<<<<<<<<<
 *                     sock = socket_socket(
 *                         family=family, type=uv.SOCK_DGRAM, proto=proto)
 */
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
        goto __pyx_L1_error;
        __pyx_L57_try_break:;
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
        goto __pyx_L45_break;
        __pyx_L53_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
      }

      /* "uvloop/loop.pyx":2864
 * 
 *             exceptions = []
 *             for ((family, proto),             # <<<<<<<<<<<<<<
 *                  (local_address, remote_address)) in addr_pairs_info:
 *                 sock = None
 */
    }
    /*else*/ {

      /* "uvloop/loop.pyx":2895
 *                     break
 *             else:
 *                 raise exceptions[0]             # <<<<<<<<<<<<<<
 * 
 *             udp = UDPTransport.new(self, sock, r_addr)
 */
      __pyx_t_10 = __Pyx_GetItemInt_List(__pyx_cur_scope->__pyx_v_exceptions, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2895, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_Raise(__pyx_t_10, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(2, 2895, __pyx_L1_error)
    }

    /* "uvloop/loop.pyx":2864
 * 
 *             exceptions = []
 *             for ((family, proto),             # <<<<<<<<<<<<<<
 *                  (local_address, remote_address)) in addr_pairs_info:
 *                 sock = None
 */
    __pyx_L45_break:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":2897
 *                 raise exceptions[0]
 * 
 *             udp = UDPTransport.new(self, sock, r_addr)             # <<<<<<<<<<<<<<
 * 
 *         protocol = protocol_factory()
 */
    __pyx_t_5 = ((PyObject *)__pyx_f_6uvloop_4loop_12UDPTransport_new(__pyx_cur_scope->__pyx_v_self, __pyx_cur_scope->__pyx_v_sock, __pyx_cur_scope->__pyx_v_r_addr)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GOTREF(((PyObject *)__pyx_cur_scope->__pyx_v_udp));
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_udp, ((struct __pyx_obj_6uvloop_4loop_UDPTransport *)__pyx_t_5));
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
  }
  __pyx_L4:;

  /* "uvloop/loop.pyx":2899
 *             udp = UDPTransport.new(self, sock, r_addr)
 * 
 *         protocol = protocol_factory()             # <<<<<<<<<<<<<<
 *         waiter = self._new_future()
 *         assert udp is not None
 */
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol_factory);
  __pyx_t_10 = __pyx_cur_scope->__pyx_v_protocol_factory; __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2899, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2899, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_cur_scope->__pyx_v_protocol = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":2900
 * 
 *         protocol = protocol_factory()
 *         waiter = self._new_future()             # <<<<<<<<<<<<<<
 *         assert udp is not None
 *         udp._set_protocol(protocol)
 */
  __pyx_t_5 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2900, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_cur_scope->__pyx_v_waiter = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":2901
 *         protocol = protocol_factory()
 *         waiter = self._new_future()
 *         assert udp is not None             # <<<<<<<<<<<<<<
 *         udp._set_protocol(protocol)
 *         udp._set_waiter(waiter)
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_1 = (((PyObject *)__pyx_cur_scope->__pyx_v_udp) != Py_None);
    if (unlikely(!(__pyx_t_1 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(2, 2901, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/loop.pyx":2902
 *         waiter = self._new_future()
 *         assert udp is not None
 *         udp._set_protocol(protocol)             # <<<<<<<<<<<<<<
 *         udp._set_waiter(waiter)
 *         udp._init_protocol()
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_cur_scope->__pyx_v_udp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._set_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_udp), __pyx_cur_scope->__pyx_v_protocol); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":2903
 *         assert udp is not None
 *         udp._set_protocol(protocol)
 *         udp._set_waiter(waiter)             # <<<<<<<<<<<<<<
 *         udp._init_protocol()
 * 
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_cur_scope->__pyx_v_udp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._set_waiter(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_udp), __pyx_cur_scope->__pyx_v_waiter); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2903, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":2904
 *         udp._set_protocol(protocol)
 *         udp._set_waiter(waiter)
 *         udp._init_protocol()             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_cur_scope->__pyx_v_udp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_cur_scope->__pyx_v_udp)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2904, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":2906
 *         udp._init_protocol()
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
    __Pyx_XGOTREF(__pyx_t_21);
    __Pyx_XGOTREF(__pyx_t_20);
    __Pyx_XGOTREF(__pyx_t_19);
    /*try:*/ {

      /* "uvloop/loop.pyx":2907
 * 
 *         try:
 *             await waiter             # <<<<<<<<<<<<<<
 *         except Exception:
 *             udp.close()
 */
      __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
      __Pyx_XGOTREF(__pyx_r);
      if (likely(__pyx_r)) {
        __Pyx_XGIVEREF(__pyx_t_19);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_19;
        __Pyx_XGIVEREF(__pyx_t_20);
        __pyx_cur_scope->__pyx_t_3 = __pyx_t_20;
        __Pyx_XGIVEREF(__pyx_t_21);
        __pyx_cur_scope->__pyx_t_4 = __pyx_t_21;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, awaiting value */
        __pyx_generator->resume_label = 3;
        return __pyx_r;
        __pyx_L88_resume_from_await:;
        __pyx_t_19 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_19);
        __pyx_t_20 = __pyx_cur_scope->__pyx_t_3;
        __pyx_cur_scope->__pyx_t_3 = 0;
        __Pyx_XGOTREF(__pyx_t_20);
        __pyx_t_21 = __pyx_cur_scope->__pyx_t_4;
        __pyx_cur_scope->__pyx_t_4 = 0;
        __Pyx_XGOTREF(__pyx_t_21);
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2907, __pyx_L82_error)
      } else {
        PyObject* exc_type = __Pyx_PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
          else __PYX_ERR(2, 2907, __pyx_L82_error)
        }
      }

      /* "uvloop/loop.pyx":2906
 *         udp._init_protocol()
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
    __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
    goto __pyx_L87_try_end;
    __pyx_L82_error:;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":2908
 *         try:
 *             await waiter
 *         except Exception:             # <<<<<<<<<<<<<<
 *             udp.close()
 *             raise
 */
    __pyx_t_18 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_18) {
      __Pyx_AddTraceback("uvloop.loop.Loop.create_datagram_endpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_10, &__pyx_t_6) < 0) __PYX_ERR(2, 2908, __pyx_L84_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GOTREF(__pyx_t_6);

      /* "uvloop/loop.pyx":2909
 *             await waiter
 *         except Exception:
 *             udp.close()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_udp), __pyx_n_s_close); if (unlikely(!__pyx_t_13)) __PYX_ERR(2, 2909, __pyx_L84_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_13);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_13, function);
        }
      }
      if (__pyx_t_3) {
        __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2909, __pyx_L84_except_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __pyx_t_12 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2909, __pyx_L84_except_error)
      }
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "uvloop/loop.pyx":2910
 *         except Exception:
 *             udp.close()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         return udp, protocol
 */
      __Pyx_GIVEREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_10, __pyx_t_6);
      __pyx_t_5 = 0; __pyx_t_10 = 0; __pyx_t_6 = 0; 
      __PYX_ERR(2, 2910, __pyx_L84_except_error)
    }
    goto __pyx_L84_except_error;
    __pyx_L84_except_error:;

    /* "uvloop/loop.pyx":2906
 *         udp._init_protocol()
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             await waiter
 *         except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_21);
    __Pyx_XGIVEREF(__pyx_t_20);
    __Pyx_XGIVEREF(__pyx_t_19);
    __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
    goto __pyx_L1_error;
    __pyx_L87_try_end:;
  }

  /* "uvloop/loop.pyx":2912
 *             raise
 * 
 *         return udp, protocol             # <<<<<<<<<<<<<<
 * 
 *     def _asyncgen_finalizer_hook(self, agen):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_v_udp));
  __Pyx_GIVEREF(((PyObject *)__pyx_cur_scope->__pyx_v_udp));
  PyTuple_SET_ITEM(__pyx_t_6, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_udp));
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_protocol);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_protocol);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_cur_scope->__pyx_v_protocol);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2766
 * 
 *     @cython.iterable_coroutine
 *     async def create_datagram_endpoint(self, protocol_factory,             # <<<<<<<<<<<<<<
 *                                        local_addr=None, remote_addr=None, *,
 *                                        family=0, proto=0, flags=0,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("create_datagram_endpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2914
 *         return udp, protocol
 * 
 *     def _asyncgen_finalizer_hook(self, agen):             # <<<<<<<<<<<<<<
 *         self._asyncgens.discard(agen)
 *         if not self.is_closed():
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_128_asyncgen_finalizer_hook(PyObject *__pyx_v_self, PyObject *__pyx_v_agen); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_127_asyncgen_finalizer_hook[] = "Loop._asyncgen_finalizer_hook(self, agen)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_128_asyncgen_finalizer_hook(PyObject *__pyx_v_self, PyObject *__pyx_v_agen) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_asyncgen_finalizer_hook (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_127_asyncgen_finalizer_hook(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_agen));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_127_asyncgen_finalizer_hook(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_agen) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_asyncgen_finalizer_hook", 0);

  /* "uvloop/loop.pyx":2915
 * 
 *     def _asyncgen_finalizer_hook(self, agen):
 *         self._asyncgens.discard(agen)             # <<<<<<<<<<<<<<
 *         if not self.is_closed():
 *             self.create_task(agen.aclose())
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_asyncgens, __pyx_n_s_discard); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_agen); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_agen};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2915, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_agen};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2915, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2915, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_agen);
      __Pyx_GIVEREF(__pyx_v_agen);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_agen);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2915, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2916
 *     def _asyncgen_finalizer_hook(self, agen):
 *         self._asyncgens.discard(agen)
 *         if not self.is_closed():             # <<<<<<<<<<<<<<
 *             self.create_task(agen.aclose())
 *             # Wake up the loop if the finalizer was called from
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_is_closed); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2916, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2916, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(2, 2916, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = ((!__pyx_t_5) != 0);
  if (__pyx_t_6) {

    /* "uvloop/loop.pyx":2917
 *         self._asyncgens.discard(agen)
 *         if not self.is_closed():
 *             self.create_task(agen.aclose())             # <<<<<<<<<<<<<<
 *             # Wake up the loop if the finalizer was called from
 *             # a different thread.
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_create_task); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_agen, __pyx_n_s_aclose); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2917, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2917, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2917, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2917, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2917, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2917, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2917, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2920
 *             # Wake up the loop if the finalizer was called from
 *             # a different thread.
 *             self.handler_async.send()             # <<<<<<<<<<<<<<
 * 
 *     def _asyncgen_firstiter_hook(self, agen):
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->handler_async->__pyx_base.__pyx_vtab)->send(__pyx_v_self->handler_async); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2920, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2916
 *     def _asyncgen_finalizer_hook(self, agen):
 *         self._asyncgens.discard(agen)
 *         if not self.is_closed():             # <<<<<<<<<<<<<<
 *             self.create_task(agen.aclose())
 *             # Wake up the loop if the finalizer was called from
 */
  }

  /* "uvloop/loop.pyx":2914
 *         return udp, protocol
 * 
 *     def _asyncgen_finalizer_hook(self, agen):             # <<<<<<<<<<<<<<
 *         self._asyncgens.discard(agen)
 *         if not self.is_closed():
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.Loop._asyncgen_finalizer_hook", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2922
 *             self.handler_async.send()
 * 
 *     def _asyncgen_firstiter_hook(self, agen):             # <<<<<<<<<<<<<<
 *         if self._asyncgens_shutdown_called:
 *             _warn_with_source(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_130_asyncgen_firstiter_hook(PyObject *__pyx_v_self, PyObject *__pyx_v_agen); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_129_asyncgen_firstiter_hook[] = "Loop._asyncgen_firstiter_hook(self, agen)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_130_asyncgen_firstiter_hook(PyObject *__pyx_v_self, PyObject *__pyx_v_agen) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_asyncgen_firstiter_hook (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_129_asyncgen_firstiter_hook(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_agen));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_129_asyncgen_firstiter_hook(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_agen) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_asyncgen_firstiter_hook", 0);

  /* "uvloop/loop.pyx":2923
 * 
 *     def _asyncgen_firstiter_hook(self, agen):
 *         if self._asyncgens_shutdown_called:             # <<<<<<<<<<<<<<
 *             _warn_with_source(
 *                 "asynchronous generator {!r} was scheduled after "
 */
  __pyx_t_1 = (__pyx_v_self->_asyncgens_shutdown_called != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2926
 *             _warn_with_source(
 *                 "asynchronous generator {!r} was scheduled after "
 *                 "loop.shutdown_asyncgens() call".format(agen),             # <<<<<<<<<<<<<<
 *                 ResourceWarning, self)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_asynchronous_generator_r_was_sch, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_agen); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2926, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_agen};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2926, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_agen};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2926, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2926, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(__pyx_v_agen);
        __Pyx_GIVEREF(__pyx_v_agen);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_agen);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2926, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/loop.pyx":2927
 *                 "asynchronous generator {!r} was scheduled after "
 *                 "loop.shutdown_asyncgens() call".format(agen),
 *                 ResourceWarning, self)             # <<<<<<<<<<<<<<
 * 
 *         self._asyncgens.add(agen)
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ResourceWarning); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2927, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/loop.pyx":2924
 *     def _asyncgen_firstiter_hook(self, agen):
 *         if self._asyncgens_shutdown_called:
 *             _warn_with_source(             # <<<<<<<<<<<<<<
 *                 "asynchronous generator {!r} was scheduled after "
 *                 "loop.shutdown_asyncgens() call".format(agen),
 */
    __pyx_t_5 = __pyx_f_6uvloop_4loop__warn_with_source(__pyx_t_2, __pyx_t_3, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2924, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":2923
 * 
 *     def _asyncgen_firstiter_hook(self, agen):
 *         if self._asyncgens_shutdown_called:             # <<<<<<<<<<<<<<
 *             _warn_with_source(
 *                 "asynchronous generator {!r} was scheduled after "
 */
  }

  /* "uvloop/loop.pyx":2929
 *                 ResourceWarning, self)
 * 
 *         self._asyncgens.add(agen)             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_asyncgens, __pyx_n_s_add); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_agen); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2929, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_agen};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2929, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_agen};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2929, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2929, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_agen);
      __Pyx_GIVEREF(__pyx_v_agen);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_agen);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2929, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/loop.pyx":2922
 *             self.handler_async.send()
 * 
 *     def _asyncgen_firstiter_hook(self, agen):             # <<<<<<<<<<<<<<
 *         if self._asyncgens_shutdown_called:
 *             _warn_with_source(
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.Loop._asyncgen_firstiter_hook", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_4Loop_133generator19(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":2932
 * 
 *     @cython.iterable_coroutine
 *     async def shutdown_asyncgens(self):             # <<<<<<<<<<<<<<
 *         """Shutdown all active asynchronous generators."""
 *         self._asyncgens_shutdown_called = True
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_132shutdown_asyncgens(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_131shutdown_asyncgens[] = "Loop.shutdown_asyncgens(self)\nShutdown all active asynchronous generators.";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_132shutdown_asyncgens(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shutdown_asyncgens (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_131shutdown_asyncgens(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_131shutdown_asyncgens(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shutdown_asyncgens", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 2932, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_4Loop_133generator19, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_shutdown_asyncgens, __pyx_n_s_Loop_shutdown_asyncgens, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 2932, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Loop.shutdown_asyncgens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_4Loop_133generator19(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shutdown_asyncgens", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L9_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2932, __pyx_L1_error)

  /* "uvloop/loop.pyx":2934
 *     async def shutdown_asyncgens(self):
 *         """Shutdown all active asynchronous generators."""
 *         self._asyncgens_shutdown_called = True             # <<<<<<<<<<<<<<
 * 
 *         if self._asyncgens is None or not len(self._asyncgens):
 */
  __pyx_cur_scope->__pyx_v_self->_asyncgens_shutdown_called = 1;

  /* "uvloop/loop.pyx":2936
 *         self._asyncgens_shutdown_called = True
 * 
 *         if self._asyncgens is None or not len(self._asyncgens):             # <<<<<<<<<<<<<<
 *             # If Python version is <3.6 or we don't have any asynchronous
 *             # generators alive.
 */
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_self->_asyncgens == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = __pyx_cur_scope->__pyx_v_self->_asyncgens;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(2, 2936, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = ((!(__pyx_t_5 != 0)) != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2939
 *             # If Python version is <3.6 or we don't have any asynchronous
 *             # generators alive.
 *             return             # <<<<<<<<<<<<<<
 * 
 *         closing_agens = list(self._asyncgens)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "uvloop/loop.pyx":2936
 *         self._asyncgens_shutdown_called = True
 * 
 *         if self._asyncgens is None or not len(self._asyncgens):             # <<<<<<<<<<<<<<
 *             # If Python version is <3.6 or we don't have any asynchronous
 *             # generators alive.
 */
  }

  /* "uvloop/loop.pyx":2941
 *             return
 * 
 *         closing_agens = list(self._asyncgens)             # <<<<<<<<<<<<<<
 *         self._asyncgens.clear()
 * 
 */
  __pyx_t_4 = PySequence_List(__pyx_cur_scope->__pyx_v_self->_asyncgens); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_closing_agens = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2942
 * 
 *         closing_agens = list(self._asyncgens)
 *         self._asyncgens.clear()             # <<<<<<<<<<<<<<
 * 
 *         shutdown_coro = aio_gather(
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_v_self->_asyncgens, __pyx_n_s_clear); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_7) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2942, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2942, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2944
 *         self._asyncgens.clear()
 * 
 *         shutdown_coro = aio_gather(             # <<<<<<<<<<<<<<
 *             *[ag.aclose() for ag in closing_agens],
 *             return_exceptions=True,
 */
  { /* enter inner scope */

    /* "uvloop/loop.pyx":2945
 * 
 *         shutdown_coro = aio_gather(
 *             *[ag.aclose() for ag in closing_agens],             # <<<<<<<<<<<<<<
 *             return_exceptions=True,
 *             loop=self)
 */
    __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2945, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __pyx_cur_scope->__pyx_v_closing_agens; __Pyx_INCREF(__pyx_t_6); __pyx_t_5 = 0;
    for (;;) {
      if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_6)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_7 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_5); __Pyx_INCREF(__pyx_t_7); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(2, 2945, __pyx_L1_error)
      #else
      __pyx_t_7 = PySequence_ITEM(__pyx_t_6, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2945, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      #endif
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_8genexpr5__pyx_v_ag);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_8genexpr5__pyx_v_ag, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_8genexpr5__pyx_v_ag, __pyx_n_s_aclose); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2945, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      if (__pyx_t_9) {
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2945, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2945, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_4, (PyObject*)__pyx_t_7))) __PYX_ERR(2, 2945, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } /* exit inner scope */

  /* "uvloop/loop.pyx":2944
 *         self._asyncgens.clear()
 * 
 *         shutdown_coro = aio_gather(             # <<<<<<<<<<<<<<
 *             *[ag.aclose() for ag in closing_agens],
 *             return_exceptions=True,
 */
  __pyx_t_6 = PySequence_Tuple(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2946
 *         shutdown_coro = aio_gather(
 *             *[ag.aclose() for ag in closing_agens],
 *             return_exceptions=True,             # <<<<<<<<<<<<<<
 *             loop=self)
 * 
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_exceptions, Py_True) < 0) __PYX_ERR(2, 2946, __pyx_L1_error)

  /* "uvloop/loop.pyx":2947
 *             *[ag.aclose() for ag in closing_agens],
 *             return_exceptions=True,
 *             loop=self)             # <<<<<<<<<<<<<<
 * 
 *         results = await shutdown_coro
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_loop, ((PyObject *)__pyx_cur_scope->__pyx_v_self)) < 0) __PYX_ERR(2, 2946, __pyx_L1_error)

  /* "uvloop/loop.pyx":2944
 *         self._asyncgens.clear()
 * 
 *         shutdown_coro = aio_gather(             # <<<<<<<<<<<<<<
 *             *[ag.aclose() for ag in closing_agens],
 *             return_exceptions=True,
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_gather, __pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_cur_scope->__pyx_v_shutdown_coro = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":2949
 *             loop=self)
 * 
 *         results = await shutdown_coro             # <<<<<<<<<<<<<<
 *         for result, agen in zip(results, closing_agens):
 *             if isinstance(result, Exception):
 */
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_shutdown_coro);
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L9_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 2949, __pyx_L1_error)
    __pyx_t_7 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_7);
  } else {
    __pyx_t_7 = NULL;
    if (__Pyx_PyGen_FetchStopIterationValue(&__pyx_t_7) < 0) __PYX_ERR(2, 2949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
  }
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_cur_scope->__pyx_v_results = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":2950
 * 
 *         results = await shutdown_coro
 *         for result, agen in zip(results, closing_agens):             # <<<<<<<<<<<<<<
 *             if isinstance(result, Exception):
 *                 self.call_exception_handler({
 */
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_results);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_results);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_cur_scope->__pyx_v_results);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_closing_agens);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_closing_agens);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_cur_scope->__pyx_v_closing_agens);
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_zip, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_7 = __pyx_t_4; __Pyx_INCREF(__pyx_t_7); __pyx_t_5 = 0;
    __pyx_t_10 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 2950, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_10)) {
      if (likely(PyList_CheckExact(__pyx_t_7))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_7)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(2, 2950, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_7, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2950, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(2, 2950, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_7, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2950, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_10(__pyx_t_7);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(2, 2950, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(2, 2950, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      #else
      __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_9 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2950, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = Py_TYPE(__pyx_t_9)->tp_iternext;
      index = 0; __pyx_t_6 = __pyx_t_11(__pyx_t_9); if (unlikely(!__pyx_t_6)) goto __pyx_L12_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      index = 1; __pyx_t_8 = __pyx_t_11(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L12_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_9), 2) < 0) __PYX_ERR(2, 2950, __pyx_L1_error)
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L13_unpacking_done;
      __pyx_L12_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(2, 2950, __pyx_L1_error)
      __pyx_L13_unpacking_done:;
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_result);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_result, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_agen);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_agen, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    __pyx_t_8 = 0;

    /* "uvloop/loop.pyx":2951
 *         results = await shutdown_coro
 *         for result, agen in zip(results, closing_agens):
 *             if isinstance(result, Exception):             # <<<<<<<<<<<<<<
 *                 self.call_exception_handler({
 *                     'message': 'an error occurred during closing of '
 */
    __pyx_t_1 = __Pyx_PyException_Check(__pyx_cur_scope->__pyx_v_result); 
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "uvloop/loop.pyx":2952
 *         for result, agen in zip(results, closing_agens):
 *             if isinstance(result, Exception):
 *                 self.call_exception_handler({             # <<<<<<<<<<<<<<
 *                     'message': 'an error occurred during closing of '
 *                                'asynchronous generator {!r}'.format(agen),
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2952, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);

      /* "uvloop/loop.pyx":2953
 *             if isinstance(result, Exception):
 *                 self.call_exception_handler({
 *                     'message': 'an error occurred during closing of '             # <<<<<<<<<<<<<<
 *                                'asynchronous generator {!r}'.format(agen),
 *                     'exception': result,
 */
      __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2953, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "uvloop/loop.pyx":2954
 *                 self.call_exception_handler({
 *                     'message': 'an error occurred during closing of '
 *                                'asynchronous generator {!r}'.format(agen),             # <<<<<<<<<<<<<<
 *                     'exception': result,
 *                     'asyncgen': agen
 */
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_an_error_occurred_during_closing, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2954, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      if (!__pyx_t_13) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_cur_scope->__pyx_v_agen); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2954, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_12)) {
          PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_cur_scope->__pyx_v_agen};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2954, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
          PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_cur_scope->__pyx_v_agen};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2954, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        {
          __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(2, 2954, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
          __Pyx_INCREF(__pyx_cur_scope->__pyx_v_agen);
          __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_agen);
          PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_cur_scope->__pyx_v_agen);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_14, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(2, 2954, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_u_message, __pyx_t_9) < 0) __PYX_ERR(2, 2953, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/loop.pyx":2955
 *                     'message': 'an error occurred during closing of '
 *                                'asynchronous generator {!r}'.format(agen),
 *                     'exception': result,             # <<<<<<<<<<<<<<
 *                     'asyncgen': agen
 *                 })
 */
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_u_exception, __pyx_cur_scope->__pyx_v_result) < 0) __PYX_ERR(2, 2953, __pyx_L1_error)

      /* "uvloop/loop.pyx":2956
 *                                'asynchronous generator {!r}'.format(agen),
 *                     'exception': result,
 *                     'asyncgen': agen             # <<<<<<<<<<<<<<
 *                 })
 * 
 */
      if (PyDict_SetItem(__pyx_t_6, __pyx_n_u_asyncgen, __pyx_cur_scope->__pyx_v_agen) < 0) __PYX_ERR(2, 2953, __pyx_L1_error)
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      if (!__pyx_t_9) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2952, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_6};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2952, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
          PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_6};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2952, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(2, 2952, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_9); __pyx_t_9 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2952, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/loop.pyx":2951
 *         results = await shutdown_coro
 *         for result, agen in zip(results, closing_agens):
 *             if isinstance(result, Exception):             # <<<<<<<<<<<<<<
 *                 self.call_exception_handler({
 *                     'message': 'an error occurred during closing of '
 */
    }

    /* "uvloop/loop.pyx":2950
 * 
 *         results = await shutdown_coro
 *         for result, agen in zip(results, closing_agens):             # <<<<<<<<<<<<<<
 *             if isinstance(result, Exception):
 *                 self.call_exception_handler({
 */
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/loop.pyx":2932
 * 
 *     @cython.iterable_coroutine
 *     async def shutdown_asyncgens(self):             # <<<<<<<<<<<<<<
 *         """Shutdown all active asynchronous generators."""
 *         self._asyncgens_shutdown_called = True
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("shutdown_asyncgens", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":41
 *         int _coroutine_origin_tracking_saved_depth
 * 
 *         public slow_callback_duration             # <<<<<<<<<<<<<<
 * 
 *         readonly bint _closed
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->slow_callback_duration);
  __pyx_r = __pyx_v_self->slow_callback_duration;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration_2__set__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration_2__set__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);
  __Pyx_INCREF(__pyx_v_value);
  __Pyx_GIVEREF(__pyx_v_value);
  __Pyx_GOTREF(__pyx_v_self->slow_callback_duration);
  __Pyx_DECREF(__pyx_v_self->slow_callback_duration);
  __pyx_v_self->slow_callback_duration = __pyx_v_value;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration_4__del__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_4Loop_22slow_callback_duration_4__del__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->slow_callback_duration);
  __Pyx_DECREF(__pyx_v_self->slow_callback_duration);
  __pyx_v_self->slow_callback_duration = Py_None;

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":43
 *         public slow_callback_duration
 * 
 *         readonly bint _closed             # <<<<<<<<<<<<<<
 *         bint _debug
 *         bint _running
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_7_closed_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_7_closed_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_7_closed___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_7_closed___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_closed); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._closed.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":91
 * 
 *         # DEBUG fields
 *         readonly bint _debug_cc  # True when compiled with DEBUG.             # <<<<<<<<<<<<<<
 *                                  # Only for unittests.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_9_debug_cc_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_9_debug_cc_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_9_debug_cc___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_9_debug_cc___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_debug_cc); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_cc.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":94
 *                                  # Only for unittests.
 * 
 *         readonly object _debug_handles_total             # <<<<<<<<<<<<<<
 *         readonly object _debug_handles_closed
 *         readonly object _debug_handles_current
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_20_debug_handles_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_20_debug_handles_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_20_debug_handles_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_20_debug_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_debug_handles_total);
  __pyx_r = __pyx_v_self->_debug_handles_total;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":95
 * 
 *         readonly object _debug_handles_total
 *         readonly object _debug_handles_closed             # <<<<<<<<<<<<<<
 *         readonly object _debug_handles_current
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_21_debug_handles_closed_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_21_debug_handles_closed_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_21_debug_handles_closed___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_21_debug_handles_closed___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_debug_handles_closed);
  __pyx_r = __pyx_v_self->_debug_handles_closed;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":96
 *         readonly object _debug_handles_total
 *         readonly object _debug_handles_closed
 *         readonly object _debug_handles_current             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _debug_uv_handles_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_22_debug_handles_current_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_22_debug_handles_current_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_22_debug_handles_current___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_22_debug_handles_current___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_debug_handles_current);
  __pyx_r = __pyx_v_self->_debug_handles_current;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":98
 *         readonly object _debug_handles_current
 * 
 *         readonly uint64_t _debug_uv_handles_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_uv_handles_freed
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_uv_handles_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_uv_handles_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_23_debug_uv_handles_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_uv_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_uv_handles_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_uv_handles_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":99
 * 
 *         readonly uint64_t _debug_uv_handles_total
 *         readonly uint64_t _debug_uv_handles_freed             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _debug_cb_handles_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_uv_handles_freed_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_uv_handles_freed_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_23_debug_uv_handles_freed___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_uv_handles_freed___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_uv_handles_freed); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_uv_handles_freed.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":101
 *         readonly uint64_t _debug_uv_handles_freed
 * 
 *         readonly uint64_t _debug_cb_handles_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_cb_handles_count
 *         readonly uint64_t _debug_cb_timer_handles_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_cb_handles_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_cb_handles_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_23_debug_cb_handles_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_cb_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_handles_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_cb_handles_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":102
 * 
 *         readonly uint64_t _debug_cb_handles_total
 *         readonly uint64_t _debug_cb_handles_count             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_cb_timer_handles_total
 *         readonly uint64_t _debug_cb_timer_handles_count
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_cb_handles_count_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_debug_cb_handles_count_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_23_debug_cb_handles_count___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_debug_cb_handles_count___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_handles_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_cb_handles_count.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":103
 *         readonly uint64_t _debug_cb_handles_total
 *         readonly uint64_t _debug_cb_handles_count
 *         readonly uint64_t _debug_cb_timer_handles_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_cb_timer_handles_count
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_timer_handles_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_cb_timer_handles_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":104
 *         readonly uint64_t _debug_cb_handles_count
 *         readonly uint64_t _debug_cb_timer_handles_total
 *         readonly uint64_t _debug_cb_timer_handles_count             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _debug_stream_shutdown_errors_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_count_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_count_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_count___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_count___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_cb_timer_handles_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_cb_timer_handles_count.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":106
 *         readonly uint64_t _debug_cb_timer_handles_count
 * 
 *         readonly uint64_t _debug_stream_shutdown_errors_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_listen_errors_total
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_35_debug_stream_shutdown_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_35_debug_stream_shutdown_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_35_debug_stream_shutdown_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_35_debug_stream_shutdown_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_shutdown_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_shutdown_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":107
 * 
 *         readonly uint64_t _debug_stream_shutdown_errors_total
 *         readonly uint64_t _debug_stream_listen_errors_total             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _debug_stream_read_cb_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_33_debug_stream_listen_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_33_debug_stream_listen_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_33_debug_stream_listen_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_33_debug_stream_listen_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_listen_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_listen_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":109
 *         readonly uint64_t _debug_stream_listen_errors_total
 * 
 *         readonly uint64_t _debug_stream_read_cb_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_read_cb_errors_total
 *         readonly uint64_t _debug_stream_read_eof_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27_debug_stream_read_cb_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27_debug_stream_read_cb_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_27_debug_stream_read_cb_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_27_debug_stream_read_cb_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_cb_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_read_cb_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":110
 * 
 *         readonly uint64_t _debug_stream_read_cb_total
 *         readonly uint64_t _debug_stream_read_cb_errors_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_read_eof_total
 *         readonly uint64_t _debug_stream_read_eof_cb_errors_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_34_debug_stream_read_cb_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_34_debug_stream_read_cb_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_34_debug_stream_read_cb_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_34_debug_stream_read_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_cb_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_read_cb_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":111
 *         readonly uint64_t _debug_stream_read_cb_total
 *         readonly uint64_t _debug_stream_read_cb_errors_total
 *         readonly uint64_t _debug_stream_read_eof_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_read_eof_cb_errors_total
 *         readonly uint64_t _debug_stream_read_errors_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_28_debug_stream_read_eof_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_28_debug_stream_read_eof_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_28_debug_stream_read_eof_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_28_debug_stream_read_eof_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_eof_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_read_eof_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":112
 *         readonly uint64_t _debug_stream_read_cb_errors_total
 *         readonly uint64_t _debug_stream_read_eof_total
 *         readonly uint64_t _debug_stream_read_eof_cb_errors_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_read_errors_total
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_38_debug_stream_read_eof_cb_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_38_debug_stream_read_eof_cb_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_38_debug_stream_read_eof_cb_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_38_debug_stream_read_eof_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_eof_cb_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_read_eof_cb_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":113
 *         readonly uint64_t _debug_stream_read_eof_total
 *         readonly uint64_t _debug_stream_read_eof_cb_errors_total
 *         readonly uint64_t _debug_stream_read_errors_total             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _debug_stream_write_tries
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_31_debug_stream_read_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_31_debug_stream_read_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_31_debug_stream_read_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_31_debug_stream_read_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_read_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_read_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":115
 *         readonly uint64_t _debug_stream_read_errors_total
 * 
 *         readonly uint64_t _debug_stream_write_tries             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_write_errors_total
 *         readonly uint64_t _debug_stream_write_ctx_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_25_debug_stream_write_tries_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_25_debug_stream_write_tries_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_25_debug_stream_write_tries___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_25_debug_stream_write_tries___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_tries); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_write_tries.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":116
 * 
 *         readonly uint64_t _debug_stream_write_tries
 *         readonly uint64_t _debug_stream_write_errors_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_write_ctx_total
 *         readonly uint64_t _debug_stream_write_ctx_cnt
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_32_debug_stream_write_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_32_debug_stream_write_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_32_debug_stream_write_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_32_debug_stream_write_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_write_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":117
 *         readonly uint64_t _debug_stream_write_tries
 *         readonly uint64_t _debug_stream_write_errors_total
 *         readonly uint64_t _debug_stream_write_ctx_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_write_ctx_cnt
 *         readonly uint64_t _debug_stream_write_cb_errors_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29_debug_stream_write_ctx_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_29_debug_stream_write_ctx_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_29_debug_stream_write_ctx_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_29_debug_stream_write_ctx_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_ctx_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_write_ctx_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":118
 *         readonly uint64_t _debug_stream_write_errors_total
 *         readonly uint64_t _debug_stream_write_ctx_total
 *         readonly uint64_t _debug_stream_write_ctx_cnt             # <<<<<<<<<<<<<<
 *         readonly uint64_t _debug_stream_write_cb_errors_total
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27_debug_stream_write_ctx_cnt_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27_debug_stream_write_ctx_cnt_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_27_debug_stream_write_ctx_cnt___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_27_debug_stream_write_ctx_cnt___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_ctx_cnt); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_write_ctx_cnt.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":119
 *         readonly uint64_t _debug_stream_write_ctx_total
 *         readonly uint64_t _debug_stream_write_ctx_cnt
 *         readonly uint64_t _debug_stream_write_cb_errors_total             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _poll_read_events_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_35_debug_stream_write_cb_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_35_debug_stream_write_cb_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_35_debug_stream_write_cb_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_35_debug_stream_write_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_stream_write_cb_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_stream_write_cb_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":121
 *         readonly uint64_t _debug_stream_write_cb_errors_total
 * 
 *         readonly uint64_t _poll_read_events_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _poll_read_cb_errors_total
 *         readonly uint64_t _poll_write_events_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_poll_read_events_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_23_poll_read_events_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_23_poll_read_events_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_23_poll_read_events_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_read_events_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._poll_read_events_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":122
 * 
 *         readonly uint64_t _poll_read_events_total
 *         readonly uint64_t _poll_read_cb_errors_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _poll_write_events_total
 *         readonly uint64_t _poll_write_cb_errors_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_26_poll_read_cb_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_26_poll_read_cb_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_26_poll_read_cb_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_26_poll_read_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_read_cb_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._poll_read_cb_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":123
 *         readonly uint64_t _poll_read_events_total
 *         readonly uint64_t _poll_read_cb_errors_total
 *         readonly uint64_t _poll_write_events_total             # <<<<<<<<<<<<<<
 *         readonly uint64_t _poll_write_cb_errors_total
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_24_poll_write_events_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_24_poll_write_events_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_24_poll_write_events_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_24_poll_write_events_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_write_events_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._poll_write_events_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":124
 *         readonly uint64_t _poll_read_cb_errors_total
 *         readonly uint64_t _poll_write_events_total
 *         readonly uint64_t _poll_write_cb_errors_total             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _sock_try_write_total
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27_poll_write_cb_errors_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_27_poll_write_cb_errors_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_27_poll_write_cb_errors_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_27_poll_write_cb_errors_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_poll_write_cb_errors_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._poll_write_cb_errors_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":126
 *         readonly uint64_t _poll_write_cb_errors_total
 * 
 *         readonly uint64_t _sock_try_write_total             # <<<<<<<<<<<<<<
 * 
 *         readonly uint64_t _debug_exception_handler_cnt
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_21_sock_try_write_total_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_21_sock_try_write_total_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_21_sock_try_write_total___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_21_sock_try_write_total___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_sock_try_write_total); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._sock_try_write_total.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pxd":128
 *         readonly uint64_t _sock_try_write_total
 * 
 *         readonly uint64_t _debug_exception_handler_cnt             # <<<<<<<<<<<<<<
 * 
 *     cdef _init_debug_fields(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_28_debug_exception_handler_cnt_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_28_debug_exception_handler_cnt_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_28_debug_exception_handler_cnt___get__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_28_debug_exception_handler_cnt___get__(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_uint64_t(__pyx_v_self->_debug_exception_handler_cnt); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop._debug_exception_handler_cnt.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_135__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_134__reduce_cython__[] = "Loop.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_135__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_134__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_134__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__123, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_137__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_4Loop_136__setstate_cython__[] = "Loop.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_4Loop_137__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_4Loop_136__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_4Loop_136__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__124, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Loop.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2960
 * 
 * 
 * cdef void __loop_alloc_buffer(uv.uv_handle_t* uvhandle,             # <<<<<<<<<<<<<<
 *                               size_t suggested_size,
 *                               uv.uv_buf_t* buf) with gil:
 */

static void __pyx_f_6uvloop_4loop___loop_alloc_buffer(uv_handle_t *__pyx_v_uvhandle, CYTHON_UNUSED size_t __pyx_v_suggested_size, uv_buf_t *__pyx_v_buf) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  PyObject *__pyx_v_exc = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  char *__pyx_t_3;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__loop_alloc_buffer", 0);

  /* "uvloop/loop.pyx":2964
 *                               uv.uv_buf_t* buf) with gil:
 *     cdef:
 *         Loop loop = (<UVHandle>uvhandle.data)._loop             # <<<<<<<<<<<<<<
 * 
 *     if loop._recv_buffer_in_use == 1:
 */
  __pyx_t_1 = ((PyObject *)((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_uvhandle->data)->_loop);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2966
 *         Loop loop = (<UVHandle>uvhandle.data)._loop
 * 
 *     if loop._recv_buffer_in_use == 1:             # <<<<<<<<<<<<<<
 *         buf.len = 0
 *         exc = RuntimeError('concurrent allocations')
 */
  __pyx_t_2 = ((__pyx_v_loop->_recv_buffer_in_use == 1) != 0);
  if (__pyx_t_2) {

    /* "uvloop/loop.pyx":2967
 * 
 *     if loop._recv_buffer_in_use == 1:
 *         buf.len = 0             # <<<<<<<<<<<<<<
 *         exc = RuntimeError('concurrent allocations')
 *         loop._handle_exception(exc)
 */
    __pyx_v_buf->len = 0;

    /* "uvloop/loop.pyx":2968
 *     if loop._recv_buffer_in_use == 1:
 *         buf.len = 0
 *         exc = RuntimeError('concurrent allocations')             # <<<<<<<<<<<<<<
 *         loop._handle_exception(exc)
 *         return
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__125, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/loop.pyx":2969
 *         buf.len = 0
 *         exc = RuntimeError('concurrent allocations')
 *         loop._handle_exception(exc)             # <<<<<<<<<<<<<<
 *         return
 * 
 */
    ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_loop->__pyx_vtab)->_handle_exception(__pyx_v_loop, __pyx_v_exc);

    /* "uvloop/loop.pyx":2970
 *         exc = RuntimeError('concurrent allocations')
 *         loop._handle_exception(exc)
 *         return             # <<<<<<<<<<<<<<
 * 
 *     loop._recv_buffer_in_use = 1
 */
    goto __pyx_L0;

    /* "uvloop/loop.pyx":2966
 *         Loop loop = (<UVHandle>uvhandle.data)._loop
 * 
 *     if loop._recv_buffer_in_use == 1:             # <<<<<<<<<<<<<<
 *         buf.len = 0
 *         exc = RuntimeError('concurrent allocations')
 */
  }

  /* "uvloop/loop.pyx":2972
 *         return
 * 
 *     loop._recv_buffer_in_use = 1             # <<<<<<<<<<<<<<
 *     buf.base = loop._recv_buffer
 *     buf.len = sizeof(loop._recv_buffer)
 */
  __pyx_v_loop->_recv_buffer_in_use = 1;

  /* "uvloop/loop.pyx":2973
 * 
 *     loop._recv_buffer_in_use = 1
 *     buf.base = loop._recv_buffer             # <<<<<<<<<<<<<<
 *     buf.len = sizeof(loop._recv_buffer)
 * 
 */
  __pyx_t_3 = __pyx_v_loop->_recv_buffer;
  __pyx_v_buf->base = __pyx_t_3;

  /* "uvloop/loop.pyx":2974
 *     loop._recv_buffer_in_use = 1
 *     buf.base = loop._recv_buffer
 *     buf.len = sizeof(loop._recv_buffer)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_buf->len = (sizeof(__pyx_v_loop->_recv_buffer));

  /* "uvloop/loop.pyx":2960
 * 
 * 
 * cdef void __loop_alloc_buffer(uv.uv_handle_t* uvhandle,             # <<<<<<<<<<<<<<
 *                               size_t suggested_size,
 *                               uv.uv_buf_t* buf) with gil:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("uvloop.loop.__loop_alloc_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/loop.pyx":2977
 * 
 * 
 * cdef inline void __loop_free_buffer(Loop loop):             # <<<<<<<<<<<<<<
 *     loop._recv_buffer_in_use = 0
 * 
 */

static CYTHON_INLINE void __pyx_f_6uvloop_4loop___loop_free_buffer(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__loop_free_buffer", 0);

  /* "uvloop/loop.pyx":2978
 * 
 * cdef inline void __loop_free_buffer(Loop loop):
 *     loop._recv_buffer_in_use = 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_loop->_recv_buffer_in_use = 0;

  /* "uvloop/loop.pyx":2977
 * 
 * 
 * cdef inline void __loop_free_buffer(Loop loop):             # <<<<<<<<<<<<<<
 *     loop._recv_buffer_in_use = 0
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/loop.pyx":2983
 * class _SyncSocketReaderFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketReaderFuture_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_23_SyncSocketReaderFuture___init__[] = "_SyncSocketReaderFuture.__init__(self, sock, loop)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_23_SyncSocketReaderFuture_1__init__ = {"__init__", (PyCFunction)__pyx_pw_6uvloop_4loop_23_SyncSocketReaderFuture_1__init__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_23_SyncSocketReaderFuture___init__};
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketReaderFuture_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_loop = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_sock,&__pyx_n_s_loop,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sock)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(2, 2983, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(2, 2983, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(2, 2983, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_sock = values[1];
    __pyx_v_loop = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2983, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SyncSocketReaderFuture.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_23_SyncSocketReaderFuture___init__(__pyx_self, __pyx_v_self, __pyx_v_sock, __pyx_v_loop);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketReaderFuture___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_loop) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/loop.pyx":2984
 * 
 *     def __init__(self, sock, loop):
 *         aio_Future.__init__(self, loop=loop)             # <<<<<<<<<<<<<<
 *         self.__sock = sock
 *         self.__loop = loop
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_Future, __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loop, __pyx_v_loop) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":2985
 *     def __init__(self, sock, loop):
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock             # <<<<<<<<<<<<<<
 *         self.__loop = loop
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketReaderFuture__sock, __pyx_v_sock) < 0) __PYX_ERR(2, 2985, __pyx_L1_error)

  /* "uvloop/loop.pyx":2986
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 *         self.__loop = loop             # <<<<<<<<<<<<<<
 * 
 *     def cancel(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketReaderFuture__loop, __pyx_v_loop) < 0) __PYX_ERR(2, 2986, __pyx_L1_error)

  /* "uvloop/loop.pyx":2983
 * class _SyncSocketReaderFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop._SyncSocketReaderFuture.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2988
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_reader(self.__sock)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketReaderFuture_3cancel(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_23_SyncSocketReaderFuture_2cancel[] = "_SyncSocketReaderFuture.cancel(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_23_SyncSocketReaderFuture_3cancel = {"cancel", (PyCFunction)__pyx_pw_6uvloop_4loop_23_SyncSocketReaderFuture_3cancel, METH_O, __pyx_doc_6uvloop_4loop_23_SyncSocketReaderFuture_2cancel};
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketReaderFuture_3cancel(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_23_SyncSocketReaderFuture_2cancel(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketReaderFuture_2cancel(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("cancel", 0);

  /* "uvloop/loop.pyx":2989
 * 
 *     def cancel(self):
 *         if self.__sock is not None and self.__sock.fileno() != -1:             # <<<<<<<<<<<<<<
 *             self.__loop.remove_reader(self.__sock)
 *             self.__sock = None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketReaderFuture__sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketReaderFuture__sock); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_fileno); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2989, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2989, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_2, __pyx_int_neg_1, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":2990
 *     def cancel(self):
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_reader(self.__sock)             # <<<<<<<<<<<<<<
 *             self.__sock = None
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketReaderFuture__loop); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_remove_reader); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketReaderFuture__sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2990, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2990, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2990, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2990, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 2990, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2990, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":2991
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_reader(self.__sock)
 *             self.__sock = None             # <<<<<<<<<<<<<<
 * 
 *         aio_Future.cancel(self)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketReaderFuture__sock, Py_None) < 0) __PYX_ERR(2, 2991, __pyx_L1_error)

    /* "uvloop/loop.pyx":2989
 * 
 *     def cancel(self):
 *         if self.__sock is not None and self.__sock.fileno() != -1:             # <<<<<<<<<<<<<<
 *             self.__loop.remove_reader(self.__sock)
 *             self.__sock = None
 */
  }

  /* "uvloop/loop.pyx":2993
 *             self.__sock = None
 * 
 *         aio_Future.cancel(self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_Future, __pyx_n_s_cancel); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2993, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2993, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2993, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_self);
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2993, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/loop.pyx":2988
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_reader(self.__sock)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop._SyncSocketReaderFuture.cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":2998
 * class _SyncSocketWriterFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketWriterFuture_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_23_SyncSocketWriterFuture___init__[] = "_SyncSocketWriterFuture.__init__(self, sock, loop)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_23_SyncSocketWriterFuture_1__init__ = {"__init__", (PyCFunction)__pyx_pw_6uvloop_4loop_23_SyncSocketWriterFuture_1__init__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_23_SyncSocketWriterFuture___init__};
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketWriterFuture_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_sock = 0;
  PyObject *__pyx_v_loop = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_sock,&__pyx_n_s_loop,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sock)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(2, 2998, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(2, 2998, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(2, 2998, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_sock = values[1];
    __pyx_v_loop = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(2, 2998, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SyncSocketWriterFuture.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_23_SyncSocketWriterFuture___init__(__pyx_self, __pyx_v_self, __pyx_v_sock, __pyx_v_loop);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketWriterFuture___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_sock, PyObject *__pyx_v_loop) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/loop.pyx":2999
 * 
 *     def __init__(self, sock, loop):
 *         aio_Future.__init__(self, loop=loop)             # <<<<<<<<<<<<<<
 *         self.__sock = sock
 *         self.__loop = loop
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_Future, __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self);
  __Pyx_GIVEREF(__pyx_v_self);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loop, __pyx_v_loop) < 0) __PYX_ERR(2, 2999, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/loop.pyx":3000
 *     def __init__(self, sock, loop):
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock             # <<<<<<<<<<<<<<
 *         self.__loop = loop
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketWriterFuture__sock, __pyx_v_sock) < 0) __PYX_ERR(2, 3000, __pyx_L1_error)

  /* "uvloop/loop.pyx":3001
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 *         self.__loop = loop             # <<<<<<<<<<<<<<
 * 
 *     def cancel(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketWriterFuture__loop, __pyx_v_loop) < 0) __PYX_ERR(2, 3001, __pyx_L1_error)

  /* "uvloop/loop.pyx":2998
 * class _SyncSocketWriterFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop._SyncSocketWriterFuture.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":3003
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_writer(self.__sock)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketWriterFuture_3cancel(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_23_SyncSocketWriterFuture_2cancel[] = "_SyncSocketWriterFuture.cancel(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_23_SyncSocketWriterFuture_3cancel = {"cancel", (PyCFunction)__pyx_pw_6uvloop_4loop_23_SyncSocketWriterFuture_3cancel, METH_O, __pyx_doc_6uvloop_4loop_23_SyncSocketWriterFuture_2cancel};
static PyObject *__pyx_pw_6uvloop_4loop_23_SyncSocketWriterFuture_3cancel(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_23_SyncSocketWriterFuture_2cancel(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_23_SyncSocketWriterFuture_2cancel(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("cancel", 0);

  /* "uvloop/loop.pyx":3004
 * 
 *     def cancel(self):
 *         if self.__sock is not None and self.__sock.fileno() != -1:             # <<<<<<<<<<<<<<
 *             self.__loop.remove_writer(self.__sock)
 *             self.__sock = None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketWriterFuture__sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__pyx_t_2 != Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketWriterFuture__sock); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_fileno); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3004, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3004, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyObject_RichCompare(__pyx_t_2, __pyx_int_neg_1, Py_NE); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_1 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":3005
 *     def cancel(self):
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_writer(self.__sock)             # <<<<<<<<<<<<<<
 *             self.__sock = None
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketWriterFuture__loop); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_remove_writer); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketWriterFuture__sock); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3005, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3005, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3005, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3005, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 3005, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3005, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/loop.pyx":3006
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_writer(self.__sock)
 *             self.__sock = None             # <<<<<<<<<<<<<<
 * 
 *         aio_Future.cancel(self)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_SyncSocketWriterFuture__sock, Py_None) < 0) __PYX_ERR(2, 3006, __pyx_L1_error)

    /* "uvloop/loop.pyx":3004
 * 
 *     def cancel(self):
 *         if self.__sock is not None and self.__sock.fileno() != -1:             # <<<<<<<<<<<<<<
 *             self.__loop.remove_writer(self.__sock)
 *             self.__sock = None
 */
  }

  /* "uvloop/loop.pyx":3008
 *             self.__sock = None
 * 
 *         aio_Future.cancel(self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_Future, __pyx_n_s_cancel); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3008, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3008, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self};
      __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3008, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3008, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_v_self);
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3008, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/loop.pyx":3003
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_writer(self.__sock)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop._SyncSocketWriterFuture.cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":4
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class Handle:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._cancelled = 0
 *         self.cb_type = 0
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_6Handle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_6Handle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle___cinit__(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_6Handle___cinit__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/cbhandles.pyx":5
 * cdef class Handle:
 *     def __cinit__(self):
 *         self._cancelled = 0             # <<<<<<<<<<<<<<
 *         self.cb_type = 0
 *         self._source_traceback = None
 */
  __pyx_v_self->_cancelled = 0;

  /* "uvloop/cbhandles.pyx":6
 *     def __cinit__(self):
 *         self._cancelled = 0
 *         self.cb_type = 0             # <<<<<<<<<<<<<<
 *         self._source_traceback = None
 * 
 */
  __pyx_v_self->cb_type = 0;

  /* "uvloop/cbhandles.pyx":7
 *         self._cancelled = 0
 *         self.cb_type = 0
 *         self._source_traceback = None             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _set_loop(self, Loop loop):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_source_traceback);
  __Pyx_DECREF(__pyx_v_self->_source_traceback);
  __pyx_v_self->_source_traceback = Py_None;

  /* "uvloop/cbhandles.pyx":4
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class Handle:
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._cancelled = 0
 *         self.cb_type = 0
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":9
 *         self._source_traceback = None
 * 
 *     cdef inline _set_loop(self, Loop loop):             # <<<<<<<<<<<<<<
 *         self.loop = loop
 *         if UVLOOP_DEBUG:
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__set_loop(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_set_loop", 0);

  /* "uvloop/cbhandles.pyx":10
 * 
 *     cdef inline _set_loop(self, Loop loop):
 *         self.loop = loop             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_cb_handles_total += 1
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_loop));
  __Pyx_GOTREF(__pyx_v_self->loop);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->loop));
  __pyx_v_self->loop = __pyx_v_loop;

  /* "uvloop/cbhandles.pyx":11
 *     cdef inline _set_loop(self, Loop loop):
 *         self.loop = loop
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_cb_handles_total += 1
 *             loop._debug_cb_handles_count += 1
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":12
 *         self.loop = loop
 *         if UVLOOP_DEBUG:
 *             loop._debug_cb_handles_total += 1             # <<<<<<<<<<<<<<
 *             loop._debug_cb_handles_count += 1
 *         if loop._debug:
 */
    __pyx_v_loop->_debug_cb_handles_total = (__pyx_v_loop->_debug_cb_handles_total + 1);

    /* "uvloop/cbhandles.pyx":13
 *         if UVLOOP_DEBUG:
 *             loop._debug_cb_handles_total += 1
 *             loop._debug_cb_handles_count += 1             # <<<<<<<<<<<<<<
 *         if loop._debug:
 *             self._source_traceback = extract_stack()
 */
    __pyx_v_loop->_debug_cb_handles_count = (__pyx_v_loop->_debug_cb_handles_count + 1);

    /* "uvloop/cbhandles.pyx":11
 *     cdef inline _set_loop(self, Loop loop):
 *         self.loop = loop
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_cb_handles_total += 1
 *             loop._debug_cb_handles_count += 1
 */
  }

  /* "uvloop/cbhandles.pyx":14
 *             loop._debug_cb_handles_total += 1
 *             loop._debug_cb_handles_count += 1
 *         if loop._debug:             # <<<<<<<<<<<<<<
 *             self._source_traceback = extract_stack()
 * 
 */
  __pyx_t_1 = (__pyx_v_loop->_debug != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":15
 *             loop._debug_cb_handles_count += 1
 *         if loop._debug:
 *             self._source_traceback = extract_stack()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _set_context(self, object context):
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_extract_stack(); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_source_traceback);
    __Pyx_DECREF(__pyx_v_self->_source_traceback);
    __pyx_v_self->_source_traceback = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/cbhandles.pyx":14
 *             loop._debug_cb_handles_total += 1
 *             loop._debug_cb_handles_count += 1
 *         if loop._debug:             # <<<<<<<<<<<<<<
 *             self._source_traceback = extract_stack()
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":9
 *         self._source_traceback = None
 * 
 *     cdef inline _set_loop(self, Loop loop):             # <<<<<<<<<<<<<<
 *         self.loop = loop
 *         if UVLOOP_DEBUG:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.Handle._set_loop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":17
 *             self._source_traceback = extract_stack()
 * 
 *     cdef inline _set_context(self, object context):             # <<<<<<<<<<<<<<
 *         if PY37:
 *             if context is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__set_context(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self, PyObject *__pyx_v_context) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyContext *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_set_context", 0);
  __Pyx_INCREF(__pyx_v_context);

  /* "uvloop/cbhandles.pyx":18
 * 
 *     cdef inline _set_context(self, object context):
 *         if PY37:             # <<<<<<<<<<<<<<
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":19
 *     cdef inline _set_context(self, object context):
 *         if PY37:
 *             if context is None:             # <<<<<<<<<<<<<<
 *                 context = <object>PyContext_CopyCurrent()
 *             self.context = context
 */
    __pyx_t_1 = (__pyx_v_context == Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "uvloop/cbhandles.pyx":20
 *         if PY37:
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()             # <<<<<<<<<<<<<<
 *             self.context = context
 *         else:
 */
      __pyx_t_3 = PyContext_CopyCurrent(); if (unlikely(__pyx_t_3 == ((PyContext *)NULL))) __PYX_ERR(3, 20, __pyx_L1_error)
      __pyx_t_4 = ((PyObject *)__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_context, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "uvloop/cbhandles.pyx":19
 *     cdef inline _set_context(self, object context):
 *         if PY37:
 *             if context is None:             # <<<<<<<<<<<<<<
 *                 context = <object>PyContext_CopyCurrent()
 *             self.context = context
 */
    }

    /* "uvloop/cbhandles.pyx":21
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()
 *             self.context = context             # <<<<<<<<<<<<<<
 *         else:
 *             if context is not None:
 */
    __Pyx_INCREF(__pyx_v_context);
    __Pyx_GIVEREF(__pyx_v_context);
    __Pyx_GOTREF(__pyx_v_self->context);
    __Pyx_DECREF(__pyx_v_self->context);
    __pyx_v_self->context = __pyx_v_context;

    /* "uvloop/cbhandles.pyx":18
 * 
 *     cdef inline _set_context(self, object context):
 *         if PY37:             # <<<<<<<<<<<<<<
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()
 */
    goto __pyx_L3;
  }

  /* "uvloop/cbhandles.pyx":23
 *             self.context = context
 *         else:
 *             if context is not None:             # <<<<<<<<<<<<<<
 *                 raise NotImplementedError(
 *                     '"context" argument requires Python 3.7')
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_context != Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/cbhandles.pyx":24
 *         else:
 *             if context is not None:
 *                 raise NotImplementedError(             # <<<<<<<<<<<<<<
 *                     '"context" argument requires Python 3.7')
 *             self.context = None
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__126, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 24, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(3, 24, __pyx_L1_error)

      /* "uvloop/cbhandles.pyx":23
 *             self.context = context
 *         else:
 *             if context is not None:             # <<<<<<<<<<<<<<
 *                 raise NotImplementedError(
 *                     '"context" argument requires Python 3.7')
 */
    }

    /* "uvloop/cbhandles.pyx":26
 *                 raise NotImplementedError(
 *                     '"context" argument requires Python 3.7')
 *             self.context = None             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->context);
    __Pyx_DECREF(__pyx_v_self->context);
    __pyx_v_self->context = Py_None;
  }
  __pyx_L3:;

  /* "uvloop/cbhandles.pyx":17
 *             self._source_traceback = extract_stack()
 * 
 *     cdef inline _set_context(self, object context):             # <<<<<<<<<<<<<<
 *         if PY37:
 *             if context is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Handle._set_context", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_context);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":28
 *             self.context = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG and self.loop is not None:
 *             self.loop._debug_cb_handles_count -= 1
 */

/* Python wrapper */
static void __pyx_pw_6uvloop_4loop_6Handle_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6uvloop_4loop_6Handle_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_6uvloop_4loop_6Handle_2__dealloc__(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6uvloop_4loop_6Handle_2__dealloc__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "uvloop/cbhandles.pyx":29
 * 
 *     def __dealloc__(self):
 *         if UVLOOP_DEBUG and self.loop is not None:             # <<<<<<<<<<<<<<
 *             self.loop._debug_cb_handles_count -= 1
 *         if self.loop is None:
 */
  __pyx_t_2 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (((PyObject *)__pyx_v_self->loop) != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":30
 *     def __dealloc__(self):
 *         if UVLOOP_DEBUG and self.loop is not None:
 *             self.loop._debug_cb_handles_count -= 1             # <<<<<<<<<<<<<<
 *         if self.loop is None:
 *             raise RuntimeError('Handle.loop is None in Handle.__dealloc__')
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self->loop));
    __pyx_t_4 = __pyx_v_self->loop;
    __pyx_t_4->_debug_cb_handles_count = (__pyx_t_4->_debug_cb_handles_count - 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

    /* "uvloop/cbhandles.pyx":29
 * 
 *     def __dealloc__(self):
 *         if UVLOOP_DEBUG and self.loop is not None:             # <<<<<<<<<<<<<<
 *             self.loop._debug_cb_handles_count -= 1
 *         if self.loop is None:
 */
  }

  /* "uvloop/cbhandles.pyx":31
 *         if UVLOOP_DEBUG and self.loop is not None:
 *             self.loop._debug_cb_handles_count -= 1
 *         if self.loop is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Handle.loop is None in Handle.__dealloc__')
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->loop) == Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/cbhandles.pyx":32
 *             self.loop._debug_cb_handles_count -= 1
 *         if self.loop is None:
 *             raise RuntimeError('Handle.loop is None in Handle.__dealloc__')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
 */
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__127, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(3, 32, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(3, 32, __pyx_L1_error)

    /* "uvloop/cbhandles.pyx":31
 *         if UVLOOP_DEBUG and self.loop is not None:
 *             self.loop._debug_cb_handles_count -= 1
 *         if self.loop is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Handle.loop is None in Handle.__dealloc__')
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":28
 *             self.context = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG and self.loop is not None:
 *             self.loop._debug_cb_handles_count -= 1
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(((PyObject *)__pyx_t_4));
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_WriteUnraisable("uvloop.loop.Handle.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/cbhandles.pyx":34
 *             raise RuntimeError('Handle.loop is None in Handle.__dealloc__')
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_6Handle_5__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_6Handle_5__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle_4__init__(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_6Handle_4__init__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/cbhandles.pyx":36
 *     def __init__(self):
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(             # <<<<<<<<<<<<<<
 *                 self.__class__.__name__))
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_is_not_supposed_to_be_instantia, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/cbhandles.pyx":37
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(
 *                 self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _run(self):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 36, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 36, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 36, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(3, 36, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 36, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/cbhandles.pyx":35
 * 
 *     def __init__(self):
 *         raise TypeError(             # <<<<<<<<<<<<<<
 *             '{} is not supposed to be instantiated from Python'.format(
 *                 self.__class__.__name__))
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(3, 35, __pyx_L1_error)

  /* "uvloop/cbhandles.pyx":34
 *             raise RuntimeError('Handle.loop is None in Handle.__dealloc__')
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.Handle.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":39
 *                 self.__class__.__name__))
 * 
 *     cdef inline _run(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int cb_type
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6Handle__run(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  int __pyx_v_cb_type;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_v_context = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  char const *__pyx_t_22;
  int __pyx_t_23;
  __Pyx_RefNannySetupContext("_run", 0);

  /* "uvloop/cbhandles.pyx":44
 *             object callback
 * 
 *         if self._cancelled:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_cancelled != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":45
 * 
 *         if self._cancelled:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cb_type = self.cb_type
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/cbhandles.pyx":44
 *             object callback
 * 
 *         if self._cancelled:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":47
 *             return
 * 
 *         cb_type = self.cb_type             # <<<<<<<<<<<<<<
 * 
 *         Py_INCREF(self)   # Since _run is a cdef and there's no BoundMethod,
 */
  __pyx_t_2 = __pyx_v_self->cb_type;
  __pyx_v_cb_type = __pyx_t_2;

  /* "uvloop/cbhandles.pyx":49
 *         cb_type = self.cb_type
 * 
 *         Py_INCREF(self)   # Since _run is a cdef and there's no BoundMethod,             # <<<<<<<<<<<<<<
 *                           # we guard 'self' manually (since the callback
 *                           # might cause GC of the handle.)
 */
  Py_INCREF(((PyObject *)__pyx_v_self));

  /* "uvloop/cbhandles.pyx":52
 *                           # we guard 'self' manually (since the callback
 *                           # might cause GC of the handle.)
 *         try:             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 assert self.context is not None
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/cbhandles.pyx":53
 *                           # might cause GC of the handle.)
 *         try:
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 assert self.context is not None
 *                 PyContext_Enter(<PyContext*>self.context)
 */
        __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
        if (__pyx_t_1) {

          /* "uvloop/cbhandles.pyx":54
 *         try:
 *             if PY37:
 *                 assert self.context is not None             # <<<<<<<<<<<<<<
 *                 PyContext_Enter(<PyContext*>self.context)
 * 
 */
          #ifndef CYTHON_WITHOUT_ASSERTIONS
          if (unlikely(!Py_OptimizeFlag)) {
            __pyx_t_1 = (__pyx_v_self->context != Py_None);
            if (unlikely(!(__pyx_t_1 != 0))) {
              PyErr_SetNone(PyExc_AssertionError);
              __PYX_ERR(3, 54, __pyx_L7_error)
            }
          }
          #endif

          /* "uvloop/cbhandles.pyx":55
 *             if PY37:
 *                 assert self.context is not None
 *                 PyContext_Enter(<PyContext*>self.context)             # <<<<<<<<<<<<<<
 * 
 *             if cb_type == 1:
 */
          __pyx_t_2 = PyContext_Enter(((PyContext *)__pyx_v_self->context)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(3, 55, __pyx_L7_error)

          /* "uvloop/cbhandles.pyx":53
 *                           # might cause GC of the handle.)
 *         try:
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 assert self.context is not None
 *                 PyContext_Enter(<PyContext*>self.context)
 */
        }

        /* "uvloop/cbhandles.pyx":57
 *                 PyContext_Enter(<PyContext*>self.context)
 * 
 *             if cb_type == 1:             # <<<<<<<<<<<<<<
 *                 callback = self.arg1
 *                 args = self.arg2
 */
        switch (__pyx_v_cb_type) {
          case 1:

          /* "uvloop/cbhandles.pyx":58
 * 
 *             if cb_type == 1:
 *                 callback = self.arg1             # <<<<<<<<<<<<<<
 *                 args = self.arg2
 * 
 */
          __pyx_t_6 = __pyx_v_self->arg1;
          __Pyx_INCREF(__pyx_t_6);
          __pyx_v_callback = __pyx_t_6;
          __pyx_t_6 = 0;

          /* "uvloop/cbhandles.pyx":59
 *             if cb_type == 1:
 *                 callback = self.arg1
 *                 args = self.arg2             # <<<<<<<<<<<<<<
 * 
 *                 if args is None:
 */
          __pyx_t_6 = __pyx_v_self->arg2;
          __Pyx_INCREF(__pyx_t_6);
          __pyx_v_args = __pyx_t_6;
          __pyx_t_6 = 0;

          /* "uvloop/cbhandles.pyx":61
 *                 args = self.arg2
 * 
 *                 if args is None:             # <<<<<<<<<<<<<<
 *                     callback()
 *                 else:
 */
          __pyx_t_1 = (__pyx_v_args == Py_None);
          __pyx_t_7 = (__pyx_t_1 != 0);
          if (__pyx_t_7) {

            /* "uvloop/cbhandles.pyx":62
 * 
 *                 if args is None:
 *                     callback()             # <<<<<<<<<<<<<<
 *                 else:
 *                     callback(*args)
 */
            __Pyx_INCREF(__pyx_v_callback);
            __pyx_t_8 = __pyx_v_callback; __pyx_t_9 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_9)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_9);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
              }
            }
            if (__pyx_t_9) {
              __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 62, __pyx_L7_error)
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            } else {
              __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 62, __pyx_L7_error)
            }
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "uvloop/cbhandles.pyx":61
 *                 args = self.arg2
 * 
 *                 if args is None:             # <<<<<<<<<<<<<<
 *                     callback()
 *                 else:
 */
            goto __pyx_L14;
          }

          /* "uvloop/cbhandles.pyx":64
 *                     callback()
 *                 else:
 *                     callback(*args)             # <<<<<<<<<<<<<<
 * 
 *             elif cb_type == 2:
 */
          /*else*/ {
            __pyx_t_6 = __Pyx_PySequence_Tuple(__pyx_v_args); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 64, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_v_callback, __pyx_t_6, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 64, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
          __pyx_L14:;

          /* "uvloop/cbhandles.pyx":57
 *                 PyContext_Enter(<PyContext*>self.context)
 * 
 *             if cb_type == 1:             # <<<<<<<<<<<<<<
 *                 callback = self.arg1
 *                 args = self.arg2
 */
          break;

          /* "uvloop/cbhandles.pyx":66
 *                     callback(*args)
 * 
 *             elif cb_type == 2:             # <<<<<<<<<<<<<<
 *                 (<method_t>self.callback)(self.arg1)
 * 
 */
          case 2:

          /* "uvloop/cbhandles.pyx":67
 * 
 *             elif cb_type == 2:
 *                 (<method_t>self.callback)(self.arg1)             # <<<<<<<<<<<<<<
 * 
 *             elif cb_type == 3:
 */
          __pyx_t_8 = __pyx_v_self->arg1;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_6 = ((__pyx_t_6uvloop_4loop_method_t)__pyx_v_self->callback)(__pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 67, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "uvloop/cbhandles.pyx":66
 *                     callback(*args)
 * 
 *             elif cb_type == 2:             # <<<<<<<<<<<<<<
 *                 (<method_t>self.callback)(self.arg1)
 * 
 */
          break;

          /* "uvloop/cbhandles.pyx":69
 *                 (<method_t>self.callback)(self.arg1)
 * 
 *             elif cb_type == 3:             # <<<<<<<<<<<<<<
 *                 (<method1_t>self.callback)(self.arg1, self.arg2)
 * 
 */
          case 3:

          /* "uvloop/cbhandles.pyx":70
 * 
 *             elif cb_type == 3:
 *                 (<method1_t>self.callback)(self.arg1, self.arg2)             # <<<<<<<<<<<<<<
 * 
 *             elif cb_type == 4:
 */
          __pyx_t_6 = __pyx_v_self->arg1;
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_8 = __pyx_v_self->arg2;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_9 = ((__pyx_t_6uvloop_4loop_method1_t)__pyx_v_self->callback)(__pyx_t_6, __pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(3, 70, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "uvloop/cbhandles.pyx":69
 *                 (<method_t>self.callback)(self.arg1)
 * 
 *             elif cb_type == 3:             # <<<<<<<<<<<<<<
 *                 (<method1_t>self.callback)(self.arg1, self.arg2)
 * 
 */
          break;

          /* "uvloop/cbhandles.pyx":72
 *                 (<method1_t>self.callback)(self.arg1, self.arg2)
 * 
 *             elif cb_type == 4:             # <<<<<<<<<<<<<<
 *                 (<method2_t>self.callback)(self.arg1, self.arg2, self.arg3)
 * 
 */
          case 4:

          /* "uvloop/cbhandles.pyx":73
 * 
 *             elif cb_type == 4:
 *                 (<method2_t>self.callback)(self.arg1, self.arg2, self.arg3)             # <<<<<<<<<<<<<<
 * 
 *             elif cb_type == 5:
 */
          __pyx_t_9 = __pyx_v_self->arg1;
          __Pyx_INCREF(__pyx_t_9);
          __pyx_t_8 = __pyx_v_self->arg2;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_6 = __pyx_v_self->arg3;
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_10 = ((__pyx_t_6uvloop_4loop_method2_t)__pyx_v_self->callback)(__pyx_t_9, __pyx_t_8, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 73, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "uvloop/cbhandles.pyx":72
 *                 (<method1_t>self.callback)(self.arg1, self.arg2)
 * 
 *             elif cb_type == 4:             # <<<<<<<<<<<<<<
 *                 (<method2_t>self.callback)(self.arg1, self.arg2, self.arg3)
 * 
 */
          break;

          /* "uvloop/cbhandles.pyx":75
 *                 (<method2_t>self.callback)(self.arg1, self.arg2, self.arg3)
 * 
 *             elif cb_type == 5:             # <<<<<<<<<<<<<<
 *                 (<method3_t>self.callback)(
 *                     self.arg1, self.arg2, self.arg3, self.arg4)
 */
          case 5:

          /* "uvloop/cbhandles.pyx":77
 *             elif cb_type == 5:
 *                 (<method3_t>self.callback)(
 *                     self.arg1, self.arg2, self.arg3, self.arg4)             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
          __pyx_t_10 = __pyx_v_self->arg1;
          __Pyx_INCREF(__pyx_t_10);
          __pyx_t_6 = __pyx_v_self->arg2;
          __Pyx_INCREF(__pyx_t_6);
          __pyx_t_8 = __pyx_v_self->arg3;
          __Pyx_INCREF(__pyx_t_8);
          __pyx_t_9 = __pyx_v_self->arg4;
          __Pyx_INCREF(__pyx_t_9);

          /* "uvloop/cbhandles.pyx":76
 * 
 *             elif cb_type == 5:
 *                 (<method3_t>self.callback)(             # <<<<<<<<<<<<<<
 *                     self.arg1, self.arg2, self.arg3, self.arg4)
 * 
 */
          __pyx_t_11 = ((__pyx_t_6uvloop_4loop_method3_t)__pyx_v_self->callback)(__pyx_t_10, __pyx_t_6, __pyx_t_8, __pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 76, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "uvloop/cbhandles.pyx":75
 *                 (<method2_t>self.callback)(self.arg1, self.arg2, self.arg3)
 * 
 *             elif cb_type == 5:             # <<<<<<<<<<<<<<
 *                 (<method3_t>self.callback)(
 *                     self.arg1, self.arg2, self.arg3, self.arg4)
 */
          break;
          default:

          /* "uvloop/cbhandles.pyx":80
 * 
 *             else:
 *                 raise RuntimeError('invalid Handle.cb_type: {}'.format(             # <<<<<<<<<<<<<<
 *                     cb_type))
 * 
 */
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_invalid_Handle_cb_type, __pyx_n_s_format); if (unlikely(!__pyx_t_9)) __PYX_ERR(3, 80, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_9);

          /* "uvloop/cbhandles.pyx":81
 *             else:
 *                 raise RuntimeError('invalid Handle.cb_type: {}'.format(
 *                     cb_type))             # <<<<<<<<<<<<<<
 * 
 *         except Exception as ex:
 */
          __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_cb_type); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 81, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_6) {
            __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 80, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_11);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_8};
              __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 80, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_8};
              __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 80, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 80, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6); __pyx_t_6 = NULL;
              __Pyx_GIVEREF(__pyx_t_8);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_8);
              __pyx_t_8 = 0;
              __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 80, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "uvloop/cbhandles.pyx":80
 * 
 *             else:
 *                 raise RuntimeError('invalid Handle.cb_type: {}'.format(             # <<<<<<<<<<<<<<
 *                     cb_type))
 * 
 */
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(3, 80, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_Raise(__pyx_t_9, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __PYX_ERR(3, 80, __pyx_L7_error)
          break;
        }

        /* "uvloop/cbhandles.pyx":52
 *                           # we guard 'self' manually (since the callback
 *                           # might cause GC of the handle.)
 *         try:             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 assert self.context is not None
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/cbhandles.pyx":83
 *                     cb_type))
 * 
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             if cb_type == 1:
 *                 msg = 'Exception in callback {}'.format(callback)
 */
      __pyx_t_2 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_2) {
        __Pyx_AddTraceback("uvloop.loop.Handle._run", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_11, &__pyx_t_10) < 0) __PYX_ERR(3, 83, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __pyx_v_ex = __pyx_t_11;
        /*try:*/ {

          /* "uvloop/cbhandles.pyx":84
 * 
 *         except Exception as ex:
 *             if cb_type == 1:             # <<<<<<<<<<<<<<
 *                 msg = 'Exception in callback {}'.format(callback)
 *             else:
 */
          __pyx_t_7 = ((__pyx_v_cb_type == 1) != 0);
          if (__pyx_t_7) {

            /* "uvloop/cbhandles.pyx":85
 *         except Exception as ex:
 *             if cb_type == 1:
 *                 msg = 'Exception in callback {}'.format(callback)             # <<<<<<<<<<<<<<
 *             else:
 *                 msg = 'Exception in callback {}'.format(self.meth_name)
 */
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Exception_in_callback, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 85, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_6);
            if (unlikely(!__pyx_v_callback)) { __Pyx_RaiseUnboundLocalError("callback"); __PYX_ERR(3, 85, __pyx_L20_error) }
            __pyx_t_12 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_6, function);
              }
            }
            if (!__pyx_t_12) {
              __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_callback); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 85, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_8);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_6)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_callback};
                __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 85, __pyx_L20_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_8);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
                PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_callback};
                __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 85, __pyx_L20_error)
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_GOTREF(__pyx_t_8);
              } else
              #endif
              {
                __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(3, 85, __pyx_L20_error)
                __Pyx_GOTREF(__pyx_t_13);
                __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
                __Pyx_INCREF(__pyx_v_callback);
                __Pyx_GIVEREF(__pyx_v_callback);
                PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_callback);
                __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 85, __pyx_L20_error)
                __Pyx_GOTREF(__pyx_t_8);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_v_msg = __pyx_t_8;
            __pyx_t_8 = 0;

            /* "uvloop/cbhandles.pyx":84
 * 
 *         except Exception as ex:
 *             if cb_type == 1:             # <<<<<<<<<<<<<<
 *                 msg = 'Exception in callback {}'.format(callback)
 *             else:
 */
            goto __pyx_L22;
          }

          /* "uvloop/cbhandles.pyx":87
 *                 msg = 'Exception in callback {}'.format(callback)
 *             else:
 *                 msg = 'Exception in callback {}'.format(self.meth_name)             # <<<<<<<<<<<<<<
 * 
 *             context = {
 */
          /*else*/ {
            __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Exception_in_callback, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 87, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_13 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
              __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_6);
              if (likely(__pyx_t_13)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_6, function);
              }
            }
            if (!__pyx_t_13) {
              __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_self->meth_name); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 87, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_8);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_6)) {
                PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_self->meth_name};
                __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 87, __pyx_L20_error)
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_GOTREF(__pyx_t_8);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
                PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_self->meth_name};
                __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 87, __pyx_L20_error)
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_GOTREF(__pyx_t_8);
              } else
              #endif
              {
                __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(3, 87, __pyx_L20_error)
                __Pyx_GOTREF(__pyx_t_12);
                __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_13); __pyx_t_13 = NULL;
                __Pyx_INCREF(__pyx_v_self->meth_name);
                __Pyx_GIVEREF(__pyx_v_self->meth_name);
                PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_v_self->meth_name);
                __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_12, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 87, __pyx_L20_error)
                __Pyx_GOTREF(__pyx_t_8);
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_v_msg = __pyx_t_8;
            __pyx_t_8 = 0;
          }
          __pyx_L22:;

          /* "uvloop/cbhandles.pyx":90
 * 
 *             context = {
 *                 'message': msg,             # <<<<<<<<<<<<<<
 *                 'exception': ex,
 *                 'handle': self,
 */
          __pyx_t_8 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 90, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_8);
          if (PyDict_SetItem(__pyx_t_8, __pyx_n_u_message, __pyx_v_msg) < 0) __PYX_ERR(3, 90, __pyx_L20_error)

          /* "uvloop/cbhandles.pyx":91
 *             context = {
 *                 'message': msg,
 *                 'exception': ex,             # <<<<<<<<<<<<<<
 *                 'handle': self,
 *             }
 */
          if (PyDict_SetItem(__pyx_t_8, __pyx_n_u_exception, __pyx_v_ex) < 0) __PYX_ERR(3, 90, __pyx_L20_error)

          /* "uvloop/cbhandles.pyx":92
 *                 'message': msg,
 *                 'exception': ex,
 *                 'handle': self,             # <<<<<<<<<<<<<<
 *             }
 * 
 */
          if (PyDict_SetItem(__pyx_t_8, __pyx_n_u_handle, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(3, 90, __pyx_L20_error)
          __pyx_v_context = __pyx_t_8;
          __pyx_t_8 = 0;

          /* "uvloop/cbhandles.pyx":95
 *             }
 * 
 *             if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *                 context['source_traceback'] = self._source_traceback
 * 
 */
          __pyx_t_7 = (__pyx_v_self->_source_traceback != Py_None);
          __pyx_t_1 = (__pyx_t_7 != 0);
          if (__pyx_t_1) {

            /* "uvloop/cbhandles.pyx":96
 * 
 *             if self._source_traceback is not None:
 *                 context['source_traceback'] = self._source_traceback             # <<<<<<<<<<<<<<
 * 
 *             self.loop.call_exception_handler(context)
 */
            __pyx_t_8 = __pyx_v_self->_source_traceback;
            __Pyx_INCREF(__pyx_t_8);
            if (unlikely(PyObject_SetItem(__pyx_v_context, __pyx_n_u_source_traceback, __pyx_t_8) < 0)) __PYX_ERR(3, 96, __pyx_L20_error)
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

            /* "uvloop/cbhandles.pyx":95
 *             }
 * 
 *             if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *                 context['source_traceback'] = self._source_traceback
 * 
 */
          }

          /* "uvloop/cbhandles.pyx":98
 *                 context['source_traceback'] = self._source_traceback
 * 
 *             self.loop.call_exception_handler(context)             # <<<<<<<<<<<<<<
 * 
 *         finally:
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 98, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          if (!__pyx_t_12) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_context); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 98, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_context};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 98, __pyx_L20_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_context};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 98, __pyx_L20_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            {
              __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(3, 98, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
              __Pyx_INCREF(__pyx_v_context);
              __Pyx_GIVEREF(__pyx_v_context);
              PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_context);
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 98, __pyx_L20_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }

        /* "uvloop/cbhandles.pyx":83
 *                     cb_type))
 * 
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             if cb_type == 1:
 *                 msg = 'Exception in callback {}'.format(callback)
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L21;
          }
          __pyx_L20_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __pyx_t_2 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
            }
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __pyx_lineno = __pyx_t_2; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
            goto __pyx_L9_except_error;
          }
          __pyx_L21:;
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/cbhandles.pyx":52
 *                           # we guard 'self' manually (since the callback
 *                           # might cause GC of the handle.)
 *         try:             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 assert self.context is not None
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L5_error;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_L12_try_end:;
    }
  }

  /* "uvloop/cbhandles.pyx":101
 * 
 *         finally:
 *             context = self.context             # <<<<<<<<<<<<<<
 *             Py_DECREF(self)
 *             if PY37:
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_10 = __pyx_v_self->context;
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_XDECREF_SET(__pyx_v_context, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "uvloop/cbhandles.pyx":102
 *         finally:
 *             context = self.context
 *             Py_DECREF(self)             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)
 */
      Py_DECREF(((PyObject *)__pyx_v_self));

      /* "uvloop/cbhandles.pyx":103
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
      __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
      if (__pyx_t_1) {

        /* "uvloop/cbhandles.pyx":104
 *             Py_DECREF(self)
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)             # <<<<<<<<<<<<<<
 * 
 *     cdef _cancel(self):
 */
        __pyx_t_14 = PyContext_Exit(((PyContext *)__pyx_v_context)); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(3, 104, __pyx_L1_error)

        /* "uvloop/cbhandles.pyx":103
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
      }
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3) < 0)) __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_21);
      __Pyx_XGOTREF(__pyx_t_20);
      __Pyx_XGOTREF(__pyx_t_19);
      __pyx_t_14 = __pyx_lineno; __pyx_t_2 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
      {

        /* "uvloop/cbhandles.pyx":101
 * 
 *         finally:
 *             context = self.context             # <<<<<<<<<<<<<<
 *             Py_DECREF(self)
 *             if PY37:
 */
        __pyx_t_10 = __pyx_v_self->context;
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_XDECREF_SET(__pyx_v_context, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "uvloop/cbhandles.pyx":102
 *         finally:
 *             context = self.context
 *             Py_DECREF(self)             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)
 */
        Py_DECREF(((PyObject *)__pyx_v_self));

        /* "uvloop/cbhandles.pyx":103
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
        __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
        if (__pyx_t_1) {

          /* "uvloop/cbhandles.pyx":104
 *             Py_DECREF(self)
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)             # <<<<<<<<<<<<<<
 * 
 *     cdef _cancel(self):
 */
          __pyx_t_23 = PyContext_Exit(((PyContext *)__pyx_v_context)); if (unlikely(__pyx_t_23 == ((int)-1))) __PYX_ERR(3, 104, __pyx_L30_error)

          /* "uvloop/cbhandles.pyx":103
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
        }
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
      }
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ErrRestore(__pyx_t_5, __pyx_t_4, __pyx_t_3);
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0;
      __pyx_lineno = __pyx_t_14; __pyx_clineno = __pyx_t_2; __pyx_filename = __pyx_t_22;
      goto __pyx_L1_error;
      __pyx_L30_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/cbhandles.pyx":39
 *                 self.__class__.__name__))
 * 
 *     cdef inline _run(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int cb_type
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.Handle._run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XDECREF(__pyx_v_context);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":106
 *                 PyContext_Exit(<PyContext*>context)
 * 
 *     cdef _cancel(self):             # <<<<<<<<<<<<<<
 *         self._cancelled = 1
 *         self.callback = NULL
 */

static PyObject *__pyx_f_6uvloop_4loop_6Handle__cancel(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_cancel", 0);

  /* "uvloop/cbhandles.pyx":107
 * 
 *     cdef _cancel(self):
 *         self._cancelled = 1             # <<<<<<<<<<<<<<
 *         self.callback = NULL
 *         self.arg2 = self.arg3 = self.arg4 = None
 */
  __pyx_v_self->_cancelled = 1;

  /* "uvloop/cbhandles.pyx":108
 *     cdef _cancel(self):
 *         self._cancelled = 1
 *         self.callback = NULL             # <<<<<<<<<<<<<<
 *         self.arg2 = self.arg3 = self.arg4 = None
 * 
 */
  __pyx_v_self->callback = NULL;

  /* "uvloop/cbhandles.pyx":109
 *         self._cancelled = 1
 *         self.callback = NULL
 *         self.arg2 = self.arg3 = self.arg4 = None             # <<<<<<<<<<<<<<
 * 
 *     cdef _format_handle(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->arg2);
  __Pyx_DECREF(__pyx_v_self->arg2);
  __pyx_v_self->arg2 = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->arg3);
  __Pyx_DECREF(__pyx_v_self->arg3);
  __pyx_v_self->arg3 = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->arg4);
  __Pyx_DECREF(__pyx_v_self->arg4);
  __pyx_v_self->arg4 = Py_None;

  /* "uvloop/cbhandles.pyx":106
 *                 PyContext_Exit(<PyContext*>context)
 * 
 *     cdef _cancel(self):             # <<<<<<<<<<<<<<
 *         self._cancelled = 1
 *         self.callback = NULL
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":111
 *         self.arg2 = self.arg3 = self.arg4 = None
 * 
 *     cdef _format_handle(self):             # <<<<<<<<<<<<<<
 *         # Mirrors `asyncio.base_events._format_handle`.
 *         if self.cb_type == 1:
 */

static PyObject *__pyx_f_6uvloop_4loop_6Handle__format_handle(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  PyObject *__pyx_v_cb = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  __Pyx_RefNannySetupContext("_format_handle", 0);

  /* "uvloop/cbhandles.pyx":113
 *     cdef _format_handle(self):
 *         # Mirrors `asyncio.base_events._format_handle`.
 *         if self.cb_type == 1:             # <<<<<<<<<<<<<<
 *             cb = self.arg1
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):
 */
  __pyx_t_1 = ((__pyx_v_self->cb_type == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":114
 *         # Mirrors `asyncio.base_events._format_handle`.
 *         if self.cb_type == 1:
 *             cb = self.arg1             # <<<<<<<<<<<<<<
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):
 *                 try:
 */
    __pyx_t_2 = __pyx_v_self->arg1;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_cb = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/cbhandles.pyx":115
 *         if self.cb_type == 1:
 *             cb = self.arg1
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):             # <<<<<<<<<<<<<<
 *                 try:
 *                     return repr(cb.__self__)
 */
    __pyx_t_2 = __Pyx_GetAttr3(__pyx_v_cb, __pyx_n_u_self, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_Task;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_1 = PyObject_IsInstance(__pyx_t_2, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(3, 115, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = (__pyx_t_1 != 0);
    if (__pyx_t_4) {

      /* "uvloop/cbhandles.pyx":116
 *             cb = self.arg1
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):
 *                 try:             # <<<<<<<<<<<<<<
 *                     return repr(cb.__self__)
 *                 except (AttributeError, TypeError, ValueError) as ex:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        /*try:*/ {

          /* "uvloop/cbhandles.pyx":117
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):
 *                 try:
 *                     return repr(cb.__self__)             # <<<<<<<<<<<<<<
 *                 except (AttributeError, TypeError, ValueError) as ex:
 *                     # Cython generates empty __code__ objects for coroutines
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_cb, __pyx_n_s_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 117, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = PyObject_Repr(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 117, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_r = __pyx_t_2;
          __pyx_t_2 = 0;
          goto __pyx_L9_try_return;

          /* "uvloop/cbhandles.pyx":116
 *             cb = self.arg1
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):
 *                 try:             # <<<<<<<<<<<<<<
 *                     return repr(cb.__self__)
 *                 except (AttributeError, TypeError, ValueError) as ex:
 */
        }
        __pyx_L5_error:;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/cbhandles.pyx":118
 *                 try:
 *                     return repr(cb.__self__)
 *                 except (AttributeError, TypeError, ValueError) as ex:             # <<<<<<<<<<<<<<
 *                     # Cython generates empty __code__ objects for coroutines
 *                     # that can crash asyncio.Task.__repr__ with an
 */
        __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
        if (__pyx_t_8) {
          __Pyx_AddTraceback("uvloop.loop.Handle._format_handle", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_9) < 0) __PYX_ERR(3, 118, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_3);
          __pyx_v_ex = __pyx_t_3;
          /*try:*/ {

            /* "uvloop/cbhandles.pyx":122
 *                     # that can crash asyncio.Task.__repr__ with an
 *                     # AttributeError etc.  Guard against that.
 *                     self.loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                         'message': 'exception in Task.__repr__',
 *                         'task': cb.__self__,
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 122, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_11);

            /* "uvloop/cbhandles.pyx":123
 *                     # AttributeError etc.  Guard against that.
 *                     self.loop.call_exception_handler({
 *                         'message': 'exception in Task.__repr__',             # <<<<<<<<<<<<<<
 *                         'task': cb.__self__,
 *                         'exception': ex,
 */
            __pyx_t_12 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_12)) __PYX_ERR(3, 123, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_12);
            if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_message, __pyx_kp_u_exception_in_Task___repr) < 0) __PYX_ERR(3, 123, __pyx_L16_error)

            /* "uvloop/cbhandles.pyx":124
 *                     self.loop.call_exception_handler({
 *                         'message': 'exception in Task.__repr__',
 *                         'task': cb.__self__,             # <<<<<<<<<<<<<<
 *                         'exception': ex,
 *                         'handle': self,
 */
            __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_cb, __pyx_n_s_self); if (unlikely(!__pyx_t_13)) __PYX_ERR(3, 124, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_13);
            if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_task, __pyx_t_13) < 0) __PYX_ERR(3, 123, __pyx_L16_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

            /* "uvloop/cbhandles.pyx":125
 *                         'message': 'exception in Task.__repr__',
 *                         'task': cb.__self__,
 *                         'exception': ex,             # <<<<<<<<<<<<<<
 *                         'handle': self,
 *                     })
 */
            if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_exception, __pyx_v_ex) < 0) __PYX_ERR(3, 123, __pyx_L16_error)

            /* "uvloop/cbhandles.pyx":126
 *                         'task': cb.__self__,
 *                         'exception': ex,
 *                         'handle': self,             # <<<<<<<<<<<<<<
 *                     })
 *         return repr(self)
 */
            if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_handle, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(3, 123, __pyx_L16_error)
            __pyx_t_13 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
              __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
              if (likely(__pyx_t_13)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_11, function);
              }
            }
            if (!__pyx_t_13) {
              __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 122, __pyx_L16_error)
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_10);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_11)) {
                PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_12};
                __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 122, __pyx_L16_error)
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_GOTREF(__pyx_t_10);
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
                PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_12};
                __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 122, __pyx_L16_error)
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_GOTREF(__pyx_t_10);
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              } else
              #endif
              {
                __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(3, 122, __pyx_L16_error)
                __Pyx_GOTREF(__pyx_t_14);
                __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
                __Pyx_GIVEREF(__pyx_t_12);
                PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_t_12);
                __pyx_t_12 = 0;
                __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_14, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 122, __pyx_L16_error)
                __Pyx_GOTREF(__pyx_t_10);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }

          /* "uvloop/cbhandles.pyx":118
 *                 try:
 *                     return repr(cb.__self__)
 *                 except (AttributeError, TypeError, ValueError) as ex:             # <<<<<<<<<<<<<<
 *                     # Cython generates empty __code__ objects for coroutines
 *                     # that can crash asyncio.Task.__repr__ with an
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
              goto __pyx_L17;
            }
            __pyx_L16_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_17);
              __Pyx_XGOTREF(__pyx_t_18);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_22);
              __pyx_t_8 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_ex);
                __pyx_v_ex = NULL;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_XGIVEREF(__pyx_t_22);
                __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
              }
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
              __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
              __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
              goto __pyx_L7_except_error;
            }
            __pyx_L17:;
          }
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L6_exception_handled;
        }
        goto __pyx_L7_except_error;
        __pyx_L7_except_error:;

        /* "uvloop/cbhandles.pyx":116
 *             cb = self.arg1
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):
 *                 try:             # <<<<<<<<<<<<<<
 *                     return repr(cb.__self__)
 *                 except (AttributeError, TypeError, ValueError) as ex:
 */
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        goto __pyx_L1_error;
        __pyx_L9_try_return:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        goto __pyx_L0;
        __pyx_L6_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      }

      /* "uvloop/cbhandles.pyx":115
 *         if self.cb_type == 1:
 *             cb = self.arg1
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):             # <<<<<<<<<<<<<<
 *                 try:
 *                     return repr(cb.__self__)
 */
    }

    /* "uvloop/cbhandles.pyx":113
 *     cdef _format_handle(self):
 *         # Mirrors `asyncio.base_events._format_handle`.
 *         if self.cb_type == 1:             # <<<<<<<<<<<<<<
 *             cb = self.arg1
 *             if isinstance(getattr(cb, '__self__', None), aio_Task):
 */
  }

  /* "uvloop/cbhandles.pyx":128
 *                         'handle': self,
 *                     })
 *         return repr(self)             # <<<<<<<<<<<<<<
 * 
 *     # Public API
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_9 = PyObject_Repr(((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_9)) __PYX_ERR(3, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":111
 *         self.arg2 = self.arg3 = self.arg4 = None
 * 
 *     cdef _format_handle(self):             # <<<<<<<<<<<<<<
 *         # Mirrors `asyncio.base_events._format_handle`.
 *         if self.cb_type == 1:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("uvloop.loop.Handle._format_handle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cb);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":132
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         info = [self.__class__.__name__]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_7__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_7__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle_6__repr__(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Handle_6__repr__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_func = NULL;
  PyObject *__pyx_v_cb_name = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/cbhandles.pyx":133
 * 
 *     def __repr__(self):
 *         info = [self.__class__.__name__]             # <<<<<<<<<<<<<<
 * 
 *         if self._cancelled:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_v_info = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":135
 *         info = [self.__class__.__name__]
 * 
 *         if self._cancelled:             # <<<<<<<<<<<<<<
 *             info.append('cancelled')
 * 
 */
  __pyx_t_3 = (__pyx_v_self->_cancelled != 0);
  if (__pyx_t_3) {

    /* "uvloop/cbhandles.pyx":136
 * 
 *         if self._cancelled:
 *             info.append('cancelled')             # <<<<<<<<<<<<<<
 * 
 *         if self.cb_type == 1:
 */
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_info, __pyx_n_u_cancelled); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 136, __pyx_L1_error)

    /* "uvloop/cbhandles.pyx":135
 *         info = [self.__class__.__name__]
 * 
 *         if self._cancelled:             # <<<<<<<<<<<<<<
 *             info.append('cancelled')
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":138
 *             info.append('cancelled')
 * 
 *         if self.cb_type == 1:             # <<<<<<<<<<<<<<
 *             func = self.arg1
 *             # Cython can unset func.__qualname__/__name__, hence the checks.
 */
  __pyx_t_3 = ((__pyx_v_self->cb_type == 1) != 0);
  if (__pyx_t_3) {

    /* "uvloop/cbhandles.pyx":139
 * 
 *         if self.cb_type == 1:
 *             func = self.arg1             # <<<<<<<<<<<<<<
 *             # Cython can unset func.__qualname__/__name__, hence the checks.
 *             if hasattr(func, '__qualname__') and func.__qualname__:
 */
    __pyx_t_1 = __pyx_v_self->arg1;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_func = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/cbhandles.pyx":141
 *             func = self.arg1
 *             # Cython can unset func.__qualname__/__name__, hence the checks.
 *             if hasattr(func, '__qualname__') and func.__qualname__:             # <<<<<<<<<<<<<<
 *                 cb_name = func.__qualname__
 *             elif hasattr(func, '__name__') and func.__name__:
 */
    __pyx_t_5 = __Pyx_HasAttr(__pyx_v_func, __pyx_n_u_qualname); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(3, 141, __pyx_L1_error)
    __pyx_t_6 = (__pyx_t_5 != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_3 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_func, __pyx_n_s_qualname); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(3, 141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_3) {

      /* "uvloop/cbhandles.pyx":142
 *             # Cython can unset func.__qualname__/__name__, hence the checks.
 *             if hasattr(func, '__qualname__') and func.__qualname__:
 *                 cb_name = func.__qualname__             # <<<<<<<<<<<<<<
 *             elif hasattr(func, '__name__') and func.__name__:
 *                 cb_name = func.__name__
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_func, __pyx_n_s_qualname); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 142, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_cb_name = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "uvloop/cbhandles.pyx":141
 *             func = self.arg1
 *             # Cython can unset func.__qualname__/__name__, hence the checks.
 *             if hasattr(func, '__qualname__') and func.__qualname__:             # <<<<<<<<<<<<<<
 *                 cb_name = func.__qualname__
 *             elif hasattr(func, '__name__') and func.__name__:
 */
      goto __pyx_L5;
    }

    /* "uvloop/cbhandles.pyx":143
 *             if hasattr(func, '__qualname__') and func.__qualname__:
 *                 cb_name = func.__qualname__
 *             elif hasattr(func, '__name__') and func.__name__:             # <<<<<<<<<<<<<<
 *                 cb_name = func.__name__
 *             else:
 */
    __pyx_t_6 = __Pyx_HasAttr(__pyx_v_func, __pyx_n_u_name); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(3, 143, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_func, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 143, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(3, 143, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __pyx_t_5;
    __pyx_L8_bool_binop_done:;
    if (__pyx_t_3) {

      /* "uvloop/cbhandles.pyx":144
 *                 cb_name = func.__qualname__
 *             elif hasattr(func, '__name__') and func.__name__:
 *                 cb_name = func.__name__             # <<<<<<<<<<<<<<
 *             else:
 *                 cb_name = repr(func)
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_func, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 144, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_cb_name = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "uvloop/cbhandles.pyx":143
 *             if hasattr(func, '__qualname__') and func.__qualname__:
 *                 cb_name = func.__qualname__
 *             elif hasattr(func, '__name__') and func.__name__:             # <<<<<<<<<<<<<<
 *                 cb_name = func.__name__
 *             else:
 */
      goto __pyx_L5;
    }

    /* "uvloop/cbhandles.pyx":146
 *                 cb_name = func.__name__
 *             else:
 *                 cb_name = repr(func)             # <<<<<<<<<<<<<<
 * 
 *             info.append(cb_name)
 */
    /*else*/ {
      __pyx_t_1 = PyObject_Repr(__pyx_v_func); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_cb_name = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "uvloop/cbhandles.pyx":148
 *                 cb_name = repr(func)
 * 
 *             info.append(cb_name)             # <<<<<<<<<<<<<<
 *         else:
 *             info.append(self.meth_name)
 */
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_info, __pyx_v_cb_name); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 148, __pyx_L1_error)

    /* "uvloop/cbhandles.pyx":138
 *             info.append('cancelled')
 * 
 *         if self.cb_type == 1:             # <<<<<<<<<<<<<<
 *             func = self.arg1
 *             # Cython can unset func.__qualname__/__name__, hence the checks.
 */
    goto __pyx_L4;
  }

  /* "uvloop/cbhandles.pyx":150
 *             info.append(cb_name)
 *         else:
 *             info.append(self.meth_name)             # <<<<<<<<<<<<<<
 * 
 *         if self._source_traceback is not None:
 */
  /*else*/ {
    __pyx_t_1 = __pyx_v_self->meth_name;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_info, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 150, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "uvloop/cbhandles.pyx":152
 *             info.append(self.meth_name)
 * 
 *         if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *             frame = self._source_traceback[-1]
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 */
  __pyx_t_3 = (__pyx_v_self->_source_traceback != Py_None);
  __pyx_t_5 = (__pyx_t_3 != 0);
  if (__pyx_t_5) {

    /* "uvloop/cbhandles.pyx":153
 * 
 *         if self._source_traceback is not None:
 *             frame = self._source_traceback[-1]             # <<<<<<<<<<<<<<
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 * 
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_self->_source_traceback, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_frame = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/cbhandles.pyx":154
 *         if self._source_traceback is not None:
 *             frame = self._source_traceback[-1]
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))             # <<<<<<<<<<<<<<
 * 
 *         return '<' + ' '.join(info) + '>'
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_created_at, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_frame, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(3, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_GetItemInt(__pyx_v_frame, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = NULL;
    __pyx_t_10 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_10 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_7, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 154, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_t_7, __pyx_t_8};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 154, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__pyx_t_9) {
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_8);
      __pyx_t_7 = 0;
      __pyx_t_8 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_info, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 154, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/cbhandles.pyx":152
 *             info.append(self.meth_name)
 * 
 *         if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *             frame = self._source_traceback[-1]
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 */
  }

  /* "uvloop/cbhandles.pyx":156
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 * 
 *         return '<' + ' '.join(info) + '>'             # <<<<<<<<<<<<<<
 * 
 *     def cancel(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__129, __pyx_v_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__128, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_kp_u__130); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":132
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         info = [self.__class__.__name__]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("uvloop.loop.Handle.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_func);
  __Pyx_XDECREF(__pyx_v_cb_name);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":158
 *         return '<' + ' '.join(info) + '>'
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         self._cancel()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_9cancel(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Handle_8cancel[] = "Handle.cancel(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_9cancel(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle_8cancel(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Handle_8cancel(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("cancel", 0);

  /* "uvloop/cbhandles.pyx":159
 * 
 *     def cancel(self):
 *         self._cancel()             # <<<<<<<<<<<<<<
 * 
 *     def cancelled(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_self->__pyx_vtab)->_cancel(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":158
 *         return '<' + ' '.join(info) + '>'
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         self._cancel()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Handle.cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":161
 *         self._cancel()
 * 
 *     def cancelled(self):             # <<<<<<<<<<<<<<
 *         return self._cancelled
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_11cancelled(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Handle_10cancelled[] = "Handle.cancelled(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_11cancelled(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancelled (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle_10cancelled(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Handle_10cancelled(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("cancelled", 0);

  /* "uvloop/cbhandles.pyx":162
 * 
 *     def cancelled(self):
 *         return self._cancelled             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_cancelled); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":161
 *         self._cancel()
 * 
 *     def cancelled(self):             # <<<<<<<<<<<<<<
 *         return self._cancelled
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Handle.cancelled", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pxd":14
 *         object __weakref__
 * 
 *         readonly _source_traceback             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _set_loop(self, Loop loop)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_17_source_traceback_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_17_source_traceback_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle_17_source_traceback___get__(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Handle_17_source_traceback___get__(struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_source_traceback);
  __pyx_r = __pyx_v_self->_source_traceback;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_13__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Handle_12__reduce_cython__[] = "Handle.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_13__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle_12__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Handle_12__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__131, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Handle.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_15__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Handle_14__setstate_cython__[] = "Handle.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_6Handle_15__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Handle_14__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Handle_14__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__132, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Handle.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":168
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class TimerHandle:
 *     def __cinit__(self, Loop loop, object callback, object args,             # <<<<<<<<<<<<<<
 *                   uint64_t delay, object context):
 * 
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_11TimerHandle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_11TimerHandle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_args = 0;
  uint64_t __pyx_v_delay;
  PyObject *__pyx_v_context = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loop,&__pyx_n_s_callback,&__pyx_n_s_args,&__pyx_n_s_delay,&__pyx_n_s_context,0};
    PyObject* values[5] = {0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 5, 5, 1); __PYX_ERR(3, 168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_args)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 5, 5, 2); __PYX_ERR(3, 168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_delay)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 5, 5, 3); __PYX_ERR(3, 168, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_context)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 5, 5, 4); __PYX_ERR(3, 168, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(3, 168, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 5) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
    }
    __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)values[0]);
    __pyx_v_callback = values[1];
    __pyx_v_args = values[2];
    __pyx_v_delay = __Pyx_PyInt_As_uint64_t(values[3]); if (unlikely((__pyx_v_delay == ((uint64_t)-1)) && PyErr_Occurred())) __PYX_ERR(3, 169, __pyx_L3_error)
    __pyx_v_context = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 5, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(3, 168, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.TimerHandle.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_loop), __pyx_ptype_6uvloop_4loop_Loop, 1, "loop", 0))) __PYX_ERR(3, 168, __pyx_L1_error)
  __pyx_r = __pyx_pf_6uvloop_4loop_11TimerHandle___cinit__(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self), __pyx_v_loop, __pyx_v_callback, __pyx_v_args, __pyx_v_delay, __pyx_v_context);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_11TimerHandle___cinit__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_callback, PyObject *__pyx_v_args, uint64_t __pyx_v_delay, PyObject *__pyx_v_context) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyContext *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_INCREF(__pyx_v_context);

  /* "uvloop/cbhandles.pyx":171
 *                   uint64_t delay, object context):
 * 
 *         self.loop = loop             # <<<<<<<<<<<<<<
 *         self.callback = callback
 *         self.args = args
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_loop));
  __Pyx_GOTREF(__pyx_v_self->loop);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->loop));
  __pyx_v_self->loop = __pyx_v_loop;

  /* "uvloop/cbhandles.pyx":172
 * 
 *         self.loop = loop
 *         self.callback = callback             # <<<<<<<<<<<<<<
 *         self.args = args
 *         self._cancelled = 0
 */
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  __Pyx_GOTREF(__pyx_v_self->callback);
  __Pyx_DECREF(__pyx_v_self->callback);
  __pyx_v_self->callback = __pyx_v_callback;

  /* "uvloop/cbhandles.pyx":173
 *         self.loop = loop
 *         self.callback = callback
 *         self.args = args             # <<<<<<<<<<<<<<
 *         self._cancelled = 0
 * 
 */
  __Pyx_INCREF(__pyx_v_args);
  __Pyx_GIVEREF(__pyx_v_args);
  __Pyx_GOTREF(__pyx_v_self->args);
  __Pyx_DECREF(__pyx_v_self->args);
  __pyx_v_self->args = __pyx_v_args;

  /* "uvloop/cbhandles.pyx":174
 *         self.callback = callback
 *         self.args = args
 *         self._cancelled = 0             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
  __pyx_v_self->_cancelled = 0;

  /* "uvloop/cbhandles.pyx":176
 *         self._cancelled = 0
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self.loop._debug_cb_timer_handles_total += 1
 *             self.loop._debug_cb_timer_handles_count += 1
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":177
 * 
 *         if UVLOOP_DEBUG:
 *             self.loop._debug_cb_timer_handles_total += 1             # <<<<<<<<<<<<<<
 *             self.loop._debug_cb_timer_handles_count += 1
 * 
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self->loop));
    __pyx_t_2 = __pyx_v_self->loop;
    __pyx_t_2->_debug_cb_timer_handles_total = (__pyx_t_2->_debug_cb_timer_handles_total + 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

    /* "uvloop/cbhandles.pyx":178
 *         if UVLOOP_DEBUG:
 *             self.loop._debug_cb_timer_handles_total += 1
 *             self.loop._debug_cb_timer_handles_count += 1             # <<<<<<<<<<<<<<
 * 
 *         if PY37:
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self->loop));
    __pyx_t_2 = __pyx_v_self->loop;
    __pyx_t_2->_debug_cb_timer_handles_count = (__pyx_t_2->_debug_cb_timer_handles_count + 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

    /* "uvloop/cbhandles.pyx":176
 *         self._cancelled = 0
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self.loop._debug_cb_timer_handles_total += 1
 *             self.loop._debug_cb_timer_handles_count += 1
 */
  }

  /* "uvloop/cbhandles.pyx":180
 *             self.loop._debug_cb_timer_handles_count += 1
 * 
 *         if PY37:             # <<<<<<<<<<<<<<
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":181
 * 
 *         if PY37:
 *             if context is None:             # <<<<<<<<<<<<<<
 *                 context = <object>PyContext_CopyCurrent()
 *             self.context = context
 */
    __pyx_t_1 = (__pyx_v_context == Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "uvloop/cbhandles.pyx":182
 *         if PY37:
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()             # <<<<<<<<<<<<<<
 *             self.context = context
 *         else:
 */
      __pyx_t_4 = PyContext_CopyCurrent(); if (unlikely(__pyx_t_4 == ((PyContext *)NULL))) __PYX_ERR(3, 182, __pyx_L1_error)
      __pyx_t_5 = ((PyObject *)__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_context, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/cbhandles.pyx":181
 * 
 *         if PY37:
 *             if context is None:             # <<<<<<<<<<<<<<
 *                 context = <object>PyContext_CopyCurrent()
 *             self.context = context
 */
    }

    /* "uvloop/cbhandles.pyx":183
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()
 *             self.context = context             # <<<<<<<<<<<<<<
 *         else:
 *             if context is not None:
 */
    __Pyx_INCREF(__pyx_v_context);
    __Pyx_GIVEREF(__pyx_v_context);
    __Pyx_GOTREF(__pyx_v_self->context);
    __Pyx_DECREF(__pyx_v_self->context);
    __pyx_v_self->context = __pyx_v_context;

    /* "uvloop/cbhandles.pyx":180
 *             self.loop._debug_cb_timer_handles_count += 1
 * 
 *         if PY37:             # <<<<<<<<<<<<<<
 *             if context is None:
 *                 context = <object>PyContext_CopyCurrent()
 */
    goto __pyx_L4;
  }

  /* "uvloop/cbhandles.pyx":185
 *             self.context = context
 *         else:
 *             if context is not None:             # <<<<<<<<<<<<<<
 *                 raise NotImplementedError(
 *                     '"context" argument requires Python 3.7')
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_context != Py_None);
    __pyx_t_1 = (__pyx_t_3 != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/cbhandles.pyx":186
 *         else:
 *             if context is not None:
 *                 raise NotImplementedError(             # <<<<<<<<<<<<<<
 *                     '"context" argument requires Python 3.7')
 *             self.context = None
 */
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__133, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(3, 186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(3, 186, __pyx_L1_error)

      /* "uvloop/cbhandles.pyx":185
 *             self.context = context
 *         else:
 *             if context is not None:             # <<<<<<<<<<<<<<
 *                 raise NotImplementedError(
 *                     '"context" argument requires Python 3.7')
 */
    }

    /* "uvloop/cbhandles.pyx":188
 *                 raise NotImplementedError(
 *                     '"context" argument requires Python 3.7')
 *             self.context = None             # <<<<<<<<<<<<<<
 * 
 *         if loop._debug:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->context);
    __Pyx_DECREF(__pyx_v_self->context);
    __pyx_v_self->context = Py_None;
  }
  __pyx_L4:;

  /* "uvloop/cbhandles.pyx":190
 *             self.context = None
 * 
 *         if loop._debug:             # <<<<<<<<<<<<<<
 *             self._source_traceback = extract_stack()
 * 
 */
  __pyx_t_1 = (__pyx_v_loop->_debug != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":191
 * 
 *         if loop._debug:
 *             self._source_traceback = extract_stack()             # <<<<<<<<<<<<<<
 * 
 *         self.timer = UVTimer.new(
 */
    __pyx_t_5 = __pyx_f_6uvloop_4loop_extract_stack(); if (unlikely(!__pyx_t_5)) __PYX_ERR(3, 191, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_v_self->_source_traceback);
    __Pyx_DECREF(__pyx_v_self->_source_traceback);
    __pyx_v_self->_source_traceback = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "uvloop/cbhandles.pyx":190
 *             self.context = None
 * 
 *         if loop._debug:             # <<<<<<<<<<<<<<
 *             self._source_traceback = extract_stack()
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":193
 *             self._source_traceback = extract_stack()
 * 
 *         self.timer = UVTimer.new(             # <<<<<<<<<<<<<<
 *             loop, <method_t>self._run, self, delay)
 * 
 */
  __pyx_t_5 = ((PyObject *)__pyx_f_6uvloop_4loop_7UVTimer_new(__pyx_v_loop, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_TimerHandle *)__pyx_v_self->__pyx_vtab)->_run), ((PyObject *)__pyx_v_self), __pyx_v_delay)); if (unlikely(!__pyx_t_5)) __PYX_ERR(3, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->timer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->timer));
  __pyx_v_self->timer = ((struct __pyx_obj_6uvloop_4loop_UVTimer *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "uvloop/cbhandles.pyx":196
 *             loop, <method_t>self._run, self, delay)
 * 
 *         self.timer.start()             # <<<<<<<<<<<<<<
 * 
 *         # Only add to loop._timers when `self.timer` is successfully created
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->timer->__pyx_base.__pyx_vtab)->start(__pyx_v_self->timer); if (unlikely(!__pyx_t_5)) __PYX_ERR(3, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/cbhandles.pyx":199
 * 
 *         # Only add to loop._timers when `self.timer` is successfully created
 *         loop._timers.add(self)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  if (unlikely(__pyx_v_loop->_timers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(3, 199, __pyx_L1_error)
  }
  __pyx_t_6 = PySet_Add(__pyx_v_loop->_timers, ((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(3, 199, __pyx_L1_error)

  /* "uvloop/cbhandles.pyx":168
 * @cython.freelist(DEFAULT_FREELIST_SIZE)
 * cdef class TimerHandle:
 *     def __cinit__(self, Loop loop, object callback, object args,             # <<<<<<<<<<<<<<
 *                   uint64_t delay, object context):
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(((PyObject *)__pyx_t_2));
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_context);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":201
 *         loop._timers.add(self)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             self.loop._debug_cb_timer_handles_count -= 1
 */

/* Python wrapper */
static void __pyx_pw_6uvloop_4loop_11TimerHandle_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6uvloop_4loop_11TimerHandle_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_6uvloop_4loop_11TimerHandle_2__dealloc__(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6uvloop_4loop_11TimerHandle_2__dealloc__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "uvloop/cbhandles.pyx":202
 * 
 *     def __dealloc__(self):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self.loop._debug_cb_timer_handles_count -= 1
 *         if self.timer is not None:
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":203
 *     def __dealloc__(self):
 *         if UVLOOP_DEBUG:
 *             self.loop._debug_cb_timer_handles_count -= 1             # <<<<<<<<<<<<<<
 *         if self.timer is not None:
 *             raise RuntimeError('active TimerHandle is deallacating')
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self->loop));
    __pyx_t_2 = __pyx_v_self->loop;
    __pyx_t_2->_debug_cb_timer_handles_count = (__pyx_t_2->_debug_cb_timer_handles_count - 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

    /* "uvloop/cbhandles.pyx":202
 * 
 *     def __dealloc__(self):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self.loop._debug_cb_timer_handles_count -= 1
 *         if self.timer is not None:
 */
  }

  /* "uvloop/cbhandles.pyx":204
 *         if UVLOOP_DEBUG:
 *             self.loop._debug_cb_timer_handles_count -= 1
 *         if self.timer is not None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('active TimerHandle is deallacating')
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->timer) != Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/cbhandles.pyx":205
 *             self.loop._debug_cb_timer_handles_count -= 1
 *         if self.timer is not None:
 *             raise RuntimeError('active TimerHandle is deallacating')             # <<<<<<<<<<<<<<
 * 
 *     cdef _cancel(self):
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__134, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(3, 205, __pyx_L1_error)

    /* "uvloop/cbhandles.pyx":204
 *         if UVLOOP_DEBUG:
 *             self.loop._debug_cb_timer_handles_count -= 1
 *         if self.timer is not None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('active TimerHandle is deallacating')
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":201
 *         loop._timers.add(self)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             self.loop._debug_cb_timer_handles_count -= 1
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(((PyObject *)__pyx_t_2));
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("uvloop.loop.TimerHandle.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/cbhandles.pyx":207
 *             raise RuntimeError('active TimerHandle is deallacating')
 * 
 *     cdef _cancel(self):             # <<<<<<<<<<<<<<
 *         if self._cancelled == 1:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_11TimerHandle__cancel(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_cancel", 0);

  /* "uvloop/cbhandles.pyx":208
 * 
 *     cdef _cancel(self):
 *         if self._cancelled == 1:             # <<<<<<<<<<<<<<
 *             return
 *         self._cancelled = 1
 */
  __pyx_t_1 = ((__pyx_v_self->_cancelled == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":209
 *     cdef _cancel(self):
 *         if self._cancelled == 1:
 *             return             # <<<<<<<<<<<<<<
 *         self._cancelled = 1
 *         self._clear()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/cbhandles.pyx":208
 * 
 *     cdef _cancel(self):
 *         if self._cancelled == 1:             # <<<<<<<<<<<<<<
 *             return
 *         self._cancelled = 1
 */
  }

  /* "uvloop/cbhandles.pyx":210
 *         if self._cancelled == 1:
 *             return
 *         self._cancelled = 1             # <<<<<<<<<<<<<<
 *         self._clear()
 * 
 */
  __pyx_v_self->_cancelled = 1;

  /* "uvloop/cbhandles.pyx":211
 *             return
 *         self._cancelled = 1
 *         self._clear()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _clear(self):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_11TimerHandle__clear(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/cbhandles.pyx":207
 *             raise RuntimeError('active TimerHandle is deallacating')
 * 
 *     cdef _cancel(self):             # <<<<<<<<<<<<<<
 *         if self._cancelled == 1:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle._cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":213
 *         self._clear()
 * 
 *     cdef inline _clear(self):             # <<<<<<<<<<<<<<
 *         if self.timer is None:
 *             return
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_11TimerHandle__clear(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  char const *__pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("_clear", 0);

  /* "uvloop/cbhandles.pyx":214
 * 
 *     cdef inline _clear(self):
 *         if self.timer is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->timer) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/cbhandles.pyx":215
 *     cdef inline _clear(self):
 *         if self.timer is None:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self.args = None
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/cbhandles.pyx":214
 * 
 *     cdef inline _clear(self):
 *         if self.timer is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":217
 *             return
 * 
 *         self.args = None             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->args);
  __Pyx_DECREF(__pyx_v_self->args);
  __pyx_v_self->args = Py_None;

  /* "uvloop/cbhandles.pyx":219
 *         self.args = None
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self.loop._timers.remove(self)
 *         finally:
 */
  /*try:*/ {

    /* "uvloop/cbhandles.pyx":220
 * 
 *         try:
 *             self.loop._timers.remove(self)             # <<<<<<<<<<<<<<
 *         finally:
 *             self.timer._close()
 */
    if (unlikely(__pyx_v_self->loop->_timers == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "remove");
      __PYX_ERR(3, 220, __pyx_L5_error)
    }
    __pyx_t_3 = __Pyx_PySet_Remove(__pyx_v_self->loop->_timers, ((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(3, 220, __pyx_L5_error)
  }

  /* "uvloop/cbhandles.pyx":222
 *             self.loop._timers.remove(self)
 *         finally:
 *             self.timer._close()             # <<<<<<<<<<<<<<
 *             self.timer = None  # let it die asap
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->timer->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self->timer)); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/cbhandles.pyx":223
 *         finally:
 *             self.timer._close()
 *             self.timer = None  # let it die asap             # <<<<<<<<<<<<<<
 * 
 *     cdef _run(self):
 */
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->timer);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->timer));
      __pyx_v_self->timer = ((struct __pyx_obj_6uvloop_4loop_UVTimer *)Py_None);
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __pyx_t_5 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_7 = __pyx_filename;
      {

        /* "uvloop/cbhandles.pyx":222
 *             self.loop._timers.remove(self)
 *         finally:
 *             self.timer._close()             # <<<<<<<<<<<<<<
 *             self.timer = None  # let it die asap
 * 
 */
        __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->timer->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self->timer)); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 222, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/cbhandles.pyx":223
 *         finally:
 *             self.timer._close()
 *             self.timer = None  # let it die asap             # <<<<<<<<<<<<<<
 * 
 *     cdef _run(self):
 */
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->timer);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->timer));
        __pyx_v_self->timer = ((struct __pyx_obj_6uvloop_4loop_UVTimer *)Py_None);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      }
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ErrRestore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_7;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/cbhandles.pyx":213
 *         self._clear()
 * 
 *     cdef inline _clear(self):             # <<<<<<<<<<<<<<
 *         if self.timer is None:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle._clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":225
 *             self.timer = None  # let it die asap
 * 
 *     cdef _run(self):             # <<<<<<<<<<<<<<
 *         if self._cancelled == 1:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_11TimerHandle__run(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_v_callback = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_started = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_context = NULL;
  PyObject *__pyx_v_delta = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  char const *__pyx_t_23;
  int __pyx_t_24;
  __Pyx_RefNannySetupContext("_run", 0);

  /* "uvloop/cbhandles.pyx":226
 * 
 *     cdef _run(self):
 *         if self._cancelled == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_cancelled == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":227
 *     cdef _run(self):
 *         if self._cancelled == 1:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         callback = self.callback
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/cbhandles.pyx":226
 * 
 *     cdef _run(self):
 *         if self._cancelled == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":229
 *             return
 * 
 *         callback = self.callback             # <<<<<<<<<<<<<<
 *         args = self.args
 *         self._clear()
 */
  __pyx_t_2 = __pyx_v_self->callback;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_callback = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/cbhandles.pyx":230
 * 
 *         callback = self.callback
 *         args = self.args             # <<<<<<<<<<<<<<
 *         self._clear()
 * 
 */
  __pyx_t_2 = __pyx_v_self->args;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_args = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/cbhandles.pyx":231
 *         callback = self.callback
 *         args = self.args
 *         self._clear()             # <<<<<<<<<<<<<<
 * 
 *         Py_INCREF(self)  # Since _run is a cdef and there's no BoundMethod,
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_11TimerHandle__clear(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/cbhandles.pyx":233
 *         self._clear()
 * 
 *         Py_INCREF(self)  # Since _run is a cdef and there's no BoundMethod,             # <<<<<<<<<<<<<<
 *                          # we guard 'self' manually.
 *         if self.loop._debug:
 */
  Py_INCREF(((PyObject *)__pyx_v_self));

  /* "uvloop/cbhandles.pyx":235
 *         Py_INCREF(self)  # Since _run is a cdef and there's no BoundMethod,
 *                          # we guard 'self' manually.
 *         if self.loop._debug:             # <<<<<<<<<<<<<<
 *             started = time_monotonic()
 *         try:
 */
  __pyx_t_1 = (__pyx_v_self->loop->_debug != 0);
  if (__pyx_t_1) {

    /* "uvloop/cbhandles.pyx":236
 *                          # we guard 'self' manually.
 *         if self.loop._debug:
 *             started = time_monotonic()             # <<<<<<<<<<<<<<
 *         try:
 *             if PY37:
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_time_monotonic);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_time_monotonic; __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 236, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 236, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_started = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/cbhandles.pyx":235
 *         Py_INCREF(self)  # Since _run is a cdef and there's no BoundMethod,
 *                          # we guard 'self' manually.
 *         if self.loop._debug:             # <<<<<<<<<<<<<<
 *             started = time_monotonic()
 *         try:
 */
  }

  /* "uvloop/cbhandles.pyx":237
 *         if self.loop._debug:
 *             started = time_monotonic()
 *         try:             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 assert self.context is not None
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "uvloop/cbhandles.pyx":238
 *             started = time_monotonic()
 *         try:
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 assert self.context is not None
 *                 PyContext_Enter(<PyContext*>self.context)
 */
        __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
        if (__pyx_t_1) {

          /* "uvloop/cbhandles.pyx":239
 *         try:
 *             if PY37:
 *                 assert self.context is not None             # <<<<<<<<<<<<<<
 *                 PyContext_Enter(<PyContext*>self.context)
 * 
 */
          #ifndef CYTHON_WITHOUT_ASSERTIONS
          if (unlikely(!Py_OptimizeFlag)) {
            __pyx_t_1 = (__pyx_v_self->context != Py_None);
            if (unlikely(!(__pyx_t_1 != 0))) {
              PyErr_SetNone(PyExc_AssertionError);
              __PYX_ERR(3, 239, __pyx_L8_error)
            }
          }
          #endif

          /* "uvloop/cbhandles.pyx":240
 *             if PY37:
 *                 assert self.context is not None
 *                 PyContext_Enter(<PyContext*>self.context)             # <<<<<<<<<<<<<<
 * 
 *             if args is not None:
 */
          __pyx_t_8 = PyContext_Enter(((PyContext *)__pyx_v_self->context)); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(3, 240, __pyx_L8_error)

          /* "uvloop/cbhandles.pyx":238
 *             started = time_monotonic()
 *         try:
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 assert self.context is not None
 *                 PyContext_Enter(<PyContext*>self.context)
 */
        }

        /* "uvloop/cbhandles.pyx":242
 *                 PyContext_Enter(<PyContext*>self.context)
 * 
 *             if args is not None:             # <<<<<<<<<<<<<<
 *                 callback(*args)
 *             else:
 */
        __pyx_t_1 = (__pyx_v_args != Py_None);
        __pyx_t_9 = (__pyx_t_1 != 0);
        if (__pyx_t_9) {

          /* "uvloop/cbhandles.pyx":243
 * 
 *             if args is not None:
 *                 callback(*args)             # <<<<<<<<<<<<<<
 *             else:
 *                 callback()
 */
          __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_v_args); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 243, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_v_callback, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 243, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "uvloop/cbhandles.pyx":242
 *                 PyContext_Enter(<PyContext*>self.context)
 * 
 *             if args is not None:             # <<<<<<<<<<<<<<
 *                 callback(*args)
 *             else:
 */
          goto __pyx_L15;
        }

        /* "uvloop/cbhandles.pyx":245
 *                 callback(*args)
 *             else:
 *                 callback()             # <<<<<<<<<<<<<<
 *         except Exception as ex:
 *             context = {
 */
        /*else*/ {
          __Pyx_INCREF(__pyx_v_callback);
          __pyx_t_2 = __pyx_v_callback; __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
            }
          }
          if (__pyx_t_4) {
            __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 245, __pyx_L8_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else {
            __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 245, __pyx_L8_error)
          }
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_L15:;

        /* "uvloop/cbhandles.pyx":237
 *         if self.loop._debug:
 *             started = time_monotonic()
 *         try:             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 assert self.context is not None
 */
      }

      /* "uvloop/cbhandles.pyx":258
 *             self.loop.call_exception_handler(context)
 *         else:
 *             if self.loop._debug:             # <<<<<<<<<<<<<<
 *                 delta = time_monotonic() - started
 *                 if delta > self.loop.slow_callback_duration:
 */
      /*else:*/ {
        __pyx_t_9 = (__pyx_v_self->loop->_debug != 0);
        if (__pyx_t_9) {

          /* "uvloop/cbhandles.pyx":259
 *         else:
 *             if self.loop._debug:
 *                 delta = time_monotonic() - started             # <<<<<<<<<<<<<<
 *                 if delta > self.loop.slow_callback_duration:
 *                     aio_logger.warning(
 */
          __Pyx_INCREF(__pyx_v_6uvloop_4loop_time_monotonic);
          __pyx_t_2 = __pyx_v_6uvloop_4loop_time_monotonic; __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
            }
          }
          if (__pyx_t_4) {
            __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 259, __pyx_L10_except_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else {
            __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 259, __pyx_L10_except_error)
          }
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_v_started)) { __Pyx_RaiseUnboundLocalError("started"); __PYX_ERR(3, 259, __pyx_L10_except_error) }
          __pyx_t_2 = PyNumber_Subtract(__pyx_t_3, __pyx_v_started); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 259, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_v_delta = __pyx_t_2;
          __pyx_t_2 = 0;

          /* "uvloop/cbhandles.pyx":260
 *             if self.loop._debug:
 *                 delta = time_monotonic() - started
 *                 if delta > self.loop.slow_callback_duration:             # <<<<<<<<<<<<<<
 *                     aio_logger.warning(
 *                         'Executing %r took %.3f seconds',
 */
          __pyx_t_2 = PyObject_RichCompare(__pyx_v_delta, __pyx_v_self->loop->slow_callback_duration, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 260, __pyx_L10_except_error)
          __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(3, 260, __pyx_L10_except_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_9) {

            /* "uvloop/cbhandles.pyx":261
 *                 delta = time_monotonic() - started
 *                 if delta > self.loop.slow_callback_duration:
 *                     aio_logger.warning(             # <<<<<<<<<<<<<<
 *                         'Executing %r took %.3f seconds',
 *                         self, delta)
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_warning); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 261, __pyx_L10_except_error)
            __Pyx_GOTREF(__pyx_t_3);

            /* "uvloop/cbhandles.pyx":263
 *                     aio_logger.warning(
 *                         'Executing %r took %.3f seconds',
 *                         self, delta)             # <<<<<<<<<<<<<<
 *         finally:
 *             context = self.context
 */
            __pyx_t_4 = NULL;
            __pyx_t_8 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
                __pyx_t_8 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_kp_u_Executing_r_took_3f_seconds, ((PyObject *)__pyx_v_self), __pyx_v_delta};
              __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 261, __pyx_L10_except_error)
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[4] = {__pyx_t_4, __pyx_kp_u_Executing_r_took_3f_seconds, ((PyObject *)__pyx_v_self), __pyx_v_delta};
              __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_8, 3+__pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 261, __pyx_L10_except_error)
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(3+__pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 261, __pyx_L10_except_error)
              __Pyx_GOTREF(__pyx_t_10);
              if (__pyx_t_4) {
                __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4); __pyx_t_4 = NULL;
              }
              __Pyx_INCREF(__pyx_kp_u_Executing_r_took_3f_seconds);
              __Pyx_GIVEREF(__pyx_kp_u_Executing_r_took_3f_seconds);
              PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_8, __pyx_kp_u_Executing_r_took_3f_seconds);
              __Pyx_INCREF(((PyObject *)__pyx_v_self));
              __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
              PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_8, ((PyObject *)__pyx_v_self));
              __Pyx_INCREF(__pyx_v_delta);
              __Pyx_GIVEREF(__pyx_v_delta);
              PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_8, __pyx_v_delta);
              __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 261, __pyx_L10_except_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "uvloop/cbhandles.pyx":260
 *             if self.loop._debug:
 *                 delta = time_monotonic() - started
 *                 if delta > self.loop.slow_callback_duration:             # <<<<<<<<<<<<<<
 *                     aio_logger.warning(
 *                         'Executing %r took %.3f seconds',
 */
          }

          /* "uvloop/cbhandles.pyx":258
 *             self.loop.call_exception_handler(context)
 *         else:
 *             if self.loop._debug:             # <<<<<<<<<<<<<<
 *                 delta = time_monotonic() - started
 *                 if delta > self.loop.slow_callback_duration:
 */
        }
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L13_try_end;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/cbhandles.pyx":246
 *             else:
 *                 callback()
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             context = {
 *                 'message': 'Exception in callback {}'.format(callback),
 */
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_8) {
        __Pyx_AddTraceback("uvloop.loop.TimerHandle._run", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_10) < 0) __PYX_ERR(3, 246, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_3);
        __pyx_v_ex = __pyx_t_3;
        /*try:*/ {

          /* "uvloop/cbhandles.pyx":248
 *         except Exception as ex:
 *             context = {
 *                 'message': 'Exception in callback {}'.format(callback),             # <<<<<<<<<<<<<<
 *                 'exception': ex,
 *                 'handle': self,
 */
          __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 248, __pyx_L23_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Exception_in_callback, __pyx_n_s_format); if (unlikely(!__pyx_t_12)) __PYX_ERR(3, 248, __pyx_L23_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          if (!__pyx_t_13) {
            __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_callback); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 248, __pyx_L23_error)
            __Pyx_GOTREF(__pyx_t_11);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_callback};
              __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 248, __pyx_L23_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_11);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_callback};
              __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 248, __pyx_L23_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_11);
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(3, 248, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
              __Pyx_INCREF(__pyx_v_callback);
              __Pyx_GIVEREF(__pyx_v_callback);
              PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_v_callback);
              __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_14, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 248, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_message, __pyx_t_11) < 0) __PYX_ERR(3, 248, __pyx_L23_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "uvloop/cbhandles.pyx":249
 *             context = {
 *                 'message': 'Exception in callback {}'.format(callback),
 *                 'exception': ex,             # <<<<<<<<<<<<<<
 *                 'handle': self,
 *             }
 */
          if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_exception, __pyx_v_ex) < 0) __PYX_ERR(3, 248, __pyx_L23_error)

          /* "uvloop/cbhandles.pyx":250
 *                 'message': 'Exception in callback {}'.format(callback),
 *                 'exception': ex,
 *                 'handle': self,             # <<<<<<<<<<<<<<
 *             }
 * 
 */
          if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_handle, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(3, 248, __pyx_L23_error)
          __pyx_v_context = __pyx_t_4;
          __pyx_t_4 = 0;

          /* "uvloop/cbhandles.pyx":253
 *             }
 * 
 *             if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *                 context['source_traceback'] = self._source_traceback
 * 
 */
          __pyx_t_9 = (__pyx_v_self->_source_traceback != Py_None);
          __pyx_t_1 = (__pyx_t_9 != 0);
          if (__pyx_t_1) {

            /* "uvloop/cbhandles.pyx":254
 * 
 *             if self._source_traceback is not None:
 *                 context['source_traceback'] = self._source_traceback             # <<<<<<<<<<<<<<
 * 
 *             self.loop.call_exception_handler(context)
 */
            __pyx_t_4 = __pyx_v_self->_source_traceback;
            __Pyx_INCREF(__pyx_t_4);
            if (unlikely(PyObject_SetItem(__pyx_v_context, __pyx_n_u_source_traceback, __pyx_t_4) < 0)) __PYX_ERR(3, 254, __pyx_L23_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "uvloop/cbhandles.pyx":253
 *             }
 * 
 *             if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *                 context['source_traceback'] = self._source_traceback
 * 
 */
          }

          /* "uvloop/cbhandles.pyx":256
 *                 context['source_traceback'] = self._source_traceback
 * 
 *             self.loop.call_exception_handler(context)             # <<<<<<<<<<<<<<
 *         else:
 *             if self.loop._debug:
 */
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_11)) __PYX_ERR(3, 256, __pyx_L23_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
            }
          }
          if (!__pyx_t_12) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_context); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 256, __pyx_L23_error)
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_11)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_context};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 256, __pyx_L23_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_context};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 256, __pyx_L23_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(3, 256, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_12); __pyx_t_12 = NULL;
              __Pyx_INCREF(__pyx_v_context);
              __Pyx_GIVEREF(__pyx_v_context);
              PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_v_context);
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_14, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(3, 256, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }

        /* "uvloop/cbhandles.pyx":246
 *             else:
 *                 callback()
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             context = {
 *                 'message': 'Exception in callback {}'.format(callback),
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L24;
          }
          __pyx_L23_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_8 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
            goto __pyx_L10_except_error;
          }
          __pyx_L24:;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L9_exception_handled;
      }
      goto __pyx_L10_except_error;
      __pyx_L10_except_error:;

      /* "uvloop/cbhandles.pyx":237
 *         if self.loop._debug:
 *             started = time_monotonic()
 *         try:             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 assert self.context is not None
 */
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L6_error;
      __pyx_L9_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L13_try_end:;
    }
  }

  /* "uvloop/cbhandles.pyx":265
 *                         self, delta)
 *         finally:
 *             context = self.context             # <<<<<<<<<<<<<<
 *             Py_DECREF(self)
 *             if PY37:
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_10 = __pyx_v_self->context;
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_XDECREF_SET(__pyx_v_context, __pyx_t_10);
      __pyx_t_10 = 0;

      /* "uvloop/cbhandles.pyx":266
 *         finally:
 *             context = self.context
 *             Py_DECREF(self)             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)
 */
      Py_DECREF(((PyObject *)__pyx_v_self));

      /* "uvloop/cbhandles.pyx":267
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
      __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
      if (__pyx_t_1) {

        /* "uvloop/cbhandles.pyx":268
 *             Py_DECREF(self)
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)             # <<<<<<<<<<<<<<
 * 
 *     # Public API
 */
        __pyx_t_15 = PyContext_Exit(((PyContext *)__pyx_v_context)); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(3, 268, __pyx_L1_error)

        /* "uvloop/cbhandles.pyx":267
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
      }
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_22);
      __Pyx_XGOTREF(__pyx_t_21);
      __Pyx_XGOTREF(__pyx_t_20);
      __pyx_t_15 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_23 = __pyx_filename;
      {

        /* "uvloop/cbhandles.pyx":265
 *                         self, delta)
 *         finally:
 *             context = self.context             # <<<<<<<<<<<<<<
 *             Py_DECREF(self)
 *             if PY37:
 */
        __pyx_t_10 = __pyx_v_self->context;
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_XDECREF_SET(__pyx_v_context, __pyx_t_10);
        __pyx_t_10 = 0;

        /* "uvloop/cbhandles.pyx":266
 *         finally:
 *             context = self.context
 *             Py_DECREF(self)             # <<<<<<<<<<<<<<
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)
 */
        Py_DECREF(((PyObject *)__pyx_v_self));

        /* "uvloop/cbhandles.pyx":267
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
        __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY37 != 0);
        if (__pyx_t_1) {

          /* "uvloop/cbhandles.pyx":268
 *             Py_DECREF(self)
 *             if PY37:
 *                 PyContext_Exit(<PyContext*>context)             # <<<<<<<<<<<<<<
 * 
 *     # Public API
 */
          __pyx_t_24 = PyContext_Exit(((PyContext *)__pyx_v_context)); if (unlikely(__pyx_t_24 == ((int)-1))) __PYX_ERR(3, 268, __pyx_L32_error)

          /* "uvloop/cbhandles.pyx":267
 *             context = self.context
 *             Py_DECREF(self)
 *             if PY37:             # <<<<<<<<<<<<<<
 *                 PyContext_Exit(<PyContext*>context)
 * 
 */
        }
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_21, __pyx_t_20);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_6, __pyx_t_5);
      __pyx_t_7 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0;
      __pyx_lineno = __pyx_t_15; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_23;
      goto __pyx_L1_error;
      __pyx_L32_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_21, __pyx_t_20);
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "uvloop/cbhandles.pyx":225
 *             self.timer = None  # let it die asap
 * 
 *     cdef _run(self):             # <<<<<<<<<<<<<<
 *         if self._cancelled == 1:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle._run", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_started);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_context);
  __Pyx_XDECREF(__pyx_v_delta);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":272
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         info = [self.__class__.__name__]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_5__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_5__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11TimerHandle_4__repr__(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_4__repr__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_func = NULL;
  PyObject *__pyx_v_cb_name = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/cbhandles.pyx":273
 * 
 *     def __repr__(self):
 *         info = [self.__class__.__name__]             # <<<<<<<<<<<<<<
 * 
 *         if self._cancelled:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_v_info = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":275
 *         info = [self.__class__.__name__]
 * 
 *         if self._cancelled:             # <<<<<<<<<<<<<<
 *             info.append('cancelled')
 * 
 */
  __pyx_t_3 = (__pyx_v_self->_cancelled != 0);
  if (__pyx_t_3) {

    /* "uvloop/cbhandles.pyx":276
 * 
 *         if self._cancelled:
 *             info.append('cancelled')             # <<<<<<<<<<<<<<
 * 
 *         func = self.callback
 */
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_info, __pyx_n_u_cancelled); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 276, __pyx_L1_error)

    /* "uvloop/cbhandles.pyx":275
 *         info = [self.__class__.__name__]
 * 
 *         if self._cancelled:             # <<<<<<<<<<<<<<
 *             info.append('cancelled')
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":278
 *             info.append('cancelled')
 * 
 *         func = self.callback             # <<<<<<<<<<<<<<
 *         if hasattr(func, '__qualname__'):
 *             cb_name = getattr(func, '__qualname__')
 */
  __pyx_t_1 = __pyx_v_self->callback;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_func = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":279
 * 
 *         func = self.callback
 *         if hasattr(func, '__qualname__'):             # <<<<<<<<<<<<<<
 *             cb_name = getattr(func, '__qualname__')
 *         elif hasattr(func, '__name__'):
 */
  __pyx_t_3 = __Pyx_HasAttr(__pyx_v_func, __pyx_n_u_qualname); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(3, 279, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_3 != 0);
  if (__pyx_t_5) {

    /* "uvloop/cbhandles.pyx":280
 *         func = self.callback
 *         if hasattr(func, '__qualname__'):
 *             cb_name = getattr(func, '__qualname__')             # <<<<<<<<<<<<<<
 *         elif hasattr(func, '__name__'):
 *             cb_name = getattr(func, '__name__')
 */
    __pyx_t_1 = __Pyx_GetAttr(__pyx_v_func, __pyx_n_u_qualname); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_cb_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/cbhandles.pyx":279
 * 
 *         func = self.callback
 *         if hasattr(func, '__qualname__'):             # <<<<<<<<<<<<<<
 *             cb_name = getattr(func, '__qualname__')
 *         elif hasattr(func, '__name__'):
 */
    goto __pyx_L4;
  }

  /* "uvloop/cbhandles.pyx":281
 *         if hasattr(func, '__qualname__'):
 *             cb_name = getattr(func, '__qualname__')
 *         elif hasattr(func, '__name__'):             # <<<<<<<<<<<<<<
 *             cb_name = getattr(func, '__name__')
 *         else:
 */
  __pyx_t_5 = __Pyx_HasAttr(__pyx_v_func, __pyx_n_u_name); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(3, 281, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_5 != 0);
  if (__pyx_t_3) {

    /* "uvloop/cbhandles.pyx":282
 *             cb_name = getattr(func, '__qualname__')
 *         elif hasattr(func, '__name__'):
 *             cb_name = getattr(func, '__name__')             # <<<<<<<<<<<<<<
 *         else:
 *             cb_name = repr(func)
 */
    __pyx_t_1 = __Pyx_GetAttr(__pyx_v_func, __pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_cb_name = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/cbhandles.pyx":281
 *         if hasattr(func, '__qualname__'):
 *             cb_name = getattr(func, '__qualname__')
 *         elif hasattr(func, '__name__'):             # <<<<<<<<<<<<<<
 *             cb_name = getattr(func, '__name__')
 *         else:
 */
    goto __pyx_L4;
  }

  /* "uvloop/cbhandles.pyx":284
 *             cb_name = getattr(func, '__name__')
 *         else:
 *             cb_name = repr(func)             # <<<<<<<<<<<<<<
 * 
 *         info.append(cb_name)
 */
  /*else*/ {
    __pyx_t_1 = PyObject_Repr(__pyx_v_func); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 284, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_cb_name = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "uvloop/cbhandles.pyx":286
 *             cb_name = repr(func)
 * 
 *         info.append(cb_name)             # <<<<<<<<<<<<<<
 * 
 *         if self._source_traceback is not None:
 */
  __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_info, __pyx_v_cb_name); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 286, __pyx_L1_error)

  /* "uvloop/cbhandles.pyx":288
 *         info.append(cb_name)
 * 
 *         if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *             frame = self._source_traceback[-1]
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 */
  __pyx_t_3 = (__pyx_v_self->_source_traceback != Py_None);
  __pyx_t_5 = (__pyx_t_3 != 0);
  if (__pyx_t_5) {

    /* "uvloop/cbhandles.pyx":289
 * 
 *         if self._source_traceback is not None:
 *             frame = self._source_traceback[-1]             # <<<<<<<<<<<<<<
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 * 
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_self->_source_traceback, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_frame = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/cbhandles.pyx":290
 *         if self._source_traceback is not None:
 *             frame = self._source_traceback[-1]
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))             # <<<<<<<<<<<<<<
 * 
 *         return '<' + ' '.join(info) + '>'
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_created_at, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_frame, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(3, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_frame, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(3, 290, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_9 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_t_7};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 290, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_t_7};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 290, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(3, 290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_7);
      __pyx_t_6 = 0;
      __pyx_t_7 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = __Pyx_PyList_Append(__pyx_v_info, __pyx_t_1); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 290, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/cbhandles.pyx":288
 *         info.append(cb_name)
 * 
 *         if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *             frame = self._source_traceback[-1]
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 */
  }

  /* "uvloop/cbhandles.pyx":292
 *             info.append('created at {}:{}'.format(frame[0], frame[1]))
 * 
 *         return '<' + ' '.join(info) + '>'             # <<<<<<<<<<<<<<
 * 
 *     def cancelled(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_Join(__pyx_kp_u__129, __pyx_v_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u__128, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_2, __pyx_kp_u__130); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":272
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         info = [self.__class__.__name__]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_func);
  __Pyx_XDECREF(__pyx_v_cb_name);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":294
 *         return '<' + ' '.join(info) + '>'
 * 
 *     def cancelled(self):             # <<<<<<<<<<<<<<
 *         return self._cancelled
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_7cancelled(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_11TimerHandle_6cancelled[] = "TimerHandle.cancelled(self)";
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_7cancelled(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancelled (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11TimerHandle_6cancelled(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_6cancelled(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("cancelled", 0);

  /* "uvloop/cbhandles.pyx":295
 * 
 *     def cancelled(self):
 *         return self._cancelled             # <<<<<<<<<<<<<<
 * 
 *     def cancel(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_cancelled); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":294
 *         return '<' + ' '.join(info) + '>'
 * 
 *     def cancelled(self):             # <<<<<<<<<<<<<<
 *         return self._cancelled
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle.cancelled", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":297
 *         return self._cancelled
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         self._cancel()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_9cancel(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_11TimerHandle_8cancel[] = "TimerHandle.cancel(self)";
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_9cancel(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11TimerHandle_8cancel(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_8cancel(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("cancel", 0);

  /* "uvloop/cbhandles.pyx":298
 * 
 *     def cancel(self):
 *         self._cancel()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TimerHandle *)__pyx_v_self->__pyx_vtab)->_cancel(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":297
 *         return self._cancelled
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         self._cancel()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle.cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pxd":34
 *         object __weakref__
 * 
 *         readonly _source_traceback             # <<<<<<<<<<<<<<
 * 
 *     cdef _run(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_17_source_traceback_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_17_source_traceback_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11TimerHandle_17_source_traceback___get__(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_17_source_traceback___get__(struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_source_traceback);
  __pyx_r = __pyx_v_self->_source_traceback;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_11__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_11TimerHandle_10__reduce_cython__[] = "TimerHandle.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_11__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11TimerHandle_10__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_10__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__135, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_13__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_11TimerHandle_12__setstate_cython__[] = "TimerHandle.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_11TimerHandle_13__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11TimerHandle_12__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_TimerHandle *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11TimerHandle_12__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__136, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TimerHandle.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":302
 * 
 * 
 * cdef new_Handle(Loop loop, object callback, object args, object context):             # <<<<<<<<<<<<<<
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 */

static PyObject *__pyx_f_6uvloop_4loop_new_Handle(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_callback, PyObject *__pyx_v_args, PyObject *__pyx_v_context) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new_Handle", 0);

  /* "uvloop/cbhandles.pyx":304
 * cdef new_Handle(Loop loop, object callback, object args, object context):
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)             # <<<<<<<<<<<<<<
 *     handle._set_loop(loop)
 *     handle._set_context(context)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_Handle(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_Handle), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 304, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":305
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)             # <<<<<<<<<<<<<<
 *     handle._set_context(context)
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_loop(__pyx_v_handle, __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 305, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":306
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)
 *     handle._set_context(context)             # <<<<<<<<<<<<<<
 * 
 *     handle.cb_type = 1
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_context(__pyx_v_handle, __pyx_v_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":308
 *     handle._set_context(context)
 * 
 *     handle.cb_type = 1             # <<<<<<<<<<<<<<
 * 
 *     handle.arg1 = callback
 */
  __pyx_v_handle->cb_type = 1;

  /* "uvloop/cbhandles.pyx":310
 *     handle.cb_type = 1
 * 
 *     handle.arg1 = callback             # <<<<<<<<<<<<<<
 *     handle.arg2 = args
 * 
 */
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  __Pyx_GOTREF(__pyx_v_handle->arg1);
  __Pyx_DECREF(__pyx_v_handle->arg1);
  __pyx_v_handle->arg1 = __pyx_v_callback;

  /* "uvloop/cbhandles.pyx":311
 * 
 *     handle.arg1 = callback
 *     handle.arg2 = args             # <<<<<<<<<<<<<<
 * 
 *     return handle
 */
  __Pyx_INCREF(__pyx_v_args);
  __Pyx_GIVEREF(__pyx_v_args);
  __Pyx_GOTREF(__pyx_v_handle->arg2);
  __Pyx_DECREF(__pyx_v_handle->arg2);
  __pyx_v_handle->arg2 = __pyx_v_args;

  /* "uvloop/cbhandles.pyx":313
 *     handle.arg2 = args
 * 
 *     return handle             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = ((PyObject *)__pyx_v_handle);
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":302
 * 
 * 
 * cdef new_Handle(Loop loop, object callback, object args, object context):             # <<<<<<<<<<<<<<
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.new_Handle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":316
 * 
 * 
 * cdef new_MethodHandle(Loop loop, str name, method_t callback, object ctx):             # <<<<<<<<<<<<<<
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 */

static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_name, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new_MethodHandle", 0);

  /* "uvloop/cbhandles.pyx":318
 * cdef new_MethodHandle(Loop loop, str name, method_t callback, object ctx):
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)             # <<<<<<<<<<<<<<
 *     handle._set_loop(loop)
 *     handle._set_context(None)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_Handle(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_Handle), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 318, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":319
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)             # <<<<<<<<<<<<<<
 *     handle._set_context(None)
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_loop(__pyx_v_handle, __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":320
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)
 *     handle._set_context(None)             # <<<<<<<<<<<<<<
 * 
 *     handle.cb_type = 2
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_context(__pyx_v_handle, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":322
 *     handle._set_context(None)
 * 
 *     handle.cb_type = 2             # <<<<<<<<<<<<<<
 *     handle.meth_name = name
 * 
 */
  __pyx_v_handle->cb_type = 2;

  /* "uvloop/cbhandles.pyx":323
 * 
 *     handle.cb_type = 2
 *     handle.meth_name = name             # <<<<<<<<<<<<<<
 * 
 *     handle.callback = <void*> callback
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_handle->meth_name);
  __Pyx_DECREF(__pyx_v_handle->meth_name);
  __pyx_v_handle->meth_name = __pyx_v_name;

  /* "uvloop/cbhandles.pyx":325
 *     handle.meth_name = name
 * 
 *     handle.callback = <void*> callback             # <<<<<<<<<<<<<<
 *     handle.arg1 = ctx
 * 
 */
  __pyx_v_handle->callback = ((void *)__pyx_v_callback);

  /* "uvloop/cbhandles.pyx":326
 * 
 *     handle.callback = <void*> callback
 *     handle.arg1 = ctx             # <<<<<<<<<<<<<<
 * 
 *     return handle
 */
  __Pyx_INCREF(__pyx_v_ctx);
  __Pyx_GIVEREF(__pyx_v_ctx);
  __Pyx_GOTREF(__pyx_v_handle->arg1);
  __Pyx_DECREF(__pyx_v_handle->arg1);
  __pyx_v_handle->arg1 = __pyx_v_ctx;

  /* "uvloop/cbhandles.pyx":328
 *     handle.arg1 = ctx
 * 
 *     return handle             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = ((PyObject *)__pyx_v_handle);
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":316
 * 
 * 
 * cdef new_MethodHandle(Loop loop, str name, method_t callback, object ctx):             # <<<<<<<<<<<<<<
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.new_MethodHandle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":331
 * 
 * 
 * cdef new_MethodHandle1(Loop loop, str name, method1_t callback,             # <<<<<<<<<<<<<<
 *                        object ctx, object arg):
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle1(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_name, __pyx_t_6uvloop_4loop_method1_t __pyx_v_callback, PyObject *__pyx_v_ctx, PyObject *__pyx_v_arg) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new_MethodHandle1", 0);

  /* "uvloop/cbhandles.pyx":335
 * 
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)             # <<<<<<<<<<<<<<
 *     handle._set_loop(loop)
 *     handle._set_context(None)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_Handle(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_Handle), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 335, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":336
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)             # <<<<<<<<<<<<<<
 *     handle._set_context(None)
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_loop(__pyx_v_handle, __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 336, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":337
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)
 *     handle._set_context(None)             # <<<<<<<<<<<<<<
 * 
 *     handle.cb_type = 3
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_context(__pyx_v_handle, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":339
 *     handle._set_context(None)
 * 
 *     handle.cb_type = 3             # <<<<<<<<<<<<<<
 *     handle.meth_name = name
 * 
 */
  __pyx_v_handle->cb_type = 3;

  /* "uvloop/cbhandles.pyx":340
 * 
 *     handle.cb_type = 3
 *     handle.meth_name = name             # <<<<<<<<<<<<<<
 * 
 *     handle.callback = <void*> callback
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_handle->meth_name);
  __Pyx_DECREF(__pyx_v_handle->meth_name);
  __pyx_v_handle->meth_name = __pyx_v_name;

  /* "uvloop/cbhandles.pyx":342
 *     handle.meth_name = name
 * 
 *     handle.callback = <void*> callback             # <<<<<<<<<<<<<<
 *     handle.arg1 = ctx
 *     handle.arg2 = arg
 */
  __pyx_v_handle->callback = ((void *)__pyx_v_callback);

  /* "uvloop/cbhandles.pyx":343
 * 
 *     handle.callback = <void*> callback
 *     handle.arg1 = ctx             # <<<<<<<<<<<<<<
 *     handle.arg2 = arg
 * 
 */
  __Pyx_INCREF(__pyx_v_ctx);
  __Pyx_GIVEREF(__pyx_v_ctx);
  __Pyx_GOTREF(__pyx_v_handle->arg1);
  __Pyx_DECREF(__pyx_v_handle->arg1);
  __pyx_v_handle->arg1 = __pyx_v_ctx;

  /* "uvloop/cbhandles.pyx":344
 *     handle.callback = <void*> callback
 *     handle.arg1 = ctx
 *     handle.arg2 = arg             # <<<<<<<<<<<<<<
 * 
 *     return handle
 */
  __Pyx_INCREF(__pyx_v_arg);
  __Pyx_GIVEREF(__pyx_v_arg);
  __Pyx_GOTREF(__pyx_v_handle->arg2);
  __Pyx_DECREF(__pyx_v_handle->arg2);
  __pyx_v_handle->arg2 = __pyx_v_arg;

  /* "uvloop/cbhandles.pyx":346
 *     handle.arg2 = arg
 * 
 *     return handle             # <<<<<<<<<<<<<<
 * 
 * cdef new_MethodHandle2(Loop loop, str name, method2_t callback, object ctx,
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = ((PyObject *)__pyx_v_handle);
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":331
 * 
 * 
 * cdef new_MethodHandle1(Loop loop, str name, method1_t callback,             # <<<<<<<<<<<<<<
 *                        object ctx, object arg):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.new_MethodHandle1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":348
 *     return handle
 * 
 * cdef new_MethodHandle2(Loop loop, str name, method2_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                        object arg1, object arg2):
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle2(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_name, __pyx_t_6uvloop_4loop_method2_t __pyx_v_callback, PyObject *__pyx_v_ctx, PyObject *__pyx_v_arg1, PyObject *__pyx_v_arg2) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new_MethodHandle2", 0);

  /* "uvloop/cbhandles.pyx":352
 * 
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)             # <<<<<<<<<<<<<<
 *     handle._set_loop(loop)
 *     handle._set_context(None)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_Handle(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_Handle), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 352, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":353
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)             # <<<<<<<<<<<<<<
 *     handle._set_context(None)
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_loop(__pyx_v_handle, __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":354
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)
 *     handle._set_context(None)             # <<<<<<<<<<<<<<
 * 
 *     handle.cb_type = 4
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_context(__pyx_v_handle, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":356
 *     handle._set_context(None)
 * 
 *     handle.cb_type = 4             # <<<<<<<<<<<<<<
 *     handle.meth_name = name
 * 
 */
  __pyx_v_handle->cb_type = 4;

  /* "uvloop/cbhandles.pyx":357
 * 
 *     handle.cb_type = 4
 *     handle.meth_name = name             # <<<<<<<<<<<<<<
 * 
 *     handle.callback = <void*> callback
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_handle->meth_name);
  __Pyx_DECREF(__pyx_v_handle->meth_name);
  __pyx_v_handle->meth_name = __pyx_v_name;

  /* "uvloop/cbhandles.pyx":359
 *     handle.meth_name = name
 * 
 *     handle.callback = <void*> callback             # <<<<<<<<<<<<<<
 *     handle.arg1 = ctx
 *     handle.arg2 = arg1
 */
  __pyx_v_handle->callback = ((void *)__pyx_v_callback);

  /* "uvloop/cbhandles.pyx":360
 * 
 *     handle.callback = <void*> callback
 *     handle.arg1 = ctx             # <<<<<<<<<<<<<<
 *     handle.arg2 = arg1
 *     handle.arg3 = arg2
 */
  __Pyx_INCREF(__pyx_v_ctx);
  __Pyx_GIVEREF(__pyx_v_ctx);
  __Pyx_GOTREF(__pyx_v_handle->arg1);
  __Pyx_DECREF(__pyx_v_handle->arg1);
  __pyx_v_handle->arg1 = __pyx_v_ctx;

  /* "uvloop/cbhandles.pyx":361
 *     handle.callback = <void*> callback
 *     handle.arg1 = ctx
 *     handle.arg2 = arg1             # <<<<<<<<<<<<<<
 *     handle.arg3 = arg2
 * 
 */
  __Pyx_INCREF(__pyx_v_arg1);
  __Pyx_GIVEREF(__pyx_v_arg1);
  __Pyx_GOTREF(__pyx_v_handle->arg2);
  __Pyx_DECREF(__pyx_v_handle->arg2);
  __pyx_v_handle->arg2 = __pyx_v_arg1;

  /* "uvloop/cbhandles.pyx":362
 *     handle.arg1 = ctx
 *     handle.arg2 = arg1
 *     handle.arg3 = arg2             # <<<<<<<<<<<<<<
 * 
 *     return handle
 */
  __Pyx_INCREF(__pyx_v_arg2);
  __Pyx_GIVEREF(__pyx_v_arg2);
  __Pyx_GOTREF(__pyx_v_handle->arg3);
  __Pyx_DECREF(__pyx_v_handle->arg3);
  __pyx_v_handle->arg3 = __pyx_v_arg2;

  /* "uvloop/cbhandles.pyx":364
 *     handle.arg3 = arg2
 * 
 *     return handle             # <<<<<<<<<<<<<<
 * 
 * cdef new_MethodHandle3(Loop loop, str name, method3_t callback, object ctx,
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = ((PyObject *)__pyx_v_handle);
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":348
 *     return handle
 * 
 * cdef new_MethodHandle2(Loop loop, str name, method2_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                        object arg1, object arg2):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.new_MethodHandle2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":366
 *     return handle
 * 
 * cdef new_MethodHandle3(Loop loop, str name, method3_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                        object arg1, object arg2, object arg3):
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_new_MethodHandle3(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_name, __pyx_t_6uvloop_4loop_method3_t __pyx_v_callback, PyObject *__pyx_v_ctx, PyObject *__pyx_v_arg1, PyObject *__pyx_v_arg2, PyObject *__pyx_v_arg3) {
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_handle = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new_MethodHandle3", 0);

  /* "uvloop/cbhandles.pyx":370
 * 
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)             # <<<<<<<<<<<<<<
 *     handle._set_loop(loop)
 *     handle._set_context(None)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_Handle(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_Handle), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 370, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":371
 *     cdef Handle handle
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)             # <<<<<<<<<<<<<<
 *     handle._set_context(None)
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_loop(__pyx_v_handle, __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":372
 *     handle = Handle.__new__(Handle)
 *     handle._set_loop(loop)
 *     handle._set_context(None)             # <<<<<<<<<<<<<<
 * 
 *     handle.cb_type = 5
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_6Handle__set_context(__pyx_v_handle, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":374
 *     handle._set_context(None)
 * 
 *     handle.cb_type = 5             # <<<<<<<<<<<<<<
 *     handle.meth_name = name
 * 
 */
  __pyx_v_handle->cb_type = 5;

  /* "uvloop/cbhandles.pyx":375
 * 
 *     handle.cb_type = 5
 *     handle.meth_name = name             # <<<<<<<<<<<<<<
 * 
 *     handle.callback = <void*> callback
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_handle->meth_name);
  __Pyx_DECREF(__pyx_v_handle->meth_name);
  __pyx_v_handle->meth_name = __pyx_v_name;

  /* "uvloop/cbhandles.pyx":377
 *     handle.meth_name = name
 * 
 *     handle.callback = <void*> callback             # <<<<<<<<<<<<<<
 *     handle.arg1 = ctx
 *     handle.arg2 = arg1
 */
  __pyx_v_handle->callback = ((void *)__pyx_v_callback);

  /* "uvloop/cbhandles.pyx":378
 * 
 *     handle.callback = <void*> callback
 *     handle.arg1 = ctx             # <<<<<<<<<<<<<<
 *     handle.arg2 = arg1
 *     handle.arg3 = arg2
 */
  __Pyx_INCREF(__pyx_v_ctx);
  __Pyx_GIVEREF(__pyx_v_ctx);
  __Pyx_GOTREF(__pyx_v_handle->arg1);
  __Pyx_DECREF(__pyx_v_handle->arg1);
  __pyx_v_handle->arg1 = __pyx_v_ctx;

  /* "uvloop/cbhandles.pyx":379
 *     handle.callback = <void*> callback
 *     handle.arg1 = ctx
 *     handle.arg2 = arg1             # <<<<<<<<<<<<<<
 *     handle.arg3 = arg2
 *     handle.arg4 = arg3
 */
  __Pyx_INCREF(__pyx_v_arg1);
  __Pyx_GIVEREF(__pyx_v_arg1);
  __Pyx_GOTREF(__pyx_v_handle->arg2);
  __Pyx_DECREF(__pyx_v_handle->arg2);
  __pyx_v_handle->arg2 = __pyx_v_arg1;

  /* "uvloop/cbhandles.pyx":380
 *     handle.arg1 = ctx
 *     handle.arg2 = arg1
 *     handle.arg3 = arg2             # <<<<<<<<<<<<<<
 *     handle.arg4 = arg3
 * 
 */
  __Pyx_INCREF(__pyx_v_arg2);
  __Pyx_GIVEREF(__pyx_v_arg2);
  __Pyx_GOTREF(__pyx_v_handle->arg3);
  __Pyx_DECREF(__pyx_v_handle->arg3);
  __pyx_v_handle->arg3 = __pyx_v_arg2;

  /* "uvloop/cbhandles.pyx":381
 *     handle.arg2 = arg1
 *     handle.arg3 = arg2
 *     handle.arg4 = arg3             # <<<<<<<<<<<<<<
 * 
 *     return handle
 */
  __Pyx_INCREF(__pyx_v_arg3);
  __Pyx_GIVEREF(__pyx_v_arg3);
  __Pyx_GOTREF(__pyx_v_handle->arg4);
  __Pyx_DECREF(__pyx_v_handle->arg4);
  __pyx_v_handle->arg4 = __pyx_v_arg3;

  /* "uvloop/cbhandles.pyx":383
 *     handle.arg4 = arg3
 * 
 *     return handle             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = ((PyObject *)__pyx_v_handle);
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":366
 *     return handle
 * 
 * cdef new_MethodHandle3(Loop loop, str name, method3_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                        object arg1, object arg2, object arg3):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.new_MethodHandle3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/cbhandles.pyx":386
 * 
 * 
 * cdef extract_stack():             # <<<<<<<<<<<<<<
 *     """Replacement for traceback.extract_stack() that only does the
 *     necessary work for asyncio debug mode.
 */

static PyObject *__pyx_f_6uvloop_4loop_extract_stack(void) {
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_v_stack = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  char const *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("extract_stack", 0);

  /* "uvloop/cbhandles.pyx":390
 *     necessary work for asyncio debug mode.
 *     """
 *     f = sys_getframe()             # <<<<<<<<<<<<<<
 *     if f is None:
 *         return
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_sys_getframe);
  __pyx_t_2 = __pyx_v_6uvloop_4loop_sys_getframe; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 390, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 390, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_f = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/cbhandles.pyx":391
 *     """
 *     f = sys_getframe()
 *     if f is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_4 = (__pyx_v_f == Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "uvloop/cbhandles.pyx":392
 *     f = sys_getframe()
 *     if f is None:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/cbhandles.pyx":391
 *     """
 *     f = sys_getframe()
 *     if f is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/cbhandles.pyx":394
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         stack = tb_StackSummary.extract(tb_walk_stack(f),
 *                                         limit=DEBUG_STACK_DEPTH,
 */
  /*try:*/ {

    /* "uvloop/cbhandles.pyx":395
 * 
 *     try:
 *         stack = tb_StackSummary.extract(tb_walk_stack(f),             # <<<<<<<<<<<<<<
 *                                         limit=DEBUG_STACK_DEPTH,
 *                                         lookup_lines=False)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_tb_StackSummary, __pyx_n_s_extract); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 395, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_tb_walk_stack);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_tb_walk_stack; __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_f); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 395, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_f};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 395, __pyx_L5_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_f};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 395, __pyx_L5_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(3, 395, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_f);
        __Pyx_GIVEREF(__pyx_v_f);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_f);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 395, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(3, 395, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/cbhandles.pyx":396
 *     try:
 *         stack = tb_StackSummary.extract(tb_walk_stack(f),
 *                                         limit=DEBUG_STACK_DEPTH,             # <<<<<<<<<<<<<<
 *                                         lookup_lines=False)
 *     finally:
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 396, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_limit, __pyx_int_10) < 0) __PYX_ERR(3, 396, __pyx_L5_error)

    /* "uvloop/cbhandles.pyx":397
 *         stack = tb_StackSummary.extract(tb_walk_stack(f),
 *                                         limit=DEBUG_STACK_DEPTH,
 *                                         lookup_lines=False)             # <<<<<<<<<<<<<<
 *     finally:
 *         f = None
 */
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_lookup_lines, Py_False) < 0) __PYX_ERR(3, 396, __pyx_L5_error)

    /* "uvloop/cbhandles.pyx":395
 * 
 *     try:
 *         stack = tb_StackSummary.extract(tb_walk_stack(f),             # <<<<<<<<<<<<<<
 *                                         limit=DEBUG_STACK_DEPTH,
 *                                         lookup_lines=False)
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(3, 395, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_stack = __pyx_t_7;
    __pyx_t_7 = 0;
  }

  /* "uvloop/cbhandles.pyx":399
 *                                         lookup_lines=False)
 *     finally:
 *         f = None             # <<<<<<<<<<<<<<
 * 
 *     stack.reverse()
 */
  /*finally:*/ {
    /*normal exit:*/{
      __Pyx_INCREF(Py_None);
      __Pyx_DECREF_SET(__pyx_v_f, Py_None);
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __pyx_t_8 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_10 = __pyx_filename;
      {
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_f, Py_None);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      }
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestore(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_10;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/cbhandles.pyx":401
 *         f = None
 * 
 *     stack.reverse()             # <<<<<<<<<<<<<<
 *     return stack
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_stack, __pyx_n_s_reverse); if (unlikely(!__pyx_t_2)) __PYX_ERR(3, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(3, 401, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(3, 401, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/cbhandles.pyx":402
 * 
 *     stack.reverse()
 *     return stack             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_stack);
  __pyx_r = __pyx_v_stack;
  goto __pyx_L0;

  /* "uvloop/cbhandles.pyx":386
 * 
 * 
 * cdef extract_stack():             # <<<<<<<<<<<<<<
 *     """Replacement for traceback.extract_stack() that only does the
 *     necessary work for asyncio debug mode.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.extract_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_stack);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":10
 *         object _sockname
 * 
 *     def __init__(self, int family, int type, int proto, int fd):             # <<<<<<<<<<<<<<
 *         self._family = family
 *         self._type = type
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_12PseudoSocket_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_12PseudoSocket_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_family;
  int __pyx_v_type;
  int __pyx_v_proto;
  int __pyx_v_fd;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_family,&__pyx_n_s_type,&__pyx_n_s_proto,&__pyx_n_s_fd,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_family)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_type)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 1); __PYX_ERR(10, 10, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_proto)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 2); __PYX_ERR(10, 10, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fd)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, 3); __PYX_ERR(10, 10, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(10, 10, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 4) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
    }
    __pyx_v_family = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_family == (int)-1) && PyErr_Occurred())) __PYX_ERR(10, 10, __pyx_L3_error)
    __pyx_v_type = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(10, 10, __pyx_L3_error)
    __pyx_v_proto = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_proto == (int)-1) && PyErr_Occurred())) __PYX_ERR(10, 10, __pyx_L3_error)
    __pyx_v_fd = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_fd == (int)-1) && PyErr_Occurred())) __PYX_ERR(10, 10, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 4, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(10, 10, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket___init__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_family, __pyx_v_type, __pyx_v_proto, __pyx_v_fd);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_12PseudoSocket___init__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_fd) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/pseudosock.pyx":11
 * 
 *     def __init__(self, int family, int type, int proto, int fd):
 *         self._family = family             # <<<<<<<<<<<<<<
 *         self._type = type
 *         self._proto = proto
 */
  __pyx_v_self->_family = __pyx_v_family;

  /* "uvloop/pseudosock.pyx":12
 *     def __init__(self, int family, int type, int proto, int fd):
 *         self._family = family
 *         self._type = type             # <<<<<<<<<<<<<<
 *         self._proto = proto
 *         self._fd = fd
 */
  __pyx_v_self->_type = __pyx_v_type;

  /* "uvloop/pseudosock.pyx":13
 *         self._family = family
 *         self._type = type
 *         self._proto = proto             # <<<<<<<<<<<<<<
 *         self._fd = fd
 *         self._peername = None
 */
  __pyx_v_self->_proto = __pyx_v_proto;

  /* "uvloop/pseudosock.pyx":14
 *         self._type = type
 *         self._proto = proto
 *         self._fd = fd             # <<<<<<<<<<<<<<
 *         self._peername = None
 *         self._sockname = None
 */
  __pyx_v_self->_fd = __pyx_v_fd;

  /* "uvloop/pseudosock.pyx":15
 *         self._proto = proto
 *         self._fd = fd
 *         self._peername = None             # <<<<<<<<<<<<<<
 *         self._sockname = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_peername);
  __Pyx_DECREF(__pyx_v_self->_peername);
  __pyx_v_self->_peername = Py_None;

  /* "uvloop/pseudosock.pyx":16
 *         self._fd = fd
 *         self._peername = None
 *         self._sockname = None             # <<<<<<<<<<<<<<
 * 
 *     cdef _na(self, what):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_sockname);
  __Pyx_DECREF(__pyx_v_self->_sockname);
  __pyx_v_self->_sockname = Py_None;

  /* "uvloop/pseudosock.pyx":10
 *         object _sockname
 * 
 *     def __init__(self, int family, int type, int proto, int fd):             # <<<<<<<<<<<<<<
 *         self._family = family
 *         self._type = type
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":18
 *         self._sockname = None
 * 
 *     cdef _na(self, what):             # <<<<<<<<<<<<<<
 *         raise TypeError('transport sockets do not support {}'.format(what))
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_12PseudoSocket__na(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_what) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_na", 0);

  /* "uvloop/pseudosock.pyx":19
 * 
 *     cdef _na(self, what):
 *         raise TypeError('transport sockets do not support {}'.format(what))             # <<<<<<<<<<<<<<
 * 
 *     cdef _make_sock(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_transport_sockets_do_not_support, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_what); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 19, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_what};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 19, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_what};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 19, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_what);
      __Pyx_GIVEREF(__pyx_v_what);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_what);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(10, 19, __pyx_L1_error)

  /* "uvloop/pseudosock.pyx":18
 *         self._sockname = None
 * 
 *     cdef _na(self, what):             # <<<<<<<<<<<<<<
 *         raise TypeError('transport sockets do not support {}'.format(what))
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket._na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":21
 *         raise TypeError('transport sockets do not support {}'.format(what))
 * 
 *     cdef _make_sock(self):             # <<<<<<<<<<<<<<
 *         return socket_socket(self._family, self._type, self._proto, self._fd)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_12PseudoSocket__make_sock(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_make_sock", 0);

  /* "uvloop/pseudosock.pyx":22
 * 
 *     cdef _make_sock(self):
 *         return socket_socket(self._family, self._type, self._proto, self._fd)             # <<<<<<<<<<<<<<
 * 
 *     property family:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->_family); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->_proto); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->_fd); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_socket);
  __pyx_t_6 = __pyx_v_6uvloop_4loop_socket_socket; __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 22, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_2, __pyx_t_3, __pyx_t_4, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 22, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(10, 22, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_t_5);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 22, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/pseudosock.pyx":21
 *         raise TypeError('transport sockets do not support {}'.format(what))
 * 
 *     cdef _make_sock(self):             # <<<<<<<<<<<<<<
 *         return socket_socket(self._family, self._type, self._proto, self._fd)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket._make_sock", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":25
 * 
 *     property family:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             try:
 *                 return socket_AddressFamily(self._family)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_6family_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_6family_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_6family___get__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_6family___get__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "uvloop/pseudosock.pyx":26
 *     property family:
 *         def __get__(self):
 *             try:             # <<<<<<<<<<<<<<
 *                 return socket_AddressFamily(self._family)
 *             except ValueError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/pseudosock.pyx":27
 *         def __get__(self):
 *             try:
 *                 return socket_AddressFamily(self._family)             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 return self._family
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->_family); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 27, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_AddressFamily);
      __pyx_t_6 = __pyx_v_6uvloop_4loop_socket_AddressFamily; __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 27, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 27, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 27, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(10, 27, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 27, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "uvloop/pseudosock.pyx":26
 *     property family:
 *         def __get__(self):
 *             try:             # <<<<<<<<<<<<<<
 *                 return socket_AddressFamily(self._family)
 *             except ValueError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/pseudosock.pyx":28
 *             try:
 *                 return socket_AddressFamily(self._family)
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 return self._family
 * 
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_9) {
      __Pyx_AddTraceback("uvloop.loop.PseudoSocket.family.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(10, 28, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_8);

      /* "uvloop/pseudosock.pyx":29
 *                 return socket_AddressFamily(self._family)
 *             except ValueError:
 *                 return self._family             # <<<<<<<<<<<<<<
 * 
 *     property type:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->_family); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 29, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/pseudosock.pyx":26
 *     property family:
 *         def __get__(self):
 *             try:             # <<<<<<<<<<<<<<
 *                 return socket_AddressFamily(self._family)
 *             except ValueError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "uvloop/pseudosock.pyx":25
 * 
 *     property family:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             try:
 *                 return socket_AddressFamily(self._family)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.family.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":32
 * 
 *     property type:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             try:
 *                 return socket_SocketKind(self._type)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_4type_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_4type_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_4type___get__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_4type___get__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "uvloop/pseudosock.pyx":33
 *     property type:
 *         def __get__(self):
 *             try:             # <<<<<<<<<<<<<<
 *                 return socket_SocketKind(self._type)
 *             except ValueError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/pseudosock.pyx":34
 *         def __get__(self):
 *             try:
 *                 return socket_SocketKind(self._type)             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 return self._type
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 34, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_SocketKind);
      __pyx_t_6 = __pyx_v_6uvloop_4loop_socket_SocketKind; __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 34, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 34, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 34, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(10, 34, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 34, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "uvloop/pseudosock.pyx":33
 *     property type:
 *         def __get__(self):
 *             try:             # <<<<<<<<<<<<<<
 *                 return socket_SocketKind(self._type)
 *             except ValueError:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/pseudosock.pyx":35
 *             try:
 *                 return socket_SocketKind(self._type)
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 return self._type
 * 
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
    if (__pyx_t_9) {
      __Pyx_AddTraceback("uvloop.loop.PseudoSocket.type.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(10, 35, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_8);

      /* "uvloop/pseudosock.pyx":36
 *                 return socket_SocketKind(self._type)
 *             except ValueError:
 *                 return self._type             # <<<<<<<<<<<<<<
 * 
 *     property proto:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 36, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/pseudosock.pyx":33
 *     property type:
 *         def __get__(self):
 *             try:             # <<<<<<<<<<<<<<
 *                 return socket_SocketKind(self._type)
 *             except ValueError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "uvloop/pseudosock.pyx":32
 * 
 *     property type:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             try:
 *                 return socket_SocketKind(self._type)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.type.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":39
 * 
 *     property proto:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._proto
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_5proto_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_5proto_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_5proto___get__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_5proto___get__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "uvloop/pseudosock.pyx":40
 *     property proto:
 *         def __get__(self):
 *             return self._proto             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_proto); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/pseudosock.pyx":39
 * 
 *     property proto:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._proto
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.proto.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":42
 *             return self._proto
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         s = ("<uvloop.PseudoSocket fd={}, family={!s}, "
 *              "type={!s}, proto={}").format(self.fileno(), self.family,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_2__repr__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_2__repr__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_v_s = NULL;
  PyObject *__pyx_v_laddr = NULL;
  PyObject *__pyx_v_raddr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/pseudosock.pyx":44
 *     def __repr__(self):
 *         s = ("<uvloop.PseudoSocket fd={}, family={!s}, "
 *              "type={!s}, proto={}").format(self.fileno(), self.family,             # <<<<<<<<<<<<<<
 *                                            self.type, self.proto)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_uvloop_PseudoSocket_fd_family_s, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_fileno); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 44, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 44, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_family); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "uvloop/pseudosock.pyx":45
 *         s = ("<uvloop.PseudoSocket fd={}, family={!s}, "
 *              "type={!s}, proto={}").format(self.fileno(), self.family,
 *                                            self.type, self.proto)             # <<<<<<<<<<<<<<
 * 
 *         if self._fd != -1:
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_proto); if (unlikely(!__pyx_t_6)) __PYX_ERR(10, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 44, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_3, __pyx_t_4, __pyx_t_5, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 44, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(10, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_t_6);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_s = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":47
 *                                            self.type, self.proto)
 * 
 *         if self._fd != -1:             # <<<<<<<<<<<<<<
 *             try:
 *                 laddr = self.getsockname()
 */
  __pyx_t_10 = ((__pyx_v_self->_fd != -1L) != 0);
  if (__pyx_t_10) {

    /* "uvloop/pseudosock.pyx":48
 * 
 *         if self._fd != -1:
 *             try:             # <<<<<<<<<<<<<<
 *                 laddr = self.getsockname()
 *                 if laddr:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      /*try:*/ {

        /* "uvloop/pseudosock.pyx":49
 *         if self._fd != -1:
 *             try:
 *                 laddr = self.getsockname()             # <<<<<<<<<<<<<<
 *                 if laddr:
 *                     s += ", laddr=%s" % str(laddr)
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getsockname); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 49, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        if (__pyx_t_9) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 49, __pyx_L4_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 49, __pyx_L4_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_laddr = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "uvloop/pseudosock.pyx":50
 *             try:
 *                 laddr = self.getsockname()
 *                 if laddr:             # <<<<<<<<<<<<<<
 *                     s += ", laddr=%s" % str(laddr)
 *             except socket_error:
 */
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_laddr); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(10, 50, __pyx_L4_error)
        if (__pyx_t_10) {

          /* "uvloop/pseudosock.pyx":51
 *                 laddr = self.getsockname()
 *                 if laddr:
 *                     s += ", laddr=%s" % str(laddr)             # <<<<<<<<<<<<<<
 *             except socket_error:
 *                 pass
 */
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_laddr); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 51, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_laddr_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 51, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_s, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 51, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "uvloop/pseudosock.pyx":50
 *             try:
 *                 laddr = self.getsockname()
 *                 if laddr:             # <<<<<<<<<<<<<<
 *                     s += ", laddr=%s" % str(laddr)
 *             except socket_error:
 */
        }

        /* "uvloop/pseudosock.pyx":48
 * 
 *         if self._fd != -1:
 *             try:             # <<<<<<<<<<<<<<
 *                 laddr = self.getsockname()
 *                 if laddr:
 */
      }
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/pseudosock.pyx":52
 *                 if laddr:
 *                     s += ", laddr=%s" % str(laddr)
 *             except socket_error:             # <<<<<<<<<<<<<<
 *                 pass
 *             try:
 */
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6uvloop_4loop_socket_error);
      if (__pyx_t_8) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;
      __pyx_L6_except_error:;

      /* "uvloop/pseudosock.pyx":48
 * 
 *         if self._fd != -1:
 *             try:             # <<<<<<<<<<<<<<
 *                 laddr = self.getsockname()
 *                 if laddr:
 */
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_L9_try_end:;
    }

    /* "uvloop/pseudosock.pyx":54
 *             except socket_error:
 *                 pass
 *             try:             # <<<<<<<<<<<<<<
 *                 raddr = self.getpeername()
 *                 if raddr:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_13, &__pyx_t_12, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_11);
      /*try:*/ {

        /* "uvloop/pseudosock.pyx":55
 *                 pass
 *             try:
 *                 raddr = self.getpeername()             # <<<<<<<<<<<<<<
 *                 if raddr:
 *                     s += ", raddr=%s" % str(raddr)
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getpeername); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 55, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        if (__pyx_t_9) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 55, __pyx_L11_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 55, __pyx_L11_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_v_raddr = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "uvloop/pseudosock.pyx":56
 *             try:
 *                 raddr = self.getpeername()
 *                 if raddr:             # <<<<<<<<<<<<<<
 *                     s += ", raddr=%s" % str(raddr)
 *             except socket_error:
 */
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_raddr); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(10, 56, __pyx_L11_error)
        if (__pyx_t_10) {

          /* "uvloop/pseudosock.pyx":57
 *                 raddr = self.getpeername()
 *                 if raddr:
 *                     s += ", raddr=%s" % str(raddr)             # <<<<<<<<<<<<<<
 *             except socket_error:
 *                 pass
 */
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_raddr); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 57, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_2 = PyUnicode_Format(__pyx_kp_u_raddr_s, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 57, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_s, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 57, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "uvloop/pseudosock.pyx":56
 *             try:
 *                 raddr = self.getpeername()
 *                 if raddr:             # <<<<<<<<<<<<<<
 *                     s += ", raddr=%s" % str(raddr)
 *             except socket_error:
 */
        }

        /* "uvloop/pseudosock.pyx":54
 *             except socket_error:
 *                 pass
 *             try:             # <<<<<<<<<<<<<<
 *                 raddr = self.getpeername()
 *                 if raddr:
 */
      }
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L16_try_end;
      __pyx_L11_error:;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/pseudosock.pyx":58
 *                 if raddr:
 *                     s += ", raddr=%s" % str(raddr)
 *             except socket_error:             # <<<<<<<<<<<<<<
 *                 pass
 *         s += '>'
 */
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6uvloop_4loop_socket_error);
      if (__pyx_t_8) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L12_exception_handled;
      }
      goto __pyx_L13_except_error;
      __pyx_L13_except_error:;

      /* "uvloop/pseudosock.pyx":54
 *             except socket_error:
 *                 pass
 *             try:             # <<<<<<<<<<<<<<
 *                 raddr = self.getpeername()
 *                 if raddr:
 */
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_12, __pyx_t_11);
      goto __pyx_L1_error;
      __pyx_L12_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_12, __pyx_t_11);
      __pyx_L16_try_end:;
    }

    /* "uvloop/pseudosock.pyx":47
 *                                            self.type, self.proto)
 * 
 *         if self._fd != -1:             # <<<<<<<<<<<<<<
 *             try:
 *                 laddr = self.getsockname()
 */
  }

  /* "uvloop/pseudosock.pyx":60
 *             except socket_error:
 *                 pass
 *         s += '>'             # <<<<<<<<<<<<<<
 *         return s
 * 
 */
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_s, __pyx_kp_u__130); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_s, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":61
 *                 pass
 *         s += '>'
 *         return s             # <<<<<<<<<<<<<<
 * 
 *     def __getstate__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_s);
  __pyx_r = __pyx_v_s;
  goto __pyx_L0;

  /* "uvloop/pseudosock.pyx":42
 *             return self._proto
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         s = ("<uvloop.PseudoSocket fd={}, family={!s}, "
 *              "type={!s}, proto={}").format(self.fileno(), self.family,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_laddr);
  __Pyx_XDECREF(__pyx_v_raddr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":63
 *         return s
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot serialize socket object")
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_5__getstate__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_4__getstate__[] = "PseudoSocket.__getstate__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_5__getstate__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getstate__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_4__getstate__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_4__getstate__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__getstate__", 0);

  /* "uvloop/pseudosock.pyx":64
 * 
 *     def __getstate__(self):
 *         raise TypeError("Cannot serialize socket object")             # <<<<<<<<<<<<<<
 * 
 *     def fileno(self):
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__137, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(10, 64, __pyx_L1_error)

  /* "uvloop/pseudosock.pyx":63
 *         return s
 * 
 *     def __getstate__(self):             # <<<<<<<<<<<<<<
 *         raise TypeError("Cannot serialize socket object")
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.__getstate__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":66
 *         raise TypeError("Cannot serialize socket object")
 * 
 *     def fileno(self):             # <<<<<<<<<<<<<<
 *         return self._fd
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_7fileno(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_6fileno[] = "PseudoSocket.fileno(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_7fileno(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fileno (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_6fileno(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_6fileno(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("fileno", 0);

  /* "uvloop/pseudosock.pyx":67
 * 
 *     def fileno(self):
 *         return self._fd             # <<<<<<<<<<<<<<
 * 
 *     def dup(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/pseudosock.pyx":66
 *         raise TypeError("Cannot serialize socket object")
 * 
 *     def fileno(self):             # <<<<<<<<<<<<<<
 *         return self._fd
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.fileno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":69
 *         return self._fd
 * 
 *     def dup(self):             # <<<<<<<<<<<<<<
 *         fd = os_dup(self._fd)
 *         sock = socket_socket(self._family, self._type, self._proto, fileno=fd)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_9dup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_8dup[] = "PseudoSocket.dup(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_9dup(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dup (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_8dup(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_8dup(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_v_sock = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("dup", 0);

  /* "uvloop/pseudosock.pyx":70
 * 
 *     def dup(self):
 *         fd = os_dup(self._fd)             # <<<<<<<<<<<<<<
 *         sock = socket_socket(self._family, self._type, self._proto, fileno=fd)
 *         sock.settimeout(0)
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_dup);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_os_dup; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 70, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 70, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 70, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 70, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 70, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_fd = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":71
 *     def dup(self):
 *         fd = os_dup(self._fd)
 *         sock = socket_socket(self._family, self._type, self._proto, fileno=fd)             # <<<<<<<<<<<<<<
 *         sock.settimeout(0)
 *         return sock
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_family); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_self->_proto); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_5);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_fileno, __pyx_v_fd) < 0) __PYX_ERR(10, 71, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_socket_socket, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_sock = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/pseudosock.pyx":72
 *         fd = os_dup(self._fd)
 *         sock = socket_socket(self._family, self._type, self._proto, fileno=fd)
 *         sock.settimeout(0)             # <<<<<<<<<<<<<<
 *         return sock
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_settimeout); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__138, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/pseudosock.pyx":73
 *         sock = socket_socket(self._family, self._type, self._proto, fileno=fd)
 *         sock.settimeout(0)
 *         return sock             # <<<<<<<<<<<<<<
 * 
 *     def get_inheritable(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_sock);
  __pyx_r = __pyx_v_sock;
  goto __pyx_L0;

  /* "uvloop/pseudosock.pyx":69
 *         return self._fd
 * 
 *     def dup(self):             # <<<<<<<<<<<<<<
 *         fd = os_dup(self._fd)
 *         sock = socket_socket(self._family, self._type, self._proto, fileno=fd)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.dup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XDECREF(__pyx_v_sock);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":75
 *         return sock
 * 
 *     def get_inheritable(self):             # <<<<<<<<<<<<<<
 *         return os_get_inheritable(self._fd)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_11get_inheritable(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_10get_inheritable[] = "PseudoSocket.get_inheritable(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_11get_inheritable(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_inheritable (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_10get_inheritable(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_10get_inheritable(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("get_inheritable", 0);

  /* "uvloop/pseudosock.pyx":76
 * 
 *     def get_inheritable(self):
 *         return os_get_inheritable(self._fd)             # <<<<<<<<<<<<<<
 * 
 *     def set_inheritable(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_get_inheritable);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_os_get_inheritable; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 76, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 76, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 76, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/pseudosock.pyx":75
 *         return sock
 * 
 *     def get_inheritable(self):             # <<<<<<<<<<<<<<
 *         return os_get_inheritable(self._fd)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.get_inheritable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":78
 *         return os_get_inheritable(self._fd)
 * 
 *     def set_inheritable(self):             # <<<<<<<<<<<<<<
 *         os_set_inheritable(self._fd)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_13set_inheritable(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_12set_inheritable[] = "PseudoSocket.set_inheritable(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_13set_inheritable(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_inheritable (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_12set_inheritable(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_12set_inheritable(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("set_inheritable", 0);

  /* "uvloop/pseudosock.pyx":79
 * 
 *     def set_inheritable(self):
 *         os_set_inheritable(self._fd)             # <<<<<<<<<<<<<<
 * 
 *     def ioctl(self, *args, **kwargs):
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 79, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 79, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 79, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(10, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":78
 *         return os_get_inheritable(self._fd)
 * 
 *     def set_inheritable(self):             # <<<<<<<<<<<<<<
 *         os_set_inheritable(self._fd)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.set_inheritable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":81
 *         os_set_inheritable(self._fd)
 * 
 *     def ioctl(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_15ioctl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_14ioctl[] = "PseudoSocket.ioctl(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_15ioctl(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ioctl (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "ioctl", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_14ioctl(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_14ioctl(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("ioctl", 0);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":84
 *         pass
 * 
 *     def getsockopt(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         sock = self._make_sock()
 *         try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_17getsockopt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_16getsockopt[] = "PseudoSocket.getsockopt(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_17getsockopt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getsockopt (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "getsockopt", 1))) return NULL;
  if (unlikely(__pyx_kwds)) {
    __pyx_v_kwargs = PyDict_Copy(__pyx_kwds); if (unlikely(!__pyx_v_kwargs)) return NULL;
    __Pyx_GOTREF(__pyx_v_kwargs);
  } else {
    __pyx_v_kwargs = NULL;
  }
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_16getsockopt(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_16getsockopt(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_sock = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  char const *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("getsockopt", 0);

  /* "uvloop/pseudosock.pyx":85
 * 
 *     def getsockopt(self, *args, **kwargs):
 *         sock = self._make_sock()             # <<<<<<<<<<<<<<
 *         try:
 *             return sock.getsockopt(*args, **kwargs)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_make_sock(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sock = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":86
 *     def getsockopt(self, *args, **kwargs):
 *         sock = self._make_sock()
 *         try:             # <<<<<<<<<<<<<<
 *             return sock.getsockopt(*args, **kwargs)
 *         finally:
 */
  /*try:*/ {

    /* "uvloop/pseudosock.pyx":87
 *         sock = self._make_sock()
 *         try:
 *             return sock.getsockopt(*args, **kwargs)             # <<<<<<<<<<<<<<
 *         finally:
 *             sock.detach()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_getsockopt); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 87, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_v_args, __pyx_v_kwargs); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 87, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3_return;
  }

  /* "uvloop/pseudosock.pyx":89
 *             return sock.getsockopt(*args, **kwargs)
 *         finally:
 *             sock.detach()             # <<<<<<<<<<<<<<
 * 
 *     def setsockopt(self, *args, **kwargs):
 */
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __pyx_t_3 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_5 = __pyx_filename;
      {
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 89, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        if (__pyx_t_12) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 89, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        } else {
          __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 89, __pyx_L7_error)
        }
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __pyx_lineno = __pyx_t_3; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_5;
      goto __pyx_L1_error;
      __pyx_L7_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_11 = __pyx_r;
      __pyx_r = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 89, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (__pyx_t_12) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 89, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 89, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;
    }
  }

  /* "uvloop/pseudosock.pyx":84
 *         pass
 * 
 *     def getsockopt(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         sock = self._make_sock()
 *         try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.getsockopt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sock);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":91
 *             sock.detach()
 * 
 *     def setsockopt(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         sock = self._make_sock()
 *         try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_19setsockopt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_18setsockopt[] = "PseudoSocket.setsockopt(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_19setsockopt(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setsockopt (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "setsockopt", 1))) return NULL;
  if (unlikely(__pyx_kwds)) {
    __pyx_v_kwargs = PyDict_Copy(__pyx_kwds); if (unlikely(!__pyx_v_kwargs)) return NULL;
    __Pyx_GOTREF(__pyx_v_kwargs);
  } else {
    __pyx_v_kwargs = NULL;
  }
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_18setsockopt(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_18setsockopt(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_v_sock = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  char const *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("setsockopt", 0);

  /* "uvloop/pseudosock.pyx":92
 * 
 *     def setsockopt(self, *args, **kwargs):
 *         sock = self._make_sock()             # <<<<<<<<<<<<<<
 *         try:
 *             return sock.setsockopt(*args, **kwargs)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_make_sock(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sock = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":93
 *     def setsockopt(self, *args, **kwargs):
 *         sock = self._make_sock()
 *         try:             # <<<<<<<<<<<<<<
 *             return sock.setsockopt(*args, **kwargs)
 *         finally:
 */
  /*try:*/ {

    /* "uvloop/pseudosock.pyx":94
 *         sock = self._make_sock()
 *         try:
 *             return sock.setsockopt(*args, **kwargs)             # <<<<<<<<<<<<<<
 *         finally:
 *             sock.detach()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_setsockopt); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 94, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_v_args, __pyx_v_kwargs); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 94, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L3_return;
  }

  /* "uvloop/pseudosock.pyx":96
 *             return sock.setsockopt(*args, **kwargs)
 *         finally:
 *             sock.detach()             # <<<<<<<<<<<<<<
 * 
 *     def getpeername(self):
 */
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __pyx_t_3 = __pyx_lineno; __pyx_t_4 = __pyx_clineno; __pyx_t_5 = __pyx_filename;
      {
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 96, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        if (__pyx_t_12) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 96, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        } else {
          __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 96, __pyx_L7_error)
        }
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      __pyx_lineno = __pyx_t_3; __pyx_clineno = __pyx_t_4; __pyx_filename = __pyx_t_5;
      goto __pyx_L1_error;
      __pyx_L7_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_11 = __pyx_r;
      __pyx_r = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 96, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (__pyx_t_12) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 96, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      } else {
        __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 96, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_11;
      __pyx_t_11 = 0;
      goto __pyx_L0;
    }
  }

  /* "uvloop/pseudosock.pyx":91
 *             sock.detach()
 * 
 *     def setsockopt(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         sock = self._make_sock()
 *         try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.setsockopt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sock);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":98
 *             sock.detach()
 * 
 *     def getpeername(self):             # <<<<<<<<<<<<<<
 *         if self._peername is not None:
 *             return self._peername
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_21getpeername(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_20getpeername[] = "PseudoSocket.getpeername(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_21getpeername(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getpeername (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_20getpeername(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_20getpeername(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_v_sock = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("getpeername", 0);

  /* "uvloop/pseudosock.pyx":99
 * 
 *     def getpeername(self):
 *         if self._peername is not None:             # <<<<<<<<<<<<<<
 *             return self._peername
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_peername != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/pseudosock.pyx":100
 *     def getpeername(self):
 *         if self._peername is not None:
 *             return self._peername             # <<<<<<<<<<<<<<
 * 
 *         sock = self._make_sock()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_peername);
    __pyx_r = __pyx_v_self->_peername;
    goto __pyx_L0;

    /* "uvloop/pseudosock.pyx":99
 * 
 *     def getpeername(self):
 *         if self._peername is not None:             # <<<<<<<<<<<<<<
 *             return self._peername
 * 
 */
  }

  /* "uvloop/pseudosock.pyx":102
 *             return self._peername
 * 
 *         sock = self._make_sock()             # <<<<<<<<<<<<<<
 *         try:
 *             self._peername = sock.getpeername()
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_make_sock(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_sock = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/pseudosock.pyx":103
 * 
 *         sock = self._make_sock()
 *         try:             # <<<<<<<<<<<<<<
 *             self._peername = sock.getpeername()
 *             return self._peername
 */
  /*try:*/ {

    /* "uvloop/pseudosock.pyx":104
 *         sock = self._make_sock()
 *         try:
 *             self._peername = sock.getpeername()             # <<<<<<<<<<<<<<
 *             return self._peername
 *         finally:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_getpeername); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 104, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 104, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 104, __pyx_L5_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->_peername);
    __Pyx_DECREF(__pyx_v_self->_peername);
    __pyx_v_self->_peername = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/pseudosock.pyx":105
 *         try:
 *             self._peername = sock.getpeername()
 *             return self._peername             # <<<<<<<<<<<<<<
 *         finally:
 *             sock.detach()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_peername);
    __pyx_r = __pyx_v_self->_peername;
    goto __pyx_L4_return;
  }

  /* "uvloop/pseudosock.pyx":107
 *             return self._peername
 *         finally:
 *             sock.detach()             # <<<<<<<<<<<<<<
 * 
 *     def getsockname(self):
 */
  /*finally:*/ {
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 107, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        if (__pyx_t_5) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 107, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else {
          __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 107, __pyx_L8_error)
        }
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L4_return: {
      __pyx_t_14 = __pyx_r;
      __pyx_r = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 107, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 107, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_14;
      __pyx_t_14 = 0;
      goto __pyx_L0;
    }
  }

  /* "uvloop/pseudosock.pyx":98
 *             sock.detach()
 * 
 *     def getpeername(self):             # <<<<<<<<<<<<<<
 *         if self._peername is not None:
 *             return self._peername
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.getpeername", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sock);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":109
 *             sock.detach()
 * 
 *     def getsockname(self):             # <<<<<<<<<<<<<<
 *         if self._sockname is not None:
 *             return self._sockname
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_23getsockname(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_22getsockname[] = "PseudoSocket.getsockname(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_23getsockname(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getsockname (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_22getsockname(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_22getsockname(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_v_sock = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("getsockname", 0);

  /* "uvloop/pseudosock.pyx":110
 * 
 *     def getsockname(self):
 *         if self._sockname is not None:             # <<<<<<<<<<<<<<
 *             return self._sockname
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_sockname != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/pseudosock.pyx":111
 *     def getsockname(self):
 *         if self._sockname is not None:
 *             return self._sockname             # <<<<<<<<<<<<<<
 * 
 *         sock = self._make_sock()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_sockname);
    __pyx_r = __pyx_v_self->_sockname;
    goto __pyx_L0;

    /* "uvloop/pseudosock.pyx":110
 * 
 *     def getsockname(self):
 *         if self._sockname is not None:             # <<<<<<<<<<<<<<
 *             return self._sockname
 * 
 */
  }

  /* "uvloop/pseudosock.pyx":113
 *             return self._sockname
 * 
 *         sock = self._make_sock()             # <<<<<<<<<<<<<<
 *         try:
 *             self._sockname = sock.getsockname()
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_make_sock(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_sock = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/pseudosock.pyx":114
 * 
 *         sock = self._make_sock()
 *         try:             # <<<<<<<<<<<<<<
 *             self._sockname = sock.getsockname()
 *             return self._sockname
 */
  /*try:*/ {

    /* "uvloop/pseudosock.pyx":115
 *         sock = self._make_sock()
 *         try:
 *             self._sockname = sock.getsockname()             # <<<<<<<<<<<<<<
 *             return self._sockname
 *         finally:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_getsockname); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 115, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 115, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 115, __pyx_L5_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->_sockname);
    __Pyx_DECREF(__pyx_v_self->_sockname);
    __pyx_v_self->_sockname = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/pseudosock.pyx":116
 *         try:
 *             self._sockname = sock.getsockname()
 *             return self._sockname             # <<<<<<<<<<<<<<
 *         finally:
 *             sock.detach()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->_sockname);
    __pyx_r = __pyx_v_self->_sockname;
    goto __pyx_L4_return;
  }

  /* "uvloop/pseudosock.pyx":118
 *             return self._sockname
 *         finally:
 *             sock.detach()             # <<<<<<<<<<<<<<
 * 
 *     def share(self, process_id):
 */
  /*finally:*/ {
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 118, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        if (__pyx_t_5) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 118, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else {
          __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 118, __pyx_L8_error)
        }
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L4_return: {
      __pyx_t_14 = __pyx_r;
      __pyx_r = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 118, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 118, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 118, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_14;
      __pyx_t_14 = 0;
      goto __pyx_L0;
    }
  }

  /* "uvloop/pseudosock.pyx":109
 *             sock.detach()
 * 
 *     def getsockname(self):             # <<<<<<<<<<<<<<
 *         if self._sockname is not None:
 *             return self._sockname
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.getsockname", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sock);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":120
 *             sock.detach()
 * 
 *     def share(self, process_id):             # <<<<<<<<<<<<<<
 *         sock = self._make_sock()
 *         try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_25share(PyObject *__pyx_v_self, PyObject *__pyx_v_process_id); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_24share[] = "PseudoSocket.share(self, process_id)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_25share(PyObject *__pyx_v_self, PyObject *__pyx_v_process_id) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("share (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_24share(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), ((PyObject *)__pyx_v_process_id));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_24share(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_process_id) {
  PyObject *__pyx_v_sock = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  char const *__pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_RefNannySetupContext("share", 0);

  /* "uvloop/pseudosock.pyx":121
 * 
 *     def share(self, process_id):
 *         sock = self._make_sock()             # <<<<<<<<<<<<<<
 *         try:
 *             return sock.share(process_id)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_make_sock(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sock = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":122
 *     def share(self, process_id):
 *         sock = self._make_sock()
 *         try:             # <<<<<<<<<<<<<<
 *             return sock.share(process_id)
 *         finally:
 */
  /*try:*/ {

    /* "uvloop/pseudosock.pyx":123
 *         sock = self._make_sock()
 *         try:
 *             return sock.share(process_id)             # <<<<<<<<<<<<<<
 *         finally:
 *             sock.detach()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_share); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 123, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_process_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 123, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_process_id};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 123, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_process_id};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 123, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 123, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_process_id);
        __Pyx_GIVEREF(__pyx_v_process_id);
        PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_process_id);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 123, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L3_return;
  }

  /* "uvloop/pseudosock.pyx":125
 *             return sock.share(process_id)
 *         finally:
 *             sock.detach()             # <<<<<<<<<<<<<<
 * 
 *     def accept(self):
 */
  /*finally:*/ {
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __pyx_t_5 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_7 = __pyx_filename;
      {
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 125, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
          }
        }
        if (__pyx_t_4) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 125, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 125, __pyx_L7_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      }
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ErrRestore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_7;
      goto __pyx_L1_error;
      __pyx_L7_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L3_return: {
      __pyx_t_13 = __pyx_r;
      __pyx_r = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_detach); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 125, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 125, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 125, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_r = __pyx_t_13;
      __pyx_t_13 = 0;
      goto __pyx_L0;
    }
  }

  /* "uvloop/pseudosock.pyx":120
 *             sock.detach()
 * 
 *     def share(self, process_id):             # <<<<<<<<<<<<<<
 *         sock = self._make_sock()
 *         try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.share", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sock);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":127
 *             sock.detach()
 * 
 *     def accept(self):             # <<<<<<<<<<<<<<
 *         self._na('accept() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_27accept(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_26accept[] = "PseudoSocket.accept(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_27accept(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("accept (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_26accept(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_26accept(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("accept", 0);

  /* "uvloop/pseudosock.pyx":128
 * 
 *     def accept(self):
 *         self._na('accept() method')             # <<<<<<<<<<<<<<
 * 
 *     def connect(self, *args):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_accept_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":127
 *             sock.detach()
 * 
 *     def accept(self):             # <<<<<<<<<<<<<<
 *         self._na('accept() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.accept", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":130
 *         self._na('accept() method')
 * 
 *     def connect(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('connect() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_29connect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_28connect[] = "PseudoSocket.connect(self, *args)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_29connect(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "connect", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_28connect(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_28connect(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("connect", 0);

  /* "uvloop/pseudosock.pyx":131
 * 
 *     def connect(self, *args):
 *         self._na('connect() method')             # <<<<<<<<<<<<<<
 * 
 *     def connect_ex(self, *args):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_connect_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":130
 *         self._na('accept() method')
 * 
 *     def connect(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('connect() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":133
 *         self._na('connect() method')
 * 
 *     def connect_ex(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('connect_ex() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_31connect_ex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_30connect_ex[] = "PseudoSocket.connect_ex(self, *args)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_31connect_ex(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect_ex (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "connect_ex", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_30connect_ex(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_30connect_ex(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("connect_ex", 0);

  /* "uvloop/pseudosock.pyx":134
 * 
 *     def connect_ex(self, *args):
 *         self._na('connect_ex() method')             # <<<<<<<<<<<<<<
 * 
 *     def bind(self, *args):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_connect_ex_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":133
 *         self._na('connect() method')
 * 
 *     def connect_ex(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('connect_ex() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.connect_ex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":136
 *         self._na('connect_ex() method')
 * 
 *     def bind(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('bind() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_33bind(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_32bind[] = "PseudoSocket.bind(self, *args)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_33bind(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("bind (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "bind", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_32bind(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_32bind(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("bind", 0);

  /* "uvloop/pseudosock.pyx":137
 * 
 *     def bind(self, *args):
 *         self._na('bind() method')             # <<<<<<<<<<<<<<
 * 
 *     def listen(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_bind_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":136
 *         self._na('connect_ex() method')
 * 
 *     def bind(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('bind() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.bind", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":139
 *         self._na('bind() method')
 * 
 *     def listen(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('listen() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_35listen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_34listen[] = "PseudoSocket.listen(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_35listen(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("listen (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "listen", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_34listen(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_34listen(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("listen", 0);

  /* "uvloop/pseudosock.pyx":140
 * 
 *     def listen(self, *args, **kwargs):
 *         self._na('listen() method')             # <<<<<<<<<<<<<<
 * 
 *     def makefile(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_listen_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":139
 *         self._na('bind() method')
 * 
 *     def listen(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('listen() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.listen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":142
 *         self._na('listen() method')
 * 
 *     def makefile(self):             # <<<<<<<<<<<<<<
 *         self._na('makefile() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_37makefile(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_36makefile[] = "PseudoSocket.makefile(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_37makefile(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("makefile (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_36makefile(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_36makefile(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("makefile", 0);

  /* "uvloop/pseudosock.pyx":143
 * 
 *     def makefile(self):
 *         self._na('makefile() method')             # <<<<<<<<<<<<<<
 * 
 *     def sendfile(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_makefile_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":142
 *         self._na('listen() method')
 * 
 *     def makefile(self):             # <<<<<<<<<<<<<<
 *         self._na('makefile() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.makefile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":145
 *         self._na('makefile() method')
 * 
 *     def sendfile(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendfile() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_39sendfile(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_38sendfile[] = "PseudoSocket.sendfile(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_39sendfile(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sendfile (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sendfile", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_38sendfile(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_38sendfile(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("sendfile", 0);

  /* "uvloop/pseudosock.pyx":146
 * 
 *     def sendfile(self, *args, **kwargs):
 *         self._na('sendfile() method')             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_sendfile_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":145
 *         self._na('makefile() method')
 * 
 *     def sendfile(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendfile() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.sendfile", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":148
 *         self._na('sendfile() method')
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         self._na('close() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_41close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_40close[] = "PseudoSocket.close(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_41close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_40close(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_40close(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("close", 0);

  /* "uvloop/pseudosock.pyx":149
 * 
 *     def close(self):
 *         self._na('close() method')             # <<<<<<<<<<<<<<
 * 
 *     def detach(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_close_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":148
 *         self._na('sendfile() method')
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         self._na('close() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":151
 *         self._na('close() method')
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         self._na('detach() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_43detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_42detach[] = "PseudoSocket.detach(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_43detach(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("detach (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_42detach(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_42detach(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("detach", 0);

  /* "uvloop/pseudosock.pyx":152
 * 
 *     def detach(self):
 *         self._na('detach() method')             # <<<<<<<<<<<<<<
 * 
 *     def shutdown(self, *args):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_detach_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":151
 *         self._na('close() method')
 * 
 *     def detach(self):             # <<<<<<<<<<<<<<
 *         self._na('detach() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.detach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":154
 *         self._na('detach() method')
 * 
 *     def shutdown(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('shutdown() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_45shutdown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_44shutdown[] = "PseudoSocket.shutdown(self, *args)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_45shutdown(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("shutdown (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "shutdown", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_44shutdown(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_44shutdown(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("shutdown", 0);

  /* "uvloop/pseudosock.pyx":155
 * 
 *     def shutdown(self, *args):
 *         self._na('shutdown() method')             # <<<<<<<<<<<<<<
 * 
 *     def sendmsg_afalg(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_shutdown_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":154
 *         self._na('detach() method')
 * 
 *     def shutdown(self, *args):             # <<<<<<<<<<<<<<
 *         self._na('shutdown() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.shutdown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":157
 *         self._na('shutdown() method')
 * 
 *     def sendmsg_afalg(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendmsg_afalg() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_47sendmsg_afalg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_46sendmsg_afalg[] = "PseudoSocket.sendmsg_afalg(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_47sendmsg_afalg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sendmsg_afalg (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sendmsg_afalg", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_46sendmsg_afalg(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_46sendmsg_afalg(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("sendmsg_afalg", 0);

  /* "uvloop/pseudosock.pyx":158
 * 
 *     def sendmsg_afalg(self, *args, **kwargs):
 *         self._na('sendmsg_afalg() method')             # <<<<<<<<<<<<<<
 * 
 *     def sendmsg(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_sendmsg_afalg_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":157
 *         self._na('shutdown() method')
 * 
 *     def sendmsg_afalg(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendmsg_afalg() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.sendmsg_afalg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":160
 *         self._na('sendmsg_afalg() method')
 * 
 *     def sendmsg(self):             # <<<<<<<<<<<<<<
 *         self._na('sendmsg() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_49sendmsg(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_48sendmsg[] = "PseudoSocket.sendmsg(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_49sendmsg(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sendmsg (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_48sendmsg(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_48sendmsg(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("sendmsg", 0);

  /* "uvloop/pseudosock.pyx":161
 * 
 *     def sendmsg(self):
 *         self._na('sendmsg() method')             # <<<<<<<<<<<<<<
 * 
 *     def sendto(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_sendmsg_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":160
 *         self._na('sendmsg_afalg() method')
 * 
 *     def sendmsg(self):             # <<<<<<<<<<<<<<
 *         self._na('sendmsg() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.sendmsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":163
 *         self._na('sendmsg() method')
 * 
 *     def sendto(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendto() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_51sendto(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_50sendto[] = "PseudoSocket.sendto(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_51sendto(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sendto (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sendto", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_50sendto(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_50sendto(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("sendto", 0);

  /* "uvloop/pseudosock.pyx":164
 * 
 *     def sendto(self, *args, **kwargs):
 *         self._na('sendto() method')             # <<<<<<<<<<<<<<
 * 
 *     def send(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_sendto_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":163
 *         self._na('sendmsg() method')
 * 
 *     def sendto(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendto() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.sendto", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":166
 *         self._na('sendto() method')
 * 
 *     def send(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('send() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_53send(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_52send[] = "PseudoSocket.send(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_53send(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("send (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "send", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_52send(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_52send(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("send", 0);

  /* "uvloop/pseudosock.pyx":167
 * 
 *     def send(self, *args, **kwargs):
 *         self._na('send() method')             # <<<<<<<<<<<<<<
 * 
 *     def sendall(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_send_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":166
 *         self._na('sendto() method')
 * 
 *     def send(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('send() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.send", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":169
 *         self._na('send() method')
 * 
 *     def sendall(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendall() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_55sendall(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_54sendall[] = "PseudoSocket.sendall(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_55sendall(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sendall (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "sendall", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_54sendall(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_54sendall(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("sendall", 0);

  /* "uvloop/pseudosock.pyx":170
 * 
 *     def sendall(self, *args, **kwargs):
 *         self._na('sendall() method')             # <<<<<<<<<<<<<<
 * 
 *     def recv_into(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_sendall_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":169
 *         self._na('send() method')
 * 
 *     def sendall(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('sendall() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.sendall", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":172
 *         self._na('sendall() method')
 * 
 *     def recv_into(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recv_into() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_57recv_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_56recv_into[] = "PseudoSocket.recv_into(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_57recv_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recv_into (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "recv_into", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_56recv_into(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_56recv_into(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("recv_into", 0);

  /* "uvloop/pseudosock.pyx":173
 * 
 *     def recv_into(self, *args, **kwargs):
 *         self._na('recv_into() method')             # <<<<<<<<<<<<<<
 * 
 *     def recvfrom_into(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_recv_into_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":172
 *         self._na('sendall() method')
 * 
 *     def recv_into(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recv_into() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.recv_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":175
 *         self._na('recv_into() method')
 * 
 *     def recvfrom_into(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvfrom_into() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_59recvfrom_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_58recvfrom_into[] = "PseudoSocket.recvfrom_into(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_59recvfrom_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recvfrom_into (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "recvfrom_into", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_58recvfrom_into(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_58recvfrom_into(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("recvfrom_into", 0);

  /* "uvloop/pseudosock.pyx":176
 * 
 *     def recvfrom_into(self, *args, **kwargs):
 *         self._na('recvfrom_into() method')             # <<<<<<<<<<<<<<
 * 
 *     def recvmsg_into(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_recvfrom_into_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":175
 *         self._na('recv_into() method')
 * 
 *     def recvfrom_into(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvfrom_into() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.recvfrom_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":178
 *         self._na('recvfrom_into() method')
 * 
 *     def recvmsg_into(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvmsg_into() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_61recvmsg_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_60recvmsg_into[] = "PseudoSocket.recvmsg_into(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_61recvmsg_into(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recvmsg_into (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "recvmsg_into", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_60recvmsg_into(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_60recvmsg_into(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("recvmsg_into", 0);

  /* "uvloop/pseudosock.pyx":179
 * 
 *     def recvmsg_into(self, *args, **kwargs):
 *         self._na('recvmsg_into() method')             # <<<<<<<<<<<<<<
 * 
 *     def recvmsg(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_recvmsg_into_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":178
 *         self._na('recvfrom_into() method')
 * 
 *     def recvmsg_into(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvmsg_into() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.recvmsg_into", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":181
 *         self._na('recvmsg_into() method')
 * 
 *     def recvmsg(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvmsg() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_63recvmsg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_62recvmsg[] = "PseudoSocket.recvmsg(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_63recvmsg(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recvmsg (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "recvmsg", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_62recvmsg(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_62recvmsg(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("recvmsg", 0);

  /* "uvloop/pseudosock.pyx":182
 * 
 *     def recvmsg(self, *args, **kwargs):
 *         self._na('recvmsg() method')             # <<<<<<<<<<<<<<
 * 
 *     def recvfrom(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_recvmsg_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":181
 *         self._na('recvmsg_into() method')
 * 
 *     def recvmsg(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvmsg() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.recvmsg", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":184
 *         self._na('recvmsg() method')
 * 
 *     def recvfrom(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvfrom() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_65recvfrom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_64recvfrom[] = "PseudoSocket.recvfrom(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_65recvfrom(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recvfrom (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "recvfrom", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_64recvfrom(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_64recvfrom(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("recvfrom", 0);

  /* "uvloop/pseudosock.pyx":185
 * 
 *     def recvfrom(self, *args, **kwargs):
 *         self._na('recvfrom() method')             # <<<<<<<<<<<<<<
 * 
 *     def recv(self, *args, **kwargs):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_recvfrom_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":184
 *         self._na('recvmsg() method')
 * 
 *     def recvfrom(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recvfrom() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.recvfrom", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":187
 *         self._na('recvfrom() method')
 * 
 *     def recv(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recv() method')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_67recv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_66recv[] = "PseudoSocket.recv(self, *args, **kwargs)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_67recv(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_args = 0;
  CYTHON_UNUSED PyObject *__pyx_v_kwargs = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("recv (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "recv", 1))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_args = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_66recv(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_args, __pyx_v_kwargs);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_66recv(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_args, CYTHON_UNUSED PyObject *__pyx_v_kwargs) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("recv", 0);

  /* "uvloop/pseudosock.pyx":188
 * 
 *     def recv(self, *args, **kwargs):
 *         self._na('recv() method')             # <<<<<<<<<<<<<<
 * 
 *     def settimeout(self, value):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_recv_method); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":187
 *         self._na('recvfrom() method')
 * 
 *     def recv(self, *args, **kwargs):             # <<<<<<<<<<<<<<
 *         self._na('recv() method')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.recv", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":190
 *         self._na('recv() method')
 * 
 *     def settimeout(self, value):             # <<<<<<<<<<<<<<
 *         if value == 0:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_69settimeout(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_68settimeout[] = "PseudoSocket.settimeout(self, value)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_69settimeout(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("settimeout (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_68settimeout(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_68settimeout(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("settimeout", 0);

  /* "uvloop/pseudosock.pyx":191
 * 
 *     def settimeout(self, value):
 *         if value == 0:             # <<<<<<<<<<<<<<
 *             return
 *         raise ValueError(
 */
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_value, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(10, 191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/pseudosock.pyx":192
 *     def settimeout(self, value):
 *         if value == 0:
 *             return             # <<<<<<<<<<<<<<
 *         raise ValueError(
 *             'settimeout(): only 0 timeout is allowed on transport sockets')
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/pseudosock.pyx":191
 * 
 *     def settimeout(self, value):
 *         if value == 0:             # <<<<<<<<<<<<<<
 *             return
 *         raise ValueError(
 */
  }

  /* "uvloop/pseudosock.pyx":193
 *         if value == 0:
 *             return
 *         raise ValueError(             # <<<<<<<<<<<<<<
 *             'settimeout(): only 0 timeout is allowed on transport sockets')
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__139, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(10, 193, __pyx_L1_error)

  /* "uvloop/pseudosock.pyx":190
 *         self._na('recv() method')
 * 
 *     def settimeout(self, value):             # <<<<<<<<<<<<<<
 *         if value == 0:
 *             return
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.settimeout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":196
 *             'settimeout(): only 0 timeout is allowed on transport sockets')
 * 
 *     def gettimeout(self):             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_71gettimeout(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_70gettimeout[] = "PseudoSocket.gettimeout(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_71gettimeout(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gettimeout (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_70gettimeout(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_70gettimeout(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("gettimeout", 0);

  /* "uvloop/pseudosock.pyx":197
 * 
 *     def gettimeout(self):
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     def setblocking(self, flag):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_int_0);
  __pyx_r = __pyx_int_0;
  goto __pyx_L0;

  /* "uvloop/pseudosock.pyx":196
 *             'settimeout(): only 0 timeout is allowed on transport sockets')
 * 
 *     def gettimeout(self):             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":199
 *         return 0
 * 
 *     def setblocking(self, flag):             # <<<<<<<<<<<<<<
 *         if not flag:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_73setblocking(PyObject *__pyx_v_self, PyObject *__pyx_v_flag); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_72setblocking[] = "PseudoSocket.setblocking(self, flag)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_73setblocking(PyObject *__pyx_v_self, PyObject *__pyx_v_flag) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("setblocking (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_72setblocking(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), ((PyObject *)__pyx_v_flag));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_72setblocking(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v_flag) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("setblocking", 0);

  /* "uvloop/pseudosock.pyx":200
 * 
 *     def setblocking(self, flag):
 *         if not flag:             # <<<<<<<<<<<<<<
 *             return
 *         raise ValueError(
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(10, 200, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "uvloop/pseudosock.pyx":201
 *     def setblocking(self, flag):
 *         if not flag:
 *             return             # <<<<<<<<<<<<<<
 *         raise ValueError(
 *             'setblocking(): transport sockets cannot be blocking')
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/pseudosock.pyx":200
 * 
 *     def setblocking(self, flag):
 *         if not flag:             # <<<<<<<<<<<<<<
 *             return
 *         raise ValueError(
 */
  }

  /* "uvloop/pseudosock.pyx":202
 *         if not flag:
 *             return
 *         raise ValueError(             # <<<<<<<<<<<<<<
 *             'setblocking(): transport sockets cannot be blocking')
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__140, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(10, 202, __pyx_L1_error)

  /* "uvloop/pseudosock.pyx":199
 *         return 0
 * 
 *     def setblocking(self, flag):             # <<<<<<<<<<<<<<
 *         if not flag:
 *             return
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.setblocking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":205
 *             'setblocking(): transport sockets cannot be blocking')
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         self._na('context manager protocol')
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_75__enter__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_74__enter__[] = "PseudoSocket.__enter__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_75__enter__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__enter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_74__enter__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_74__enter__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__enter__", 0);

  /* "uvloop/pseudosock.pyx":206
 * 
 *     def __enter__(self):
 *         self._na('context manager protocol')             # <<<<<<<<<<<<<<
 * 
 *     def __exit__(self, *err):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_context_manager_protocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":205
 *             'setblocking(): transport sockets cannot be blocking')
 * 
 *     def __enter__(self):             # <<<<<<<<<<<<<<
 *         self._na('context manager protocol')
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.__enter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/pseudosock.pyx":208
 *         self._na('context manager protocol')
 * 
 *     def __exit__(self, *err):             # <<<<<<<<<<<<<<
 *         self._na('context manager protocol')
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_77__exit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_76__exit__[] = "PseudoSocket.__exit__(self, *err)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_77__exit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_err = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__exit__ (wrapper)", 0);
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__exit__", 0))) return NULL;
  __Pyx_INCREF(__pyx_args);
  __pyx_v_err = __pyx_args;
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_76__exit__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), __pyx_v_err);

  /* function exit code */
  __Pyx_XDECREF(__pyx_v_err);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_76__exit__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_err) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__exit__", 0);

  /* "uvloop/pseudosock.pyx":209
 * 
 *     def __exit__(self, *err):
 *         self._na('context manager protocol')             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx_vtab)->_na(__pyx_v_self, __pyx_kp_u_context_manager_protocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/pseudosock.pyx":208
 *         self._na('context manager protocol')
 * 
 *     def __exit__(self, *err):             # <<<<<<<<<<<<<<
 *         self._na('context manager protocol')
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.__exit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._family, self._fd, self._peername, self._proto, self._sockname, self._type)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_79__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_78__reduce_cython__[] = "PseudoSocket.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_79__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_78__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_78__reduce_cython__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self) {
  int __pyx_v_use_setstate;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v__dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     cdef bint use_setstate
 *     state = (self._family, self._fd, self._peername, self._proto, self._sockname, self._type)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_family); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_self->_proto); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(6); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->_peername);
  __Pyx_GIVEREF(__pyx_v_self->_peername);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_self->_peername);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_3);
  __Pyx_INCREF(__pyx_v_self->_sockname);
  __Pyx_GIVEREF(__pyx_v_self->_sockname);
  PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_v_self->_sockname);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 5, __pyx_t_4);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "(tree fragment)":4
 *     cdef bint use_setstate
 *     state = (self._family, self._fd, self._peername, self._proto, self._sockname, self._type)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_5 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v__dict = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "(tree fragment)":5
 *     state = (self._family, self._fd, self._peername, self._proto, self._sockname, self._type)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_6 = (__pyx_v__dict != Py_None);
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":6
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v__dict);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":7
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._peername is not None or self._sockname is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":5
 *     state = (self._family, self._fd, self._peername, self._proto, self._sockname, self._type)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":9
 *         use_setstate = True
 *     else:
 *         use_setstate = self._peername is not None or self._sockname is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, None), state
 */
  /*else*/ {
    __pyx_t_6 = (__pyx_v_self->_peername != Py_None);
    __pyx_t_8 = (__pyx_t_6 != 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_8 = (__pyx_v_self->_sockname != Py_None);
    __pyx_t_6 = (__pyx_t_8 != 0);
    __pyx_t_7 = __pyx_t_6;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_7;
  }
  __pyx_L3:;

  /* "(tree fragment)":10
 *     else:
 *         use_setstate = self._peername is not None or self._sockname is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, None), state
 *     else:
 */
  __pyx_t_7 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":11
 *         use_setstate = self._peername is not None or self._sockname is not None
 *     if use_setstate:
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle_PseudoSocket); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_143395587);
    __Pyx_GIVEREF(__pyx_int_143395587);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_143395587);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_5, 2, Py_None);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_state);
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":10
 *     else:
 *         use_setstate = self._peername is not None or self._sockname is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, None), state
 *     else:
 */
  }

  /* "(tree fragment)":13
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, None), state
 *     else:
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_PseudoSocket__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle_PseudoSocket); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_143395587);
    __Pyx_GIVEREF(__pyx_int_143395587);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_int_143395587);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._family, self._fd, self._peername, self._proto, self._sockname, self._type)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_PseudoSocket__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_81__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_12PseudoSocket_80__setstate_cython__[] = "PseudoSocket.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_12PseudoSocket_81__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12PseudoSocket_80__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12PseudoSocket_80__setstate_cython__(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":15
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_PseudoSocket__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(9, 15, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pyx_unpickle_PseudoSocket__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle_PseudoSocket, (type(self), 0x88c0b03, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_PseudoSocket__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.PseudoSocket.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":15
 *     """
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._closed = 0
 *         self._inited = 0
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_8UVHandle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_8UVHandle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVHandle___cinit__(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_8UVHandle___cinit__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/handle.pyx":16
 * 
 *     def __cinit__(self):
 *         self._closed = 0             # <<<<<<<<<<<<<<
 *         self._inited = 0
 *         self._has_handle = 1
 */
  __pyx_v_self->_closed = 0;

  /* "uvloop/handles/handle.pyx":17
 *     def __cinit__(self):
 *         self._closed = 0
 *         self._inited = 0             # <<<<<<<<<<<<<<
 *         self._has_handle = 1
 *         self._handle = NULL
 */
  __pyx_v_self->_inited = 0;

  /* "uvloop/handles/handle.pyx":18
 *         self._closed = 0
 *         self._inited = 0
 *         self._has_handle = 1             # <<<<<<<<<<<<<<
 *         self._handle = NULL
 *         self._loop = None
 */
  __pyx_v_self->_has_handle = 1;

  /* "uvloop/handles/handle.pyx":19
 *         self._inited = 0
 *         self._has_handle = 1
 *         self._handle = NULL             # <<<<<<<<<<<<<<
 *         self._loop = None
 *         self._source_traceback = None
 */
  __pyx_v_self->_handle = NULL;

  /* "uvloop/handles/handle.pyx":20
 *         self._has_handle = 1
 *         self._handle = NULL
 *         self._loop = None             # <<<<<<<<<<<<<<
 *         self._source_traceback = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_loop);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_loop));
  __pyx_v_self->_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None);

  /* "uvloop/handles/handle.pyx":21
 *         self._handle = NULL
 *         self._loop = None
 *         self._source_traceback = None             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_source_traceback);
  __Pyx_DECREF(__pyx_v_self->_source_traceback);
  __pyx_v_self->_source_traceback = Py_None;

  /* "uvloop/handles/handle.pyx":15
 *     """
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._closed = 0
 *         self._inited = 0
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":23
 *         self._source_traceback = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_8UVHandle_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_8UVHandle_3__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVHandle_2__init__(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_8UVHandle_2__init__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/handles/handle.pyx":25
 *     def __init__(self):
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(             # <<<<<<<<<<<<<<
 *                 self.__class__.__name__))
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_is_not_supposed_to_be_instantia, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/handles/handle.pyx":26
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(
 *                 self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 25, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 25, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 25, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/handle.pyx":24
 * 
 *     def __init__(self):
 *         raise TypeError(             # <<<<<<<<<<<<<<
 *             '{} is not supposed to be instantiated from Python'.format(
 *                 self.__class__.__name__))
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(4, 24, __pyx_L1_error)

  /* "uvloop/handles/handle.pyx":23
 *         self._source_traceback = None
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             '{} is not supposed to be instantiated from Python'.format(
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVHandle.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":28
 *                 self.__class__.__name__))
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self._dealloc_impl()
 * 
 */

/* Python wrapper */
static void __pyx_pw_6uvloop_4loop_8UVHandle_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6uvloop_4loop_8UVHandle_5__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_6uvloop_4loop_8UVHandle_4__dealloc__(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6uvloop_4loop_8UVHandle_4__dealloc__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "uvloop/handles/handle.pyx":29
 * 
 *     def __dealloc__(self):
 *         self._dealloc_impl()             # <<<<<<<<<<<<<<
 * 
 *     cdef _dealloc_impl(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_self->__pyx_vtab)->_dealloc_impl(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/handle.pyx":28
 *                 self.__class__.__name__))
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self._dealloc_impl()
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_WriteUnraisable("uvloop.loop.UVHandle.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/handles/handle.pyx":31
 *         self._dealloc_impl()
 * 
 *     cdef _dealloc_impl(self):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__dealloc_impl(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("_dealloc_impl", 0);

  /* "uvloop/handles/handle.pyx":32
 * 
 *     cdef _dealloc_impl(self):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self._loop is not None:
 *                 self._loop._debug_handles_current.subtract([
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":33
 *     cdef _dealloc_impl(self):
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:             # <<<<<<<<<<<<<<
 *                 self._loop._debug_handles_current.subtract([
 *                     self.__class__.__name__])
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_loop) != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (likely(__pyx_t_2)) {

      /* "uvloop/handles/handle.pyx":34
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:
 *                 self._loop._debug_handles_current.subtract([             # <<<<<<<<<<<<<<
 *                     self.__class__.__name__])
 *             else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_loop->_debug_handles_current, __pyx_n_s_subtract); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 34, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "uvloop/handles/handle.pyx":35
 *             if self._loop is not None:
 *                 self._loop._debug_handles_current.subtract([
 *                     self.__class__.__name__])             # <<<<<<<<<<<<<<
 *             else:
 *                 # No "@cython.no_gc_clear" decorator on this UVHandle
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/handles/handle.pyx":34
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:
 *                 self._loop._debug_handles_current.subtract([             # <<<<<<<<<<<<<<
 *                     self.__class__.__name__])
 *             else:
 */
      __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 34, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_6);
      PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 34, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 34, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 34, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 34, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 34, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/handle.pyx":33
 *     cdef _dealloc_impl(self):
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:             # <<<<<<<<<<<<<<
 *                 self._loop._debug_handles_current.subtract([
 *                     self.__class__.__name__])
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/handle.pyx":38
 *             else:
 *                 # No "@cython.no_gc_clear" decorator on this UVHandle
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{} without @no_gc_clear; loop was set to None by GC'
 *                     .format(self.__class__.__name__))
 */
    /*else*/ {

      /* "uvloop/handles/handle.pyx":40
 *                 raise RuntimeError(
 *                     '{} without @no_gc_clear; loop was set to None by GC'
 *                     .format(self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *         if self._handle is NULL:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_without_no_gc_clear_loop_was_se, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 40, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 40, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 40, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 40, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 40, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/handles/handle.pyx":38
 *             else:
 *                 # No "@cython.no_gc_clear" decorator on this UVHandle
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{} without @no_gc_clear; loop was set to None by GC'
 *                     .format(self.__class__.__name__))
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 38, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(4, 38, __pyx_L1_error)
    }
    __pyx_L4:;

    /* "uvloop/handles/handle.pyx":32
 * 
 *     cdef _dealloc_impl(self):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self._loop is not None:
 *                 self._loop._debug_handles_current.subtract([
 */
  }

  /* "uvloop/handles/handle.pyx":42
 *                     .format(self.__class__.__name__))
 * 
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 if self._has_handle == 0:
 */
  __pyx_t_2 = ((__pyx_v_self->_handle == NULL) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":43
 * 
 *         if self._handle is NULL:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self._has_handle == 0:
 *                     self._loop._debug_uv_handles_freed += 1
 */
    __pyx_t_2 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/handle.pyx":44
 *         if self._handle is NULL:
 *             if UVLOOP_DEBUG:
 *                 if self._has_handle == 0:             # <<<<<<<<<<<<<<
 *                     self._loop._debug_uv_handles_freed += 1
 *             return
 */
      __pyx_t_2 = ((__pyx_v_self->_has_handle == 0) != 0);
      if (__pyx_t_2) {

        /* "uvloop/handles/handle.pyx":45
 *             if UVLOOP_DEBUG:
 *                 if self._has_handle == 0:
 *                     self._loop._debug_uv_handles_freed += 1             # <<<<<<<<<<<<<<
 *             return
 * 
 */
        __Pyx_INCREF(((PyObject *)__pyx_v_self->_loop));
        __pyx_t_8 = __pyx_v_self->_loop;
        __pyx_t_8->_debug_uv_handles_freed = (__pyx_t_8->_debug_uv_handles_freed + 1);
        __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

        /* "uvloop/handles/handle.pyx":44
 *         if self._handle is NULL:
 *             if UVLOOP_DEBUG:
 *                 if self._has_handle == 0:             # <<<<<<<<<<<<<<
 *                     self._loop._debug_uv_handles_freed += 1
 *             return
 */
      }

      /* "uvloop/handles/handle.pyx":43
 * 
 *         if self._handle is NULL:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self._has_handle == 0:
 *                     self._loop._debug_uv_handles_freed += 1
 */
    }

    /* "uvloop/handles/handle.pyx":46
 *                 if self._has_handle == 0:
 *                     self._loop._debug_uv_handles_freed += 1
 *             return             # <<<<<<<<<<<<<<
 * 
 *         # -> When we're at this point, something is wrong <-
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":42
 *                     .format(self.__class__.__name__))
 * 
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 if self._has_handle == 0:
 */
  }

  /* "uvloop/handles/handle.pyx":50
 *         # -> When we're at this point, something is wrong <-
 * 
 *         if self._handle.loop is NULL:             # <<<<<<<<<<<<<<
 *             # The handle wasn't initialized with "uv_{handle}_init"
 *             self._closed = 1
 */
  __pyx_t_2 = ((__pyx_v_self->_handle->loop == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/handle.pyx":52
 *         if self._handle.loop is NULL:
 *             # The handle wasn't initialized with "uv_{handle}_init"
 *             self._closed = 1             # <<<<<<<<<<<<<<
 *             self._free()
 *             raise RuntimeError(
 */
    __pyx_v_self->_closed = 1;

    /* "uvloop/handles/handle.pyx":53
 *             # The handle wasn't initialized with "uv_{handle}_init"
 *             self._closed = 1
 *             self._free()             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 '{} is open in __dealloc__ with loop set to NULL'
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_self->__pyx_vtab)->_free(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 53, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/handle.pyx":56
 *             raise RuntimeError(
 *                 '{} is open in __dealloc__ with loop set to NULL'
 *                 .format(self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *         if self._closed:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_is_open_in___dealloc___with_loo, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 56, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 56, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 56, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 56, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 56, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":54
 *             self._closed = 1
 *             self._free()
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 '{} is open in __dealloc__ with loop set to NULL'
 *                 .format(self.__class__.__name__))
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(4, 54, __pyx_L1_error)

    /* "uvloop/handles/handle.pyx":50
 *         # -> When we're at this point, something is wrong <-
 * 
 *         if self._handle.loop is NULL:             # <<<<<<<<<<<<<<
 *             # The handle wasn't initialized with "uv_{handle}_init"
 *             self._closed = 1
 */
  }

  /* "uvloop/handles/handle.pyx":58
 *                 .format(self.__class__.__name__))
 * 
 *         if self._closed:             # <<<<<<<<<<<<<<
 *             # So _handle is not NULL and self._closed == 1?
 *             raise RuntimeError(
 */
  __pyx_t_2 = (__pyx_v_self->_closed != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/handle.pyx":61
 *             # So _handle is not NULL and self._closed == 1?
 *             raise RuntimeError(
 *                 '{}.__dealloc__: _handle is NULL, _closed == 1'.format(             # <<<<<<<<<<<<<<
 *                     self.__class__.__name__))
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_dealloc____handle_is_NULL__cl, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "uvloop/handles/handle.pyx":62
 *             raise RuntimeError(
 *                 '{}.__dealloc__: _handle is NULL, _closed == 1'.format(
 *                     self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *         # The handle is dealloced while open.  Let's try to close it.
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 62, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 61, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 61, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 61, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 61, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 61, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/handle.pyx":60
 *         if self._closed:
 *             # So _handle is not NULL and self._closed == 1?
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 '{}.__dealloc__: _handle is NULL, _closed == 1'.format(
 *                     self.__class__.__name__))
 */
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(4, 60, __pyx_L1_error)

    /* "uvloop/handles/handle.pyx":58
 *                 .format(self.__class__.__name__))
 * 
 *         if self._closed:             # <<<<<<<<<<<<<<
 *             # So _handle is not NULL and self._closed == 1?
 *             raise RuntimeError(
 */
  }

  /* "uvloop/handles/handle.pyx":67
 *         # Situations when this is possible include unhandled exceptions,
 *         # errors during Handle.__cinit__/__init__ etc.
 *         if self._inited:             # <<<<<<<<<<<<<<
 *             self._handle.data = NULL
 *             uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 */
  __pyx_t_2 = (__pyx_v_self->_inited != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":68
 *         # errors during Handle.__cinit__/__init__ etc.
 *         if self._inited:
 *             self._handle.data = NULL             # <<<<<<<<<<<<<<
 *             uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 *             self._handle = NULL
 */
    __pyx_v_self->_handle->data = NULL;

    /* "uvloop/handles/handle.pyx":69
 *         if self._inited:
 *             self._handle.data = NULL
 *             uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors             # <<<<<<<<<<<<<<
 *             self._handle = NULL
 *             self._warn_unclosed()
 */
    uv_close(__pyx_v_self->_handle, __pyx_f_6uvloop_4loop___uv_close_handle_cb);

    /* "uvloop/handles/handle.pyx":70
 *             self._handle.data = NULL
 *             uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 *             self._handle = NULL             # <<<<<<<<<<<<<<
 *             self._warn_unclosed()
 *         else:
 */
    __pyx_v_self->_handle = NULL;

    /* "uvloop/handles/handle.pyx":71
 *             uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 *             self._handle = NULL
 *             self._warn_unclosed()             # <<<<<<<<<<<<<<
 *         else:
 *             # The handle was allocated, but not initialized
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_self->__pyx_vtab)->_warn_unclosed(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/handle.pyx":67
 *         # Situations when this is possible include unhandled exceptions,
 *         # errors during Handle.__cinit__/__init__ etc.
 *         if self._inited:             # <<<<<<<<<<<<<<
 *             self._handle.data = NULL
 *             uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 */
    goto __pyx_L10;
  }

  /* "uvloop/handles/handle.pyx":74
 *         else:
 *             # The handle was allocated, but not initialized
 *             self._closed = 1             # <<<<<<<<<<<<<<
 *             self._free()
 * 
 */
  /*else*/ {
    __pyx_v_self->_closed = 1;

    /* "uvloop/handles/handle.pyx":75
 *             # The handle was allocated, but not initialized
 *             self._closed = 1
 *             self._free()             # <<<<<<<<<<<<<<
 * 
 *     cdef _free(self):
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_self->__pyx_vtab)->_free(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L10:;

  /* "uvloop/handles/handle.pyx":31
 *         self._dealloc_impl()
 * 
 *     cdef _dealloc_impl(self):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(((PyObject *)__pyx_t_8));
  __Pyx_AddTraceback("uvloop.loop.UVHandle._dealloc_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":77
 *             self._free()
 * 
 *     cdef _free(self):             # <<<<<<<<<<<<<<
 *         if self._handle == NULL:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__free(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_free", 0);

  /* "uvloop/handles/handle.pyx":78
 * 
 *     cdef _free(self):
 *         if self._handle == NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_handle == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":79
 *     cdef _free(self):
 *         if self._handle == NULL:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":78
 * 
 *     cdef _free(self):
 *         if self._handle == NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":81
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_uv_handles_freed += 1
 * 
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":82
 * 
 *         if UVLOOP_DEBUG:
 *             self._loop._debug_uv_handles_freed += 1             # <<<<<<<<<<<<<<
 * 
 *         PyMem_RawFree(self._handle)
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self->_loop));
    __pyx_t_2 = __pyx_v_self->_loop;
    __pyx_t_2->_debug_uv_handles_freed = (__pyx_t_2->_debug_uv_handles_freed + 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

    /* "uvloop/handles/handle.pyx":81
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_uv_handles_freed += 1
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":84
 *             self._loop._debug_uv_handles_freed += 1
 * 
 *         PyMem_RawFree(self._handle)             # <<<<<<<<<<<<<<
 *         self._handle = NULL
 * 
 */
  PyMem_RawFree(__pyx_v_self->_handle);

  /* "uvloop/handles/handle.pyx":85
 * 
 *         PyMem_RawFree(self._handle)
 *         self._handle = NULL             # <<<<<<<<<<<<<<
 * 
 *     cdef _warn_unclosed(self):
 */
  __pyx_v_self->_handle = NULL;

  /* "uvloop/handles/handle.pyx":77
 *             self._free()
 * 
 *     cdef _free(self):             # <<<<<<<<<<<<<<
 *         if self._handle == NULL:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":87
 *         self._handle = NULL
 * 
 *     cdef _warn_unclosed(self):             # <<<<<<<<<<<<<<
 *         if self._source_traceback is not None:
 *             try:
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__warn_unclosed(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_v_tb = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  __Pyx_RefNannySetupContext("_warn_unclosed", 0);

  /* "uvloop/handles/handle.pyx":88
 * 
 *     cdef _warn_unclosed(self):
 *         if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 tb = ''.join(tb_format_list(self._source_traceback))
 */
  __pyx_t_1 = (__pyx_v_self->_source_traceback != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":89
 *     cdef _warn_unclosed(self):
 *         if self._source_traceback is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 tb = ''.join(tb_format_list(self._source_traceback))
 *                 tb = 'object created at (most recent call last):\n{}'.format(
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/handles/handle.pyx":90
 *         if self._source_traceback is not None:
 *             try:
 *                 tb = ''.join(tb_format_list(self._source_traceback))             # <<<<<<<<<<<<<<
 *                 tb = 'object created at (most recent call last):\n{}'.format(
 *                     tb.rstrip())
 */
        __Pyx_INCREF(__pyx_v_6uvloop_4loop_tb_format_list);
        __pyx_t_7 = __pyx_v_6uvloop_4loop_tb_format_list; __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (!__pyx_t_8) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_self->_source_traceback); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 90, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_6);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_source_traceback};
            __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 90, __pyx_L4_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_source_traceback};
            __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 90, __pyx_L4_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_6);
          } else
          #endif
          {
            __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 90, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
            __Pyx_INCREF(__pyx_v_self->_source_traceback);
            __Pyx_GIVEREF(__pyx_v_self->_source_traceback);
            PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_self->_source_traceback);
            __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 90, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyUnicode_Join(__pyx_kp_u__7, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 90, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_tb = __pyx_t_7;
        __pyx_t_7 = 0;

        /* "uvloop/handles/handle.pyx":91
 *             try:
 *                 tb = ''.join(tb_format_list(self._source_traceback))
 *                 tb = 'object created at (most recent call last):\n{}'.format(             # <<<<<<<<<<<<<<
 *                     tb.rstrip())
 *             except Exception as ex:
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_object_created_at_most_recent_ca, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 91, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);

        /* "uvloop/handles/handle.pyx":92
 *                 tb = ''.join(tb_format_list(self._source_traceback))
 *                 tb = 'object created at (most recent call last):\n{}'.format(
 *                     tb.rstrip())             # <<<<<<<<<<<<<<
 *             except Exception as ex:
 *                 msg = (
 */
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_tb, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_8)) __PYX_ERR(4, 92, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (__pyx_t_10) {
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 92, __pyx_L4_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else {
          __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 92, __pyx_L4_error)
        }
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (!__pyx_t_8) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 91, __pyx_L4_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_9};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 91, __pyx_L4_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_9};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 91, __pyx_L4_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          } else
          #endif
          {
            __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(4, 91, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
            __Pyx_GIVEREF(__pyx_t_9);
            PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_9);
            __pyx_t_9 = 0;
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 91, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_tb, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "uvloop/handles/handle.pyx":89
 *     cdef _warn_unclosed(self):
 *         if self._source_traceback is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 tb = ''.join(tb_format_list(self._source_traceback))
 *                 tb = 'object created at (most recent call last):\n{}'.format(
 */
      }

      /* "uvloop/handles/handle.pyx":99
 *                 ).format(self, type(ex).__name__, ex)
 *             else:
 *                 msg = 'unclosed resource {!r}; {}'.format(self, tb)             # <<<<<<<<<<<<<<
 *         else:
 *             msg = 'unclosed resource {!r}'.format(self)
 */
      /*else:*/ {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_unclosed_resource_r, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 99, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_10 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[3] = {__pyx_t_10, ((PyObject *)__pyx_v_self), __pyx_v_tb};
          __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 99, __pyx_L6_except_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[3] = {__pyx_t_10, ((PyObject *)__pyx_v_self), __pyx_v_tb};
          __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 99, __pyx_L6_except_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_7);
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 99, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          if (__pyx_t_10) {
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10); __pyx_t_10 = NULL;
          }
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_11, ((PyObject *)__pyx_v_self));
          __Pyx_INCREF(__pyx_v_tb);
          __Pyx_GIVEREF(__pyx_v_tb);
          PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_11, __pyx_v_tb);
          __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 99, __pyx_L6_except_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_msg = __pyx_t_7;
        __pyx_t_7 = 0;
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/handles/handle.pyx":93
 *                 tb = 'object created at (most recent call last):\n{}'.format(
 *                     tb.rstrip())
 *             except Exception as ex:             # <<<<<<<<<<<<<<
 *                 msg = (
 *                     'unclosed resource {!r}; could not serialize '
 */
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_11) {
        __Pyx_AddTraceback("uvloop.loop.UVHandle._warn_unclosed", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_9) < 0) __PYX_ERR(4, 93, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_ex = __pyx_t_6;
        /*try:*/ {

          /* "uvloop/handles/handle.pyx":97
 *                     'unclosed resource {!r}; could not serialize '
 *                     'debug traceback: {}: {}'
 *                 ).format(self, type(ex).__name__, ex)             # <<<<<<<<<<<<<<
 *             else:
 *                 msg = 'unclosed resource {!r}; {}'.format(self, tb)
 */
          __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_unclosed_resource_r_could_not_se, __pyx_n_s_format); if (unlikely(!__pyx_t_8)) __PYX_ERR(4, 97, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_ex)), __pyx_n_s_name); if (unlikely(!__pyx_t_12)) __PYX_ERR(4, 97, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = NULL;
          __pyx_t_11 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_8, function);
              __pyx_t_11 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[4] = {__pyx_t_13, ((PyObject *)__pyx_v_self), __pyx_t_12, __pyx_v_ex};
            __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(4, 97, __pyx_L15_error)
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[4] = {__pyx_t_13, ((PyObject *)__pyx_v_self), __pyx_t_12, __pyx_v_ex};
            __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_10)) __PYX_ERR(4, 97, __pyx_L15_error)
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          } else
          #endif
          {
            __pyx_t_14 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_14)) __PYX_ERR(4, 97, __pyx_L15_error)
            __Pyx_GOTREF(__pyx_t_14);
            if (__pyx_t_13) {
              __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
            }
            __Pyx_INCREF(((PyObject *)__pyx_v_self));
            __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
            PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_11, ((PyObject *)__pyx_v_self));
            __Pyx_GIVEREF(__pyx_t_12);
            PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_11, __pyx_t_12);
            __Pyx_INCREF(__pyx_v_ex);
            __Pyx_GIVEREF(__pyx_v_ex);
            PyTuple_SET_ITEM(__pyx_t_14, 2+__pyx_t_11, __pyx_v_ex);
            __pyx_t_12 = 0;
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_14, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(4, 97, __pyx_L15_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          }
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_v_msg = __pyx_t_10;
          __pyx_t_10 = 0;
        }

        /* "uvloop/handles/handle.pyx":93
 *                 tb = 'object created at (most recent call last):\n{}'.format(
 *                     tb.rstrip())
 *             except Exception as ex:             # <<<<<<<<<<<<<<
 *                 msg = (
 *                     'unclosed resource {!r}; could not serialize '
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L16;
          }
          __pyx_L15_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_11 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
            goto __pyx_L6_except_error;
          }
          __pyx_L16:;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;
      __pyx_L6_except_error:;

      /* "uvloop/handles/handle.pyx":89
 *     cdef _warn_unclosed(self):
 *         if self._source_traceback is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 tb = ''.join(tb_format_list(self._source_traceback))
 *                 tb = 'object created at (most recent call last):\n{}'.format(
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_L9_try_end:;
    }

    /* "uvloop/handles/handle.pyx":88
 * 
 *     cdef _warn_unclosed(self):
 *         if self._source_traceback is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 tb = ''.join(tb_format_list(self._source_traceback))
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/handle.pyx":101
 *                 msg = 'unclosed resource {!r}; {}'.format(self, tb)
 *         else:
 *             msg = 'unclosed resource {!r}'.format(self)             # <<<<<<<<<<<<<<
 *         warnings_warn(msg, ResourceWarning)
 * 
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_unclosed_resource_r_2, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_6, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, ((PyObject *)__pyx_v_self)};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 101, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, ((PyObject *)__pyx_v_self)};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 101, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(4, 101, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, ((PyObject *)__pyx_v_self));
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 101, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_msg = __pyx_t_9;
    __pyx_t_9 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/handle.pyx":102
 *         else:
 *             msg = 'unclosed resource {!r}'.format(self)
 *         warnings_warn(msg, ResourceWarning)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _abort_init(self):
 */
  __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ResourceWarning); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_warnings_warn);
  __pyx_t_10 = __pyx_v_6uvloop_4loop_warnings_warn; __pyx_t_7 = NULL;
  __pyx_t_15 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
      __pyx_t_15 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_10)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_msg, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 102, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
    PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_v_msg, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 102, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(2+__pyx_t_15); if (unlikely(!__pyx_t_8)) __PYX_ERR(4, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_INCREF(__pyx_v_msg);
    __Pyx_GIVEREF(__pyx_v_msg);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_15, __pyx_v_msg);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_15, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/handles/handle.pyx":87
 *         self._handle = NULL
 * 
 *     cdef _warn_unclosed(self):             # <<<<<<<<<<<<<<
 *         if self._source_traceback is not None:
 *             try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("uvloop.loop.UVHandle._warn_unclosed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tb);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":104
 *         warnings_warn(msg, ResourceWarning)
 * 
 *     cdef inline _abort_init(self):             # <<<<<<<<<<<<<<
 *         if self._handle is not NULL:
 *             self._free()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__abort_init(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_abort_init", 0);

  /* "uvloop/handles/handle.pyx":105
 * 
 *     cdef inline _abort_init(self):
 *         if self._handle is not NULL:             # <<<<<<<<<<<<<<
 *             self._free()
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_handle != NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":106
 *     cdef inline _abort_init(self):
 *         if self._handle is not NULL:
 *             self._free()             # <<<<<<<<<<<<<<
 * 
 *         self._closed = 1
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_self->__pyx_vtab)->_free(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/handle.pyx":105
 * 
 *     cdef inline _abort_init(self):
 *         if self._handle is not NULL:             # <<<<<<<<<<<<<<
 *             self._free()
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":108
 *             self._free()
 * 
 *         self._closed = 1             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
  __pyx_v_self->_closed = 1;

  /* "uvloop/handles/handle.pyx":110
 *         self._closed = 1
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             name = self.__class__.__name__
 *             if self._inited:
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":111
 * 
 *         if UVLOOP_DEBUG:
 *             name = self.__class__.__name__             # <<<<<<<<<<<<<<
 *             if self._inited:
 *                 raise RuntimeError(
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 111, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_name = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":112
 *         if UVLOOP_DEBUG:
 *             name = self.__class__.__name__
 *             if self._inited:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '_abort_init: {}._inited is set'.format(name))
 */
    __pyx_t_1 = (__pyx_v_self->_inited != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/handles/handle.pyx":114
 *             if self._inited:
 *                 raise RuntimeError(
 *                     '_abort_init: {}._inited is set'.format(name))             # <<<<<<<<<<<<<<
 *             if self._closed:
 *                 raise RuntimeError(
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_abort_init__inited_is_set, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 114, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_name};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 114, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_name};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 114, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 114, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_name);
          __Pyx_GIVEREF(__pyx_v_name);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_name);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 114, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/handle.pyx":113
 *             name = self.__class__.__name__
 *             if self._inited:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '_abort_init: {}._inited is set'.format(name))
 *             if self._closed:
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(4, 113, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":112
 *         if UVLOOP_DEBUG:
 *             name = self.__class__.__name__
 *             if self._inited:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '_abort_init: {}._inited is set'.format(name))
 */
    }

    /* "uvloop/handles/handle.pyx":115
 *                 raise RuntimeError(
 *                     '_abort_init: {}._inited is set'.format(name))
 *             if self._closed:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '_abort_init: {}._closed is set'.format(name))
 */
    __pyx_t_1 = (__pyx_v_self->_closed != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/handles/handle.pyx":117
 *             if self._closed:
 *                 raise RuntimeError(
 *                     '_abort_init: {}._closed is set'.format(name))             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _finish_init(self):
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_abort_init__closed_is_set, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 117, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 117, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 117, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 117, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 117, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_v_name);
          __Pyx_GIVEREF(__pyx_v_name);
          PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_name);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 117, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/handle.pyx":116
 *                     '_abort_init: {}._inited is set'.format(name))
 *             if self._closed:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '_abort_init: {}._closed is set'.format(name))
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(4, 116, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":115
 *                 raise RuntimeError(
 *                     '_abort_init: {}._inited is set'.format(name))
 *             if self._closed:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '_abort_init: {}._closed is set'.format(name))
 */
    }

    /* "uvloop/handles/handle.pyx":110
 *         self._closed = 1
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             name = self.__class__.__name__
 *             if self._inited:
 */
  }

  /* "uvloop/handles/handle.pyx":104
 *         warnings_warn(msg, ResourceWarning)
 * 
 *     cdef inline _abort_init(self):             # <<<<<<<<<<<<<<
 *         if self._handle is not NULL:
 *             self._free()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVHandle._abort_init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":119
 *                     '_abort_init: {}._closed is set'.format(name))
 * 
 *     cdef inline _finish_init(self):             # <<<<<<<<<<<<<<
 *         self._inited = 1
 *         if self._has_handle == 1:
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__finish_init(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_finish_init", 0);

  /* "uvloop/handles/handle.pyx":120
 * 
 *     cdef inline _finish_init(self):
 *         self._inited = 1             # <<<<<<<<<<<<<<
 *         if self._has_handle == 1:
 *             self._handle.data = <void*>self
 */
  __pyx_v_self->_inited = 1;

  /* "uvloop/handles/handle.pyx":121
 *     cdef inline _finish_init(self):
 *         self._inited = 1
 *         if self._has_handle == 1:             # <<<<<<<<<<<<<<
 *             self._handle.data = <void*>self
 *         if self._loop._debug:
 */
  __pyx_t_1 = ((__pyx_v_self->_has_handle == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":122
 *         self._inited = 1
 *         if self._has_handle == 1:
 *             self._handle.data = <void*>self             # <<<<<<<<<<<<<<
 *         if self._loop._debug:
 *             self._source_traceback = extract_stack()
 */
    __pyx_v_self->_handle->data = ((void *)__pyx_v_self);

    /* "uvloop/handles/handle.pyx":121
 *     cdef inline _finish_init(self):
 *         self._inited = 1
 *         if self._has_handle == 1:             # <<<<<<<<<<<<<<
 *             self._handle.data = <void*>self
 *         if self._loop._debug:
 */
  }

  /* "uvloop/handles/handle.pyx":123
 *         if self._has_handle == 1:
 *             self._handle.data = <void*>self
 *         if self._loop._debug:             # <<<<<<<<<<<<<<
 *             self._source_traceback = extract_stack()
 *         if UVLOOP_DEBUG:
 */
  __pyx_t_1 = (__pyx_v_self->_loop->_debug != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":124
 *             self._handle.data = <void*>self
 *         if self._loop._debug:
 *             self._source_traceback = extract_stack()             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             self._loop._debug_uv_handles_total += 1
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_extract_stack(); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_source_traceback);
    __Pyx_DECREF(__pyx_v_self->_source_traceback);
    __pyx_v_self->_source_traceback = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/handle.pyx":123
 *         if self._has_handle == 1:
 *             self._handle.data = <void*>self
 *         if self._loop._debug:             # <<<<<<<<<<<<<<
 *             self._source_traceback = extract_stack()
 *         if UVLOOP_DEBUG:
 */
  }

  /* "uvloop/handles/handle.pyx":125
 *         if self._loop._debug:
 *             self._source_traceback = extract_stack()
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_uv_handles_total += 1
 * 
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":126
 *             self._source_traceback = extract_stack()
 *         if UVLOOP_DEBUG:
 *             self._loop._debug_uv_handles_total += 1             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _start_init(self, Loop loop):
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self->_loop));
    __pyx_t_3 = __pyx_v_self->_loop;
    __pyx_t_3->_debug_uv_handles_total = (__pyx_t_3->_debug_uv_handles_total + 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":125
 *         if self._loop._debug:
 *             self._source_traceback = extract_stack()
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_uv_handles_total += 1
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":119
 *                     '_abort_init: {}._closed is set'.format(name))
 * 
 *     cdef inline _finish_init(self):             # <<<<<<<<<<<<<<
 *         self._inited = 1
 *         if self._has_handle == 1:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(((PyObject *)__pyx_t_3));
  __Pyx_AddTraceback("uvloop.loop.UVHandle._finish_init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":128
 *             self._loop._debug_uv_handles_total += 1
 * 
 *     cdef inline _start_init(self, Loop loop):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__start_init(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop) {
  PyObject *__pyx_v_cls_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_start_init", 0);

  /* "uvloop/handles/handle.pyx":129
 * 
 *     cdef inline _start_init(self, Loop loop):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self._loop is not None:
 *                 raise RuntimeError(
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":130
 *     cdef inline _start_init(self, Loop loop):
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._start_init can only be called once'.format(
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_loop) != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/handles/handle.pyx":132
 *             if self._loop is not None:
 *                 raise RuntimeError(
 *                     '{}._start_init can only be called once'.format(             # <<<<<<<<<<<<<<
 *                         self.__class__.__name__))
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_start_init_can_only_be_called, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 132, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "uvloop/handles/handle.pyx":133
 *                 raise RuntimeError(
 *                     '{}._start_init can only be called once'.format(
 *                         self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *             cls_name = self.__class__.__name__
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 133, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 132, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 132, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 132, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 132, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 132, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/handles/handle.pyx":131
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{}._start_init can only be called once'.format(
 *                         self.__class__.__name__))
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(4, 131, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":130
 *     cdef inline _start_init(self, Loop loop):
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._start_init can only be called once'.format(
 */
    }

    /* "uvloop/handles/handle.pyx":135
 *                         self.__class__.__name__))
 * 
 *             cls_name = self.__class__.__name__             # <<<<<<<<<<<<<<
 *             loop._debug_handles_total.update([cls_name])
 *             loop._debug_handles_current.update([cls_name])
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_cls_name = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":136
 * 
 *             cls_name = self.__class__.__name__
 *             loop._debug_handles_total.update([cls_name])             # <<<<<<<<<<<<<<
 *             loop._debug_handles_current.update([cls_name])
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop->_debug_handles_total, __pyx_n_s_update); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_cls_name);
    __Pyx_GIVEREF(__pyx_v_cls_name);
    PyList_SET_ITEM(__pyx_t_7, 0, __pyx_v_cls_name);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 136, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 136, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_7};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 136, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 136, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 136, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":137
 *             cls_name = self.__class__.__name__
 *             loop._debug_handles_total.update([cls_name])
 *             loop._debug_handles_current.update([cls_name])             # <<<<<<<<<<<<<<
 * 
 *         self._loop = loop
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_loop->_debug_handles_current, __pyx_n_s_update); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_cls_name);
    __Pyx_GIVEREF(__pyx_v_cls_name);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_cls_name);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 137, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 137, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 137, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 137, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 137, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":129
 * 
 *     cdef inline _start_init(self, Loop loop):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self._loop is not None:
 *                 raise RuntimeError(
 */
  }

  /* "uvloop/handles/handle.pyx":139
 *             loop._debug_handles_current.update([cls_name])
 * 
 *         self._loop = loop             # <<<<<<<<<<<<<<
 * 
 *     cdef inline bint _is_alive(self):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_loop));
  __Pyx_GOTREF(__pyx_v_self->_loop);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_loop));
  __pyx_v_self->_loop = __pyx_v_loop;

  /* "uvloop/handles/handle.pyx":128
 *             self._loop._debug_uv_handles_total += 1
 * 
 *     cdef inline _start_init(self, Loop loop):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if self._loop is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.UVHandle._start_init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cls_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":141
 *         self._loop = loop
 * 
 *     cdef inline bint _is_alive(self):             # <<<<<<<<<<<<<<
 *         cdef bint res
 *         res = self._closed != 1 and self._inited == 1
 */

static CYTHON_INLINE int __pyx_f_6uvloop_4loop_8UVHandle__is_alive(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  int __pyx_v_res;
  PyObject *__pyx_v_name = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_is_alive", 0);

  /* "uvloop/handles/handle.pyx":143
 *     cdef inline bint _is_alive(self):
 *         cdef bint res
 *         res = self._closed != 1 and self._inited == 1             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if res and self._has_handle == 1:
 */
  __pyx_t_2 = ((__pyx_v_self->_closed != 1) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_self->_inited == 1) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_v_res = __pyx_t_1;

  /* "uvloop/handles/handle.pyx":144
 *         cdef bint res
 *         res = self._closed != 1 and self._inited == 1
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if res and self._has_handle == 1:
 *                 name = self.__class__.__name__
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":145
 *         res = self._closed != 1 and self._inited == 1
 *         if UVLOOP_DEBUG:
 *             if res and self._has_handle == 1:             # <<<<<<<<<<<<<<
 *                 name = self.__class__.__name__
 *                 if self._handle is NULL:
 */
    __pyx_t_2 = (__pyx_v_res != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_2 = ((__pyx_v_self->_has_handle == 1) != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_1) {

      /* "uvloop/handles/handle.pyx":146
 *         if UVLOOP_DEBUG:
 *             if res and self._has_handle == 1:
 *                 name = self.__class__.__name__             # <<<<<<<<<<<<<<
 *                 if self._handle is NULL:
 *                     raise RuntimeError(
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_name = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "uvloop/handles/handle.pyx":147
 *             if res and self._has_handle == 1:
 *                 name = self.__class__.__name__
 *                 if self._handle is NULL:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle is NULL'.format(name))
 */
      __pyx_t_1 = ((__pyx_v_self->_handle == NULL) != 0);
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/handles/handle.pyx":149
 *                 if self._handle is NULL:
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle is NULL'.format(name))             # <<<<<<<<<<<<<<
 *                 if self._loop is None:
 *                     raise RuntimeError(
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_is_alive_but__handle_is_NULL, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 149, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_5) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 149, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 149, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 149, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          {
            __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 149, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
            __Pyx_INCREF(__pyx_v_name);
            __Pyx_GIVEREF(__pyx_v_name);
            PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_name);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 149, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/handle.pyx":148
 *                 name = self.__class__.__name__
 *                 if self._handle is NULL:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '{} is alive, but _handle is NULL'.format(name))
 *                 if self._loop is None:
 */
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 148, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(4, 148, __pyx_L1_error)

        /* "uvloop/handles/handle.pyx":147
 *             if res and self._has_handle == 1:
 *                 name = self.__class__.__name__
 *                 if self._handle is NULL:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle is NULL'.format(name))
 */
      }

      /* "uvloop/handles/handle.pyx":150
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle is NULL'.format(name))
 *                 if self._loop is None:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _loop is None'.format(name))
 */
      __pyx_t_1 = (((PyObject *)__pyx_v_self->_loop) == Py_None);
      __pyx_t_2 = (__pyx_t_1 != 0);
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/handles/handle.pyx":152
 *                 if self._loop is None:
 *                     raise RuntimeError(
 *                         '{} is alive, but _loop is None'.format(name))             # <<<<<<<<<<<<<<
 *                 if self._handle.loop is not self._loop.uvloop:
 *                     raise RuntimeError(
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_is_alive_but__loop_is_None, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 152, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        if (!__pyx_t_6) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 152, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_name};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 152, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_name};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 152, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          {
            __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 152, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
            __Pyx_INCREF(__pyx_v_name);
            __Pyx_GIVEREF(__pyx_v_name);
            PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_name);
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 152, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/handles/handle.pyx":151
 *                         '{} is alive, but _handle is NULL'.format(name))
 *                 if self._loop is None:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '{} is alive, but _loop is None'.format(name))
 *                 if self._handle.loop is not self._loop.uvloop:
 */
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 151, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(4, 151, __pyx_L1_error)

        /* "uvloop/handles/handle.pyx":150
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle is NULL'.format(name))
 *                 if self._loop is None:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _loop is None'.format(name))
 */
      }

      /* "uvloop/handles/handle.pyx":153
 *                     raise RuntimeError(
 *                         '{} is alive, but _loop is None'.format(name))
 *                 if self._handle.loop is not self._loop.uvloop:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle.loop is not '
 */
      __pyx_t_2 = ((__pyx_v_self->_handle->loop != __pyx_v_self->_loop->uvloop) != 0);
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/handles/handle.pyx":156
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle.loop is not '
 *                         'initialized'.format(name))             # <<<<<<<<<<<<<<
 *                 if self._handle.data is not <void*>self:
 *                     raise RuntimeError(
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_is_alive_but__handle_loop_is_no, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 156, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (!__pyx_t_5) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 156, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 156, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_name};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 156, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else
          #endif
          {
            __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 156, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
            __Pyx_INCREF(__pyx_v_name);
            __Pyx_GIVEREF(__pyx_v_name);
            PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_name);
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 156, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/handle.pyx":154
 *                         '{} is alive, but _loop is None'.format(name))
 *                 if self._handle.loop is not self._loop.uvloop:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '{} is alive, but _handle.loop is not '
 *                         'initialized'.format(name))
 */
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 154, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(4, 154, __pyx_L1_error)

        /* "uvloop/handles/handle.pyx":153
 *                     raise RuntimeError(
 *                         '{} is alive, but _loop is None'.format(name))
 *                 if self._handle.loop is not self._loop.uvloop:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle.loop is not '
 */
      }

      /* "uvloop/handles/handle.pyx":157
 *                         '{} is alive, but _handle.loop is not '
 *                         'initialized'.format(name))
 *                 if self._handle.data is not <void*>self:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle.data is not '
 */
      __pyx_t_2 = ((__pyx_v_self->_handle->data != ((void *)__pyx_v_self)) != 0);
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/handles/handle.pyx":160
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle.data is not '
 *                         'initialized'.format(name))             # <<<<<<<<<<<<<<
 *         return res
 * 
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_is_alive_but__handle_data_is_no, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 160, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        if (!__pyx_t_6) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 160, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_name};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 160, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_name};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 160, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else
          #endif
          {
            __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 160, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
            __Pyx_INCREF(__pyx_v_name);
            __Pyx_GIVEREF(__pyx_v_name);
            PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_name);
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 160, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/handles/handle.pyx":158
 *                         'initialized'.format(name))
 *                 if self._handle.data is not <void*>self:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '{} is alive, but _handle.data is not '
 *                         'initialized'.format(name))
 */
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 158, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(4, 158, __pyx_L1_error)

        /* "uvloop/handles/handle.pyx":157
 *                         '{} is alive, but _handle.loop is not '
 *                         'initialized'.format(name))
 *                 if self._handle.data is not <void*>self:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '{} is alive, but _handle.data is not '
 */
      }

      /* "uvloop/handles/handle.pyx":145
 *         res = self._closed != 1 and self._inited == 1
 *         if UVLOOP_DEBUG:
 *             if res and self._has_handle == 1:             # <<<<<<<<<<<<<<
 *                 name = self.__class__.__name__
 *                 if self._handle is NULL:
 */
    }

    /* "uvloop/handles/handle.pyx":144
 *         cdef bint res
 *         res = self._closed != 1 and self._inited == 1
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if res and self._has_handle == 1:
 *                 name = self.__class__.__name__
 */
  }

  /* "uvloop/handles/handle.pyx":161
 *                         '{} is alive, but _handle.data is not '
 *                         'initialized'.format(name))
 *         return res             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _ensure_alive(self):
 */
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "uvloop/handles/handle.pyx":141
 *         self._loop = loop
 * 
 *     cdef inline bint _is_alive(self):             # <<<<<<<<<<<<<<
 *         cdef bint res
 *         res = self._closed != 1 and self._inited == 1
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("uvloop.loop.UVHandle._is_alive", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":163
 *         return res
 * 
 *     cdef inline _ensure_alive(self):             # <<<<<<<<<<<<<<
 *         if not self._is_alive():
 *             raise RuntimeError(
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVHandle__ensure_alive(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_ensure_alive", 0);

  /* "uvloop/handles/handle.pyx":164
 * 
 *     cdef inline _ensure_alive(self):
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'unable to perform operation on {!r}; '
 */
  __pyx_t_1 = ((!(__pyx_f_6uvloop_4loop_8UVHandle__is_alive(__pyx_v_self) != 0)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/handle.pyx":167
 *             raise RuntimeError(
 *                 'unable to perform operation on {!r}; '
 *                 'the handler is closed'.format(self))             # <<<<<<<<<<<<<<
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_unable_to_perform_operation_on_r, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 167, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, ((PyObject *)__pyx_v_self)};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 167, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, ((PyObject *)__pyx_v_self)};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 167, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, ((PyObject *)__pyx_v_self));
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":165
 *     cdef inline _ensure_alive(self):
 *         if not self._is_alive():
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'unable to perform operation on {!r}; '
 *                 'the handler is closed'.format(self))
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(4, 165, __pyx_L1_error)

    /* "uvloop/handles/handle.pyx":164
 * 
 *     cdef inline _ensure_alive(self):
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'unable to perform operation on {!r}; '
 */
  }

  /* "uvloop/handles/handle.pyx":163
 *         return res
 * 
 *     cdef inline _ensure_alive(self):             # <<<<<<<<<<<<<<
 *         if not self._is_alive():
 *             raise RuntimeError(
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVHandle._ensure_alive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":169
 *                 'the handler is closed'.format(self))
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         # Fatal error means an error that was returned by the
 *         # underlying libuv handle function.  We usually can't
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__fatal_error(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error *__pyx_optional_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("_fatal_error", 0);
  if (__pyx_optional_args) {
  }

  /* "uvloop/handles/handle.pyx":173
 *         # underlying libuv handle function.  We usually can't
 *         # recover from that, hence we just close the handle.
 *         self._close()             # <<<<<<<<<<<<<<
 * 
 *         if throw or self._loop is None:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_self->__pyx_vtab)->_close(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/handle.pyx":175
 *         self._close()
 * 
 *         if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *             raise exc
 *         else:
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_throw); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(4, 175, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (((PyObject *)__pyx_v_self->_loop) == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/handle.pyx":176
 * 
 *         if throw or self._loop is None:
 *             raise exc             # <<<<<<<<<<<<<<
 *         else:
 *             self._loop._handle_exception(exc)
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(4, 176, __pyx_L1_error)

    /* "uvloop/handles/handle.pyx":175
 *         self._close()
 * 
 *         if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *             raise exc
 *         else:
 */
  }

  /* "uvloop/handles/handle.pyx":178
 *             raise exc
 *         else:
 *             self._loop._handle_exception(exc)             # <<<<<<<<<<<<<<
 * 
 *     cdef _error(self, exc, throw):
 */
  /*else*/ {
    ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->_loop->__pyx_vtab)->_handle_exception(__pyx_v_self->_loop, __pyx_v_exc);
  }

  /* "uvloop/handles/handle.pyx":169
 *                 'the handler is closed'.format(self))
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         # Fatal error means an error that was returned by the
 *         # underlying libuv handle function.  We usually can't
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVHandle._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":180
 *             self._loop._handle_exception(exc)
 * 
 *     cdef _error(self, exc, throw):             # <<<<<<<<<<<<<<
 *         # A non-fatal error is usually an error that was caught
 *         # by the handler, but was originated in the client code
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__error(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("_error", 0);

  /* "uvloop/handles/handle.pyx":185
 *         # (not in libuv).  In this case we either want to simply
 *         # raise or log it.
 *         if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *             raise exc
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_throw); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(4, 185, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (((PyObject *)__pyx_v_self->_loop) == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/handle.pyx":186
 *         # raise or log it.
 *         if throw or self._loop is None:
 *             raise exc             # <<<<<<<<<<<<<<
 *         else:
 *             self._loop._handle_exception(exc)
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(4, 186, __pyx_L1_error)

    /* "uvloop/handles/handle.pyx":185
 *         # (not in libuv).  In this case we either want to simply
 *         # raise or log it.
 *         if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *             raise exc
 *         else:
 */
  }

  /* "uvloop/handles/handle.pyx":188
 *             raise exc
 *         else:
 *             self._loop._handle_exception(exc)             # <<<<<<<<<<<<<<
 * 
 *     cdef _close(self):
 */
  /*else*/ {
    ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->_loop->__pyx_vtab)->_handle_exception(__pyx_v_self->_loop, __pyx_v_exc);
  }

  /* "uvloop/handles/handle.pyx":180
 *             self._loop._handle_exception(exc)
 * 
 *     cdef _error(self, exc, throw):             # <<<<<<<<<<<<<<
 *         # A non-fatal error is usually an error that was caught
 *         # by the handler, but was originated in the client code
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.UVHandle._error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":190
 *             self._loop._handle_exception(exc)
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self._closed == 1:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVHandle__close(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "uvloop/handles/handle.pyx":191
 * 
 *     cdef _close(self):
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_closed == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":192
 *     cdef _close(self):
 *         if self._closed == 1:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._closed = 1
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":191
 * 
 *     cdef _close(self):
 *         if self._closed == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":194
 *             return
 * 
 *         self._closed = 1             # <<<<<<<<<<<<<<
 * 
 *         if self._handle is NULL:
 */
  __pyx_v_self->_closed = 1;

  /* "uvloop/handles/handle.pyx":196
 *         self._closed = 1
 * 
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_handle == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":197
 * 
 *         if self._handle is NULL:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":196
 *         self._closed = 1
 * 
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":199
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self._handle.data is NULL:
 *                 raise RuntimeError(
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":200
 * 
 *         if UVLOOP_DEBUG:
 *             if self._handle.data is NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is NULL'.format(
 */
    __pyx_t_1 = ((__pyx_v_self->_handle->data == NULL) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/handles/handle.pyx":202
 *             if self._handle.data is NULL:
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is NULL'.format(             # <<<<<<<<<<<<<<
 *                         self.__class__.__name__))
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_close__handle_data_is_NULL, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 202, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/handles/handle.pyx":203
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is NULL'.format(
 *                         self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *             if <object>self._handle.data is not self:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 202, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 202, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 202, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 202, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/handle.pyx":201
 *         if UVLOOP_DEBUG:
 *             if self._handle.data is NULL:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{}._close: _handle.data is NULL'.format(
 *                         self.__class__.__name__))
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(4, 201, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":200
 * 
 *         if UVLOOP_DEBUG:
 *             if self._handle.data is NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is NULL'.format(
 */
    }

    /* "uvloop/handles/handle.pyx":205
 *                         self.__class__.__name__))
 * 
 *             if <object>self._handle.data is not self:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is not UVHandle/self'.format(
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->_handle->data) != ((PyObject *)__pyx_v_self));
    __pyx_t_7 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_7)) {

      /* "uvloop/handles/handle.pyx":207
 *             if <object>self._handle.data is not self:
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is not UVHandle/self'.format(             # <<<<<<<<<<<<<<
 *                         self.__class__.__name__))
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_close__handle_data_is_not_UVHa, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 207, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "uvloop/handles/handle.pyx":208
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is not UVHandle/self'.format(
 *                         self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *             if uv.uv_is_closing(self._handle):
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 207, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 207, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 207, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 207, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 207, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/handle.pyx":206
 * 
 *             if <object>self._handle.data is not self:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{}._close: _handle.data is not UVHandle/self'.format(
 *                         self.__class__.__name__))
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 206, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(4, 206, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":205
 *                         self.__class__.__name__))
 * 
 *             if <object>self._handle.data is not self:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._close: _handle.data is not UVHandle/self'.format(
 */
    }

    /* "uvloop/handles/handle.pyx":210
 *                         self.__class__.__name__))
 * 
 *             if uv.uv_is_closing(self._handle):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._close: uv_is_closing() is true'.format(
 */
    __pyx_t_7 = (uv_is_closing(__pyx_v_self->_handle) != 0);
    if (unlikely(__pyx_t_7)) {

      /* "uvloop/handles/handle.pyx":212
 *             if uv.uv_is_closing(self._handle):
 *                 raise RuntimeError(
 *                     '{}._close: uv_is_closing() is true'.format(             # <<<<<<<<<<<<<<
 *                         self.__class__.__name__))
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_close_uv_is_closing_is_true, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/handles/handle.pyx":213
 *                 raise RuntimeError(
 *                     '{}._close: uv_is_closing() is true'.format(
 *                         self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *         # We want the handle wrapper (UVHandle) to stay alive until
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 213, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 212, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 212, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 212, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 212, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 212, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/handle.pyx":211
 * 
 *             if uv.uv_is_closing(self._handle):
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{}._close: uv_is_closing() is true'.format(
 *                         self.__class__.__name__))
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 211, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(4, 211, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":210
 *                         self.__class__.__name__))
 * 
 *             if uv.uv_is_closing(self._handle):             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}._close: uv_is_closing() is true'.format(
 */
    }

    /* "uvloop/handles/handle.pyx":199
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self._handle.data is NULL:
 *                 raise RuntimeError(
 */
  }

  /* "uvloop/handles/handle.pyx":217
 *         # We want the handle wrapper (UVHandle) to stay alive until
 *         # the closing callback fires.
 *         Py_INCREF(self)             # <<<<<<<<<<<<<<
 *         uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 * 
 */
  Py_INCREF(((PyObject *)__pyx_v_self));

  /* "uvloop/handles/handle.pyx":218
 *         # the closing callback fires.
 *         Py_INCREF(self)
 *         uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  uv_close(__pyx_v_self->_handle, __pyx_f_6uvloop_4loop___uv_close_handle_cb);

  /* "uvloop/handles/handle.pyx":190
 *             self._loop._handle_exception(exc)
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self._closed == 1:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVHandle._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":220
 *         uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<{} closed={} {:#x}>'.format(
 *             self.__class__.__name__,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_7__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_7__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVHandle_6__repr__(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_6__repr__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/handles/handle.pyx":221
 * 
 *     def __repr__(self):
 *         return '<{} closed={} {:#x}>'.format(             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             self._closed,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_closed_x, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/handles/handle.pyx":222
 *     def __repr__(self):
 *         return '<{} closed={} {:#x}>'.format(
 *             self.__class__.__name__,             # <<<<<<<<<<<<<<
 *             self._closed,
 *             id(self))
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/handle.pyx":223
 *         return '<{} closed={} {:#x}>'.format(
 *             self.__class__.__name__,
 *             self._closed,             # <<<<<<<<<<<<<<
 *             id(self))
 * 
 */
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_self->_closed); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/handles/handle.pyx":224
 *             self.__class__.__name__,
 *             self._closed,
 *             id(self))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  __pyx_t_7 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_7 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, __pyx_t_3, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 221, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, __pyx_t_3, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 221, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(4, 221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_t_5);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 221, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/handle.pyx":220
 *         uv.uv_close(self._handle, __uv_close_handle_cb) # void; no errors
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<{} closed={} {:#x}>'.format(
 *             self.__class__.__name__,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.UVHandle.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pxd":5
 *         uv.uv_handle_t *_handle
 *         Loop _loop
 *         readonly _source_traceback             # <<<<<<<<<<<<<<
 *         bint _closed
 *         bint _inited
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_17_source_traceback_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_17_source_traceback_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVHandle_17_source_traceback___get__(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_17_source_traceback___get__(struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_source_traceback);
  __pyx_r = __pyx_v_self->_source_traceback;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVHandle_8__reduce_cython__[] = "UVHandle.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVHandle_8__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__141, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVHandle.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVHandle_10__setstate_cython__[] = "UVHandle.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVHandle_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVHandle_10__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVHandle_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__142, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVHandle.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":230
 * cdef class UVSocketHandle(UVHandle):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._fileobj = None
 *         self.__cached_socket = None
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_14UVSocketHandle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_14UVSocketHandle_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_14UVSocketHandle___cinit__(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_14UVSocketHandle___cinit__(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/handle.pyx":231
 * 
 *     def __cinit__(self):
 *         self._fileobj = None             # <<<<<<<<<<<<<<
 *         self.__cached_socket = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_fileobj);
  __Pyx_DECREF(__pyx_v_self->_fileobj);
  __pyx_v_self->_fileobj = Py_None;

  /* "uvloop/handles/handle.pyx":232
 *     def __cinit__(self):
 *         self._fileobj = None
 *         self.__cached_socket = None             # <<<<<<<<<<<<<<
 * 
 *     cdef _fileno(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->__pyx___cached_socket);
  __Pyx_DECREF(__pyx_v_self->__pyx___cached_socket);
  __pyx_v_self->__pyx___cached_socket = Py_None;

  /* "uvloop/handles/handle.pyx":230
 * cdef class UVSocketHandle(UVHandle):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._fileobj = None
 *         self.__cached_socket = None
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":234
 *         self.__cached_socket = None
 * 
 *     cdef _fileno(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int fd
 */

static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__fileno(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self) {
  int __pyx_v_fd;
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_fileno", 0);

  /* "uvloop/handles/handle.pyx":239
 *             int err
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         err = uv.uv_fileno(self._handle, <uv.uv_os_fd_t*>&fd)
 *         if err < 0:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/handle.pyx":240
 * 
 *         self._ensure_alive()
 *         err = uv.uv_fileno(self._handle, <uv.uv_os_fd_t*>&fd)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
  __pyx_v_err = uv_fileno(__pyx_v_self->__pyx_base._handle, ((uv_os_fd_t *)(&__pyx_v_fd)));

  /* "uvloop/handles/handle.pyx":241
 *         self._ensure_alive()
 *         err = uv.uv_fileno(self._handle, <uv.uv_os_fd_t*>&fd)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/handle.pyx":242
 *         err = uv.uv_fileno(self._handle, <uv.uv_os_fd_t*>&fd)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         return fd
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(4, 242, __pyx_L1_error)

    /* "uvloop/handles/handle.pyx":241
 *         self._ensure_alive()
 *         err = uv.uv_fileno(self._handle, <uv.uv_os_fd_t*>&fd)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":244
 *             raise convert_error(err)
 * 
 *         return fd             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/handle.pyx":234
 *         self.__cached_socket = None
 * 
 *     cdef _fileno(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int fd
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._fileno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":246
 *         return fd
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__new_socket(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/handle.pyx":247
 * 
 *     cdef _new_socket(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _get_socket(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(4, 247, __pyx_L1_error)

  /* "uvloop/handles/handle.pyx":246
 *         return fd
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":249
 *         raise NotImplementedError
 * 
 *     cdef inline _get_socket(self):             # <<<<<<<<<<<<<<
 *         if self.__cached_socket is not None:
 *             return self.__cached_socket
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__get_socket(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_get_socket", 0);

  /* "uvloop/handles/handle.pyx":250
 * 
 *     cdef inline _get_socket(self):
 *         if self.__cached_socket is not None:             # <<<<<<<<<<<<<<
 *             return self.__cached_socket
 * 
 */
  __pyx_t_1 = (__pyx_v_self->__pyx___cached_socket != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":251
 *     cdef inline _get_socket(self):
 *         if self.__cached_socket is not None:
 *             return self.__cached_socket             # <<<<<<<<<<<<<<
 * 
 *         if not self._is_alive():
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_self->__pyx___cached_socket);
    __pyx_r = __pyx_v_self->__pyx___cached_socket;
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":250
 * 
 *     cdef inline _get_socket(self):
 *         if self.__cached_socket is not None:             # <<<<<<<<<<<<<<
 *             return self.__cached_socket
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":253
 *             return self.__cached_socket
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  __pyx_t_2 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":254
 * 
 *         if not self._is_alive():
 *             return None             # <<<<<<<<<<<<<<
 * 
 *         self.__cached_socket = self._new_socket()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":253
 *             return self.__cached_socket
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             return None
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":256
 *             return None
 * 
 *         self.__cached_socket = self._new_socket()             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             # We don't "dup" for the "__cached_socket".
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle *)__pyx_v_self->__pyx_base.__pyx_vtab)->_new_socket(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->__pyx___cached_socket);
  __Pyx_DECREF(__pyx_v_self->__pyx___cached_socket);
  __pyx_v_self->__pyx___cached_socket = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/handles/handle.pyx":257
 * 
 *         self.__cached_socket = self._new_socket()
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             # We don't "dup" for the "__cached_socket".
 *             assert self.__cached_socket.fileno() == self._fileno()
 */
  __pyx_t_2 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":259
 *         if UVLOOP_DEBUG:
 *             # We don't "dup" for the "__cached_socket".
 *             assert self.__cached_socket.fileno() == self._fileno()             # <<<<<<<<<<<<<<
 *         return self.__cached_socket
 * 
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx___cached_socket, __pyx_n_s_fileno); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 259, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 259, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 259, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle *)__pyx_v_self->__pyx_base.__pyx_vtab)->_fileno(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 259, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 259, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(4, 259, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(4, 259, __pyx_L1_error)
      }
    }
    #endif

    /* "uvloop/handles/handle.pyx":257
 * 
 *         self.__cached_socket = self._new_socket()
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             # We don't "dup" for the "__cached_socket".
 *             assert self.__cached_socket.fileno() == self._fileno()
 */
  }

  /* "uvloop/handles/handle.pyx":260
 *             # We don't "dup" for the "__cached_socket".
 *             assert self.__cached_socket.fileno() == self._fileno()
 *         return self.__cached_socket             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _attach_fileobj(self, object file):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx___cached_socket);
  __pyx_r = __pyx_v_self->__pyx___cached_socket;
  goto __pyx_L0;

  /* "uvloop/handles/handle.pyx":249
 *         raise NotImplementedError
 * 
 *     cdef inline _get_socket(self):             # <<<<<<<<<<<<<<
 *         if self.__cached_socket is not None:
 *             return self.__cached_socket
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._get_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":262
 *         return self.__cached_socket
 * 
 *     cdef inline _attach_fileobj(self, object file):             # <<<<<<<<<<<<<<
 *         # When we create a TCP/PIPE/etc connection/server based on
 *         # a Python file object, we need to close the file object when
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__attach_fileobj(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self, PyObject *__pyx_v_file) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_attach_fileobj", 0);

  /* "uvloop/handles/handle.pyx":266
 *         # a Python file object, we need to close the file object when
 *         # the uv handle is closed.
 *         socket_inc_io_ref(file)             # <<<<<<<<<<<<<<
 *         self._fileobj = file
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_socket_inc_io_ref(__pyx_v_file); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/handle.pyx":267
 *         # the uv handle is closed.
 *         socket_inc_io_ref(file)
 *         self._fileobj = file             # <<<<<<<<<<<<<<
 * 
 *     cdef _close(self):
 */
  __Pyx_INCREF(__pyx_v_file);
  __Pyx_GIVEREF(__pyx_v_file);
  __Pyx_GOTREF(__pyx_v_self->_fileobj);
  __Pyx_DECREF(__pyx_v_self->_fileobj);
  __pyx_v_self->_fileobj = __pyx_v_file;

  /* "uvloop/handles/handle.pyx":262
 *         return self.__cached_socket
 * 
 *     cdef inline _attach_fileobj(self, object file):             # <<<<<<<<<<<<<<
 *         # When we create a TCP/PIPE/etc connection/server based on
 *         # a Python file object, we need to close the file object when
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._attach_fileobj", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":269
 *         self._fileobj = file
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self.__cached_socket is not None:
 *             (<PseudoSocket>self.__cached_socket)._fd = -1
 */

static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__close(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self) {
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  char const *__pyx_t_28;
  char const *__pyx_t_29;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "uvloop/handles/handle.pyx":270
 * 
 *     cdef _close(self):
 *         if self.__cached_socket is not None:             # <<<<<<<<<<<<<<
 *             (<PseudoSocket>self.__cached_socket)._fd = -1
 * 
 */
  __pyx_t_1 = (__pyx_v_self->__pyx___cached_socket != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":271
 *     cdef _close(self):
 *         if self.__cached_socket is not None:
 *             (<PseudoSocket>self.__cached_socket)._fd = -1             # <<<<<<<<<<<<<<
 * 
 *         UVHandle._close(self)
 */
    ((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v_self->__pyx___cached_socket)->_fd = -1;

    /* "uvloop/handles/handle.pyx":270
 * 
 *     cdef _close(self):
 *         if self.__cached_socket is not None:             # <<<<<<<<<<<<<<
 *             (<PseudoSocket>self.__cached_socket)._fd = -1
 * 
 */
  }

  /* "uvloop/handles/handle.pyx":273
 *             (<PseudoSocket>self.__cached_socket)._fd = -1
 * 
 *         UVHandle._close(self)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_8UVHandle__close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 273, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/handle.pyx":275
 *         UVHandle._close(self)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             # This code will only run for transports created from
 *             # Python sockets, i.e. with `loop.create_server(sock=sock)` etc.
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/handles/handle.pyx":278
 *             # This code will only run for transports created from
 *             # Python sockets, i.e. with `loop.create_server(sock=sock)` etc.
 *             if self._fileobj is not None:             # <<<<<<<<<<<<<<
 *                 if isinstance(self._fileobj, socket_socket):
 *                     # Detaching the socket object is the ideal solution:
 */
        __pyx_t_2 = (__pyx_v_self->_fileobj != Py_None);
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "uvloop/handles/handle.pyx":279
 *             # Python sockets, i.e. with `loop.create_server(sock=sock)` etc.
 *             if self._fileobj is not None:
 *                 if isinstance(self._fileobj, socket_socket):             # <<<<<<<<<<<<<<
 *                     # Detaching the socket object is the ideal solution:
 *                     # * libuv will actually close the FD;
 */
          __pyx_t_3 = __pyx_v_self->_fileobj;
          __Pyx_INCREF(__pyx_t_3);
          __pyx_t_7 = __pyx_v_6uvloop_4loop_socket_socket;
          __Pyx_INCREF(__pyx_t_7);
          __pyx_t_1 = PyObject_IsInstance(__pyx_t_3, __pyx_t_7); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(4, 279, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_2 = (__pyx_t_1 != 0);
          if (__pyx_t_2) {

            /* "uvloop/handles/handle.pyx":288
 *                     # No need to call `socket_dec_io_ref()`, as
 *                     # `socket.detach()` ignores `socket._io_refs`.
 *                     self._fileobj.detach()             # <<<<<<<<<<<<<<
 *                 else:
 *                     try:
 */
            __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_fileobj, __pyx_n_s_detach); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 288, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_8 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_3, function);
              }
            }
            if (__pyx_t_8) {
              __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 288, __pyx_L7_error)
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            } else {
              __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 288, __pyx_L7_error)
            }
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "uvloop/handles/handle.pyx":279
 *             # Python sockets, i.e. with `loop.create_server(sock=sock)` etc.
 *             if self._fileobj is not None:
 *                 if isinstance(self._fileobj, socket_socket):             # <<<<<<<<<<<<<<
 *                     # Detaching the socket object is the ideal solution:
 *                     # * libuv will actually close the FD;
 */
            goto __pyx_L14;
          }

          /* "uvloop/handles/handle.pyx":290
 *                     self._fileobj.detach()
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         # `socket.close()` will raise an EBADF because libuv
 *                         # has already closed the underlying FD.
 */
          /*else*/ {
            {
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
              __Pyx_XGOTREF(__pyx_t_9);
              __Pyx_XGOTREF(__pyx_t_10);
              __Pyx_XGOTREF(__pyx_t_11);
              /*try:*/ {

                /* "uvloop/handles/handle.pyx":293
 *                         # `socket.close()` will raise an EBADF because libuv
 *                         # has already closed the underlying FD.
 *                         self._fileobj.close()             # <<<<<<<<<<<<<<
 *                     except OSError as ex:
 *                         if ex.errno != errno_EBADF:
 */
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_fileobj, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 293, __pyx_L15_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_8 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
                  __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
                  if (likely(__pyx_t_8)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                    __Pyx_INCREF(__pyx_t_8);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_3, function);
                  }
                }
                if (__pyx_t_8) {
                  __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 293, __pyx_L15_error)
                  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                } else {
                  __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 293, __pyx_L15_error)
                }
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

                /* "uvloop/handles/handle.pyx":290
 *                     self._fileobj.detach()
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         # `socket.close()` will raise an EBADF because libuv
 *                         # has already closed the underlying FD.
 */
              }
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              goto __pyx_L20_try_end;
              __pyx_L15_error:;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

              /* "uvloop/handles/handle.pyx":294
 *                         # has already closed the underlying FD.
 *                         self._fileobj.close()
 *                     except OSError as ex:             # <<<<<<<<<<<<<<
 *                         if ex.errno != errno_EBADF:
 *                             raise
 */
              __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
              if (__pyx_t_12) {
                __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
                if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_3, &__pyx_t_8) < 0) __PYX_ERR(4, 294, __pyx_L17_except_error)
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_GOTREF(__pyx_t_3);
                __Pyx_GOTREF(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_3);
                __pyx_v_ex = __pyx_t_3;
                /*try:*/ {

                  /* "uvloop/handles/handle.pyx":295
 *                         self._fileobj.close()
 *                     except OSError as ex:
 *                         if ex.errno != errno_EBADF:             # <<<<<<<<<<<<<<
 *                             raise
 *         except Exception as ex:
 */
                  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_ex, __pyx_n_s_errno); if (unlikely(!__pyx_t_13)) __PYX_ERR(4, 295, __pyx_L26_error)
                  __Pyx_GOTREF(__pyx_t_13);
                  __pyx_t_14 = PyObject_RichCompare(__pyx_t_13, __pyx_v_6uvloop_4loop_errno_EBADF, Py_NE); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(4, 295, __pyx_L26_error)
                  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(4, 295, __pyx_L26_error)
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  if (unlikely(__pyx_t_2)) {

                    /* "uvloop/handles/handle.pyx":296
 *                     except OSError as ex:
 *                         if ex.errno != errno_EBADF:
 *                             raise             # <<<<<<<<<<<<<<
 *         except Exception as ex:
 *             self._loop.call_exception_handler({
 */
                    __Pyx_GIVEREF(__pyx_t_7);
                    __Pyx_GIVEREF(__pyx_t_3);
                    __Pyx_XGIVEREF(__pyx_t_8);
                    __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_3, __pyx_t_8);
                    __pyx_t_7 = 0; __pyx_t_3 = 0; __pyx_t_8 = 0; 
                    __PYX_ERR(4, 296, __pyx_L26_error)

                    /* "uvloop/handles/handle.pyx":295
 *                         self._fileobj.close()
 *                     except OSError as ex:
 *                         if ex.errno != errno_EBADF:             # <<<<<<<<<<<<<<
 *                             raise
 *         except Exception as ex:
 */
                  }
                }

                /* "uvloop/handles/handle.pyx":294
 *                         # has already closed the underlying FD.
 *                         self._fileobj.close()
 *                     except OSError as ex:             # <<<<<<<<<<<<<<
 *                         if ex.errno != errno_EBADF:
 *                             raise
 */
                /*finally:*/ {
                  /*normal exit:*/{
                    __Pyx_DECREF(__pyx_v_ex);
                    __pyx_v_ex = NULL;
                    goto __pyx_L27;
                  }
                  __pyx_L26_error:;
                  /*exception exit:*/{
                    __Pyx_PyThreadState_declare
                    __Pyx_PyThreadState_assign
                    __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
                    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                    if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
                    if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
                    __Pyx_XGOTREF(__pyx_t_17);
                    __Pyx_XGOTREF(__pyx_t_18);
                    __Pyx_XGOTREF(__pyx_t_19);
                    __Pyx_XGOTREF(__pyx_t_20);
                    __Pyx_XGOTREF(__pyx_t_21);
                    __Pyx_XGOTREF(__pyx_t_22);
                    __pyx_t_12 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
                    {
                      __Pyx_DECREF(__pyx_v_ex);
                      __pyx_v_ex = NULL;
                    }
                    if (PY_MAJOR_VERSION >= 3) {
                      __Pyx_XGIVEREF(__pyx_t_20);
                      __Pyx_XGIVEREF(__pyx_t_21);
                      __Pyx_XGIVEREF(__pyx_t_22);
                      __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
                    }
                    __Pyx_XGIVEREF(__pyx_t_17);
                    __Pyx_XGIVEREF(__pyx_t_18);
                    __Pyx_XGIVEREF(__pyx_t_19);
                    __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
                    __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
                    __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
                    goto __pyx_L17_except_error;
                  }
                  __pyx_L27:;
                }
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                goto __pyx_L16_exception_handled;
              }
              goto __pyx_L17_except_error;
              __pyx_L17_except_error:;

              /* "uvloop/handles/handle.pyx":290
 *                     self._fileobj.detach()
 *                 else:
 *                     try:             # <<<<<<<<<<<<<<
 *                         # `socket.close()` will raise an EBADF because libuv
 *                         # has already closed the underlying FD.
 */
              __Pyx_XGIVEREF(__pyx_t_9);
              __Pyx_XGIVEREF(__pyx_t_10);
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
              goto __pyx_L7_error;
              __pyx_L16_exception_handled:;
              __Pyx_XGIVEREF(__pyx_t_9);
              __Pyx_XGIVEREF(__pyx_t_10);
              __Pyx_XGIVEREF(__pyx_t_11);
              __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
              __pyx_L20_try_end:;
            }
          }
          __pyx_L14:;

          /* "uvloop/handles/handle.pyx":278
 *             # This code will only run for transports created from
 *             # Python sockets, i.e. with `loop.create_server(sock=sock)` etc.
 *             if self._fileobj is not None:             # <<<<<<<<<<<<<<
 *                 if isinstance(self._fileobj, socket_socket):
 *                     # Detaching the socket object is the ideal solution:
 */
        }

        /* "uvloop/handles/handle.pyx":275
 *         UVHandle._close(self)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             # This code will only run for transports created from
 *             # Python sockets, i.e. with `loop.create_server(sock=sock)` etc.
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/handles/handle.pyx":297
 *                         if ex.errno != errno_EBADF:
 *                             raise
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             self._loop.call_exception_handler({
 *                 'exception': ex,
 */
      __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_15) {
        __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_3, &__pyx_t_7) < 0) __PYX_ERR(4, 297, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_ex, __pyx_t_3);
        /*try:*/ {

          /* "uvloop/handles/handle.pyx":298
 *                             raise
 *         except Exception as ex:
 *             self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                 'exception': ex,
 *                 'transport': self,
 */
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base._loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_13)) __PYX_ERR(4, 298, __pyx_L38_error)
          __Pyx_GOTREF(__pyx_t_13);

          /* "uvloop/handles/handle.pyx":299
 *         except Exception as ex:
 *             self._loop.call_exception_handler({
 *                 'exception': ex,             # <<<<<<<<<<<<<<
 *                 'transport': self,
 *                 'message': 'could not close attached file object {!r}'.
 */
          __pyx_t_23 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_23)) __PYX_ERR(4, 299, __pyx_L38_error)
          __Pyx_GOTREF(__pyx_t_23);
          if (PyDict_SetItem(__pyx_t_23, __pyx_n_u_exception, __pyx_v_ex) < 0) __PYX_ERR(4, 299, __pyx_L38_error)

          /* "uvloop/handles/handle.pyx":300
 *             self._loop.call_exception_handler({
 *                 'exception': ex,
 *                 'transport': self,             # <<<<<<<<<<<<<<
 *                 'message': 'could not close attached file object {!r}'.
 *                     format(self._fileobj)
 */
          if (PyDict_SetItem(__pyx_t_23, __pyx_n_u_transport, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(4, 299, __pyx_L38_error)

          /* "uvloop/handles/handle.pyx":301
 *                 'exception': ex,
 *                 'transport': self,
 *                 'message': 'could not close attached file object {!r}'.             # <<<<<<<<<<<<<<
 *                     format(self._fileobj)
 *             })
 */
          __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_could_not_close_attached_file_ob, __pyx_n_s_format); if (unlikely(!__pyx_t_25)) __PYX_ERR(4, 301, __pyx_L38_error)
          __Pyx_GOTREF(__pyx_t_25);

          /* "uvloop/handles/handle.pyx":302
 *                 'transport': self,
 *                 'message': 'could not close attached file object {!r}'.
 *                     format(self._fileobj)             # <<<<<<<<<<<<<<
 *             })
 *         finally:
 */
          __pyx_t_26 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_25))) {
            __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_25);
            if (likely(__pyx_t_26)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
              __Pyx_INCREF(__pyx_t_26);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_25, function);
            }
          }
          if (!__pyx_t_26) {
            __pyx_t_24 = __Pyx_PyObject_CallOneArg(__pyx_t_25, __pyx_v_self->_fileobj); if (unlikely(!__pyx_t_24)) __PYX_ERR(4, 302, __pyx_L38_error)
            __Pyx_GOTREF(__pyx_t_24);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_25)) {
              PyObject *__pyx_temp[2] = {__pyx_t_26, __pyx_v_self->_fileobj};
              __pyx_t_24 = __Pyx_PyFunction_FastCall(__pyx_t_25, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_24)) __PYX_ERR(4, 302, __pyx_L38_error)
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              __Pyx_GOTREF(__pyx_t_24);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_25)) {
              PyObject *__pyx_temp[2] = {__pyx_t_26, __pyx_v_self->_fileobj};
              __pyx_t_24 = __Pyx_PyCFunction_FastCall(__pyx_t_25, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_24)) __PYX_ERR(4, 302, __pyx_L38_error)
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              __Pyx_GOTREF(__pyx_t_24);
            } else
            #endif
            {
              __pyx_t_27 = PyTuple_New(1+1); if (unlikely(!__pyx_t_27)) __PYX_ERR(4, 302, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_27);
              __Pyx_GIVEREF(__pyx_t_26); PyTuple_SET_ITEM(__pyx_t_27, 0, __pyx_t_26); __pyx_t_26 = NULL;
              __Pyx_INCREF(__pyx_v_self->_fileobj);
              __Pyx_GIVEREF(__pyx_v_self->_fileobj);
              PyTuple_SET_ITEM(__pyx_t_27, 0+1, __pyx_v_self->_fileobj);
              __pyx_t_24 = __Pyx_PyObject_Call(__pyx_t_25, __pyx_t_27, NULL); if (unlikely(!__pyx_t_24)) __PYX_ERR(4, 302, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_24);
              __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
          if (PyDict_SetItem(__pyx_t_23, __pyx_n_u_message, __pyx_t_24) < 0) __PYX_ERR(4, 299, __pyx_L38_error)
          __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
          __pyx_t_24 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_24)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_24);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          if (!__pyx_t_24) {
            __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_23); if (unlikely(!__pyx_t_14)) __PYX_ERR(4, 298, __pyx_L38_error)
            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
            __Pyx_GOTREF(__pyx_t_14);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_13)) {
              PyObject *__pyx_temp[2] = {__pyx_t_24, __pyx_t_23};
              __pyx_t_14 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(4, 298, __pyx_L38_error)
              __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
              PyObject *__pyx_temp[2] = {__pyx_t_24, __pyx_t_23};
              __pyx_t_14 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(4, 298, __pyx_L38_error)
              __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
            } else
            #endif
            {
              __pyx_t_25 = PyTuple_New(1+1); if (unlikely(!__pyx_t_25)) __PYX_ERR(4, 298, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_25);
              __Pyx_GIVEREF(__pyx_t_24); PyTuple_SET_ITEM(__pyx_t_25, 0, __pyx_t_24); __pyx_t_24 = NULL;
              __Pyx_GIVEREF(__pyx_t_23);
              PyTuple_SET_ITEM(__pyx_t_25, 0+1, __pyx_t_23);
              __pyx_t_23 = 0;
              __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_25, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(4, 298, __pyx_L38_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        }

        /* "uvloop/handles/handle.pyx":297
 *                         if ex.errno != errno_EBADF:
 *                             raise
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             self._loop.call_exception_handler({
 *                 'exception': ex,
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L39;
          }
          __pyx_L38_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_9 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0;
            __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
            __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
            __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
            __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
            __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9);
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_9);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_20);
            __pyx_t_15 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_28 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_21, __pyx_t_20);
            }
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_9);
            __Pyx_ErrRestore(__pyx_t_11, __pyx_t_10, __pyx_t_9);
            __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_9 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0;
            __pyx_lineno = __pyx_t_15; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_28;
            goto __pyx_L9_except_error;
          }
          __pyx_L39:;
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/handles/handle.pyx":275
 *         UVHandle._close(self)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             # This code will only run for transports created from
 *             # Python sockets, i.e. with `loop.create_server(sock=sock)` etc.
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L5_error;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_L12_try_end:;
    }
  }

  /* "uvloop/handles/handle.pyx":305
 *             })
 *         finally:
 *             self._fileobj = None             # <<<<<<<<<<<<<<
 * 
 *     cdef _open(self, int sockfd):
 */
  /*finally:*/ {
    /*normal exit:*/{
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->_fileobj);
      __Pyx_DECREF(__pyx_v_self->_fileobj);
      __pyx_v_self->_fileobj = Py_None;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
      __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
      __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
      __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
      __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
      __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_20);
      __Pyx_XGOTREF(__pyx_t_21);
      __Pyx_XGOTREF(__pyx_t_22);
      __pyx_t_12 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_29 = __pyx_filename;
      {
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->_fileobj);
        __Pyx_DECREF(__pyx_v_self->_fileobj);
        __pyx_v_self->_fileobj = Py_None;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
      }
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
      __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_29;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/handles/handle.pyx":269
 *         self._fileobj = file
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self.__cached_socket is not None:
 *             (<PseudoSocket>self.__cached_socket)._fd = -1
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":307
 *             self._fileobj = None
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_14UVSocketHandle__open(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self, CYTHON_UNUSED int __pyx_v_sockfd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_open", 0);

  /* "uvloop/handles/handle.pyx":308
 * 
 *     cdef _open(self, int sockfd):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(4, 308, __pyx_L1_error)

  /* "uvloop/handles/handle.pyx":307
 *             self._fileobj = None
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_14UVSocketHandle_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_14UVSocketHandle_2__reduce_cython__[] = "UVSocketHandle.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_14UVSocketHandle_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_14UVSocketHandle_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_14UVSocketHandle_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__143, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_14UVSocketHandle_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_14UVSocketHandle_4__setstate_cython__[] = "UVSocketHandle.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_14UVSocketHandle_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_14UVSocketHandle_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_14UVSocketHandle_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__144, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVSocketHandle.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":311
 * 
 * 
 * cdef inline bint __ensure_handle_data(uv.uv_handle_t* handle,             # <<<<<<<<<<<<<<
 *                                       const char* handle_ctx):
 * 
 */

static CYTHON_INLINE int __pyx_f_6uvloop_4loop___ensure_handle_data(uv_handle_t *__pyx_v_handle, char const *__pyx_v_handle_ctx) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("__ensure_handle_data", 0);

  /* "uvloop/handles/handle.pyx":316
 *     cdef Loop loop
 * 
 *     if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *         if handle.loop is NULL:
 *             raise RuntimeError(
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":317
 * 
 *     if UVLOOP_DEBUG:
 *         if handle.loop is NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'handle.loop is NULL in __ensure_handle_data')
 */
    __pyx_t_1 = ((__pyx_v_handle->loop == NULL) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/handles/handle.pyx":318
 *     if UVLOOP_DEBUG:
 *         if handle.loop is NULL:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'handle.loop is NULL in __ensure_handle_data')
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__145, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 318, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(4, 318, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":317
 * 
 *     if UVLOOP_DEBUG:
 *         if handle.loop is NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'handle.loop is NULL in __ensure_handle_data')
 */
    }

    /* "uvloop/handles/handle.pyx":321
 *                 'handle.loop is NULL in __ensure_handle_data')
 * 
 *         if handle.loop.data is NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'handle.loop.data is NULL in __ensure_handle_data')
 */
    __pyx_t_1 = ((__pyx_v_handle->loop->data == NULL) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/handles/handle.pyx":322
 * 
 *         if handle.loop.data is NULL:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'handle.loop.data is NULL in __ensure_handle_data')
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__146, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 322, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(4, 322, __pyx_L1_error)

      /* "uvloop/handles/handle.pyx":321
 *                 'handle.loop is NULL in __ensure_handle_data')
 * 
 *         if handle.loop.data is NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'handle.loop.data is NULL in __ensure_handle_data')
 */
    }

    /* "uvloop/handles/handle.pyx":316
 *     cdef Loop loop
 * 
 *     if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *         if handle.loop is NULL:
 *             raise RuntimeError(
 */
  }

  /* "uvloop/handles/handle.pyx":325
 *                 'handle.loop.data is NULL in __ensure_handle_data')
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         loop = <Loop>handle.loop.data
 *         loop.call_exception_handler({
 */
  __pyx_t_1 = ((__pyx_v_handle->data == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":326
 * 
 *     if handle.data is NULL:
 *         loop = <Loop>handle.loop.data             # <<<<<<<<<<<<<<
 *         loop.call_exception_handler({
 *             'message': '{} called with handle.data == NULL'.format(
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_handle->loop->data);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/handles/handle.pyx":327
 *     if handle.data is NULL:
 *         loop = <Loop>handle.loop.data
 *         loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *             'message': '{} called with handle.data == NULL'.format(
 *                 handle_ctx.decode('latin-1'))
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/handles/handle.pyx":328
 *         loop = <Loop>handle.loop.data
 *         loop.call_exception_handler({
 *             'message': '{} called with handle.data == NULL'.format(             # <<<<<<<<<<<<<<
 *                 handle_ctx.decode('latin-1'))
 *         })
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_called_with_handle_data_NULL, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "uvloop/handles/handle.pyx":329
 *         loop.call_exception_handler({
 *             'message': '{} called with handle.data == NULL'.format(
 *                 handle_ctx.decode('latin-1'))             # <<<<<<<<<<<<<<
 *         })
 *         return 0
 */
    __pyx_t_7 = __Pyx_decode_c_string(__pyx_v_handle_ctx, 0, strlen(__pyx_v_handle_ctx), NULL, NULL, PyUnicode_DecodeLatin1); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 328, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 328, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 328, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 328, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 328, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_message, __pyx_t_5) < 0) __PYX_ERR(4, 328, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 327, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 327, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 327, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 327, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 327, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/handle.pyx":331
 *                 handle_ctx.decode('latin-1'))
 *         })
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     if handle.data is NULL:
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":325
 *                 'handle.loop.data is NULL in __ensure_handle_data')
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         loop = <Loop>handle.loop.data
 *         loop.call_exception_handler({
 */
  }

  /* "uvloop/handles/handle.pyx":333
 *         return 0
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         # The underlying UVHandle object was GCed with an open uv_handle_t.
 *         loop = <Loop>handle.loop.data
 */
  __pyx_t_1 = ((__pyx_v_handle->data == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":335
 *     if handle.data is NULL:
 *         # The underlying UVHandle object was GCed with an open uv_handle_t.
 *         loop = <Loop>handle.loop.data             # <<<<<<<<<<<<<<
 *         loop.call_exception_handler({
 *             'message': '{} called after destroying the UVHandle'.format(
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_handle->loop->data);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "uvloop/handles/handle.pyx":336
 *         # The underlying UVHandle object was GCed with an open uv_handle_t.
 *         loop = <Loop>handle.loop.data
 *         loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *             'message': '{} called after destroying the UVHandle'.format(
 *                 handle_ctx.decode('latin-1'))
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/handles/handle.pyx":337
 *         loop = <Loop>handle.loop.data
 *         loop.call_exception_handler({
 *             'message': '{} called after destroying the UVHandle'.format(             # <<<<<<<<<<<<<<
 *                 handle_ctx.decode('latin-1'))
 *         })
 */
    __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_called_after_destroying_the_UVH, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "uvloop/handles/handle.pyx":338
 *         loop.call_exception_handler({
 *             'message': '{} called after destroying the UVHandle'.format(
 *                 handle_ctx.decode('latin-1'))             # <<<<<<<<<<<<<<
 *         })
 *         return 0
 */
    __pyx_t_9 = __Pyx_decode_c_string(__pyx_v_handle_ctx, 0, strlen(__pyx_v_handle_ctx), NULL, NULL, PyUnicode_DecodeLatin1); if (unlikely(!__pyx_t_9)) __PYX_ERR(4, 338, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 337, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_9};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 337, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_9};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 337, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(4, 337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_u_message, __pyx_t_4) < 0) __PYX_ERR(4, 337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 336, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_6};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 336, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 336, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/handle.pyx":340
 *                 handle_ctx.decode('latin-1'))
 *         })
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     return 1
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":333
 *         return 0
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         # The underlying UVHandle object was GCed with an open uv_handle_t.
 *         loop = <Loop>handle.loop.data
 */
  }

  /* "uvloop/handles/handle.pyx":342
 *         return 0
 * 
 *     return 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 1;
  goto __pyx_L0;

  /* "uvloop/handles/handle.pyx":311
 * 
 * 
 * cdef inline bint __ensure_handle_data(uv.uv_handle_t* handle,             # <<<<<<<<<<<<<<
 *                                       const char* handle_ctx):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__ensure_handle_data", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/handle.pyx":345
 * 
 * 
 * cdef void __uv_close_handle_cb(uv.uv_handle_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     cdef UVHandle h
 * 
 */

static void __pyx_f_6uvloop_4loop___uv_close_handle_cb(uv_handle_t *__pyx_v_handle) {
  struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_h = 0;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_close_handle_cb", 0);

  /* "uvloop/handles/handle.pyx":348
 *     cdef UVHandle h
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         # The original UVHandle is long dead. Just free the mem of
 *         # the uv_handle_t* handler.
 */
  __pyx_t_1 = ((__pyx_v_handle->data == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/handle.pyx":352
 *         # the uv_handle_t* handler.
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if handle.loop == NULL or handle.loop.data == NULL:
 *                 raise RuntimeError(
 */
    __pyx_t_1 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/handle.pyx":353
 * 
 *         if UVLOOP_DEBUG:
 *             if handle.loop == NULL or handle.loop.data == NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '__uv_close_handle_cb: handle.loop is invalid')
 */
      __pyx_t_2 = ((__pyx_v_handle->loop == NULL) != 0);
      if (!__pyx_t_2) {
      } else {
        __pyx_t_1 = __pyx_t_2;
        goto __pyx_L6_bool_binop_done;
      }
      __pyx_t_2 = ((__pyx_v_handle->loop->data == NULL) != 0);
      __pyx_t_1 = __pyx_t_2;
      __pyx_L6_bool_binop_done:;
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/handles/handle.pyx":354
 *         if UVLOOP_DEBUG:
 *             if handle.loop == NULL or handle.loop.data == NULL:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '__uv_close_handle_cb: handle.loop is invalid')
 *             (<Loop>handle.loop.data)._debug_uv_handles_freed += 1
 */
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__147, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 354, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(4, 354, __pyx_L1_error)

        /* "uvloop/handles/handle.pyx":353
 * 
 *         if UVLOOP_DEBUG:
 *             if handle.loop == NULL or handle.loop.data == NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '__uv_close_handle_cb: handle.loop is invalid')
 */
      }

      /* "uvloop/handles/handle.pyx":356
 *                 raise RuntimeError(
 *                     '__uv_close_handle_cb: handle.loop is invalid')
 *             (<Loop>handle.loop.data)._debug_uv_handles_freed += 1             # <<<<<<<<<<<<<<
 * 
 *         PyMem_RawFree(handle)
 */
      __Pyx_INCREF(((PyObject *)((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_handle->loop->data)));
      __pyx_t_4 = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_v_handle->loop->data);
      __pyx_t_4->_debug_uv_handles_freed = (__pyx_t_4->_debug_uv_handles_freed + 1);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

      /* "uvloop/handles/handle.pyx":352
 *         # the uv_handle_t* handler.
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if handle.loop == NULL or handle.loop.data == NULL:
 *                 raise RuntimeError(
 */
    }

    /* "uvloop/handles/handle.pyx":358
 *             (<Loop>handle.loop.data)._debug_uv_handles_freed += 1
 * 
 *         PyMem_RawFree(handle)             # <<<<<<<<<<<<<<
 *     else:
 *         h = <UVHandle>handle.data
 */
    PyMem_RawFree(__pyx_v_handle);

    /* "uvloop/handles/handle.pyx":348
 *     cdef UVHandle h
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         # The original UVHandle is long dead. Just free the mem of
 *         # the uv_handle_t* handler.
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/handle.pyx":360
 *         PyMem_RawFree(handle)
 *     else:
 *         h = <UVHandle>handle.data             # <<<<<<<<<<<<<<
 *         try:
 *             if UVLOOP_DEBUG:
 */
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_handle->data);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_h = ((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/handles/handle.pyx":361
 *     else:
 *         h = <UVHandle>handle.data
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 if not h._has_handle:
 */
    /*try:*/ {

      /* "uvloop/handles/handle.pyx":362
 *         h = <UVHandle>handle.data
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if not h._has_handle:
 *                     raise RuntimeError(
 */
      __pyx_t_1 = (UVLOOP_DEBUG != 0);
      if (__pyx_t_1) {

        /* "uvloop/handles/handle.pyx":363
 *         try:
 *             if UVLOOP_DEBUG:
 *                 if not h._has_handle:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         'has_handle=0 in __uv_close_handle_cb')
 */
        __pyx_t_1 = ((!(__pyx_v_h->_has_handle != 0)) != 0);
        if (unlikely(__pyx_t_1)) {

          /* "uvloop/handles/handle.pyx":364
 *             if UVLOOP_DEBUG:
 *                 if not h._has_handle:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         'has_handle=0 in __uv_close_handle_cb')
 *                 h._loop._debug_handles_closed.update([
 */
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__148, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 364, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_Raise(__pyx_t_3, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __PYX_ERR(4, 364, __pyx_L9_error)

          /* "uvloop/handles/handle.pyx":363
 *         try:
 *             if UVLOOP_DEBUG:
 *                 if not h._has_handle:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         'has_handle=0 in __uv_close_handle_cb')
 */
        }

        /* "uvloop/handles/handle.pyx":366
 *                     raise RuntimeError(
 *                         'has_handle=0 in __uv_close_handle_cb')
 *                 h._loop._debug_handles_closed.update([             # <<<<<<<<<<<<<<
 *                     h.__class__.__name__])
 *             h._free()
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_h->_loop->_debug_handles_closed, __pyx_n_s_update); if (unlikely(!__pyx_t_5)) __PYX_ERR(4, 366, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_5);

        /* "uvloop/handles/handle.pyx":367
 *                         'has_handle=0 in __uv_close_handle_cb')
 *                 h._loop._debug_handles_closed.update([
 *                     h.__class__.__name__])             # <<<<<<<<<<<<<<
 *             h._free()
 *         finally:
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_h), __pyx_n_s_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 367, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(4, 367, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/handles/handle.pyx":366
 *                     raise RuntimeError(
 *                         'has_handle=0 in __uv_close_handle_cb')
 *                 h._loop._debug_handles_closed.update([             # <<<<<<<<<<<<<<
 *                     h.__class__.__name__])
 *             h._free()
 */
        __pyx_t_6 = PyList_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 366, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_7);
        PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (!__pyx_t_7) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 366, __pyx_L9_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 366, __pyx_L9_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 366, __pyx_L9_error)
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          {
            __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(4, 366, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
            __Pyx_GIVEREF(__pyx_t_6);
            PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_6);
            __pyx_t_6 = 0;
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 366, __pyx_L9_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/handle.pyx":362
 *         h = <UVHandle>handle.data
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if not h._has_handle:
 *                     raise RuntimeError(
 */
      }

      /* "uvloop/handles/handle.pyx":368
 *                 h._loop._debug_handles_closed.update([
 *                     h.__class__.__name__])
 *             h._free()             # <<<<<<<<<<<<<<
 *         finally:
 *             Py_DECREF(h) # Was INCREFed in UVHandle._close
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_h->__pyx_vtab)->_free(__pyx_v_h); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 368, __pyx_L9_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }

    /* "uvloop/handles/handle.pyx":370
 *             h._free()
 *         finally:
 *             Py_DECREF(h) # Was INCREFed in UVHandle._close             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*finally:*/ {
      /*normal exit:*/{
        Py_DECREF(((PyObject *)__pyx_v_h));
        goto __pyx_L10;
      }
      __pyx_L9_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
        __Pyx_XDECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
        if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        __pyx_t_9 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
        {
          Py_DECREF(((PyObject *)__pyx_v_h));
        }
        if (PY_MAJOR_VERSION >= 3) {
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        }
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
        __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
        __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
        goto __pyx_L1_error;
      }
      __pyx_L10:;
    }
  }
  __pyx_L3:;

  /* "uvloop/handles/handle.pyx":345
 * 
 * 
 * cdef void __uv_close_handle_cb(uv.uv_handle_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     cdef UVHandle h
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(((PyObject *)__pyx_t_4));
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_close_handle_cb", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_h);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/handle.pyx":373
 * 
 * 
 * cdef void __close_all_handles(Loop loop):             # <<<<<<<<<<<<<<
 *     uv.uv_walk(loop.uvloop, __uv_walk_close_all_handles_cb, <void*>loop) # void
 * 
 */

static void __pyx_f_6uvloop_4loop___close_all_handles(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__close_all_handles", 0);

  /* "uvloop/handles/handle.pyx":374
 * 
 * cdef void __close_all_handles(Loop loop):
 *     uv.uv_walk(loop.uvloop, __uv_walk_close_all_handles_cb, <void*>loop) # void             # <<<<<<<<<<<<<<
 * 
 * cdef void __uv_walk_close_all_handles_cb(uv.uv_handle_t* handle, void* arg) with gil:
 */
  uv_walk(__pyx_v_loop->uvloop, __pyx_f_6uvloop_4loop___uv_walk_close_all_handles_cb, ((void *)__pyx_v_loop));

  /* "uvloop/handles/handle.pyx":373
 * 
 * 
 * cdef void __close_all_handles(Loop loop):             # <<<<<<<<<<<<<<
 *     uv.uv_walk(loop.uvloop, __uv_walk_close_all_handles_cb, <void*>loop) # void
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/handles/handle.pyx":376
 *     uv.uv_walk(loop.uvloop, __uv_walk_close_all_handles_cb, <void*>loop) # void
 * 
 * cdef void __uv_walk_close_all_handles_cb(uv.uv_handle_t* handle, void* arg) with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         Loop loop = <Loop>arg
 */

static void __pyx_f_6uvloop_4loop___uv_walk_close_all_handles_cb(uv_handle_t *__pyx_v_handle, void *__pyx_v_arg) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  struct __pyx_obj_6uvloop_4loop_UVHandle *__pyx_v_h = 0;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_walk_close_all_handles_cb", 0);

  /* "uvloop/handles/handle.pyx":378
 * cdef void __uv_walk_close_all_handles_cb(uv.uv_handle_t* handle, void* arg) with gil:
 *     cdef:
 *         Loop loop = <Loop>arg             # <<<<<<<<<<<<<<
 *         UVHandle h
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_arg);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/handle.pyx":381
 *         UVHandle h
 * 
 *     if uv.uv_is_closing(handle):             # <<<<<<<<<<<<<<
 *         # The handle is closed or is closing.
 *         return
 */
  __pyx_t_2 = (uv_is_closing(__pyx_v_handle) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":383
 *     if uv.uv_is_closing(handle):
 *         # The handle is closed or is closing.
 *         return             # <<<<<<<<<<<<<<
 * 
 *     if handle.data is NULL:
 */
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":381
 *         UVHandle h
 * 
 *     if uv.uv_is_closing(handle):             # <<<<<<<<<<<<<<
 *         # The handle is closed or is closing.
 *         return
 */
  }

  /* "uvloop/handles/handle.pyx":385
 *         return
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         # This shouldn't happen. Ever.
 *         loop.call_exception_handler({
 */
  __pyx_t_2 = ((__pyx_v_handle->data == NULL) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":387
 *     if handle.data is NULL:
 *         # This shouldn't happen. Ever.
 *         loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *             'message': 'handle.data is NULL in __close_all_handles_cb'
 *         })
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 387, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/handles/handle.pyx":388
 *         # This shouldn't happen. Ever.
 *         loop.call_exception_handler({
 *             'message': 'handle.data is NULL in __close_all_handles_cb'             # <<<<<<<<<<<<<<
 *         })
 *         return
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 388, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_message, __pyx_kp_u_handle_data_is_NULL_in___close_a) < 0) __PYX_ERR(4, 388, __pyx_L1_error)
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 387, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 387, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 387, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(4, 387, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 387, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/handle.pyx":390
 *             'message': 'handle.data is NULL in __close_all_handles_cb'
 *         })
 *         return             # <<<<<<<<<<<<<<
 * 
 *     h = <UVHandle>handle.data
 */
    goto __pyx_L0;

    /* "uvloop/handles/handle.pyx":385
 *         return
 * 
 *     if handle.data is NULL:             # <<<<<<<<<<<<<<
 *         # This shouldn't happen. Ever.
 *         loop.call_exception_handler({
 */
  }

  /* "uvloop/handles/handle.pyx":392
 *         return
 * 
 *     h = <UVHandle>handle.data             # <<<<<<<<<<<<<<
 *     if not h._closed:
 *         h._warn_unclosed()
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_h = ((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/handle.pyx":393
 * 
 *     h = <UVHandle>handle.data
 *     if not h._closed:             # <<<<<<<<<<<<<<
 *         h._warn_unclosed()
 *         h._close()
 */
  __pyx_t_2 = ((!(__pyx_v_h->_closed != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/handle.pyx":394
 *     h = <UVHandle>handle.data
 *     if not h._closed:
 *         h._warn_unclosed()             # <<<<<<<<<<<<<<
 *         h._close()
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_h->__pyx_vtab)->_warn_unclosed(__pyx_v_h); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 394, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/handle.pyx":395
 *     if not h._closed:
 *         h._warn_unclosed()
 *         h._close()             # <<<<<<<<<<<<<<
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVHandle *)__pyx_v_h->__pyx_vtab)->_close(__pyx_v_h); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/handle.pyx":393
 * 
 *     h = <UVHandle>handle.data
 *     if not h._closed:             # <<<<<<<<<<<<<<
 *         h._warn_unclosed()
 *         h._close()
 */
  }

  /* "uvloop/handles/handle.pyx":376
 *     uv.uv_walk(loop.uvloop, __uv_walk_close_all_handles_cb, <void*>loop) # void
 * 
 * cdef void __uv_walk_close_all_handles_cb(uv.uv_handle_t* handle, void* arg) with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         Loop loop = <Loop>arg
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_walk_close_all_handles_cb", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_XDECREF((PyObject *)__pyx_v_h);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/async_.pyx":3
 * @cython.no_gc_clear
 * cdef class UVAsync(UVHandle):
 *     cdef _init(self, Loop loop, method_t callback, object ctx):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_7UVAsync__init(struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/async_.pyx":6
 *         cdef int err
 * 
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 * 
 *         self._handle = <uv.uv_handle_t*> \
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/async_.pyx":8
 *         self._start_init(loop)
 * 
 *         self._handle = <uv.uv_handle_t*> \             # <<<<<<<<<<<<<<
 *                             PyMem_RawMalloc(sizeof(uv.uv_async_t))
 *         if self._handle is NULL:
 */
  __pyx_v_self->__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_async_t))));

  /* "uvloop/handles/async_.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_async_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  __pyx_t_2 = ((__pyx_v_self->__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/async_.pyx":11
 *                             PyMem_RawMalloc(sizeof(uv.uv_async_t))
 *         if self._handle is NULL:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/async_.pyx":12
 *         if self._handle is NULL:
 *             self._abort_init()
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_async_init(self._loop.uvloop,
 */
    PyErr_NoMemory(); __PYX_ERR(11, 12, __pyx_L1_error)

    /* "uvloop/handles/async_.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_async_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  }

  /* "uvloop/handles/async_.pyx":14
 *             raise MemoryError()
 * 
 *         err = uv.uv_async_init(self._loop.uvloop,             # <<<<<<<<<<<<<<
 *                                <uv.uv_async_t*>self._handle,
 *                                __uvasync_callback)
 */
  __pyx_v_err = uv_async_init(__pyx_v_self->__pyx_base._loop->uvloop, ((uv_async_t *)__pyx_v_self->__pyx_base._handle), __pyx_f_6uvloop_4loop___uvasync_callback);

  /* "uvloop/handles/async_.pyx":17
 *                                <uv.uv_async_t*>self._handle,
 *                                __uvasync_callback)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/async_.pyx":18
 *                                __uvasync_callback)
 *         if err < 0:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 18, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/async_.pyx":19
 *         if err < 0:
 *             self._abort_init()
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         self._finish_init()
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 19, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(11, 19, __pyx_L1_error)

    /* "uvloop/handles/async_.pyx":17
 *                                <uv.uv_async_t*>self._handle,
 *                                __uvasync_callback)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  }

  /* "uvloop/handles/async_.pyx":21
 *             raise convert_error(err)
 * 
 *         self._finish_init()             # <<<<<<<<<<<<<<
 * 
 *         self.callback = callback
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/async_.pyx":23
 *         self._finish_init()
 * 
 *         self.callback = callback             # <<<<<<<<<<<<<<
 *         self.ctx = ctx
 * 
 */
  __pyx_v_self->callback = __pyx_v_callback;

  /* "uvloop/handles/async_.pyx":24
 * 
 *         self.callback = callback
 *         self.ctx = ctx             # <<<<<<<<<<<<<<
 * 
 *     cdef send(self):
 */
  __Pyx_INCREF(__pyx_v_ctx);
  __Pyx_GIVEREF(__pyx_v_ctx);
  __Pyx_GOTREF(__pyx_v_self->ctx);
  __Pyx_DECREF(__pyx_v_self->ctx);
  __pyx_v_self->ctx = __pyx_v_ctx;

  /* "uvloop/handles/async_.pyx":3
 * @cython.no_gc_clear
 * cdef class UVAsync(UVHandle):
 *     cdef _init(self, Loop loop, method_t callback, object ctx):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVAsync._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/async_.pyx":26
 *         self.ctx = ctx
 * 
 *     cdef send(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_7UVAsync_send(struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("send", 0);

  /* "uvloop/handles/async_.pyx":29
 *         cdef int err
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_async_send(<uv.uv_async_t*>self._handle)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/async_.pyx":31
 *         self._ensure_alive()
 * 
 *         err = uv.uv_async_send(<uv.uv_async_t*>self._handle)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             exc = convert_error(err)
 */
  __pyx_v_err = uv_async_send(((uv_async_t *)__pyx_v_self->__pyx_base._handle));

  /* "uvloop/handles/async_.pyx":32
 * 
 *         err = uv.uv_async_send(<uv.uv_async_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/async_.pyx":33
 *         err = uv.uv_async_send(<uv.uv_async_t*>self._handle)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 33, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/async_.pyx":34
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/async_.pyx":35
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/async_.pyx":32
 * 
 *         err = uv.uv_async_send(<uv.uv_async_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/async_.pyx":26
 *         self.ctx = ctx
 * 
 *     cdef send(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVAsync.send", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/async_.pyx":38
 * 
 *     @staticmethod
 *     cdef UVAsync new(Loop loop, method_t callback, object ctx):             # <<<<<<<<<<<<<<
 *         cdef UVAsync handle
 *         handle = UVAsync.__new__(UVAsync)
 */

static struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_f_6uvloop_4loop_7UVAsync_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx) {
  struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/async_.pyx":40
 *     cdef UVAsync new(Loop loop, method_t callback, object ctx):
 *         cdef UVAsync handle
 *         handle = UVAsync.__new__(UVAsync)             # <<<<<<<<<<<<<<
 *         handle._init(loop, callback, ctx)
 *         return handle
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UVAsync(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UVAsync), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 40, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UVAsync *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/async_.pyx":41
 *         cdef UVAsync handle
 *         handle = UVAsync.__new__(UVAsync)
 *         handle._init(loop, callback, ctx)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_handle->__pyx_base.__pyx_vtab)->_init(__pyx_v_handle, __pyx_v_loop, __pyx_v_callback, __pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/async_.pyx":42
 *         handle = UVAsync.__new__(UVAsync)
 *         handle._init(loop, callback, ctx)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/async_.pyx":38
 * 
 *     @staticmethod
 *     cdef UVAsync new(Loop loop, method_t callback, object ctx):             # <<<<<<<<<<<<<<
 *         cdef UVAsync handle
 *         handle = UVAsync.__new__(UVAsync)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVAsync.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_7UVAsync_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_7UVAsync___reduce_cython__[] = "UVAsync.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_7UVAsync_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_7UVAsync___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVAsync *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_7UVAsync___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__149, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVAsync.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_7UVAsync_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_7UVAsync_2__setstate_cython__[] = "UVAsync.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_7UVAsync_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_7UVAsync_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVAsync *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_7UVAsync_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__150, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVAsync.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/async_.pyx":45
 * 
 * 
 * cdef void __uvasync_callback(uv.uv_async_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVAsync callback") == 0:
 *         return
 */

static void __pyx_f_6uvloop_4loop___uvasync_callback(uv_async_t *__pyx_v_handle) {
  struct __pyx_obj_6uvloop_4loop_UVAsync *__pyx_v_async_ = 0;
  __pyx_t_6uvloop_4loop_method_t __pyx_v_cb;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __pyx_t_6uvloop_4loop_method_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  char const *__pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uvasync_callback", 0);

  /* "uvloop/handles/async_.pyx":46
 * 
 * cdef void __uvasync_callback(uv.uv_async_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVAsync callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_handle), ((char const *)"UVAsync callback")) == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/async_.pyx":47
 * cdef void __uvasync_callback(uv.uv_async_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVAsync callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/async_.pyx":46
 * 
 * cdef void __uvasync_callback(uv.uv_async_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVAsync callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/handles/async_.pyx":50
 * 
 *     cdef:
 *         UVAsync async_ = <UVAsync> handle.data             # <<<<<<<<<<<<<<
 *         method_t cb = async_.callback
 *     try:
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_async_ = ((struct __pyx_obj_6uvloop_4loop_UVAsync *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/async_.pyx":51
 *     cdef:
 *         UVAsync async_ = <UVAsync> handle.data
 *         method_t cb = async_.callback             # <<<<<<<<<<<<<<
 *     try:
 *         cb(async_.ctx)
 */
  __pyx_t_3 = __pyx_v_async_->callback;
  __pyx_v_cb = __pyx_t_3;

  /* "uvloop/handles/async_.pyx":52
 *         UVAsync async_ = <UVAsync> handle.data
 *         method_t cb = async_.callback
 *     try:             # <<<<<<<<<<<<<<
 *         cb(async_.ctx)
 *     except BaseException as ex:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/handles/async_.pyx":53
 *         method_t cb = async_.callback
 *     try:
 *         cb(async_.ctx)             # <<<<<<<<<<<<<<
 *     except BaseException as ex:
 *         async_._error(ex, False)
 */
      __pyx_t_2 = __pyx_v_async_->ctx;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = __pyx_v_cb(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(11, 53, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/handles/async_.pyx":52
 *         UVAsync async_ = <UVAsync> handle.data
 *         method_t cb = async_.callback
 *     try:             # <<<<<<<<<<<<<<
 *         cb(async_.ctx)
 *     except BaseException as ex:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/handles/async_.pyx":54
 *     try:
 *         cb(async_.ctx)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         async_._error(ex, False)
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("uvloop.loop.__uvasync_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_2, &__pyx_t_9) < 0) __PYX_ERR(11, 54, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_ex = __pyx_t_2;
      /*try:*/ {

        /* "uvloop/handles/async_.pyx":55
 *         cb(async_.ctx)
 *     except BaseException as ex:
 *         async_._error(ex, False)             # <<<<<<<<<<<<<<
 */
        __pyx_t_10 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVAsync *)__pyx_v_async_->__pyx_base.__pyx_vtab)->__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_async_), __pyx_v_ex, Py_False); if (unlikely(!__pyx_t_10)) __PYX_ERR(11, 55, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }

      /* "uvloop/handles/async_.pyx":54
 *     try:
 *         cb(async_.ctx)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         async_._error(ex, False)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex);
          __pyx_v_ex = NULL;
          goto __pyx_L16;
        }
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __pyx_t_8 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_12 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          }
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ErrRestore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_12;
          goto __pyx_L6_except_error;
        }
        __pyx_L16:;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/handles/async_.pyx":52
 *         UVAsync async_ = <UVAsync> handle.data
 *         method_t cb = async_.callback
 *     try:             # <<<<<<<<<<<<<<
 *         cb(async_.ctx)
 *     except BaseException as ex:
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/async_.pyx":45
 * 
 * 
 * cdef void __uvasync_callback(uv.uv_async_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVAsync callback") == 0:
 *         return
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_WriteUnraisable("uvloop.loop.__uvasync_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_async_);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/idle.pyx":3
 * @cython.no_gc_clear
 * cdef class UVIdle(UVHandle):
 *     cdef _init(self, Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVIdle__init(struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/idle.pyx":6
 *         cdef int err
 * 
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 * 
 *         self._handle = <uv.uv_handle_t*> \
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/idle.pyx":8
 *         self._start_init(loop)
 * 
 *         self._handle = <uv.uv_handle_t*> \             # <<<<<<<<<<<<<<
 *                             PyMem_RawMalloc(sizeof(uv.uv_idle_t))
 *         if self._handle is NULL:
 */
  __pyx_v_self->__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_idle_t))));

  /* "uvloop/handles/idle.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_idle_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  __pyx_t_2 = ((__pyx_v_self->__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/idle.pyx":11
 *                             PyMem_RawMalloc(sizeof(uv.uv_idle_t))
 *         if self._handle is NULL:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/idle.pyx":12
 *         if self._handle is NULL:
 *             self._abort_init()
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_idle_init(self._loop.uvloop, <uv.uv_idle_t*>self._handle)
 */
    PyErr_NoMemory(); __PYX_ERR(12, 12, __pyx_L1_error)

    /* "uvloop/handles/idle.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_idle_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  }

  /* "uvloop/handles/idle.pyx":14
 *             raise MemoryError()
 * 
 *         err = uv.uv_idle_init(self._loop.uvloop, <uv.uv_idle_t*>self._handle)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             self._abort_init()
 */
  __pyx_v_err = uv_idle_init(__pyx_v_self->__pyx_base._loop->uvloop, ((uv_idle_t *)__pyx_v_self->__pyx_base._handle));

  /* "uvloop/handles/idle.pyx":15
 * 
 *         err = uv.uv_idle_init(self._loop.uvloop, <uv.uv_idle_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/idle.pyx":16
 *         err = uv.uv_idle_init(self._loop.uvloop, <uv.uv_idle_t*>self._handle)
 *         if err < 0:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 16, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/idle.pyx":17
 *         if err < 0:
 *             self._abort_init()
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         self._finish_init()
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(12, 17, __pyx_L1_error)

    /* "uvloop/handles/idle.pyx":15
 * 
 *         err = uv.uv_idle_init(self._loop.uvloop, <uv.uv_idle_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  }

  /* "uvloop/handles/idle.pyx":19
 *             raise convert_error(err)
 * 
 *         self._finish_init()             # <<<<<<<<<<<<<<
 * 
 *         self.h = h
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/idle.pyx":21
 *         self._finish_init()
 * 
 *         self.h = h             # <<<<<<<<<<<<<<
 *         self.running = 0
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_h));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_h));
  __Pyx_GOTREF(__pyx_v_self->h);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->h));
  __pyx_v_self->h = __pyx_v_h;

  /* "uvloop/handles/idle.pyx":22
 * 
 *         self.h = h
 *         self.running = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef inline stop(self):
 */
  __pyx_v_self->running = 0;

  /* "uvloop/handles/idle.pyx":3
 * @cython.no_gc_clear
 * cdef class UVIdle(UVHandle):
 *     cdef _init(self, Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVIdle._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/idle.pyx":24
 *         self.running = 0
 * 
 *     cdef inline stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVIdle_stop(struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("stop", 0);

  /* "uvloop/handles/idle.pyx":27
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             return
 */
  __pyx_t_1 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/idle.pyx":28
 * 
 *         if not self._is_alive():
 *             self.running = 0             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_v_self->running = 0;

    /* "uvloop/handles/idle.pyx":29
 *         if not self._is_alive():
 *             self.running = 0
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self.running == 1:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/idle.pyx":27
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             return
 */
  }

  /* "uvloop/handles/idle.pyx":31
 *             return
 * 
 *         if self.running == 1:             # <<<<<<<<<<<<<<
 *             err = uv.uv_idle_stop(<uv.uv_idle_t*>self._handle)
 *             self.running = 0
 */
  __pyx_t_1 = ((__pyx_v_self->running == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/idle.pyx":32
 * 
 *         if self.running == 1:
 *             err = uv.uv_idle_stop(<uv.uv_idle_t*>self._handle)             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             if err < 0:
 */
    __pyx_v_err = uv_idle_stop(((uv_idle_t *)__pyx_v_self->__pyx_base._handle));

    /* "uvloop/handles/idle.pyx":33
 *         if self.running == 1:
 *             err = uv.uv_idle_stop(<uv.uv_idle_t*>self._handle)
 *             self.running = 0             # <<<<<<<<<<<<<<
 *             if err < 0:
 *                 exc = convert_error(err)
 */
    __pyx_v_self->running = 0;

    /* "uvloop/handles/idle.pyx":34
 *             err = uv.uv_idle_stop(<uv.uv_idle_t*>self._handle)
 *             self.running = 0
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    __pyx_t_1 = ((__pyx_v_err < 0) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/idle.pyx":35
 *             self.running = 0
 *             if err < 0:
 *                 exc = convert_error(err)             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, True)
 *                 return
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/handles/idle.pyx":36
 *             if err < 0:
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                 return
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 36, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/idle.pyx":37
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *     cdef inline start(self):
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/handles/idle.pyx":34
 *             err = uv.uv_idle_stop(<uv.uv_idle_t*>self._handle)
 *             self.running = 0
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    }

    /* "uvloop/handles/idle.pyx":31
 *             return
 * 
 *         if self.running == 1:             # <<<<<<<<<<<<<<
 *             err = uv.uv_idle_stop(<uv.uv_idle_t*>self._handle)
 *             self.running = 0
 */
  }

  /* "uvloop/handles/idle.pyx":24
 *         self.running = 0
 * 
 *     cdef inline stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVIdle.stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/idle.pyx":39
 *                 return
 * 
 *     cdef inline start(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVIdle_start(struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("start", 0);

  /* "uvloop/handles/idle.pyx":42
 *         cdef int err
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if self.running == 0:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/idle.pyx":44
 *         self._ensure_alive()
 * 
 *         if self.running == 0:             # <<<<<<<<<<<<<<
 *             err = uv.uv_idle_start(<uv.uv_idle_t*>self._handle,
 *                                    cb_idle_callback)
 */
  __pyx_t_2 = ((__pyx_v_self->running == 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/idle.pyx":45
 * 
 *         if self.running == 0:
 *             err = uv.uv_idle_start(<uv.uv_idle_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                    cb_idle_callback)
 *             if err < 0:
 */
    __pyx_v_err = uv_idle_start(((uv_idle_t *)__pyx_v_self->__pyx_base._handle), __pyx_f_6uvloop_4loop_cb_idle_callback);

    /* "uvloop/handles/idle.pyx":47
 *             err = uv.uv_idle_start(<uv.uv_idle_t*>self._handle,
 *                                    cb_idle_callback)
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    __pyx_t_2 = ((__pyx_v_err < 0) != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/idle.pyx":48
 *                                    cb_idle_callback)
 *             if err < 0:
 *                 exc = convert_error(err)             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, True)
 *                 return
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 48, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_exc = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "uvloop/handles/idle.pyx":49
 *             if err < 0:
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                 return
 *             self.running = 1
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 49, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/idle.pyx":50
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 *                 return             # <<<<<<<<<<<<<<
 *             self.running = 1
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/handles/idle.pyx":47
 *             err = uv.uv_idle_start(<uv.uv_idle_t*>self._handle,
 *                                    cb_idle_callback)
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    }

    /* "uvloop/handles/idle.pyx":51
 *                 self._fatal_error(exc, True)
 *                 return
 *             self.running = 1             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
    __pyx_v_self->running = 1;

    /* "uvloop/handles/idle.pyx":44
 *         self._ensure_alive()
 * 
 *         if self.running == 0:             # <<<<<<<<<<<<<<
 *             err = uv.uv_idle_start(<uv.uv_idle_t*>self._handle,
 *                                    cb_idle_callback)
 */
  }

  /* "uvloop/handles/idle.pyx":39
 *                 return
 * 
 *     cdef inline start(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVIdle.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/idle.pyx":54
 * 
 *     @staticmethod
 *     cdef UVIdle new(Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef UVIdle handle
 *         handle = UVIdle.__new__(UVIdle)
 */

static struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_f_6uvloop_4loop_6UVIdle_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h) {
  struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/idle.pyx":56
 *     cdef UVIdle new(Loop loop, Handle h):
 *         cdef UVIdle handle
 *         handle = UVIdle.__new__(UVIdle)             # <<<<<<<<<<<<<<
 *         handle._init(loop, h)
 *         return handle
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UVIdle(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UVIdle), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 56, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UVIdle *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/idle.pyx":57
 *         cdef UVIdle handle
 *         handle = UVIdle.__new__(UVIdle)
 *         handle._init(loop, h)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_handle->__pyx_base.__pyx_vtab)->_init(__pyx_v_handle, __pyx_v_loop, __pyx_v_h); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/idle.pyx":58
 *         handle = UVIdle.__new__(UVIdle)
 *         handle._init(loop, h)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/idle.pyx":54
 * 
 *     @staticmethod
 *     cdef UVIdle new(Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef UVIdle handle
 *         handle = UVIdle.__new__(UVIdle)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVIdle.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6UVIdle_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6UVIdle___reduce_cython__[] = "UVIdle.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6UVIdle_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6UVIdle___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVIdle *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6UVIdle___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__151, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVIdle.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6UVIdle_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_6UVIdle_2__setstate_cython__[] = "UVIdle.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_6UVIdle_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6UVIdle_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVIdle *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6UVIdle_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__152, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVIdle.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/idle.pyx":61
 * 
 * 
 * cdef void cb_idle_callback(uv.uv_idle_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVIdle callback") == 0:
 *         return
 */

static void __pyx_f_6uvloop_4loop_cb_idle_callback(uv_idle_t *__pyx_v_handle) {
  struct __pyx_obj_6uvloop_4loop_UVIdle *__pyx_v_idle = 0;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h = 0;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("cb_idle_callback", 0);

  /* "uvloop/handles/idle.pyx":62
 * 
 * cdef void cb_idle_callback(uv.uv_idle_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVIdle callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_handle), ((char const *)"UVIdle callback")) == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/idle.pyx":63
 * cdef void cb_idle_callback(uv.uv_idle_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVIdle callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/idle.pyx":62
 * 
 * cdef void cb_idle_callback(uv.uv_idle_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVIdle callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/handles/idle.pyx":66
 * 
 *     cdef:
 *         UVIdle idle = <UVIdle> handle.data             # <<<<<<<<<<<<<<
 *         Handle h = idle.h
 *     try:
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_idle = ((struct __pyx_obj_6uvloop_4loop_UVIdle *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/idle.pyx":67
 *     cdef:
 *         UVIdle idle = <UVIdle> handle.data
 *         Handle h = idle.h             # <<<<<<<<<<<<<<
 *     try:
 *         h._run()
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_idle->h);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_h = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/idle.pyx":68
 *         UVIdle idle = <UVIdle> handle.data
 *         Handle h = idle.h
 *     try:             # <<<<<<<<<<<<<<
 *         h._run()
 *     except BaseException as ex:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "uvloop/handles/idle.pyx":69
 *         Handle h = idle.h
 *     try:
 *         h._run()             # <<<<<<<<<<<<<<
 *     except BaseException as ex:
 *         idle._error(ex, False)
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_h); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 69, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/idle.pyx":68
 *         UVIdle idle = <UVIdle> handle.data
 *         Handle h = idle.h
 *     try:             # <<<<<<<<<<<<<<
 *         h._run()
 *     except BaseException as ex:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/idle.pyx":70
 *     try:
 *         h._run()
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         idle._error(ex, False)
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.cb_idle_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(12, 70, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_ex = __pyx_t_7;
      /*try:*/ {

        /* "uvloop/handles/idle.pyx":71
 *         h._run()
 *     except BaseException as ex:
 *         idle._error(ex, False)             # <<<<<<<<<<<<<<
 */
        __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVIdle *)__pyx_v_idle->__pyx_base.__pyx_vtab)->__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_idle), __pyx_v_ex, Py_False); if (unlikely(!__pyx_t_9)) __PYX_ERR(12, 71, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }

      /* "uvloop/handles/idle.pyx":70
 *     try:
 *         h._run()
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         idle._error(ex, False)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex);
          __pyx_v_ex = NULL;
          goto __pyx_L16;
        }
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __pyx_t_6 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          }
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
          __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
          goto __pyx_L6_except_error;
        }
        __pyx_L16:;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/handles/idle.pyx":68
 *         UVIdle idle = <UVIdle> handle.data
 *         Handle h = idle.h
 *     try:             # <<<<<<<<<<<<<<
 *         h._run()
 *     except BaseException as ex:
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/idle.pyx":61
 * 
 * 
 * cdef void cb_idle_callback(uv.uv_idle_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVIdle callback") == 0:
 *         return
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.cb_idle_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_idle);
  __Pyx_XDECREF((PyObject *)__pyx_v_h);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/check.pyx":3
 * @cython.no_gc_clear
 * cdef class UVCheck(UVHandle):
 *     cdef _init(self, Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_7UVCheck__init(struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/check.pyx":6
 *         cdef int err
 * 
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 * 
 *         self._handle = <uv.uv_handle_t*> \
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/check.pyx":8
 *         self._start_init(loop)
 * 
 *         self._handle = <uv.uv_handle_t*> \             # <<<<<<<<<<<<<<
 *                             PyMem_RawMalloc(sizeof(uv.uv_check_t))
 *         if self._handle is NULL:
 */
  __pyx_v_self->__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_check_t))));

  /* "uvloop/handles/check.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_check_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  __pyx_t_2 = ((__pyx_v_self->__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/check.pyx":11
 *                             PyMem_RawMalloc(sizeof(uv.uv_check_t))
 *         if self._handle is NULL:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/check.pyx":12
 *         if self._handle is NULL:
 *             self._abort_init()
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_check_init(self._loop.uvloop, <uv.uv_check_t*>self._handle)
 */
    PyErr_NoMemory(); __PYX_ERR(13, 12, __pyx_L1_error)

    /* "uvloop/handles/check.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_check_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  }

  /* "uvloop/handles/check.pyx":14
 *             raise MemoryError()
 * 
 *         err = uv.uv_check_init(self._loop.uvloop, <uv.uv_check_t*>self._handle)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             self._abort_init()
 */
  __pyx_v_err = uv_check_init(__pyx_v_self->__pyx_base._loop->uvloop, ((uv_check_t *)__pyx_v_self->__pyx_base._handle));

  /* "uvloop/handles/check.pyx":15
 * 
 *         err = uv.uv_check_init(self._loop.uvloop, <uv.uv_check_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/check.pyx":16
 *         err = uv.uv_check_init(self._loop.uvloop, <uv.uv_check_t*>self._handle)
 *         if err < 0:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 16, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/check.pyx":17
 *         if err < 0:
 *             self._abort_init()
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         self._finish_init()
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(13, 17, __pyx_L1_error)

    /* "uvloop/handles/check.pyx":15
 * 
 *         err = uv.uv_check_init(self._loop.uvloop, <uv.uv_check_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  }

  /* "uvloop/handles/check.pyx":19
 *             raise convert_error(err)
 * 
 *         self._finish_init()             # <<<<<<<<<<<<<<
 * 
 *         self.h = h
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/check.pyx":21
 *         self._finish_init()
 * 
 *         self.h = h             # <<<<<<<<<<<<<<
 *         self.running = 0
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_h));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_h));
  __Pyx_GOTREF(__pyx_v_self->h);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->h));
  __pyx_v_self->h = __pyx_v_h;

  /* "uvloop/handles/check.pyx":22
 * 
 *         self.h = h
 *         self.running = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef inline stop(self):
 */
  __pyx_v_self->running = 0;

  /* "uvloop/handles/check.pyx":3
 * @cython.no_gc_clear
 * cdef class UVCheck(UVHandle):
 *     cdef _init(self, Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVCheck._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/check.pyx":24
 *         self.running = 0
 * 
 *     cdef inline stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_7UVCheck_stop(struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("stop", 0);

  /* "uvloop/handles/check.pyx":27
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             return
 */
  __pyx_t_1 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/check.pyx":28
 * 
 *         if not self._is_alive():
 *             self.running = 0             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_v_self->running = 0;

    /* "uvloop/handles/check.pyx":29
 *         if not self._is_alive():
 *             self.running = 0
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self.running == 1:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/check.pyx":27
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             return
 */
  }

  /* "uvloop/handles/check.pyx":31
 *             return
 * 
 *         if self.running == 1:             # <<<<<<<<<<<<<<
 *             err = uv.uv_check_stop(<uv.uv_check_t*>self._handle)
 *             self.running = 0
 */
  __pyx_t_1 = ((__pyx_v_self->running == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/check.pyx":32
 * 
 *         if self.running == 1:
 *             err = uv.uv_check_stop(<uv.uv_check_t*>self._handle)             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             if err < 0:
 */
    __pyx_v_err = uv_check_stop(((uv_check_t *)__pyx_v_self->__pyx_base._handle));

    /* "uvloop/handles/check.pyx":33
 *         if self.running == 1:
 *             err = uv.uv_check_stop(<uv.uv_check_t*>self._handle)
 *             self.running = 0             # <<<<<<<<<<<<<<
 *             if err < 0:
 *                 exc = convert_error(err)
 */
    __pyx_v_self->running = 0;

    /* "uvloop/handles/check.pyx":34
 *             err = uv.uv_check_stop(<uv.uv_check_t*>self._handle)
 *             self.running = 0
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    __pyx_t_1 = ((__pyx_v_err < 0) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/check.pyx":35
 *             self.running = 0
 *             if err < 0:
 *                 exc = convert_error(err)             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, True)
 *                 return
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(13, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/handles/check.pyx":36
 *             if err < 0:
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                 return
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(13, 36, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/check.pyx":37
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *     cdef inline start(self):
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/handles/check.pyx":34
 *             err = uv.uv_check_stop(<uv.uv_check_t*>self._handle)
 *             self.running = 0
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    }

    /* "uvloop/handles/check.pyx":31
 *             return
 * 
 *         if self.running == 1:             # <<<<<<<<<<<<<<
 *             err = uv.uv_check_stop(<uv.uv_check_t*>self._handle)
 *             self.running = 0
 */
  }

  /* "uvloop/handles/check.pyx":24
 *         self.running = 0
 * 
 *     cdef inline stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVCheck.stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/check.pyx":39
 *                 return
 * 
 *     cdef inline start(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_7UVCheck_start(struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("start", 0);

  /* "uvloop/handles/check.pyx":42
 *         cdef int err
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if self.running == 0:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/check.pyx":44
 *         self._ensure_alive()
 * 
 *         if self.running == 0:             # <<<<<<<<<<<<<<
 *             err = uv.uv_check_start(<uv.uv_check_t*>self._handle,
 *                                     cb_check_callback)
 */
  __pyx_t_2 = ((__pyx_v_self->running == 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/check.pyx":45
 * 
 *         if self.running == 0:
 *             err = uv.uv_check_start(<uv.uv_check_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                     cb_check_callback)
 *             if err < 0:
 */
    __pyx_v_err = uv_check_start(((uv_check_t *)__pyx_v_self->__pyx_base._handle), __pyx_f_6uvloop_4loop_cb_check_callback);

    /* "uvloop/handles/check.pyx":47
 *             err = uv.uv_check_start(<uv.uv_check_t*>self._handle,
 *                                     cb_check_callback)
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    __pyx_t_2 = ((__pyx_v_err < 0) != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/check.pyx":48
 *                                     cb_check_callback)
 *             if err < 0:
 *                 exc = convert_error(err)             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, True)
 *                 return
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 48, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_exc = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "uvloop/handles/check.pyx":49
 *             if err < 0:
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                 return
 *             self.running = 1
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 49, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/check.pyx":50
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 *                 return             # <<<<<<<<<<<<<<
 *             self.running = 1
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/handles/check.pyx":47
 *             err = uv.uv_check_start(<uv.uv_check_t*>self._handle,
 *                                     cb_check_callback)
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    }

    /* "uvloop/handles/check.pyx":51
 *                 self._fatal_error(exc, True)
 *                 return
 *             self.running = 1             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
    __pyx_v_self->running = 1;

    /* "uvloop/handles/check.pyx":44
 *         self._ensure_alive()
 * 
 *         if self.running == 0:             # <<<<<<<<<<<<<<
 *             err = uv.uv_check_start(<uv.uv_check_t*>self._handle,
 *                                     cb_check_callback)
 */
  }

  /* "uvloop/handles/check.pyx":39
 *                 return
 * 
 *     cdef inline start(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVCheck.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/check.pyx":54
 * 
 *     @staticmethod
 *     cdef UVCheck new(Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef UVCheck handle
 *         handle = UVCheck.__new__(UVCheck)
 */

static struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_f_6uvloop_4loop_7UVCheck_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h) {
  struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/check.pyx":56
 *     cdef UVCheck new(Loop loop, Handle h):
 *         cdef UVCheck handle
 *         handle = UVCheck.__new__(UVCheck)             # <<<<<<<<<<<<<<
 *         handle._init(loop, h)
 *         return handle
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UVCheck(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UVCheck), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 56, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UVCheck *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/check.pyx":57
 *         cdef UVCheck handle
 *         handle = UVCheck.__new__(UVCheck)
 *         handle._init(loop, h)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_handle->__pyx_base.__pyx_vtab)->_init(__pyx_v_handle, __pyx_v_loop, __pyx_v_h); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/check.pyx":58
 *         handle = UVCheck.__new__(UVCheck)
 *         handle._init(loop, h)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/check.pyx":54
 * 
 *     @staticmethod
 *     cdef UVCheck new(Loop loop, Handle h):             # <<<<<<<<<<<<<<
 *         cdef UVCheck handle
 *         handle = UVCheck.__new__(UVCheck)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVCheck.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_7UVCheck_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_7UVCheck___reduce_cython__[] = "UVCheck.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_7UVCheck_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_7UVCheck___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVCheck *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_7UVCheck___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__153, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVCheck.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_7UVCheck_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_7UVCheck_2__setstate_cython__[] = "UVCheck.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_7UVCheck_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_7UVCheck_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVCheck *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_7UVCheck_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__154, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVCheck.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/check.pyx":61
 * 
 * 
 * cdef void cb_check_callback(uv.uv_check_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVCheck callback") == 0:
 *         return
 */

static void __pyx_f_6uvloop_4loop_cb_check_callback(uv_check_t *__pyx_v_handle) {
  struct __pyx_obj_6uvloop_4loop_UVCheck *__pyx_v_check = 0;
  struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_h = 0;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("cb_check_callback", 0);

  /* "uvloop/handles/check.pyx":62
 * 
 * cdef void cb_check_callback(uv.uv_check_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVCheck callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_handle), ((char const *)"UVCheck callback")) == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/check.pyx":63
 * cdef void cb_check_callback(uv.uv_check_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVCheck callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/check.pyx":62
 * 
 * cdef void cb_check_callback(uv.uv_check_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVCheck callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/handles/check.pyx":66
 * 
 *     cdef:
 *         UVCheck check = <UVCheck> handle.data             # <<<<<<<<<<<<<<
 *         Handle h = check.h
 *     try:
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_check = ((struct __pyx_obj_6uvloop_4loop_UVCheck *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/check.pyx":67
 *     cdef:
 *         UVCheck check = <UVCheck> handle.data
 *         Handle h = check.h             # <<<<<<<<<<<<<<
 *     try:
 *         h._run()
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_check->h);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_h = ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/check.pyx":68
 *         UVCheck check = <UVCheck> handle.data
 *         Handle h = check.h
 *     try:             # <<<<<<<<<<<<<<
 *         h._run()
 *     except BaseException as ex:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "uvloop/handles/check.pyx":69
 *         Handle h = check.h
 *     try:
 *         h._run()             # <<<<<<<<<<<<<<
 *     except BaseException as ex:
 *         check._error(ex, False)
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_h); if (unlikely(!__pyx_t_2)) __PYX_ERR(13, 69, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/check.pyx":68
 *         UVCheck check = <UVCheck> handle.data
 *         Handle h = check.h
 *     try:             # <<<<<<<<<<<<<<
 *         h._run()
 *     except BaseException as ex:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/check.pyx":70
 *     try:
 *         h._run()
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         check._error(ex, False)
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.cb_check_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(13, 70, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_ex = __pyx_t_7;
      /*try:*/ {

        /* "uvloop/handles/check.pyx":71
 *         h._run()
 *     except BaseException as ex:
 *         check._error(ex, False)             # <<<<<<<<<<<<<<
 */
        __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVCheck *)__pyx_v_check->__pyx_base.__pyx_vtab)->__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_check), __pyx_v_ex, Py_False); if (unlikely(!__pyx_t_9)) __PYX_ERR(13, 71, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }

      /* "uvloop/handles/check.pyx":70
 *     try:
 *         h._run()
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         check._error(ex, False)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex);
          __pyx_v_ex = NULL;
          goto __pyx_L16;
        }
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __pyx_t_6 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          }
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
          __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
          goto __pyx_L6_except_error;
        }
        __pyx_L16:;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/handles/check.pyx":68
 *         UVCheck check = <UVCheck> handle.data
 *         Handle h = check.h
 *     try:             # <<<<<<<<<<<<<<
 *         h._run()
 *     except BaseException as ex:
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/check.pyx":61
 * 
 * 
 * cdef void cb_check_callback(uv.uv_check_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVCheck callback") == 0:
 *         return
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.cb_check_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_check);
  __Pyx_XDECREF((PyObject *)__pyx_v_h);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/timer.pyx":3
 * @cython.no_gc_clear
 * cdef class UVTimer(UVHandle):
 *     cdef _init(self, Loop loop, method_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                uint64_t timeout):
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_7UVTimer__init(struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx, uint64_t __pyx_v_timeout) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/timer.pyx":8
 *         cdef int err
 * 
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 * 
 *         self._handle = <uv.uv_handle_t*> PyMem_RawMalloc(sizeof(uv.uv_timer_t))
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/timer.pyx":10
 *         self._start_init(loop)
 * 
 *         self._handle = <uv.uv_handle_t*> PyMem_RawMalloc(sizeof(uv.uv_timer_t))             # <<<<<<<<<<<<<<
 *         if self._handle is NULL:
 *             self._abort_init()
 */
  __pyx_v_self->__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_timer_t))));

  /* "uvloop/handles/timer.pyx":11
 * 
 *         self._handle = <uv.uv_handle_t*> PyMem_RawMalloc(sizeof(uv.uv_timer_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  __pyx_t_2 = ((__pyx_v_self->__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/timer.pyx":12
 *         self._handle = <uv.uv_handle_t*> PyMem_RawMalloc(sizeof(uv.uv_timer_t))
 *         if self._handle is NULL:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/timer.pyx":13
 *         if self._handle is NULL:
 *             self._abort_init()
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_timer_init(self._loop.uvloop, <uv.uv_timer_t*>self._handle)
 */
    PyErr_NoMemory(); __PYX_ERR(14, 13, __pyx_L1_error)

    /* "uvloop/handles/timer.pyx":11
 * 
 *         self._handle = <uv.uv_handle_t*> PyMem_RawMalloc(sizeof(uv.uv_timer_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  }

  /* "uvloop/handles/timer.pyx":15
 *             raise MemoryError()
 * 
 *         err = uv.uv_timer_init(self._loop.uvloop, <uv.uv_timer_t*>self._handle)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             self._abort_init()
 */
  __pyx_v_err = uv_timer_init(__pyx_v_self->__pyx_base._loop->uvloop, ((uv_timer_t *)__pyx_v_self->__pyx_base._handle));

  /* "uvloop/handles/timer.pyx":16
 * 
 *         err = uv.uv_timer_init(self._loop.uvloop, <uv.uv_timer_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/timer.pyx":17
 *         err = uv.uv_timer_init(self._loop.uvloop, <uv.uv_timer_t*>self._handle)
 *         if err < 0:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/timer.pyx":18
 *         if err < 0:
 *             self._abort_init()
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         self._finish_init()
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 18, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(14, 18, __pyx_L1_error)

    /* "uvloop/handles/timer.pyx":16
 * 
 *         err = uv.uv_timer_init(self._loop.uvloop, <uv.uv_timer_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  }

  /* "uvloop/handles/timer.pyx":20
 *             raise convert_error(err)
 * 
 *         self._finish_init()             # <<<<<<<<<<<<<<
 * 
 *         self.callback = callback
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/timer.pyx":22
 *         self._finish_init()
 * 
 *         self.callback = callback             # <<<<<<<<<<<<<<
 *         self.ctx = ctx
 *         self.running = 0
 */
  __pyx_v_self->callback = __pyx_v_callback;

  /* "uvloop/handles/timer.pyx":23
 * 
 *         self.callback = callback
 *         self.ctx = ctx             # <<<<<<<<<<<<<<
 *         self.running = 0
 *         self.timeout = timeout
 */
  __Pyx_INCREF(__pyx_v_ctx);
  __Pyx_GIVEREF(__pyx_v_ctx);
  __Pyx_GOTREF(__pyx_v_self->ctx);
  __Pyx_DECREF(__pyx_v_self->ctx);
  __pyx_v_self->ctx = __pyx_v_ctx;

  /* "uvloop/handles/timer.pyx":24
 *         self.callback = callback
 *         self.ctx = ctx
 *         self.running = 0             # <<<<<<<<<<<<<<
 *         self.timeout = timeout
 * 
 */
  __pyx_v_self->running = 0;

  /* "uvloop/handles/timer.pyx":25
 *         self.ctx = ctx
 *         self.running = 0
 *         self.timeout = timeout             # <<<<<<<<<<<<<<
 * 
 *     cdef stop(self):
 */
  __pyx_v_self->timeout = __pyx_v_timeout;

  /* "uvloop/handles/timer.pyx":3
 * @cython.no_gc_clear
 * cdef class UVTimer(UVHandle):
 *     cdef _init(self, Loop loop, method_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                uint64_t timeout):
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVTimer._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/timer.pyx":27
 *         self.timeout = timeout
 * 
 *     cdef stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_7UVTimer_stop(struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("stop", 0);

  /* "uvloop/handles/timer.pyx":30
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             return
 */
  __pyx_t_1 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/timer.pyx":31
 * 
 *         if not self._is_alive():
 *             self.running = 0             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_v_self->running = 0;

    /* "uvloop/handles/timer.pyx":32
 *         if not self._is_alive():
 *             self.running = 0
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self.running == 1:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/timer.pyx":30
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             return
 */
  }

  /* "uvloop/handles/timer.pyx":34
 *             return
 * 
 *         if self.running == 1:             # <<<<<<<<<<<<<<
 *             err = uv.uv_timer_stop(<uv.uv_timer_t*>self._handle)
 *             self.running = 0
 */
  __pyx_t_1 = ((__pyx_v_self->running == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/timer.pyx":35
 * 
 *         if self.running == 1:
 *             err = uv.uv_timer_stop(<uv.uv_timer_t*>self._handle)             # <<<<<<<<<<<<<<
 *             self.running = 0
 *             if err < 0:
 */
    __pyx_v_err = uv_timer_stop(((uv_timer_t *)__pyx_v_self->__pyx_base._handle));

    /* "uvloop/handles/timer.pyx":36
 *         if self.running == 1:
 *             err = uv.uv_timer_stop(<uv.uv_timer_t*>self._handle)
 *             self.running = 0             # <<<<<<<<<<<<<<
 *             if err < 0:
 *                 exc = convert_error(err)
 */
    __pyx_v_self->running = 0;

    /* "uvloop/handles/timer.pyx":37
 *             err = uv.uv_timer_stop(<uv.uv_timer_t*>self._handle)
 *             self.running = 0
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    __pyx_t_1 = ((__pyx_v_err < 0) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/timer.pyx":38
 *             self.running = 0
 *             if err < 0:
 *                 exc = convert_error(err)             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, True)
 *                 return
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(14, 38, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/handles/timer.pyx":39
 *             if err < 0:
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                 return
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(14, 39, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/timer.pyx":40
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *     cdef start(self):
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/handles/timer.pyx":37
 *             err = uv.uv_timer_stop(<uv.uv_timer_t*>self._handle)
 *             self.running = 0
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    }

    /* "uvloop/handles/timer.pyx":34
 *             return
 * 
 *         if self.running == 1:             # <<<<<<<<<<<<<<
 *             err = uv.uv_timer_stop(<uv.uv_timer_t*>self._handle)
 *             self.running = 0
 */
  }

  /* "uvloop/handles/timer.pyx":27
 *         self.timeout = timeout
 * 
 *     cdef stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVTimer.stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/timer.pyx":42
 *                 return
 * 
 *     cdef start(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_7UVTimer_start(struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("start", 0);

  /* "uvloop/handles/timer.pyx":45
 *         cdef int err
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if self.running == 0:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/timer.pyx":47
 *         self._ensure_alive()
 * 
 *         if self.running == 0:             # <<<<<<<<<<<<<<
 *             # Update libuv internal time.
 *             uv.uv_update_time(self._loop.uvloop)  # void
 */
  __pyx_t_2 = ((__pyx_v_self->running == 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/timer.pyx":49
 *         if self.running == 0:
 *             # Update libuv internal time.
 *             uv.uv_update_time(self._loop.uvloop)  # void             # <<<<<<<<<<<<<<
 * 
 *             err = uv.uv_timer_start(<uv.uv_timer_t*>self._handle,
 */
    uv_update_time(__pyx_v_self->__pyx_base._loop->uvloop);

    /* "uvloop/handles/timer.pyx":51
 *             uv.uv_update_time(self._loop.uvloop)  # void
 * 
 *             err = uv.uv_timer_start(<uv.uv_timer_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                     __uvtimer_callback,
 *                                     self.timeout, 0)
 */
    __pyx_v_err = uv_timer_start(((uv_timer_t *)__pyx_v_self->__pyx_base._handle), __pyx_f_6uvloop_4loop___uvtimer_callback, __pyx_v_self->timeout, 0);

    /* "uvloop/handles/timer.pyx":54
 *                                     __uvtimer_callback,
 *                                     self.timeout, 0)
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    __pyx_t_2 = ((__pyx_v_err < 0) != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/timer.pyx":55
 *                                     self.timeout, 0)
 *             if err < 0:
 *                 exc = convert_error(err)             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, True)
 *                 return
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 55, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_exc = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "uvloop/handles/timer.pyx":56
 *             if err < 0:
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                 return
 *             self.running = 1
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 56, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/timer.pyx":57
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 *                 return             # <<<<<<<<<<<<<<
 *             self.running = 1
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/handles/timer.pyx":54
 *                                     __uvtimer_callback,
 *                                     self.timeout, 0)
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 exc = convert_error(err)
 *                 self._fatal_error(exc, True)
 */
    }

    /* "uvloop/handles/timer.pyx":58
 *                 self._fatal_error(exc, True)
 *                 return
 *             self.running = 1             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
    __pyx_v_self->running = 1;

    /* "uvloop/handles/timer.pyx":47
 *         self._ensure_alive()
 * 
 *         if self.running == 0:             # <<<<<<<<<<<<<<
 *             # Update libuv internal time.
 *             uv.uv_update_time(self._loop.uvloop)  # void
 */
  }

  /* "uvloop/handles/timer.pyx":42
 *                 return
 * 
 *     cdef start(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVTimer.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/timer.pyx":61
 * 
 *     @staticmethod
 *     cdef UVTimer new(Loop loop, method_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                      uint64_t timeout):
 * 
 */

static struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_f_6uvloop_4loop_7UVTimer_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, __pyx_t_6uvloop_4loop_method_t __pyx_v_callback, PyObject *__pyx_v_ctx, uint64_t __pyx_v_timeout) {
  struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/timer.pyx":65
 * 
 *         cdef UVTimer handle
 *         handle = UVTimer.__new__(UVTimer)             # <<<<<<<<<<<<<<
 *         handle._init(loop, callback, ctx, timeout)
 *         return handle
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UVTimer(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UVTimer), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 65, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UVTimer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/timer.pyx":66
 *         cdef UVTimer handle
 *         handle = UVTimer.__new__(UVTimer)
 *         handle._init(loop, callback, ctx, timeout)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_handle->__pyx_base.__pyx_vtab)->_init(__pyx_v_handle, __pyx_v_loop, __pyx_v_callback, __pyx_v_ctx, __pyx_v_timeout); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/timer.pyx":67
 *         handle = UVTimer.__new__(UVTimer)
 *         handle._init(loop, callback, ctx, timeout)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/timer.pyx":61
 * 
 *     @staticmethod
 *     cdef UVTimer new(Loop loop, method_t callback, object ctx,             # <<<<<<<<<<<<<<
 *                      uint64_t timeout):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVTimer.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_7UVTimer_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_7UVTimer___reduce_cython__[] = "UVTimer.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_7UVTimer_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_7UVTimer___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVTimer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_7UVTimer___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__155, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVTimer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_7UVTimer_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_7UVTimer_2__setstate_cython__[] = "UVTimer.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_7UVTimer_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_7UVTimer_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVTimer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_7UVTimer_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__156, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVTimer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/timer.pyx":70
 * 
 * 
 * cdef void __uvtimer_callback(uv.uv_timer_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVTimer callback") == 0:
 *         return
 */

static void __pyx_f_6uvloop_4loop___uvtimer_callback(uv_timer_t *__pyx_v_handle) {
  struct __pyx_obj_6uvloop_4loop_UVTimer *__pyx_v_timer = 0;
  __pyx_t_6uvloop_4loop_method_t __pyx_v_cb;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __pyx_t_6uvloop_4loop_method_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  char const *__pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uvtimer_callback", 0);

  /* "uvloop/handles/timer.pyx":71
 * 
 * cdef void __uvtimer_callback(uv.uv_timer_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVTimer callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_handle), ((char const *)"UVTimer callback")) == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/timer.pyx":72
 * cdef void __uvtimer_callback(uv.uv_timer_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVTimer callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/timer.pyx":71
 * 
 * cdef void __uvtimer_callback(uv.uv_timer_t* handle) with gil:
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVTimer callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/handles/timer.pyx":75
 * 
 *     cdef:
 *         UVTimer timer = <UVTimer> handle.data             # <<<<<<<<<<<<<<
 *         method_t cb = timer.callback
 * 
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_timer = ((struct __pyx_obj_6uvloop_4loop_UVTimer *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/timer.pyx":76
 *     cdef:
 *         UVTimer timer = <UVTimer> handle.data
 *         method_t cb = timer.callback             # <<<<<<<<<<<<<<
 * 
 *     timer.running = 0
 */
  __pyx_t_3 = __pyx_v_timer->callback;
  __pyx_v_cb = __pyx_t_3;

  /* "uvloop/handles/timer.pyx":78
 *         method_t cb = timer.callback
 * 
 *     timer.running = 0             # <<<<<<<<<<<<<<
 *     try:
 *         cb(timer.ctx)
 */
  __pyx_v_timer->running = 0;

  /* "uvloop/handles/timer.pyx":79
 * 
 *     timer.running = 0
 *     try:             # <<<<<<<<<<<<<<
 *         cb(timer.ctx)
 *     except BaseException as ex:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/handles/timer.pyx":80
 *     timer.running = 0
 *     try:
 *         cb(timer.ctx)             # <<<<<<<<<<<<<<
 *     except BaseException as ex:
 *         timer._error(ex, False)
 */
      __pyx_t_2 = __pyx_v_timer->ctx;
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = __pyx_v_cb(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(14, 80, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/handles/timer.pyx":79
 * 
 *     timer.running = 0
 *     try:             # <<<<<<<<<<<<<<
 *         cb(timer.ctx)
 *     except BaseException as ex:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/handles/timer.pyx":81
 *     try:
 *         cb(timer.ctx)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         timer._error(ex, False)
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("uvloop.loop.__uvtimer_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_2, &__pyx_t_9) < 0) __PYX_ERR(14, 81, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_v_ex = __pyx_t_2;
      /*try:*/ {

        /* "uvloop/handles/timer.pyx":82
 *         cb(timer.ctx)
 *     except BaseException as ex:
 *         timer._error(ex, False)             # <<<<<<<<<<<<<<
 */
        __pyx_t_10 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVTimer *)__pyx_v_timer->__pyx_base.__pyx_vtab)->__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_timer), __pyx_v_ex, Py_False); if (unlikely(!__pyx_t_10)) __PYX_ERR(14, 82, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }

      /* "uvloop/handles/timer.pyx":81
 *     try:
 *         cb(timer.ctx)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         timer._error(ex, False)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex);
          __pyx_v_ex = NULL;
          goto __pyx_L16;
        }
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __pyx_t_8 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_12 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          }
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ErrRestore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_12;
          goto __pyx_L6_except_error;
        }
        __pyx_L16:;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/handles/timer.pyx":79
 * 
 *     timer.running = 0
 *     try:             # <<<<<<<<<<<<<<
 *         cb(timer.ctx)
 *     except BaseException as ex:
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/timer.pyx":70
 * 
 * 
 * cdef void __uvtimer_callback(uv.uv_timer_t* handle) with gil:             # <<<<<<<<<<<<<<
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVTimer callback") == 0:
 *         return
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_WriteUnraisable("uvloop.loop.__uvtimer_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_timer);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/poll.pyx":3
 * @cython.no_gc_clear
 * cdef class UVPoll(UVHandle):
 *     cdef _init(self, Loop loop, int fd):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll__init(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, int __pyx_v_fd) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/poll.pyx":6
 *         cdef int err
 * 
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 * 
 *         self._handle = <uv.uv_handle_t*> \
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/poll.pyx":8
 *         self._start_init(loop)
 * 
 *         self._handle = <uv.uv_handle_t*> \             # <<<<<<<<<<<<<<
 *                             PyMem_RawMalloc(sizeof(uv.uv_poll_t))
 *         if self._handle is NULL:
 */
  __pyx_v_self->__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_poll_t))));

  /* "uvloop/handles/poll.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_poll_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  __pyx_t_2 = ((__pyx_v_self->__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/poll.pyx":11
 *                             PyMem_RawMalloc(sizeof(uv.uv_poll_t))
 *         if self._handle is NULL:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/poll.pyx":12
 *         if self._handle is NULL:
 *             self._abort_init()
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_poll_init(self._loop.uvloop,
 */
    PyErr_NoMemory(); __PYX_ERR(15, 12, __pyx_L1_error)

    /* "uvloop/handles/poll.pyx":10
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_poll_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  }

  /* "uvloop/handles/poll.pyx":14
 *             raise MemoryError()
 * 
 *         err = uv.uv_poll_init(self._loop.uvloop,             # <<<<<<<<<<<<<<
 *                               <uv.uv_poll_t *>self._handle, fd)
 *         if err < 0:
 */
  __pyx_v_err = uv_poll_init(__pyx_v_self->__pyx_base._loop->uvloop, ((uv_poll_t *)__pyx_v_self->__pyx_base._handle), __pyx_v_fd);

  /* "uvloop/handles/poll.pyx":16
 *         err = uv.uv_poll_init(self._loop.uvloop,
 *                               <uv.uv_poll_t *>self._handle, fd)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/poll.pyx":17
 *                               <uv.uv_poll_t *>self._handle, fd)
 *         if err < 0:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/poll.pyx":18
 *         if err < 0:
 *             self._abort_init()
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         self._finish_init()
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 18, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(15, 18, __pyx_L1_error)

    /* "uvloop/handles/poll.pyx":16
 *         err = uv.uv_poll_init(self._loop.uvloop,
 *                               <uv.uv_poll_t *>self._handle, fd)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise convert_error(err)
 */
  }

  /* "uvloop/handles/poll.pyx":20
 *             raise convert_error(err)
 * 
 *         self._finish_init()             # <<<<<<<<<<<<<<
 * 
 *         self.fd = fd
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/poll.pyx":22
 *         self._finish_init()
 * 
 *         self.fd = fd             # <<<<<<<<<<<<<<
 *         self.reading_handle = None
 *         self.writing_handle = None
 */
  __pyx_v_self->fd = __pyx_v_fd;

  /* "uvloop/handles/poll.pyx":23
 * 
 *         self.fd = fd
 *         self.reading_handle = None             # <<<<<<<<<<<<<<
 *         self.writing_handle = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->reading_handle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->reading_handle));
  __pyx_v_self->reading_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

  /* "uvloop/handles/poll.pyx":24
 *         self.fd = fd
 *         self.reading_handle = None
 *         self.writing_handle = None             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->writing_handle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->writing_handle));
  __pyx_v_self->writing_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

  /* "uvloop/handles/poll.pyx":3
 * @cython.no_gc_clear
 * cdef class UVPoll(UVHandle):
 *     cdef _init(self, Loop loop, int fd):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVPoll._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":27
 * 
 *     @staticmethod
 *     cdef UVPoll new(Loop loop, int fd):             # <<<<<<<<<<<<<<
 *         cdef UVPoll handle
 *         handle = UVPoll.__new__(UVPoll)
 */

static struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_f_6uvloop_4loop_6UVPoll_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, int __pyx_v_fd) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/poll.pyx":29
 *     cdef UVPoll new(Loop loop, int fd):
 *         cdef UVPoll handle
 *         handle = UVPoll.__new__(UVPoll)             # <<<<<<<<<<<<<<
 *         handle._init(loop, fd)
 *         return handle
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UVPoll(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UVPoll), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 29, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/poll.pyx":30
 *         cdef UVPoll handle
 *         handle = UVPoll.__new__(UVPoll)
 *         handle._init(loop, fd)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_handle->__pyx_base.__pyx_vtab)->_init(__pyx_v_handle, __pyx_v_loop, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/poll.pyx":31
 *         handle = UVPoll.__new__(UVPoll)
 *         handle._init(loop, fd)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef int is_active(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/poll.pyx":27
 * 
 *     @staticmethod
 *     cdef UVPoll new(Loop loop, int fd):             # <<<<<<<<<<<<<<
 *         cdef UVPoll handle
 *         handle = UVPoll.__new__(UVPoll)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":33
 *         return handle
 * 
 *     cdef int is_active(self):             # <<<<<<<<<<<<<<
 *         return (self.reading_handle is not None or
 *                 self.writing_handle is not None)
 */

static int __pyx_f_6uvloop_4loop_6UVPoll_is_active(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("is_active", 0);

  /* "uvloop/handles/poll.pyx":34
 * 
 *     cdef int is_active(self):
 *         return (self.reading_handle is not None or             # <<<<<<<<<<<<<<
 *                 self.writing_handle is not None)
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->reading_handle) != Py_None);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "uvloop/handles/poll.pyx":35
 *     cdef int is_active(self):
 *         return (self.reading_handle is not None or
 *                 self.writing_handle is not None)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _poll_start(self, int flags):
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->writing_handle) != Py_None);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "uvloop/handles/poll.pyx":33
 *         return handle
 * 
 *     cdef int is_active(self):             # <<<<<<<<<<<<<<
 *         return (self.reading_handle is not None or
 *                 self.writing_handle is not None)
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":37
 *                 self.writing_handle is not None)
 * 
 *     cdef inline _poll_start(self, int flags):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVPoll__poll_start(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, int __pyx_v_flags) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_poll_start", 0);

  /* "uvloop/handles/poll.pyx":40
 *         cdef int err
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_poll_start(
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/poll.pyx":42
 *         self._ensure_alive()
 * 
 *         err = uv.uv_poll_start(             # <<<<<<<<<<<<<<
 *             <uv.uv_poll_t*>self._handle,
 *             flags,
 */
  __pyx_v_err = uv_poll_start(((uv_poll_t *)__pyx_v_self->__pyx_base._handle), __pyx_v_flags, __pyx_f_6uvloop_4loop___on_uvpoll_event);

  /* "uvloop/handles/poll.pyx":47
 *             __on_uvpoll_event)
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/poll.pyx":48
 * 
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/poll.pyx":49
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/poll.pyx":50
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _poll_stop(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/poll.pyx":47
 *             __on_uvpoll_event)
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/poll.pyx":37
 *                 self.writing_handle is not None)
 * 
 *     cdef inline _poll_start(self, int flags):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVPoll._poll_start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":52
 *             return
 * 
 *     cdef inline _poll_stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_6UVPoll__poll_stop(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  int __pyx_v_backend_id;
  struct epoll_event __pyx_v_dummy_event;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_poll_stop", 0);

  /* "uvloop/handles/poll.pyx":55
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":56
 * 
 *         if not self._is_alive():
 *             return             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_poll_stop(<uv.uv_poll_t*>self._handle)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/poll.pyx":55
 *         cdef int err
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/poll.pyx":58
 *             return
 * 
 *         err = uv.uv_poll_stop(<uv.uv_poll_t*>self._handle)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             exc = convert_error(err)
 */
  __pyx_v_err = uv_poll_stop(((uv_poll_t *)__pyx_v_self->__pyx_base._handle));

  /* "uvloop/handles/poll.pyx":59
 * 
 *         err = uv.uv_poll_stop(<uv.uv_poll_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":60
 *         err = uv.uv_poll_stop(<uv.uv_poll_t*>self._handle)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/poll.pyx":61
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 61, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/poll.pyx":62
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/poll.pyx":59
 * 
 *         err = uv.uv_poll_stop(<uv.uv_poll_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/poll.pyx":68
 *             system.epoll_event dummy_event
 * 
 *         if system.PLATFORM_IS_LINUX:             # <<<<<<<<<<<<<<
 *             # libuv doesn't remove the FD from epoll immediately
 *             # after uv_poll_stop or uv_poll_close, causing hard
 */
  __pyx_t_1 = (PLATFORM_IS_LINUX != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":78
 *             # after calling uv_poll_stop.
 * 
 *             backend_id = uv.uv_backend_fd(self._loop.uvloop)             # <<<<<<<<<<<<<<
 *             if backend_id != -1:
 *                 memset(&dummy_event, 0, sizeof(dummy_event))
 */
    __pyx_v_backend_id = uv_backend_fd(__pyx_v_self->__pyx_base._loop->uvloop);

    /* "uvloop/handles/poll.pyx":79
 * 
 *             backend_id = uv.uv_backend_fd(self._loop.uvloop)
 *             if backend_id != -1:             # <<<<<<<<<<<<<<
 *                 memset(&dummy_event, 0, sizeof(dummy_event))
 *                 system.epoll_ctl(
 */
    __pyx_t_1 = ((__pyx_v_backend_id != -1L) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/poll.pyx":80
 *             backend_id = uv.uv_backend_fd(self._loop.uvloop)
 *             if backend_id != -1:
 *                 memset(&dummy_event, 0, sizeof(dummy_event))             # <<<<<<<<<<<<<<
 *                 system.epoll_ctl(
 *                     backend_id,
 */
      (void)(memset((&__pyx_v_dummy_event), 0, (sizeof(__pyx_v_dummy_event))));

      /* "uvloop/handles/poll.pyx":81
 *             if backend_id != -1:
 *                 memset(&dummy_event, 0, sizeof(dummy_event))
 *                 system.epoll_ctl(             # <<<<<<<<<<<<<<
 *                     backend_id,
 *                     system.EPOLL_CTL_DEL,
 */
      (void)(epoll_ctl(__pyx_v_backend_id, EPOLL_CTL_DEL, __pyx_v_self->fd, (&__pyx_v_dummy_event)));

      /* "uvloop/handles/poll.pyx":79
 * 
 *             backend_id = uv.uv_backend_fd(self._loop.uvloop)
 *             if backend_id != -1:             # <<<<<<<<<<<<<<
 *                 memset(&dummy_event, 0, sizeof(dummy_event))
 *                 system.epoll_ctl(
 */
    }

    /* "uvloop/handles/poll.pyx":68
 *             system.epoll_event dummy_event
 * 
 *         if system.PLATFORM_IS_LINUX:             # <<<<<<<<<<<<<<
 *             # libuv doesn't remove the FD from epoll immediately
 *             # after uv_poll_stop or uv_poll_close, causing hard
 */
  }

  /* "uvloop/handles/poll.pyx":52
 *             return
 * 
 *     cdef inline _poll_stop(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVPoll._poll_stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":87
 *                     &dummy_event)  # ignore errors
 * 
 *     cdef is_reading(self):             # <<<<<<<<<<<<<<
 *         return self._is_alive() and self.reading_handle is not None
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_is_reading(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("is_reading", 0);

  /* "uvloop/handles/poll.pyx":88
 * 
 *     cdef is_reading(self):
 *         return self._is_alive() and self.reading_handle is not None             # <<<<<<<<<<<<<<
 * 
 *     cdef is_writing(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));
  if (__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (((PyObject *)__pyx_v_self->reading_handle) != Py_None);
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/poll.pyx":87
 *                     &dummy_event)  # ignore errors
 * 
 *     cdef is_reading(self):             # <<<<<<<<<<<<<<
 *         return self._is_alive() and self.reading_handle is not None
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.is_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":90
 *         return self._is_alive() and self.reading_handle is not None
 * 
 *     cdef is_writing(self):             # <<<<<<<<<<<<<<
 *         return self._is_alive() and self.writing_handle is not None
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_is_writing(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("is_writing", 0);

  /* "uvloop/handles/poll.pyx":91
 * 
 *     cdef is_writing(self):
 *         return self._is_alive() and self.writing_handle is not None             # <<<<<<<<<<<<<<
 * 
 *     cdef start_reading(self, Handle callback):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self));
  if (__pyx_t_2) {
  } else {
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (((PyObject *)__pyx_v_self->writing_handle) != Py_None);
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/poll.pyx":90
 *         return self._is_alive() and self.reading_handle is not None
 * 
 *     cdef is_writing(self):             # <<<<<<<<<<<<<<
 *         return self._is_alive() and self.writing_handle is not None
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.is_writing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":93
 *         return self._is_alive() and self.writing_handle is not None
 * 
 *     cdef start_reading(self, Handle callback):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int mask = 0
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_start_reading(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_callback) {
  int __pyx_v_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("start_reading", 0);

  /* "uvloop/handles/poll.pyx":95
 *     cdef start_reading(self, Handle callback):
 *         cdef:
 *             int mask = 0             # <<<<<<<<<<<<<<
 * 
 *         if self.reading_handle is None:
 */
  __pyx_v_mask = 0;

  /* "uvloop/handles/poll.pyx":97
 *             int mask = 0
 * 
 *         if self.reading_handle is None:             # <<<<<<<<<<<<<<
 *             # not reading right now, setup the handle
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->reading_handle) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/poll.pyx":100
 *             # not reading right now, setup the handle
 * 
 *             mask = uv.UV_READABLE             # <<<<<<<<<<<<<<
 *             if self.writing_handle is not None:
 *                 # are we writing right now?
 */
    __pyx_v_mask = UV_READABLE;

    /* "uvloop/handles/poll.pyx":101
 * 
 *             mask = uv.UV_READABLE
 *             if self.writing_handle is not None:             # <<<<<<<<<<<<<<
 *                 # are we writing right now?
 *                 mask |= uv.UV_WRITABLE
 */
    __pyx_t_2 = (((PyObject *)__pyx_v_self->writing_handle) != Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/poll.pyx":103
 *             if self.writing_handle is not None:
 *                 # are we writing right now?
 *                 mask |= uv.UV_WRITABLE             # <<<<<<<<<<<<<<
 * 
 *             self._poll_start(mask)
 */
      __pyx_v_mask = (__pyx_v_mask | UV_WRITABLE);

      /* "uvloop/handles/poll.pyx":101
 * 
 *             mask = uv.UV_READABLE
 *             if self.writing_handle is not None:             # <<<<<<<<<<<<<<
 *                 # are we writing right now?
 *                 mask |= uv.UV_WRITABLE
 */
    }

    /* "uvloop/handles/poll.pyx":105
 *                 mask |= uv.UV_WRITABLE
 * 
 *             self._poll_start(mask)             # <<<<<<<<<<<<<<
 *         else:
 *             self.reading_handle._cancel()
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_6UVPoll__poll_start(__pyx_v_self, __pyx_v_mask); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/poll.pyx":97
 *             int mask = 0
 * 
 *         if self.reading_handle is None:             # <<<<<<<<<<<<<<
 *             # not reading right now, setup the handle
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/poll.pyx":107
 *             self._poll_start(mask)
 *         else:
 *             self.reading_handle._cancel()             # <<<<<<<<<<<<<<
 * 
 *         self.reading_handle = callback
 */
  /*else*/ {
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_self->reading_handle->__pyx_vtab)->_cancel(__pyx_v_self->reading_handle); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/poll.pyx":109
 *             self.reading_handle._cancel()
 * 
 *         self.reading_handle = callback             # <<<<<<<<<<<<<<
 * 
 *     cdef start_writing(self, Handle callback):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_callback));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_callback));
  __Pyx_GOTREF(__pyx_v_self->reading_handle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->reading_handle));
  __pyx_v_self->reading_handle = __pyx_v_callback;

  /* "uvloop/handles/poll.pyx":93
 *         return self._is_alive() and self.writing_handle is not None
 * 
 *     cdef start_reading(self, Handle callback):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int mask = 0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.start_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":111
 *         self.reading_handle = callback
 * 
 *     cdef start_writing(self, Handle callback):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int mask = 0
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_start_writing(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Handle *__pyx_v_callback) {
  int __pyx_v_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("start_writing", 0);

  /* "uvloop/handles/poll.pyx":113
 *     cdef start_writing(self, Handle callback):
 *         cdef:
 *             int mask = 0             # <<<<<<<<<<<<<<
 * 
 *         if self.writing_handle is None:
 */
  __pyx_v_mask = 0;

  /* "uvloop/handles/poll.pyx":115
 *             int mask = 0
 * 
 *         if self.writing_handle is None:             # <<<<<<<<<<<<<<
 *             # not writing right now, setup the handle
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->writing_handle) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/poll.pyx":118
 *             # not writing right now, setup the handle
 * 
 *             mask = uv.UV_WRITABLE             # <<<<<<<<<<<<<<
 *             if self.reading_handle is not None:
 *                 # are we reading right now?
 */
    __pyx_v_mask = UV_WRITABLE;

    /* "uvloop/handles/poll.pyx":119
 * 
 *             mask = uv.UV_WRITABLE
 *             if self.reading_handle is not None:             # <<<<<<<<<<<<<<
 *                 # are we reading right now?
 *                 mask |= uv.UV_READABLE
 */
    __pyx_t_2 = (((PyObject *)__pyx_v_self->reading_handle) != Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/poll.pyx":121
 *             if self.reading_handle is not None:
 *                 # are we reading right now?
 *                 mask |= uv.UV_READABLE             # <<<<<<<<<<<<<<
 * 
 *             self._poll_start(mask)
 */
      __pyx_v_mask = (__pyx_v_mask | UV_READABLE);

      /* "uvloop/handles/poll.pyx":119
 * 
 *             mask = uv.UV_WRITABLE
 *             if self.reading_handle is not None:             # <<<<<<<<<<<<<<
 *                 # are we reading right now?
 *                 mask |= uv.UV_READABLE
 */
    }

    /* "uvloop/handles/poll.pyx":123
 *                 mask |= uv.UV_READABLE
 * 
 *             self._poll_start(mask)             # <<<<<<<<<<<<<<
 *         else:
 *             self.writing_handle._cancel()
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_6UVPoll__poll_start(__pyx_v_self, __pyx_v_mask); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 123, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/poll.pyx":115
 *             int mask = 0
 * 
 *         if self.writing_handle is None:             # <<<<<<<<<<<<<<
 *             # not writing right now, setup the handle
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/poll.pyx":125
 *             self._poll_start(mask)
 *         else:
 *             self.writing_handle._cancel()             # <<<<<<<<<<<<<<
 * 
 *         self.writing_handle = callback
 */
  /*else*/ {
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_self->writing_handle->__pyx_vtab)->_cancel(__pyx_v_self->writing_handle); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/poll.pyx":127
 *             self.writing_handle._cancel()
 * 
 *         self.writing_handle = callback             # <<<<<<<<<<<<<<
 * 
 *     cdef stop_reading(self):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_callback));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_callback));
  __Pyx_GOTREF(__pyx_v_self->writing_handle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->writing_handle));
  __pyx_v_self->writing_handle = __pyx_v_callback;

  /* "uvloop/handles/poll.pyx":111
 *         self.reading_handle = callback
 * 
 *     cdef start_writing(self, Handle callback):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int mask = 0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.start_writing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":129
 *         self.writing_handle = callback
 * 
 *     cdef stop_reading(self):             # <<<<<<<<<<<<<<
 *         if self.reading_handle is None:
 *             return False
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_stop_reading(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("stop_reading", 0);

  /* "uvloop/handles/poll.pyx":130
 * 
 *     cdef stop_reading(self):
 *         if self.reading_handle is None:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->reading_handle) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/poll.pyx":131
 *     cdef stop_reading(self):
 *         if self.reading_handle is None:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         self.reading_handle._cancel()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "uvloop/handles/poll.pyx":130
 * 
 *     cdef stop_reading(self):
 *         if self.reading_handle is None:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "uvloop/handles/poll.pyx":133
 *             return False
 * 
 *         self.reading_handle._cancel()             # <<<<<<<<<<<<<<
 *         self.reading_handle = None
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_self->reading_handle->__pyx_vtab)->_cancel(__pyx_v_self->reading_handle); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/poll.pyx":134
 * 
 *         self.reading_handle._cancel()
 *         self.reading_handle = None             # <<<<<<<<<<<<<<
 * 
 *         if self.writing_handle is None:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->reading_handle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->reading_handle));
  __pyx_v_self->reading_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

  /* "uvloop/handles/poll.pyx":136
 *         self.reading_handle = None
 * 
 *         if self.writing_handle is None:             # <<<<<<<<<<<<<<
 *             self.stop()
 *         else:
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->writing_handle) == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":137
 * 
 *         if self.writing_handle is None:
 *             self.stop()             # <<<<<<<<<<<<<<
 *         else:
 *             self._poll_start(uv.UV_WRITABLE)
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->stop(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 137, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/poll.pyx":136
 *         self.reading_handle = None
 * 
 *         if self.writing_handle is None:             # <<<<<<<<<<<<<<
 *             self.stop()
 *         else:
 */
    goto __pyx_L4;
  }

  /* "uvloop/handles/poll.pyx":139
 *             self.stop()
 *         else:
 *             self._poll_start(uv.UV_WRITABLE)             # <<<<<<<<<<<<<<
 * 
 *         return True
 */
  /*else*/ {
    __pyx_t_3 = __pyx_f_6uvloop_4loop_6UVPoll__poll_start(__pyx_v_self, UV_WRITABLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "uvloop/handles/poll.pyx":141
 *             self._poll_start(uv.UV_WRITABLE)
 * 
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     cdef stop_writing(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "uvloop/handles/poll.pyx":129
 *         self.writing_handle = callback
 * 
 *     cdef stop_reading(self):             # <<<<<<<<<<<<<<
 *         if self.reading_handle is None:
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.stop_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":143
 *         return True
 * 
 *     cdef stop_writing(self):             # <<<<<<<<<<<<<<
 *         if self.writing_handle is None:
 *             return False
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_stop_writing(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("stop_writing", 0);

  /* "uvloop/handles/poll.pyx":144
 * 
 *     cdef stop_writing(self):
 *         if self.writing_handle is None:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->writing_handle) == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/poll.pyx":145
 *     cdef stop_writing(self):
 *         if self.writing_handle is None:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         self.writing_handle._cancel()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "uvloop/handles/poll.pyx":144
 * 
 *     cdef stop_writing(self):
 *         if self.writing_handle is None:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
  }

  /* "uvloop/handles/poll.pyx":147
 *             return False
 * 
 *         self.writing_handle._cancel()             # <<<<<<<<<<<<<<
 *         self.writing_handle = None
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_self->writing_handle->__pyx_vtab)->_cancel(__pyx_v_self->writing_handle); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/poll.pyx":148
 * 
 *         self.writing_handle._cancel()
 *         self.writing_handle = None             # <<<<<<<<<<<<<<
 * 
 *         if self.reading_handle is None:
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->writing_handle);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->writing_handle));
  __pyx_v_self->writing_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

  /* "uvloop/handles/poll.pyx":150
 *         self.writing_handle = None
 * 
 *         if self.reading_handle is None:             # <<<<<<<<<<<<<<
 *             self.stop()
 *         else:
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->reading_handle) == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":151
 * 
 *         if self.reading_handle is None:
 *             self.stop()             # <<<<<<<<<<<<<<
 *         else:
 *             self._poll_start(uv.UV_READABLE)
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->stop(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/poll.pyx":150
 *         self.writing_handle = None
 * 
 *         if self.reading_handle is None:             # <<<<<<<<<<<<<<
 *             self.stop()
 *         else:
 */
    goto __pyx_L4;
  }

  /* "uvloop/handles/poll.pyx":153
 *             self.stop()
 *         else:
 *             self._poll_start(uv.UV_READABLE)             # <<<<<<<<<<<<<<
 * 
 *         return True
 */
  /*else*/ {
    __pyx_t_3 = __pyx_f_6uvloop_4loop_6UVPoll__poll_start(__pyx_v_self, UV_READABLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "uvloop/handles/poll.pyx":155
 *             self._poll_start(uv.UV_READABLE)
 * 
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     cdef stop(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "uvloop/handles/poll.pyx":143
 *         return True
 * 
 *     cdef stop_writing(self):             # <<<<<<<<<<<<<<
 *         if self.writing_handle is None:
 *             return False
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.stop_writing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":157
 *         return True
 * 
 *     cdef stop(self):             # <<<<<<<<<<<<<<
 *         if self.reading_handle is not None:
 *             self.reading_handle._cancel()
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll_stop(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("stop", 0);

  /* "uvloop/handles/poll.pyx":158
 * 
 *     cdef stop(self):
 *         if self.reading_handle is not None:             # <<<<<<<<<<<<<<
 *             self.reading_handle._cancel()
 *             self.reading_handle = None
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->reading_handle) != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/poll.pyx":159
 *     cdef stop(self):
 *         if self.reading_handle is not None:
 *             self.reading_handle._cancel()             # <<<<<<<<<<<<<<
 *             self.reading_handle = None
 * 
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_self->reading_handle->__pyx_vtab)->_cancel(__pyx_v_self->reading_handle); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/poll.pyx":160
 *         if self.reading_handle is not None:
 *             self.reading_handle._cancel()
 *             self.reading_handle = None             # <<<<<<<<<<<<<<
 * 
 *         if self.writing_handle is not None:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->reading_handle);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->reading_handle));
    __pyx_v_self->reading_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

    /* "uvloop/handles/poll.pyx":158
 * 
 *     cdef stop(self):
 *         if self.reading_handle is not None:             # <<<<<<<<<<<<<<
 *             self.reading_handle._cancel()
 *             self.reading_handle = None
 */
  }

  /* "uvloop/handles/poll.pyx":162
 *             self.reading_handle = None
 * 
 *         if self.writing_handle is not None:             # <<<<<<<<<<<<<<
 *             self.writing_handle._cancel()
 *             self.writing_handle = None
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->writing_handle) != Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":163
 * 
 *         if self.writing_handle is not None:
 *             self.writing_handle._cancel()             # <<<<<<<<<<<<<<
 *             self.writing_handle = None
 * 
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Handle *)__pyx_v_self->writing_handle->__pyx_vtab)->_cancel(__pyx_v_self->writing_handle); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 163, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/poll.pyx":164
 *         if self.writing_handle is not None:
 *             self.writing_handle._cancel()
 *             self.writing_handle = None             # <<<<<<<<<<<<<<
 * 
 *         self._poll_stop()
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->writing_handle);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->writing_handle));
    __pyx_v_self->writing_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

    /* "uvloop/handles/poll.pyx":162
 *             self.reading_handle = None
 * 
 *         if self.writing_handle is not None:             # <<<<<<<<<<<<<<
 *             self.writing_handle._cancel()
 *             self.writing_handle = None
 */
  }

  /* "uvloop/handles/poll.pyx":166
 *             self.writing_handle = None
 * 
 *         self._poll_stop()             # <<<<<<<<<<<<<<
 * 
 *     cdef _close(self):
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_6UVPoll__poll_stop(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/poll.pyx":157
 *         return True
 * 
 *     cdef stop(self):             # <<<<<<<<<<<<<<
 *         if self.reading_handle is not None:
 *             self.reading_handle._cancel()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.stop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":168
 *         self._poll_stop()
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self.is_active():
 *             self.stop()
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll__close(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "uvloop/handles/poll.pyx":169
 * 
 *     cdef _close(self):
 *         if self.is_active():             # <<<<<<<<<<<<<<
 *             self.stop()
 * 
 */
  __pyx_t_1 = (((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->is_active(__pyx_v_self) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":170
 *     cdef _close(self):
 *         if self.is_active():
 *             self.stop()             # <<<<<<<<<<<<<<
 * 
 *         UVHandle._close(<UVHandle>self)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->stop(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/poll.pyx":169
 * 
 *     cdef _close(self):
 *         if self.is_active():             # <<<<<<<<<<<<<<
 *             self.stop()
 * 
 */
  }

  /* "uvloop/handles/poll.pyx":172
 *             self.stop()
 * 
 *         UVHandle._close(<UVHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVHandle__close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/poll.pyx":168
 *         self._poll_stop()
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         if self.is_active():
 *             self.stop()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVPoll._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":174
 *         UVHandle._close(<UVHandle>self)
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         try:
 *             if self.reading_handle is not None:
 */

static PyObject *__pyx_f_6uvloop_4loop_6UVPoll__fatal_error(struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_exc, CYTHON_UNUSED PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_6UVPoll__fatal_error *__pyx_optional_args) {
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("_fatal_error", 0);
  if (__pyx_optional_args) {
  }

  /* "uvloop/handles/poll.pyx":175
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):
 *         try:             # <<<<<<<<<<<<<<
 *             if self.reading_handle is not None:
 *                 try:
 */
  /*try:*/ {

    /* "uvloop/handles/poll.pyx":176
 *     cdef _fatal_error(self, exc, throw, reason=None):
 *         try:
 *             if self.reading_handle is not None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.reading_handle._run()
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->reading_handle) != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/poll.pyx":177
 *         try:
 *             if self.reading_handle is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.reading_handle._run()
 *                 except BaseException as ex:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_5);
        /*try:*/ {

          /* "uvloop/handles/poll.pyx":178
 *             if self.reading_handle is not None:
 *                 try:
 *                     self.reading_handle._run()             # <<<<<<<<<<<<<<
 *                 except BaseException as ex:
 *                     self._loop._handle_exception(ex)
 */
          __pyx_t_6 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_self->reading_handle); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 178, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "uvloop/handles/poll.pyx":177
 *         try:
 *             if self.reading_handle is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.reading_handle._run()
 *                 except BaseException as ex:
 */
        }
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L12_try_end;
        __pyx_L7_error:;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/handles/poll.pyx":179
 *                 try:
 *                     self.reading_handle._run()
 *                 except BaseException as ex:             # <<<<<<<<<<<<<<
 *                     self._loop._handle_exception(ex)
 *                 self.reading_handle = None
 */
        __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
        if (__pyx_t_7) {
          __Pyx_AddTraceback("uvloop.loop.UVPoll._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(15, 179, __pyx_L9_except_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_v_ex = __pyx_t_8;
          /*try:*/ {

            /* "uvloop/handles/poll.pyx":180
 *                     self.reading_handle._run()
 *                 except BaseException as ex:
 *                     self._loop._handle_exception(ex)             # <<<<<<<<<<<<<<
 *                 self.reading_handle = None
 * 
 */
            ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_base._loop->__pyx_vtab)->_handle_exception(__pyx_v_self->__pyx_base._loop, __pyx_v_ex);
          }

          /* "uvloop/handles/poll.pyx":179
 *                 try:
 *                     self.reading_handle._run()
 *                 except BaseException as ex:             # <<<<<<<<<<<<<<
 *                     self._loop._handle_exception(ex)
 *                 self.reading_handle = None
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
              goto __pyx_L19;
            }
            __pyx_L19:;
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          goto __pyx_L8_exception_handled;
        }
        goto __pyx_L9_except_error;
        __pyx_L9_except_error:;

        /* "uvloop/handles/poll.pyx":177
 *         try:
 *             if self.reading_handle is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.reading_handle._run()
 *                 except BaseException as ex:
 */
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
        goto __pyx_L4_error;
        __pyx_L8_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
        __pyx_L12_try_end:;
      }

      /* "uvloop/handles/poll.pyx":181
 *                 except BaseException as ex:
 *                     self._loop._handle_exception(ex)
 *                 self.reading_handle = None             # <<<<<<<<<<<<<<
 * 
 *             if self.writing_handle is not None:
 */
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->reading_handle);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->reading_handle));
      __pyx_v_self->reading_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

      /* "uvloop/handles/poll.pyx":176
 *     cdef _fatal_error(self, exc, throw, reason=None):
 *         try:
 *             if self.reading_handle is not None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.reading_handle._run()
 */
    }

    /* "uvloop/handles/poll.pyx":183
 *                 self.reading_handle = None
 * 
 *             if self.writing_handle is not None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.writing_handle._run()
 */
    __pyx_t_2 = (((PyObject *)__pyx_v_self->writing_handle) != Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/poll.pyx":184
 * 
 *             if self.writing_handle is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.writing_handle._run()
 *                 except BaseException as ex:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_3);
        /*try:*/ {

          /* "uvloop/handles/poll.pyx":185
 *             if self.writing_handle is not None:
 *                 try:
 *                     self.writing_handle._run()             # <<<<<<<<<<<<<<
 *                 except BaseException as ex:
 *                     self._loop._handle_exception(ex)
 */
          __pyx_t_9 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_self->writing_handle); if (unlikely(!__pyx_t_9)) __PYX_ERR(15, 185, __pyx_L21_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "uvloop/handles/poll.pyx":184
 * 
 *             if self.writing_handle is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.writing_handle._run()
 *                 except BaseException as ex:
 */
        }
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L26_try_end;
        __pyx_L21_error:;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "uvloop/handles/poll.pyx":186
 *                 try:
 *                     self.writing_handle._run()
 *                 except BaseException as ex:             # <<<<<<<<<<<<<<
 *                     self._loop._handle_exception(ex)
 *                 self.writing_handle = None
 */
        __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
        if (__pyx_t_7) {
          __Pyx_AddTraceback("uvloop.loop.UVPoll._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_6) < 0) __PYX_ERR(15, 186, __pyx_L23_except_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_v_ex = __pyx_t_8;
          /*try:*/ {

            /* "uvloop/handles/poll.pyx":187
 *                     self.writing_handle._run()
 *                 except BaseException as ex:
 *                     self._loop._handle_exception(ex)             # <<<<<<<<<<<<<<
 *                 self.writing_handle = None
 * 
 */
            ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_base._loop->__pyx_vtab)->_handle_exception(__pyx_v_self->__pyx_base._loop, __pyx_v_ex);
          }

          /* "uvloop/handles/poll.pyx":186
 *                 try:
 *                     self.writing_handle._run()
 *                 except BaseException as ex:             # <<<<<<<<<<<<<<
 *                     self._loop._handle_exception(ex)
 *                 self.writing_handle = None
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
              goto __pyx_L33;
            }
            __pyx_L33:;
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L22_exception_handled;
        }
        goto __pyx_L23_except_error;
        __pyx_L23_except_error:;

        /* "uvloop/handles/poll.pyx":184
 * 
 *             if self.writing_handle is not None:
 *                 try:             # <<<<<<<<<<<<<<
 *                     self.writing_handle._run()
 *                 except BaseException as ex:
 */
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
        goto __pyx_L4_error;
        __pyx_L22_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
        __pyx_L26_try_end:;
      }

      /* "uvloop/handles/poll.pyx":188
 *                 except BaseException as ex:
 *                     self._loop._handle_exception(ex)
 *                 self.writing_handle = None             # <<<<<<<<<<<<<<
 * 
 *         finally:
 */
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->writing_handle);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->writing_handle));
      __pyx_v_self->writing_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None);

      /* "uvloop/handles/poll.pyx":183
 *                 self.reading_handle = None
 * 
 *             if self.writing_handle is not None:             # <<<<<<<<<<<<<<
 *                 try:
 *                     self.writing_handle._run()
 */
    }
  }

  /* "uvloop/handles/poll.pyx":191
 * 
 *         finally:
 *             self._close()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 191, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_3 = 0; __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5) < 0)) __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_7 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
      {
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 191, __pyx_L35_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ErrRestore(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_t_3 = 0; __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
      goto __pyx_L1_error;
      __pyx_L35_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "uvloop/handles/poll.pyx":174
 *         UVHandle._close(<UVHandle>self)
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         try:
 *             if self.reading_handle is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.UVPoll._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6UVPoll_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6UVPoll___reduce_cython__[] = "UVPoll.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6UVPoll_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6UVPoll___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6UVPoll___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__157, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6UVPoll_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_6UVPoll_2__setstate_cython__[] = "UVPoll.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_6UVPoll_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6UVPoll_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6UVPoll_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__158, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVPoll.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/poll.pyx":194
 * 
 * 
 * cdef void __on_uvpoll_event(uv.uv_poll_t* handle,             # <<<<<<<<<<<<<<
 *                             int status, int events) with gil:
 * 
 */

static void __pyx_f_6uvloop_4loop___on_uvpoll_event(uv_poll_t *__pyx_v_handle, int __pyx_v_status, int __pyx_v_events) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *__pyx_v_poll = 0;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  char const *__pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  char const *__pyx_t_21;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__on_uvpoll_event", 0);

  /* "uvloop/handles/poll.pyx":197
 *                             int status, int events) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVPoll callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_handle), ((char const *)"UVPoll callback")) == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":198
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVPoll callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/poll.pyx":197
 *                             int status, int events) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle, "UVPoll callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/handles/poll.pyx":201
 * 
 *     cdef:
 *         UVPoll poll = <UVPoll> handle.data             # <<<<<<<<<<<<<<
 * 
 *     if status < 0:
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/poll.pyx":203
 *         UVPoll poll = <UVPoll> handle.data
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(status)
 *         poll._fatal_error(exc, False)
 */
  __pyx_t_1 = ((__pyx_v_status < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":204
 * 
 *     if status < 0:
 *         exc = convert_error(status)             # <<<<<<<<<<<<<<
 *         poll._fatal_error(exc, False)
 *         return
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/poll.pyx":205
 *     if status < 0:
 *         exc = convert_error(status)
 *         poll._fatal_error(exc, False)             # <<<<<<<<<<<<<<
 *         return
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_poll), __pyx_v_exc, Py_False, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/poll.pyx":206
 *         exc = convert_error(status)
 *         poll._fatal_error(exc, False)
 *         return             # <<<<<<<<<<<<<<
 * 
 *     if ((events & (uv.UV_READABLE | uv.UV_DISCONNECT)) and
 */
    goto __pyx_L0;

    /* "uvloop/handles/poll.pyx":203
 *         UVPoll poll = <UVPoll> handle.data
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(status)
 *         poll._fatal_error(exc, False)
 */
  }

  /* "uvloop/handles/poll.pyx":208
 *         return
 * 
 *     if ((events & (uv.UV_READABLE | uv.UV_DISCONNECT)) and             # <<<<<<<<<<<<<<
 *             poll.reading_handle is not None):
 * 
 */
  __pyx_t_3 = ((__pyx_v_events & (UV_READABLE | UV_DISCONNECT)) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L6_bool_binop_done;
  }

  /* "uvloop/handles/poll.pyx":209
 * 
 *     if ((events & (uv.UV_READABLE | uv.UV_DISCONNECT)) and
 *             poll.reading_handle is not None):             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_3 = (((PyObject *)__pyx_v_poll->reading_handle) != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_4;
  __pyx_L6_bool_binop_done:;

  /* "uvloop/handles/poll.pyx":208
 *         return
 * 
 *     if ((events & (uv.UV_READABLE | uv.UV_DISCONNECT)) and             # <<<<<<<<<<<<<<
 *             poll.reading_handle is not None):
 * 
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":211
 *             poll.reading_handle is not None):
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_events_total += 1
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "uvloop/handles/poll.pyx":212
 * 
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_read_events_total += 1
 *             poll.reading_handle._run()
 */
        __pyx_t_1 = (UVLOOP_DEBUG != 0);
        if (__pyx_t_1) {

          /* "uvloop/handles/poll.pyx":213
 *         try:
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_events_total += 1             # <<<<<<<<<<<<<<
 *             poll.reading_handle._run()
 *         except BaseException as ex:
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_poll->__pyx_base._loop));
          __pyx_t_8 = __pyx_v_poll->__pyx_base._loop;
          __pyx_t_8->_poll_read_events_total = (__pyx_t_8->_poll_read_events_total + 1);
          __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

          /* "uvloop/handles/poll.pyx":212
 * 
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_read_events_total += 1
 *             poll.reading_handle._run()
 */
        }

        /* "uvloop/handles/poll.pyx":214
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_events_total += 1
 *             poll.reading_handle._run()             # <<<<<<<<<<<<<<
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:
 */
        __pyx_t_2 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_poll->reading_handle); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 214, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/handles/poll.pyx":211
 *             poll.reading_handle is not None):
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_events_total += 1
 */
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L13_try_end;
      __pyx_L8_error:;
      __Pyx_XDECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/poll.pyx":215
 *                 poll._loop._poll_read_events_total += 1
 *             poll.reading_handle._run()
 *         except BaseException as ex:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_cb_errors_total += 1
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("uvloop.loop.__on_uvpoll_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_10, &__pyx_t_11) < 0) __PYX_ERR(15, 215, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_10);
        __pyx_v_ex = __pyx_t_10;
        /*try:*/ {

          /* "uvloop/handles/poll.pyx":216
 *             poll.reading_handle._run()
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_read_cb_errors_total += 1
 *             poll._error(ex, False)
 */
          __pyx_t_1 = (UVLOOP_DEBUG != 0);
          if (__pyx_t_1) {

            /* "uvloop/handles/poll.pyx":217
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_cb_errors_total += 1             # <<<<<<<<<<<<<<
 *             poll._error(ex, False)
 *             # continue code execution
 */
            __Pyx_INCREF(((PyObject *)__pyx_v_poll->__pyx_base._loop));
            __pyx_t_8 = __pyx_v_poll->__pyx_base._loop;
            __pyx_t_8->_poll_read_cb_errors_total = (__pyx_t_8->_poll_read_cb_errors_total + 1);
            __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

            /* "uvloop/handles/poll.pyx":216
 *             poll.reading_handle._run()
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_read_cb_errors_total += 1
 *             poll._error(ex, False)
 */
          }

          /* "uvloop/handles/poll.pyx":218
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_cb_errors_total += 1
 *             poll._error(ex, False)             # <<<<<<<<<<<<<<
 *             # continue code execution
 * 
 */
          __pyx_t_12 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_poll), __pyx_v_ex, Py_False); if (unlikely(!__pyx_t_12)) __PYX_ERR(15, 218, __pyx_L20_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }

        /* "uvloop/handles/poll.pyx":215
 *                 poll._loop._poll_read_events_total += 1
 *             poll.reading_handle._run()
 *         except BaseException as ex:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_cb_errors_total += 1
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L21;
          }
          __pyx_L20_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
            __Pyx_XDECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __pyx_t_9 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
            }
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
            __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
            __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
            goto __pyx_L10_except_error;
          }
          __pyx_L21:;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L9_exception_handled;
      }
      goto __pyx_L10_except_error;
      __pyx_L10_except_error:;

      /* "uvloop/handles/poll.pyx":211
 *             poll.reading_handle is not None):
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_read_events_total += 1
 */
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L9_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L13_try_end:;
    }

    /* "uvloop/handles/poll.pyx":208
 *         return
 * 
 *     if ((events & (uv.UV_READABLE | uv.UV_DISCONNECT)) and             # <<<<<<<<<<<<<<
 *             poll.reading_handle is not None):
 * 
 */
  }

  /* "uvloop/handles/poll.pyx":221
 *             # continue code execution
 * 
 *     if ((events & (uv.UV_WRITABLE | uv.UV_DISCONNECT)) and             # <<<<<<<<<<<<<<
 *             poll.writing_handle is not None):
 * 
 */
  __pyx_t_4 = ((__pyx_v_events & (UV_WRITABLE | UV_DISCONNECT)) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L28_bool_binop_done;
  }

  /* "uvloop/handles/poll.pyx":222
 * 
 *     if ((events & (uv.UV_WRITABLE | uv.UV_DISCONNECT)) and
 *             poll.writing_handle is not None):             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_4 = (((PyObject *)__pyx_v_poll->writing_handle) != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L28_bool_binop_done:;

  /* "uvloop/handles/poll.pyx":221
 *             # continue code execution
 * 
 *     if ((events & (uv.UV_WRITABLE | uv.UV_DISCONNECT)) and             # <<<<<<<<<<<<<<
 *             poll.writing_handle is not None):
 * 
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/poll.pyx":224
 *             poll.writing_handle is not None):
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_events_total += 1
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/handles/poll.pyx":225
 * 
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_write_events_total += 1
 *             poll.writing_handle._run()
 */
        __pyx_t_1 = (UVLOOP_DEBUG != 0);
        if (__pyx_t_1) {

          /* "uvloop/handles/poll.pyx":226
 *         try:
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_events_total += 1             # <<<<<<<<<<<<<<
 *             poll.writing_handle._run()
 *         except BaseException as ex:
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_poll->__pyx_base._loop));
          __pyx_t_8 = __pyx_v_poll->__pyx_base._loop;
          __pyx_t_8->_poll_write_events_total = (__pyx_t_8->_poll_write_events_total + 1);
          __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

          /* "uvloop/handles/poll.pyx":225
 * 
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_write_events_total += 1
 *             poll.writing_handle._run()
 */
        }

        /* "uvloop/handles/poll.pyx":227
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_events_total += 1
 *             poll.writing_handle._run()             # <<<<<<<<<<<<<<
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:
 */
        __pyx_t_11 = __pyx_f_6uvloop_4loop_6Handle__run(__pyx_v_poll->writing_handle); if (unlikely(!__pyx_t_11)) __PYX_ERR(15, 227, __pyx_L30_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "uvloop/handles/poll.pyx":224
 *             poll.writing_handle is not None):
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_events_total += 1
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L35_try_end;
      __pyx_L30_error:;
      __Pyx_XDECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "uvloop/handles/poll.pyx":228
 *                 poll._loop._poll_write_events_total += 1
 *             poll.writing_handle._run()
 *         except BaseException as ex:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_cb_errors_total += 1
 */
      __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
      if (__pyx_t_13) {
        __Pyx_AddTraceback("uvloop.loop.__on_uvpoll_event", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_10, &__pyx_t_2) < 0) __PYX_ERR(15, 228, __pyx_L32_except_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_10);
        __pyx_v_ex = __pyx_t_10;
        /*try:*/ {

          /* "uvloop/handles/poll.pyx":229
 *             poll.writing_handle._run()
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_write_cb_errors_total += 1
 *             poll._error(ex, False)
 */
          __pyx_t_1 = (UVLOOP_DEBUG != 0);
          if (__pyx_t_1) {

            /* "uvloop/handles/poll.pyx":230
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_cb_errors_total += 1             # <<<<<<<<<<<<<<
 *             poll._error(ex, False)
 */
            __Pyx_INCREF(((PyObject *)__pyx_v_poll->__pyx_base._loop));
            __pyx_t_8 = __pyx_v_poll->__pyx_base._loop;
            __pyx_t_8->_poll_write_cb_errors_total = (__pyx_t_8->_poll_write_cb_errors_total + 1);
            __Pyx_DECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;

            /* "uvloop/handles/poll.pyx":229
 *             poll.writing_handle._run()
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 poll._loop._poll_write_cb_errors_total += 1
 *             poll._error(ex, False)
 */
          }

          /* "uvloop/handles/poll.pyx":231
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_cb_errors_total += 1
 *             poll._error(ex, False)             # <<<<<<<<<<<<<<
 */
          __pyx_t_12 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_poll->__pyx_base.__pyx_vtab)->__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_poll), __pyx_v_ex, Py_False); if (unlikely(!__pyx_t_12)) __PYX_ERR(15, 231, __pyx_L42_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }

        /* "uvloop/handles/poll.pyx":228
 *                 poll._loop._poll_write_events_total += 1
 *             poll.writing_handle._run()
 *         except BaseException as ex:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_cb_errors_total += 1
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L43;
          }
          __pyx_L42_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
            __Pyx_XDECREF(((PyObject *)__pyx_t_8)); __pyx_t_8 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_15);
            __pyx_t_13 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
            }
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ErrRestore(__pyx_t_20, __pyx_t_19, __pyx_t_18);
            __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
            __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_21;
            goto __pyx_L32_except_error;
          }
          __pyx_L43:;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L31_exception_handled;
      }
      goto __pyx_L32_except_error;
      __pyx_L32_except_error:;

      /* "uvloop/handles/poll.pyx":224
 *             poll.writing_handle is not None):
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 poll._loop._poll_write_events_total += 1
 */
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L31_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
      __pyx_L35_try_end:;
    }

    /* "uvloop/handles/poll.pyx":221
 *             # continue code execution
 * 
 *     if ((events & (uv.UV_WRITABLE | uv.UV_DISCONNECT)) and             # <<<<<<<<<<<<<<
 *             poll.writing_handle is not None):
 * 
 */
  }

  /* "uvloop/handles/poll.pyx":194
 * 
 * 
 * cdef void __on_uvpoll_event(uv.uv_poll_t* handle,             # <<<<<<<<<<<<<<
 *                             int status, int events) with gil:
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(((PyObject *)__pyx_t_8));
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_WriteUnraisable("uvloop.loop.__on_uvpoll_event", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_poll);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/basetransport.pyx":4
 * cdef class UVBaseTransport(UVSocketHandle):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         # Flow control
 *         self._high_water = FLOW_CONTROL_HIGH_WATER
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_15UVBaseTransport_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_15UVBaseTransport_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport___cinit__(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_15UVBaseTransport___cinit__(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/basetransport.pyx":6
 *     def __cinit__(self):
 *         # Flow control
 *         self._high_water = FLOW_CONTROL_HIGH_WATER             # <<<<<<<<<<<<<<
 *         self._low_water = FLOW_CONTROL_LOW_WATER
 * 
 */
  __pyx_v_self->_high_water = 0x10000;

  /* "uvloop/handles/basetransport.pyx":7
 *         # Flow control
 *         self._high_water = FLOW_CONTROL_HIGH_WATER
 *         self._low_water = FLOW_CONTROL_LOW_WATER             # <<<<<<<<<<<<<<
 * 
 *         self._protocol = None
 */
  __pyx_v_self->_low_water = 0x4000;

  /* "uvloop/handles/basetransport.pyx":9
 *         self._low_water = FLOW_CONTROL_LOW_WATER
 * 
 *         self._protocol = None             # <<<<<<<<<<<<<<
 *         self._protocol_connected = 0
 *         self._protocol_paused = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol);
  __Pyx_DECREF(__pyx_v_self->_protocol);
  __pyx_v_self->_protocol = Py_None;

  /* "uvloop/handles/basetransport.pyx":10
 * 
 *         self._protocol = None
 *         self._protocol_connected = 0             # <<<<<<<<<<<<<<
 *         self._protocol_paused = 0
 *         self._protocol_data_received = None
 */
  __pyx_v_self->_protocol_connected = 0;

  /* "uvloop/handles/basetransport.pyx":11
 *         self._protocol = None
 *         self._protocol_connected = 0
 *         self._protocol_paused = 0             # <<<<<<<<<<<<<<
 *         self._protocol_data_received = None
 * 
 */
  __pyx_v_self->_protocol_paused = 0;

  /* "uvloop/handles/basetransport.pyx":12
 *         self._protocol_connected = 0
 *         self._protocol_paused = 0
 *         self._protocol_data_received = None             # <<<<<<<<<<<<<<
 * 
 *         self._server = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol_data_received);
  __Pyx_DECREF(__pyx_v_self->_protocol_data_received);
  __pyx_v_self->_protocol_data_received = Py_None;

  /* "uvloop/handles/basetransport.pyx":14
 *         self._protocol_data_received = None
 * 
 *         self._server = None             # <<<<<<<<<<<<<<
 *         self._waiter = None
 *         self._extra_info = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_server);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_server));
  __pyx_v_self->_server = ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None);

  /* "uvloop/handles/basetransport.pyx":15
 * 
 *         self._server = None
 *         self._waiter = None             # <<<<<<<<<<<<<<
 *         self._extra_info = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_waiter);
  __Pyx_DECREF(__pyx_v_self->_waiter);
  __pyx_v_self->_waiter = Py_None;

  /* "uvloop/handles/basetransport.pyx":16
 *         self._server = None
 *         self._waiter = None
 *         self._extra_info = None             # <<<<<<<<<<<<<<
 * 
 *         self._conn_lost = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_extra_info);
  __Pyx_DECREF(__pyx_v_self->_extra_info);
  __pyx_v_self->_extra_info = ((PyObject*)Py_None);

  /* "uvloop/handles/basetransport.pyx":18
 *         self._extra_info = None
 * 
 *         self._conn_lost = 0             # <<<<<<<<<<<<<<
 * 
 *         self._closing = 0
 */
  __pyx_v_self->_conn_lost = 0;

  /* "uvloop/handles/basetransport.pyx":20
 *         self._conn_lost = 0
 * 
 *         self._closing = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef size_t _get_write_buffer_size(self):
 */
  __pyx_v_self->_closing = 0;

  /* "uvloop/handles/basetransport.pyx":4
 * cdef class UVBaseTransport(UVSocketHandle):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         # Flow control
 *         self._high_water = FLOW_CONTROL_HIGH_WATER
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":22
 *         self._closing = 0
 * 
 *     cdef size_t _get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */

static size_t __pyx_f_6uvloop_4loop_15UVBaseTransport__get_write_buffer_size(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_write_buffer_size", 0);

  /* "uvloop/handles/basetransport.pyx":23
 * 
 *     cdef size_t _get_write_buffer_size(self):
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _schedule_call_connection_made(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "uvloop/handles/basetransport.pyx":22
 *         self._closing = 0
 * 
 *     cdef size_t _get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":25
 *         return 0
 * 
 *     cdef inline _schedule_call_connection_made(self):             # <<<<<<<<<<<<<<
 *         self._loop._call_soon_handle(
 *             new_MethodHandle(self._loop,
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_made(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_schedule_call_connection_made", 0);

  /* "uvloop/handles/basetransport.pyx":27
 *     cdef inline _schedule_call_connection_made(self):
 *         self._loop._call_soon_handle(
 *             new_MethodHandle(self._loop,             # <<<<<<<<<<<<<<
 *                              "UVTransport._call_connection_made",
 *                              <method_t>self._call_connection_made,
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_1);

  /* "uvloop/handles/basetransport.pyx":30
 *                              "UVTransport._call_connection_made",
 *                              <method_t>self._call_connection_made,
 *                              self))             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _schedule_call_connection_lost(self, exc):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_new_MethodHandle(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1), __pyx_kp_u_UVTransport__call_connection_mad, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_call_connection_made), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":27
 *     cdef inline _schedule_call_connection_made(self):
 *         self._loop._call_soon_handle(
 *             new_MethodHandle(self._loop,             # <<<<<<<<<<<<<<
 *                              "UVTransport._call_connection_made",
 *                              <method_t>self._call_connection_made,
 */
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(16, 27, __pyx_L1_error)

  /* "uvloop/handles/basetransport.pyx":26
 * 
 *     cdef inline _schedule_call_connection_made(self):
 *         self._loop._call_soon_handle(             # <<<<<<<<<<<<<<
 *             new_MethodHandle(self._loop,
 *                              "UVTransport._call_connection_made",
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__call_soon_handle(__pyx_v_self->__pyx_base.__pyx_base._loop, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":25
 *         return 0
 * 
 *     cdef inline _schedule_call_connection_made(self):             # <<<<<<<<<<<<<<
 *         self._loop._call_soon_handle(
 *             new_MethodHandle(self._loop,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._schedule_call_connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":32
 *                              self))
 * 
 *     cdef inline _schedule_call_connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         self._loop._call_soon_handle(
 *             new_MethodHandle1(self._loop,
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_lost(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_schedule_call_connection_lost", 0);

  /* "uvloop/handles/basetransport.pyx":34
 *     cdef inline _schedule_call_connection_lost(self, exc):
 *         self._loop._call_soon_handle(
 *             new_MethodHandle1(self._loop,             # <<<<<<<<<<<<<<
 *                               "UVTransport._call_connection_lost",
 *                               <method1_t>self._call_connection_lost,
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_1);

  /* "uvloop/handles/basetransport.pyx":37
 *                               "UVTransport._call_connection_lost",
 *                               <method1_t>self._call_connection_lost,
 *                               self, exc))             # <<<<<<<<<<<<<<
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_new_MethodHandle1(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1), __pyx_kp_u_UVTransport__call_connection_los, ((__pyx_t_6uvloop_4loop_method1_t)((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_call_connection_lost), ((PyObject *)__pyx_v_self), __pyx_v_exc); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":34
 *     cdef inline _schedule_call_connection_lost(self, exc):
 *         self._loop._call_soon_handle(
 *             new_MethodHandle1(self._loop,             # <<<<<<<<<<<<<<
 *                               "UVTransport._call_connection_lost",
 *                               <method1_t>self._call_connection_lost,
 */
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(16, 34, __pyx_L1_error)

  /* "uvloop/handles/basetransport.pyx":33
 * 
 *     cdef inline _schedule_call_connection_lost(self, exc):
 *         self._loop._call_soon_handle(             # <<<<<<<<<<<<<<
 *             new_MethodHandle1(self._loop,
 *                               "UVTransport._call_connection_lost",
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__call_soon_handle(__pyx_v_self->__pyx_base.__pyx_base._loop, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":32
 *                              self))
 * 
 *     cdef inline _schedule_call_connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         self._loop._call_soon_handle(
 *             new_MethodHandle1(self._loop,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._schedule_call_connection_lost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":39
 *                               self, exc))
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         # Overload UVHandle._fatal_error
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__fatal_error(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__fatal_error *__pyx_optional_args) {
  PyObject *__pyx_v_reason = ((PyObject *)Py_None);
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("_fatal_error", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_reason = __pyx_optional_args->reason;
    }
  }

  /* "uvloop/handles/basetransport.pyx":42
 *         # Overload UVHandle._fatal_error
 * 
 *         self._force_close(exc)             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(exc, (BrokenPipeError,
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_force_close); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 42, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 42, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 42, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_v_exc);
      __Pyx_GIVEREF(__pyx_v_exc);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_exc);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":44
 *         self._force_close(exc)
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_BrokenPipeError); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/handles/basetransport.pyx":45
 * 
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,             # <<<<<<<<<<<<<<
 *                                 ConnectionAbortedError)):
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionResetError); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/handles/basetransport.pyx":46
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):             # <<<<<<<<<<<<<<
 * 
 *             if throw or self._loop is None:
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionAbortedError); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "uvloop/handles/basetransport.pyx":44
 *         self._force_close(exc)
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_1); 
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L4_bool_binop_done;
  }

  /* "uvloop/handles/basetransport.pyx":45
 * 
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,             # <<<<<<<<<<<<<<
 *                                 ConnectionAbortedError)):
 * 
 */
  __pyx_t_7 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_2); 
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "uvloop/handles/basetransport.pyx":46
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):             # <<<<<<<<<<<<<<
 * 
 *             if throw or self._loop is None:
 */
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_4); 
  __pyx_t_7 = (__pyx_t_6 != 0);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":44
 *         self._force_close(exc)
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  __pyx_t_7 = ((!(__pyx_t_5 != 0)) != 0);
  if (__pyx_t_7) {

    /* "uvloop/handles/basetransport.pyx":48
 *                                 ConnectionAbortedError)):
 * 
 *             if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_throw); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(16, 48, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_7 = __pyx_t_5;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_5 = (((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop) == Py_None);
    __pyx_t_6 = (__pyx_t_5 != 0);
    __pyx_t_7 = __pyx_t_6;
    __pyx_L8_bool_binop_done:;
    if (unlikely(__pyx_t_7)) {

      /* "uvloop/handles/basetransport.pyx":49
 * 
 *             if throw or self._loop is None:
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *             msg = 'Fatal error on transport {}'.format(
 */
      __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
      __PYX_ERR(16, 49, __pyx_L1_error)

      /* "uvloop/handles/basetransport.pyx":48
 *                                 ConnectionAbortedError)):
 * 
 *             if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
    }

    /* "uvloop/handles/basetransport.pyx":51
 *                 raise exc
 * 
 *             msg = 'Fatal error on transport {}'.format(             # <<<<<<<<<<<<<<
 *                     self.__class__.__name__)
 *             if reason is not None:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Fatal_error_on_transport, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "uvloop/handles/basetransport.pyx":52
 * 
 *             msg = 'Fatal error on transport {}'.format(
 *                     self.__class__.__name__)             # <<<<<<<<<<<<<<
 *             if reason is not None:
 *                 msg = '{} ({})'.format(msg, reason)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 51, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 51, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 51, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(16, 51, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_4); __pyx_t_4 = NULL;
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 51, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_msg = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/basetransport.pyx":53
 *             msg = 'Fatal error on transport {}'.format(
 *                     self.__class__.__name__)
 *             if reason is not None:             # <<<<<<<<<<<<<<
 *                 msg = '{} ({})'.format(msg, reason)
 * 
 */
    __pyx_t_7 = (__pyx_v_reason != Py_None);
    __pyx_t_6 = (__pyx_t_7 != 0);
    if (__pyx_t_6) {

      /* "uvloop/handles/basetransport.pyx":54
 *                     self.__class__.__name__)
 *             if reason is not None:
 *                 msg = '{} ({})'.format(msg, reason)             # <<<<<<<<<<<<<<
 * 
 *             self._loop.call_exception_handler({
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u__159, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 54, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_msg, __pyx_v_reason};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 54, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_msg, __pyx_v_reason};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 54, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 54, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_v_msg);
        __Pyx_GIVEREF(__pyx_v_msg);
        PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_9, __pyx_v_msg);
        __Pyx_INCREF(__pyx_v_reason);
        __Pyx_GIVEREF(__pyx_v_reason);
        PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_9, __pyx_v_reason);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 54, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_msg, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "uvloop/handles/basetransport.pyx":53
 *             msg = 'Fatal error on transport {}'.format(
 *                     self.__class__.__name__)
 *             if reason is not None:             # <<<<<<<<<<<<<<
 *                 msg = '{} ({})'.format(msg, reason)
 * 
 */
    }

    /* "uvloop/handles/basetransport.pyx":56
 *                 msg = '{} ({})'.format(msg, reason)
 * 
 *             self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                 'message': msg,
 *                 'exception': exc,
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "uvloop/handles/basetransport.pyx":57
 * 
 *             self._loop.call_exception_handler({
 *                 'message': msg,             # <<<<<<<<<<<<<<
 *                 'exception': exc,
 *                 'transport': self,
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_message, __pyx_v_msg) < 0) __PYX_ERR(16, 57, __pyx_L1_error)

    /* "uvloop/handles/basetransport.pyx":58
 *             self._loop.call_exception_handler({
 *                 'message': msg,
 *                 'exception': exc,             # <<<<<<<<<<<<<<
 *                 'transport': self,
 *                 'protocol': self._protocol,
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_exception, __pyx_v_exc) < 0) __PYX_ERR(16, 57, __pyx_L1_error)

    /* "uvloop/handles/basetransport.pyx":59
 *                 'message': msg,
 *                 'exception': exc,
 *                 'transport': self,             # <<<<<<<<<<<<<<
 *                 'protocol': self._protocol,
 *             })
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_transport, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(16, 57, __pyx_L1_error)

    /* "uvloop/handles/basetransport.pyx":60
 *                 'exception': exc,
 *                 'transport': self,
 *                 'protocol': self._protocol,             # <<<<<<<<<<<<<<
 *             })
 * 
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_protocol, __pyx_v_self->_protocol) < 0) __PYX_ERR(16, 57, __pyx_L1_error)
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 56, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 56, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_3};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 56, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 56, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 56, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/basetransport.pyx":44
 *         self._force_close(exc)
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  }

  /* "uvloop/handles/basetransport.pyx":39
 *                               self, exc))
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         # Overload UVHandle._fatal_error
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":63
 *             })
 * 
 *     cdef inline _set_write_buffer_limits(self, int high=-1, int low=-1):             # <<<<<<<<<<<<<<
 *         if high == -1:
 *             if low == -1:
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits *__pyx_optional_args) {
  int __pyx_v_high = ((int)-1);
  int __pyx_v_low = ((int)-1);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_set_write_buffer_limits", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_high = __pyx_optional_args->high;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_low = __pyx_optional_args->low;
      }
    }
  }

  /* "uvloop/handles/basetransport.pyx":64
 * 
 *     cdef inline _set_write_buffer_limits(self, int high=-1, int low=-1):
 *         if high == -1:             # <<<<<<<<<<<<<<
 *             if low == -1:
 *                 high = FLOW_CONTROL_HIGH_WATER
 */
  __pyx_t_1 = ((__pyx_v_high == -1L) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":65
 *     cdef inline _set_write_buffer_limits(self, int high=-1, int low=-1):
 *         if high == -1:
 *             if low == -1:             # <<<<<<<<<<<<<<
 *                 high = FLOW_CONTROL_HIGH_WATER
 *             else:
 */
    __pyx_t_1 = ((__pyx_v_low == -1L) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/basetransport.pyx":66
 *         if high == -1:
 *             if low == -1:
 *                 high = FLOW_CONTROL_HIGH_WATER             # <<<<<<<<<<<<<<
 *             else:
 *                 high = FLOW_CONTROL_LOW_WATER
 */
      __pyx_v_high = 0x10000;

      /* "uvloop/handles/basetransport.pyx":65
 *     cdef inline _set_write_buffer_limits(self, int high=-1, int low=-1):
 *         if high == -1:
 *             if low == -1:             # <<<<<<<<<<<<<<
 *                 high = FLOW_CONTROL_HIGH_WATER
 *             else:
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/basetransport.pyx":68
 *                 high = FLOW_CONTROL_HIGH_WATER
 *             else:
 *                 high = FLOW_CONTROL_LOW_WATER             # <<<<<<<<<<<<<<
 * 
 *         if low == -1:
 */
    /*else*/ {
      __pyx_v_high = 0x4000;
    }
    __pyx_L4:;

    /* "uvloop/handles/basetransport.pyx":64
 * 
 *     cdef inline _set_write_buffer_limits(self, int high=-1, int low=-1):
 *         if high == -1:             # <<<<<<<<<<<<<<
 *             if low == -1:
 *                 high = FLOW_CONTROL_HIGH_WATER
 */
  }

  /* "uvloop/handles/basetransport.pyx":70
 *                 high = FLOW_CONTROL_LOW_WATER
 * 
 *         if low == -1:             # <<<<<<<<<<<<<<
 *             low = high // 4
 * 
 */
  __pyx_t_1 = ((__pyx_v_low == -1L) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":71
 * 
 *         if low == -1:
 *             low = high // 4             # <<<<<<<<<<<<<<
 * 
 *         if not high >= low >= 0:
 */
    __pyx_v_low = __Pyx_div_long(__pyx_v_high, 4);

    /* "uvloop/handles/basetransport.pyx":70
 *                 high = FLOW_CONTROL_LOW_WATER
 * 
 *         if low == -1:             # <<<<<<<<<<<<<<
 *             low = high // 4
 * 
 */
  }

  /* "uvloop/handles/basetransport.pyx":73
 *             low = high // 4
 * 
 *         if not high >= low >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError('high (%r) must be >= low (%r) must be >= 0' %
 *                              (high, low))
 */
  __pyx_t_1 = (__pyx_v_high >= __pyx_v_low);
  if (__pyx_t_1) {
    __pyx_t_1 = (__pyx_v_low >= 0);
  }
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/basetransport.pyx":74
 * 
 *         if not high >= low >= 0:
 *             raise ValueError('high (%r) must be >= low (%r) must be >= 0' %             # <<<<<<<<<<<<<<
 *                              (high, low))
 * 
 */
    __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_high);
    __pyx_t_4 += 6;
    __Pyx_GIVEREF(__pyx_kp_u_high);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_high);

    /* "uvloop/handles/basetransport.pyx":75
 *         if not high >= low >= 0:
 *             raise ValueError('high (%r) must be >= low (%r) must be >= 0' %
 *                              (high, low))             # <<<<<<<<<<<<<<
 * 
 *         self._high_water = high
 */
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_high, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_must_be_low);
    __pyx_t_4 += 18;
    __Pyx_GIVEREF(__pyx_kp_u_must_be_low);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_must_be_low);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_low, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_must_be_0);
    __pyx_t_4 += 14;
    __Pyx_GIVEREF(__pyx_kp_u_must_be_0);
    PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_kp_u_must_be_0);

    /* "uvloop/handles/basetransport.pyx":74
 * 
 *         if not high >= low >= 0:
 *             raise ValueError('high (%r) must be >= low (%r) must be >= 0' %             # <<<<<<<<<<<<<<
 *                              (high, low))
 * 
 */
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_3, 5, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(16, 74, __pyx_L1_error)

    /* "uvloop/handles/basetransport.pyx":73
 *             low = high // 4
 * 
 *         if not high >= low >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError('high (%r) must be >= low (%r) must be >= 0' %
 *                              (high, low))
 */
  }

  /* "uvloop/handles/basetransport.pyx":77
 *                              (high, low))
 * 
 *         self._high_water = high             # <<<<<<<<<<<<<<
 *         self._low_water = low
 * 
 */
  __pyx_v_self->_high_water = __pyx_v_high;

  /* "uvloop/handles/basetransport.pyx":78
 * 
 *         self._high_water = high
 *         self._low_water = low             # <<<<<<<<<<<<<<
 * 
 *         self._maybe_pause_protocol()
 */
  __pyx_v_self->_low_water = __pyx_v_low;

  /* "uvloop/handles/basetransport.pyx":80
 *         self._low_water = low
 * 
 *         self._maybe_pause_protocol()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _maybe_pause_protocol(self):
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_pause_protocol(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/basetransport.pyx":63
 *             })
 * 
 *     cdef inline _set_write_buffer_limits(self, int high=-1, int low=-1):             # <<<<<<<<<<<<<<
 *         if high == -1:
 *             if low == -1:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._set_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":82
 *         self._maybe_pause_protocol()
 * 
 *     cdef inline _maybe_pause_protocol(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size = self._get_write_buffer_size()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_pause_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  size_t __pyx_v_size;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("_maybe_pause_protocol", 0);

  /* "uvloop/handles/basetransport.pyx":84
 *     cdef inline _maybe_pause_protocol(self):
 *         cdef:
 *             size_t size = self._get_write_buffer_size()             # <<<<<<<<<<<<<<
 * 
 *         if size <= self._high_water:
 */
  __pyx_v_size = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_get_write_buffer_size(__pyx_v_self);

  /* "uvloop/handles/basetransport.pyx":86
 *             size_t size = self._get_write_buffer_size()
 * 
 *         if size <= self._high_water:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_size <= __pyx_v_self->_high_water) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":87
 * 
 *         if size <= self._high_water:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if not self._protocol_paused:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":86
 *             size_t size = self._get_write_buffer_size()
 * 
 *         if size <= self._high_water:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/basetransport.pyx":89
 *             return
 * 
 *         if not self._protocol_paused:             # <<<<<<<<<<<<<<
 *             self._protocol_paused = 1
 *             try:
 */
  __pyx_t_1 = ((!(__pyx_v_self->_protocol_paused != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":90
 * 
 *         if not self._protocol_paused:
 *             self._protocol_paused = 1             # <<<<<<<<<<<<<<
 *             try:
 *                 self._protocol.pause_writing()
 */
    __pyx_v_self->_protocol_paused = 1;

    /* "uvloop/handles/basetransport.pyx":91
 *         if not self._protocol_paused:
 *             self._protocol_paused = 1
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol.pause_writing()
 *             except Exception as exc:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "uvloop/handles/basetransport.pyx":92
 *             self._protocol_paused = 1
 *             try:
 *                 self._protocol.pause_writing()             # <<<<<<<<<<<<<<
 *             except Exception as exc:
 *                 self._loop.call_exception_handler({
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_pause_writing); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 92, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        if (__pyx_t_7) {
          __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 92, __pyx_L5_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else {
          __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 92, __pyx_L5_error)
        }
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "uvloop/handles/basetransport.pyx":91
 *         if not self._protocol_paused:
 *             self._protocol_paused = 1
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol.pause_writing()
 *             except Exception as exc:
 */
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L10_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/handles/basetransport.pyx":93
 *             try:
 *                 self._protocol.pause_writing()
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.pause_writing() failed',
 */
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_8) {
        __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._maybe_pause_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(16, 93, __pyx_L7_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_exc = __pyx_t_6;
        /*try:*/ {

          /* "uvloop/handles/basetransport.pyx":94
 *                 self._protocol.pause_writing()
 *             except Exception as exc:
 *                 self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                     'message': 'protocol.pause_writing() failed',
 *                     'exception': exc,
 */
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_10)) __PYX_ERR(16, 94, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_10);

          /* "uvloop/handles/basetransport.pyx":95
 *             except Exception as exc:
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.pause_writing() failed',             # <<<<<<<<<<<<<<
 *                     'exception': exc,
 *                     'transport': self,
 */
          __pyx_t_11 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_11)) __PYX_ERR(16, 95, __pyx_L16_error)
          __Pyx_GOTREF(__pyx_t_11);
          if (PyDict_SetItem(__pyx_t_11, __pyx_n_u_message, __pyx_kp_u_protocol_pause_writing_failed) < 0) __PYX_ERR(16, 95, __pyx_L16_error)

          /* "uvloop/handles/basetransport.pyx":96
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.pause_writing() failed',
 *                     'exception': exc,             # <<<<<<<<<<<<<<
 *                     'transport': self,
 *                     'protocol': self._protocol,
 */
          if (PyDict_SetItem(__pyx_t_11, __pyx_n_u_exception, __pyx_v_exc) < 0) __PYX_ERR(16, 95, __pyx_L16_error)

          /* "uvloop/handles/basetransport.pyx":97
 *                     'message': 'protocol.pause_writing() failed',
 *                     'exception': exc,
 *                     'transport': self,             # <<<<<<<<<<<<<<
 *                     'protocol': self._protocol,
 *                 })
 */
          if (PyDict_SetItem(__pyx_t_11, __pyx_n_u_transport, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(16, 95, __pyx_L16_error)

          /* "uvloop/handles/basetransport.pyx":98
 *                     'exception': exc,
 *                     'transport': self,
 *                     'protocol': self._protocol,             # <<<<<<<<<<<<<<
 *                 })
 * 
 */
          if (PyDict_SetItem(__pyx_t_11, __pyx_n_u_protocol, __pyx_v_self->_protocol) < 0) __PYX_ERR(16, 95, __pyx_L16_error)
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          if (!__pyx_t_12) {
            __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 94, __pyx_L16_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_GOTREF(__pyx_t_9);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_11};
              __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 94, __pyx_L16_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
              PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_11};
              __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 94, __pyx_L16_error)
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            } else
            #endif
            {
              __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(16, 94, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
              __Pyx_GIVEREF(__pyx_t_11);
              PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_11);
              __pyx_t_11 = 0;
              __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 94, __pyx_L16_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }

        /* "uvloop/handles/basetransport.pyx":93
 *             try:
 *                 self._protocol.pause_writing()
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.pause_writing() failed',
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            goto __pyx_L17;
          }
          __pyx_L16_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __pyx_t_8 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
            }
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
            goto __pyx_L7_except_error;
          }
          __pyx_L17:;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "uvloop/handles/basetransport.pyx":91
 *         if not self._protocol_paused:
 *             self._protocol_paused = 1
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol.pause_writing()
 *             except Exception as exc:
 */
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      __pyx_L10_try_end:;
    }

    /* "uvloop/handles/basetransport.pyx":89
 *             return
 * 
 *         if not self._protocol_paused:             # <<<<<<<<<<<<<<
 *             self._protocol_paused = 1
 *             try:
 */
  }

  /* "uvloop/handles/basetransport.pyx":82
 *         self._maybe_pause_protocol()
 * 
 *     cdef inline _maybe_pause_protocol(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size = self._get_write_buffer_size()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._maybe_pause_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":101
 *                 })
 * 
 *     cdef inline _maybe_resume_protocol(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size = self._get_write_buffer_size()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_resume_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  size_t __pyx_v_size;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  __Pyx_RefNannySetupContext("_maybe_resume_protocol", 0);

  /* "uvloop/handles/basetransport.pyx":103
 *     cdef inline _maybe_resume_protocol(self):
 *         cdef:
 *             size_t size = self._get_write_buffer_size()             # <<<<<<<<<<<<<<
 * 
 *         if self._protocol_paused and size <= self._low_water:
 */
  __pyx_v_size = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_get_write_buffer_size(__pyx_v_self);

  /* "uvloop/handles/basetransport.pyx":105
 *             size_t size = self._get_write_buffer_size()
 * 
 *         if self._protocol_paused and size <= self._low_water:             # <<<<<<<<<<<<<<
 *             self._protocol_paused = 0
 *             try:
 */
  __pyx_t_2 = (__pyx_v_self->_protocol_paused != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_size <= __pyx_v_self->_low_water) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":106
 * 
 *         if self._protocol_paused and size <= self._low_water:
 *             self._protocol_paused = 0             # <<<<<<<<<<<<<<
 *             try:
 *                 self._protocol.resume_writing()
 */
    __pyx_v_self->_protocol_paused = 0;

    /* "uvloop/handles/basetransport.pyx":107
 *         if self._protocol_paused and size <= self._low_water:
 *             self._protocol_paused = 0
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol.resume_writing()
 *             except Exception as exc:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/handles/basetransport.pyx":108
 *             self._protocol_paused = 0
 *             try:
 *                 self._protocol.resume_writing()             # <<<<<<<<<<<<<<
 *             except Exception as exc:
 *                 self._loop.call_exception_handler({
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_resume_writing); if (unlikely(!__pyx_t_7)) __PYX_ERR(16, 108, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (__pyx_t_8) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 108, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else {
          __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 108, __pyx_L6_error)
        }
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/handles/basetransport.pyx":107
 *         if self._protocol_paused and size <= self._low_water:
 *             self._protocol_paused = 0
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol.resume_writing()
 *             except Exception as exc:
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/handles/basetransport.pyx":109
 *             try:
 *                 self._protocol.resume_writing()
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.resume_writing() failed',
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_9) {
        __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._maybe_resume_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(16, 109, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_exc = __pyx_t_7;
        /*try:*/ {

          /* "uvloop/handles/basetransport.pyx":110
 *                 self._protocol.resume_writing()
 *             except Exception as exc:
 *                 self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                     'message': 'protocol.resume_writing() failed',
 *                     'exception': exc,
 */
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_11)) __PYX_ERR(16, 110, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_11);

          /* "uvloop/handles/basetransport.pyx":111
 *             except Exception as exc:
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.resume_writing() failed',             # <<<<<<<<<<<<<<
 *                     'exception': exc,
 *                     'transport': self,
 */
          __pyx_t_12 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_12)) __PYX_ERR(16, 111, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_message, __pyx_kp_u_protocol_resume_writing_failed) < 0) __PYX_ERR(16, 111, __pyx_L17_error)

          /* "uvloop/handles/basetransport.pyx":112
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.resume_writing() failed',
 *                     'exception': exc,             # <<<<<<<<<<<<<<
 *                     'transport': self,
 *                     'protocol': self._protocol,
 */
          if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_exception, __pyx_v_exc) < 0) __PYX_ERR(16, 111, __pyx_L17_error)

          /* "uvloop/handles/basetransport.pyx":113
 *                     'message': 'protocol.resume_writing() failed',
 *                     'exception': exc,
 *                     'transport': self,             # <<<<<<<<<<<<<<
 *                     'protocol': self._protocol,
 *                 })
 */
          if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_transport, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(16, 111, __pyx_L17_error)

          /* "uvloop/handles/basetransport.pyx":114
 *                     'exception': exc,
 *                     'transport': self,
 *                     'protocol': self._protocol,             # <<<<<<<<<<<<<<
 *                 })
 * 
 */
          if (PyDict_SetItem(__pyx_t_12, __pyx_n_u_protocol, __pyx_v_self->_protocol) < 0) __PYX_ERR(16, 111, __pyx_L17_error)
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
            }
          }
          if (!__pyx_t_13) {
            __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(16, 110, __pyx_L17_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_10);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_11)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_12};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(16, 110, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_12};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(16, 110, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(16, 110, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
              __Pyx_GIVEREF(__pyx_t_12);
              PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_t_12);
              __pyx_t_12 = 0;
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_14, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(16, 110, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }

        /* "uvloop/handles/basetransport.pyx":109
 *             try:
 *                 self._protocol.resume_writing()
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._loop.call_exception_handler({
 *                     'message': 'protocol.resume_writing() failed',
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            goto __pyx_L18;
          }
          __pyx_L17_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_9 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
            goto __pyx_L8_except_error;
          }
          __pyx_L18:;
        }
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_exception_handled;
      }
      goto __pyx_L8_except_error;
      __pyx_L8_except_error:;

      /* "uvloop/handles/basetransport.pyx":107
 *         if self._protocol_paused and size <= self._low_water:
 *             self._protocol_paused = 0
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol.resume_writing()
 *             except Exception as exc:
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_L11_try_end:;
    }

    /* "uvloop/handles/basetransport.pyx":105
 *             size_t size = self._get_write_buffer_size()
 * 
 *         if self._protocol_paused and size <= self._low_water:             # <<<<<<<<<<<<<<
 *             self._protocol_paused = 0
 *             try:
 */
  }

  /* "uvloop/handles/basetransport.pyx":101
 *                 })
 * 
 *     cdef inline _maybe_resume_protocol(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             size_t size = self._get_write_buffer_size()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._maybe_resume_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":117
 *                 })
 * 
 *     cdef _wakeup_waiter(self):             # <<<<<<<<<<<<<<
 *         if self._waiter is not None:
 *             if not self._waiter.cancelled():
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__wakeup_waiter(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_wakeup_waiter", 0);

  /* "uvloop/handles/basetransport.pyx":118
 * 
 *     cdef _wakeup_waiter(self):
 *         if self._waiter is not None:             # <<<<<<<<<<<<<<
 *             if not self._waiter.cancelled():
 *                 if not self._is_alive():
 */
  __pyx_t_1 = (__pyx_v_self->_waiter != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/basetransport.pyx":119
 *     cdef _wakeup_waiter(self):
 *         if self._waiter is not None:
 *             if not self._waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 if not self._is_alive():
 *                     self._waiter.set_exception(
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_waiter, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 119, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 119, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(16, 119, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = ((!__pyx_t_2) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/basetransport.pyx":120
 *         if self._waiter is not None:
 *             if not self._waiter.cancelled():
 *                 if not self._is_alive():             # <<<<<<<<<<<<<<
 *                     self._waiter.set_exception(
 *                         RuntimeError(
 */
      __pyx_t_1 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
      if (__pyx_t_1) {

        /* "uvloop/handles/basetransport.pyx":121
 *             if not self._waiter.cancelled():
 *                 if not self._is_alive():
 *                     self._waiter.set_exception(             # <<<<<<<<<<<<<<
 *                         RuntimeError(
 *                             'closed Transport handle and unset waiter'))
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_waiter, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 121, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);

        /* "uvloop/handles/basetransport.pyx":122
 *                 if not self._is_alive():
 *                     self._waiter.set_exception(
 *                         RuntimeError(             # <<<<<<<<<<<<<<
 *                             'closed Transport handle and unset waiter'))
 *                 else:
 */
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__160, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        if (!__pyx_t_6) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 121, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 121, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 121, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          } else
          #endif
          {
            __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(16, 121, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
            __Pyx_GIVEREF(__pyx_t_5);
            PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
            __pyx_t_5 = 0;
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 121, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/basetransport.pyx":120
 *         if self._waiter is not None:
 *             if not self._waiter.cancelled():
 *                 if not self._is_alive():             # <<<<<<<<<<<<<<
 *                     self._waiter.set_exception(
 *                         RuntimeError(
 */
        goto __pyx_L5;
      }

      /* "uvloop/handles/basetransport.pyx":125
 *                             'closed Transport handle and unset waiter'))
 *                 else:
 *                     self._waiter.set_result(True)             # <<<<<<<<<<<<<<
 *             self._waiter = None
 * 
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_waiter, __pyx_n_s_set_result); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 125, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__161, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 125, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_L5:;

      /* "uvloop/handles/basetransport.pyx":119
 *     cdef _wakeup_waiter(self):
 *         if self._waiter is not None:
 *             if not self._waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 if not self._is_alive():
 *                     self._waiter.set_exception(
 */
    }

    /* "uvloop/handles/basetransport.pyx":126
 *                 else:
 *                     self._waiter.set_result(True)
 *             self._waiter = None             # <<<<<<<<<<<<<<
 * 
 *     cdef _call_connection_made(self):
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_waiter);
    __Pyx_DECREF(__pyx_v_self->_waiter);
    __pyx_v_self->_waiter = Py_None;

    /* "uvloop/handles/basetransport.pyx":118
 * 
 *     cdef _wakeup_waiter(self):
 *         if self._waiter is not None:             # <<<<<<<<<<<<<<
 *             if not self._waiter.cancelled():
 *                 if not self._is_alive():
 */
  }

  /* "uvloop/handles/basetransport.pyx":117
 *                 })
 * 
 *     cdef _wakeup_waiter(self):             # <<<<<<<<<<<<<<
 *         if self._waiter is not None:
 *             if not self._waiter.cancelled():
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._wakeup_waiter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":128
 *             self._waiter = None
 * 
 *     cdef _call_connection_made(self):             # <<<<<<<<<<<<<<
 *         if self._protocol is None:
 *             raise RuntimeError(
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__call_connection_made(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_call_connection_made", 0);

  /* "uvloop/handles/basetransport.pyx":129
 * 
 *     cdef _call_connection_made(self):
 *         if self._protocol is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'protocol is not set, cannot call connection_made()')
 */
  __pyx_t_1 = (__pyx_v_self->_protocol == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/basetransport.pyx":130
 *     cdef _call_connection_made(self):
 *         if self._protocol is None:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'protocol is not set, cannot call connection_made()')
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__162, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(16, 130, __pyx_L1_error)

    /* "uvloop/handles/basetransport.pyx":129
 * 
 *     cdef _call_connection_made(self):
 *         if self._protocol is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'protocol is not set, cannot call connection_made()')
 */
  }

  /* "uvloop/handles/basetransport.pyx":136
 *         # `transport._close()` in `loop.create_connection()` if an
 *         # exception happens during `await waiter`.
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             # A connection waiter can be cancelled between
 *             # 'await loop.create_connection()' and
 */
  __pyx_t_2 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/basetransport.pyx":141
 *             # `_schedule_call_connection_made` and
 *             # the actual `_call_connection_made`.
 *             self._wakeup_waiter()             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_wakeup_waiter(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/basetransport.pyx":142
 *             # the actual `_call_connection_made`.
 *             self._wakeup_waiter()
 *             return             # <<<<<<<<<<<<<<
 * 
 *         # Set _protocol_connected to 1 before calling "connection_made":
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":136
 *         # `transport._close()` in `loop.create_connection()` if an
 *         # exception happens during `await waiter`.
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             # A connection waiter can be cancelled between
 *             # 'await loop.create_connection()' and
 */
  }

  /* "uvloop/handles/basetransport.pyx":147
 *         # if transport is aborted or closed, "connection_lost" will
 *         # still be scheduled.
 *         self._protocol_connected = 1             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_v_self->_protocol_connected = 1;

  /* "uvloop/handles/basetransport.pyx":149
 *         self._protocol_connected = 1
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol.connection_made(self)
 *         except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/handles/basetransport.pyx":150
 * 
 *         try:
 *             self._protocol.connection_made(self)             # <<<<<<<<<<<<<<
 *         except:
 *             self._wakeup_waiter()
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_connection_made); if (unlikely(!__pyx_t_7)) __PYX_ERR(16, 150, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_8) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 150, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, ((PyObject *)__pyx_v_self)};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 150, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, ((PyObject *)__pyx_v_self)};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 150, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 150, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_9, 0+1, ((PyObject *)__pyx_v_self));
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 150, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/basetransport.pyx":149
 *         self._protocol_connected = 1
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol.connection_made(self)
 *         except:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/basetransport.pyx":151
 *         try:
 *             self._protocol.connection_made(self)
 *         except:             # <<<<<<<<<<<<<<
 *             self._wakeup_waiter()
 *             raise
 */
    /*except:*/ {
      __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._call_connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(16, 151, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_9);

      /* "uvloop/handles/basetransport.pyx":152
 *             self._protocol.connection_made(self)
 *         except:
 *             self._wakeup_waiter()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_wakeup_waiter(__pyx_v_self); if (unlikely(!__pyx_t_8)) __PYX_ERR(16, 152, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/handles/basetransport.pyx":153
 *         except:
 *             self._wakeup_waiter()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         if not self._is_alive():
 */
      __Pyx_GIVEREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestoreWithState(__pyx_t_3, __pyx_t_7, __pyx_t_9);
      __pyx_t_3 = 0; __pyx_t_7 = 0; __pyx_t_9 = 0; 
      __PYX_ERR(16, 153, __pyx_L7_except_error)
    }
    __pyx_L7_except_error:;

    /* "uvloop/handles/basetransport.pyx":149
 *         self._protocol_connected = 1
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol.connection_made(self)
 *         except:
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L10_try_end:;
  }

  /* "uvloop/handles/basetransport.pyx":155
 *             raise
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             # This might happen when "transport.abort()" is called
 *             # from "Protocol.connection_made".
 */
  __pyx_t_2 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/basetransport.pyx":158
 *             # This might happen when "transport.abort()" is called
 *             # from "Protocol.connection_made".
 *             self._wakeup_waiter()             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_wakeup_waiter(__pyx_v_self); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 158, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/handles/basetransport.pyx":159
 *             # from "Protocol.connection_made".
 *             self._wakeup_waiter()
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._start_reading()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":155
 *             raise
 * 
 *         if not self._is_alive():             # <<<<<<<<<<<<<<
 *             # This might happen when "transport.abort()" is called
 *             # from "Protocol.connection_made".
 */
  }

  /* "uvloop/handles/basetransport.pyx":161
 *             return
 * 
 *         self._start_reading()             # <<<<<<<<<<<<<<
 *         self._wakeup_waiter()
 * 
 */
  __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_start_reading(__pyx_v_self); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/handles/basetransport.pyx":162
 * 
 *         self._start_reading()
 *         self._wakeup_waiter()             # <<<<<<<<<<<<<<
 * 
 *     cdef _call_connection_lost(self, exc):
 */
  __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_wakeup_waiter(__pyx_v_self); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/handles/basetransport.pyx":128
 *             self._waiter = None
 * 
 *     cdef _call_connection_made(self):             # <<<<<<<<<<<<<<
 *         if self._protocol is None:
 *             raise RuntimeError(
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._call_connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":164
 *         self._wakeup_waiter()
 * 
 *     cdef _call_connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         if self._waiter is not None:
 *             # This shouldn't ever happen!
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__call_connection_lost(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc) {
  struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  __Pyx_RefNannySetupContext("_call_connection_lost", 0);

  /* "uvloop/handles/basetransport.pyx":165
 * 
 *     cdef _call_connection_lost(self, exc):
 *         if self._waiter is not None:             # <<<<<<<<<<<<<<
 *             # This shouldn't ever happen!
 *             self._loop.call_exception_handler({
 */
  __pyx_t_1 = (__pyx_v_self->_waiter != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/basetransport.pyx":167
 *         if self._waiter is not None:
 *             # This shouldn't ever happen!
 *             self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                 'message': 'waiter is not None in {}._call_connection_lost'.
 *                     format(self.__class__.__name__)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 167, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "uvloop/handles/basetransport.pyx":168
 *             # This shouldn't ever happen!
 *             self._loop.call_exception_handler({
 *                 'message': 'waiter is not None in {}._call_connection_lost'.             # <<<<<<<<<<<<<<
 *                     format(self.__class__.__name__)
 *             })
 */
    __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "uvloop/handles/basetransport.pyx":169
 *             self._loop.call_exception_handler({
 *                 'message': 'waiter is not None in {}._call_connection_lost'.
 *                     format(self.__class__.__name__)             # <<<<<<<<<<<<<<
 *             })
 *             if not self._waiter.done():
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_waiter_is_not_None_in__call_conn, __pyx_n_s_format); if (unlikely(!__pyx_t_7)) __PYX_ERR(16, 168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_8)) __PYX_ERR(16, 169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_name); if (unlikely(!__pyx_t_9)) __PYX_ERR(16, 169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 169, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_9};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 169, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_9};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 169, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(16, 169, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 169, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_u_message, __pyx_t_6) < 0) __PYX_ERR(16, 168, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 167, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 167, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 167, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(16, 167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 167, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/basetransport.pyx":171
 *                     format(self.__class__.__name__)
 *             })
 *             if not self._waiter.done():             # <<<<<<<<<<<<<<
 *                 self._waiter.set_exception(exc)
 *             self._waiter = None
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_waiter, __pyx_n_s_done); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 171, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 171, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 171, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(16, 171, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = ((!__pyx_t_2) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/basetransport.pyx":172
 *             })
 *             if not self._waiter.done():
 *                 self._waiter.set_exception(exc)             # <<<<<<<<<<<<<<
 *             self._waiter = None
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_waiter, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 172, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_exc};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 172, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_exc};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 172, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 172, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_GIVEREF(__pyx_v_exc);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_exc);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 172, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/basetransport.pyx":171
 *                     format(self.__class__.__name__)
 *             })
 *             if not self._waiter.done():             # <<<<<<<<<<<<<<
 *                 self._waiter.set_exception(exc)
 *             self._waiter = None
 */
    }

    /* "uvloop/handles/basetransport.pyx":173
 *             if not self._waiter.done():
 *                 self._waiter.set_exception(exc)
 *             self._waiter = None             # <<<<<<<<<<<<<<
 * 
 *         if self._closed:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_waiter);
    __Pyx_DECREF(__pyx_v_self->_waiter);
    __pyx_v_self->_waiter = Py_None;

    /* "uvloop/handles/basetransport.pyx":165
 * 
 *     cdef _call_connection_lost(self, exc):
 *         if self._waiter is not None:             # <<<<<<<<<<<<<<
 *             # This shouldn't ever happen!
 *             self._loop.call_exception_handler({
 */
  }

  /* "uvloop/handles/basetransport.pyx":175
 *             self._waiter = None
 * 
 *         if self._closed:             # <<<<<<<<<<<<<<
 *             # The handle is closed -- likely, _call_connection_lost
 *             # was already called before.
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base.__pyx_base._closed != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":178
 *             # The handle is closed -- likely, _call_connection_lost
 *             # was already called before.
 *             return             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":175
 *             self._waiter = None
 * 
 *         if self._closed:             # <<<<<<<<<<<<<<
 *             # The handle is closed -- likely, _call_connection_lost
 *             # was already called before.
 */
  }

  /* "uvloop/handles/basetransport.pyx":180
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self._protocol_connected:
 *                 self._protocol.connection_lost(exc)
 */
  /*try:*/ {

    /* "uvloop/handles/basetransport.pyx":181
 * 
 *         try:
 *             if self._protocol_connected:             # <<<<<<<<<<<<<<
 *                 self._protocol.connection_lost(exc)
 *         finally:
 */
    __pyx_t_1 = (__pyx_v_self->_protocol_connected != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/basetransport.pyx":182
 *         try:
 *             if self._protocol_connected:
 *                 self._protocol.connection_lost(exc)             # <<<<<<<<<<<<<<
 *         finally:
 *             self._clear_protocol()
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_connection_lost); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 182, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 182, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_exc};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 182, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_exc};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 182, __pyx_L7_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(16, 182, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_GIVEREF(__pyx_v_exc);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_exc);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 182, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/basetransport.pyx":181
 * 
 *         try:
 *             if self._protocol_connected:             # <<<<<<<<<<<<<<
 *                 self._protocol.connection_lost(exc)
 *         finally:
 */
    }
  }

  /* "uvloop/handles/basetransport.pyx":184
 *                 self._protocol.connection_lost(exc)
 *         finally:
 *             self._clear_protocol()             # <<<<<<<<<<<<<<
 * 
 *             self._close()
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_clear_protocol(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 184, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/basetransport.pyx":186
 *             self._clear_protocol()
 * 
 *             self._close()             # <<<<<<<<<<<<<<
 * 
 *             server = self._server
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 186, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/basetransport.pyx":188
 *             self._close()
 * 
 *             server = self._server             # <<<<<<<<<<<<<<
 *             if server is not None:
 *                 (<Server>server)._detach()
 */
      __pyx_t_3 = ((PyObject *)__pyx_v_self->_server);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_server = ((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "uvloop/handles/basetransport.pyx":189
 * 
 *             server = self._server
 *             if server is not None:             # <<<<<<<<<<<<<<
 *                 (<Server>server)._detach()
 *                 self._server = None
 */
      __pyx_t_1 = (((PyObject *)__pyx_v_server) != Py_None);
      __pyx_t_2 = (__pyx_t_1 != 0);
      if (__pyx_t_2) {

        /* "uvloop/handles/basetransport.pyx":190
 *             server = self._server
 *             if server is not None:
 *                 (<Server>server)._detach()             # <<<<<<<<<<<<<<
 *                 self._server = None
 * 
 */
        __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_server)->__pyx_vtab)->_detach(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_server)); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 190, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/basetransport.pyx":191
 *             if server is not None:
 *                 (<Server>server)._detach()
 *                 self._server = None             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _set_server(self, Server server):
 */
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->_server);
        __Pyx_DECREF(((PyObject *)__pyx_v_self->_server));
        __pyx_v_self->_server = ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None);

        /* "uvloop/handles/basetransport.pyx":189
 * 
 *             server = self._server
 *             if server is not None:             # <<<<<<<<<<<<<<
 *                 (<Server>server)._detach()
 *                 self._server = None
 */
      }
      goto __pyx_L8;
    }
    __pyx_L7_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_19);
      __pyx_t_11 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
      {

        /* "uvloop/handles/basetransport.pyx":184
 *                 self._protocol.connection_lost(exc)
 *         finally:
 *             self._clear_protocol()             # <<<<<<<<<<<<<<
 * 
 *             self._close()
 */
        __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_clear_protocol(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 184, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/basetransport.pyx":186
 *             self._clear_protocol()
 * 
 *             self._close()             # <<<<<<<<<<<<<<
 * 
 *             server = self._server
 */
        __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 186, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/basetransport.pyx":188
 *             self._close()
 * 
 *             server = self._server             # <<<<<<<<<<<<<<
 *             if server is not None:
 *                 (<Server>server)._detach()
 */
        __pyx_t_3 = ((PyObject *)__pyx_v_self->_server);
        __Pyx_INCREF(__pyx_t_3);
        __pyx_v_server = ((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_t_3);
        __pyx_t_3 = 0;

        /* "uvloop/handles/basetransport.pyx":189
 * 
 *             server = self._server
 *             if server is not None:             # <<<<<<<<<<<<<<
 *                 (<Server>server)._detach()
 *                 self._server = None
 */
        __pyx_t_2 = (((PyObject *)__pyx_v_server) != Py_None);
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "uvloop/handles/basetransport.pyx":190
 *             server = self._server
 *             if server is not None:
 *                 (<Server>server)._detach()             # <<<<<<<<<<<<<<
 *                 self._server = None
 * 
 */
          __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_server)->__pyx_vtab)->_detach(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_server)); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 190, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "uvloop/handles/basetransport.pyx":191
 *             if server is not None:
 *                 (<Server>server)._detach()
 *                 self._server = None             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _set_server(self, Server server):
 */
          __Pyx_INCREF(Py_None);
          __Pyx_GIVEREF(Py_None);
          __Pyx_GOTREF(__pyx_v_self->_server);
          __Pyx_DECREF(((PyObject *)__pyx_v_self->_server));
          __pyx_v_self->_server = ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None);

          /* "uvloop/handles/basetransport.pyx":189
 * 
 *             server = self._server
 *             if server is not None:             # <<<<<<<<<<<<<<
 *                 (<Server>server)._detach()
 *                 self._server = None
 */
        }
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
      }
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_XGIVEREF(__pyx_t_15);
      __Pyx_XGIVEREF(__pyx_t_16);
      __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
      __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
      goto __pyx_L1_error;
      __pyx_L12_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
      }
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L8:;
  }

  /* "uvloop/handles/basetransport.pyx":164
 *         self._wakeup_waiter()
 * 
 *     cdef _call_connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         if self._waiter is not None:
 *             # This shouldn't ever happen!
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._call_connection_lost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_server);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":193
 *                 self._server = None
 * 
 *     cdef inline _set_server(self, Server server):             # <<<<<<<<<<<<<<
 *         self._server = server
 *         (<Server>server)._attach()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_server(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_set_server", 0);

  /* "uvloop/handles/basetransport.pyx":194
 * 
 *     cdef inline _set_server(self, Server server):
 *         self._server = server             # <<<<<<<<<<<<<<
 *         (<Server>server)._attach()
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_server));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_server));
  __Pyx_GOTREF(__pyx_v_self->_server);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_server));
  __pyx_v_self->_server = __pyx_v_server;

  /* "uvloop/handles/basetransport.pyx":195
 *     cdef inline _set_server(self, Server server):
 *         self._server = server
 *         (<Server>server)._attach()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _set_waiter(self, object waiter):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_server)->__pyx_vtab)->_attach(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_server)); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":193
 *                 self._server = None
 * 
 *     cdef inline _set_server(self, Server server):             # <<<<<<<<<<<<<<
 *         self._server = server
 *         (<Server>server)._attach()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._set_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":197
 *         (<Server>server)._attach()
 * 
 *     cdef inline _set_waiter(self, object waiter):             # <<<<<<<<<<<<<<
 *         if waiter is not None and not isfuture(waiter):
 *             raise TypeError(
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_waiter(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_waiter) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_set_waiter", 0);

  /* "uvloop/handles/basetransport.pyx":198
 * 
 *     cdef inline _set_waiter(self, object waiter):
 *         if waiter is not None and not isfuture(waiter):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 'invalid waiter object {!r}, expected asyncio.Future'.
 */
  __pyx_t_2 = (__pyx_v_waiter != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __pyx_f_6uvloop_4loop_isfuture(__pyx_v_waiter); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(16, 198, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = ((!__pyx_t_3) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/basetransport.pyx":200
 *         if waiter is not None and not isfuture(waiter):
 *             raise TypeError(
 *                 'invalid waiter object {!r}, expected asyncio.Future'.             # <<<<<<<<<<<<<<
 *                     format(waiter))
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_invalid_waiter_object_r_expected, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 200, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "uvloop/handles/basetransport.pyx":201
 *             raise TypeError(
 *                 'invalid waiter object {!r}, expected asyncio.Future'.
 *                     format(waiter))             # <<<<<<<<<<<<<<
 * 
 *         self._waiter = waiter
 */
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_waiter); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 201, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_waiter};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 201, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_waiter};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 201, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(16, 201, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_waiter);
        __Pyx_GIVEREF(__pyx_v_waiter);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_waiter);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 201, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/basetransport.pyx":199
 *     cdef inline _set_waiter(self, object waiter):
 *         if waiter is not None and not isfuture(waiter):
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 'invalid waiter object {!r}, expected asyncio.Future'.
 *                     format(waiter))
 */
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(16, 199, __pyx_L1_error)

    /* "uvloop/handles/basetransport.pyx":198
 * 
 *     cdef inline _set_waiter(self, object waiter):
 *         if waiter is not None and not isfuture(waiter):             # <<<<<<<<<<<<<<
 *             raise TypeError(
 *                 'invalid waiter object {!r}, expected asyncio.Future'.
 */
  }

  /* "uvloop/handles/basetransport.pyx":203
 *                     format(waiter))
 * 
 *         self._waiter = waiter             # <<<<<<<<<<<<<<
 * 
 *     cdef _set_protocol(self, object protocol):
 */
  __Pyx_INCREF(__pyx_v_waiter);
  __Pyx_GIVEREF(__pyx_v_waiter);
  __Pyx_GOTREF(__pyx_v_self->_waiter);
  __Pyx_DECREF(__pyx_v_self->_waiter);
  __pyx_v_self->_waiter = __pyx_v_waiter;

  /* "uvloop/handles/basetransport.pyx":197
 *         (<Server>server)._attach()
 * 
 *     cdef inline _set_waiter(self, object waiter):             # <<<<<<<<<<<<<<
 *         if waiter is not None and not isfuture(waiter):
 *             raise TypeError(
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._set_waiter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":205
 *         self._waiter = waiter
 * 
 *     cdef _set_protocol(self, object protocol):             # <<<<<<<<<<<<<<
 *         self._protocol = protocol
 *         # Store a reference to the bound method directly
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__set_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_protocol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("_set_protocol", 0);

  /* "uvloop/handles/basetransport.pyx":206
 * 
 *     cdef _set_protocol(self, object protocol):
 *         self._protocol = protocol             # <<<<<<<<<<<<<<
 *         # Store a reference to the bound method directly
 *         try:
 */
  __Pyx_INCREF(__pyx_v_protocol);
  __Pyx_GIVEREF(__pyx_v_protocol);
  __Pyx_GOTREF(__pyx_v_self->_protocol);
  __Pyx_DECREF(__pyx_v_self->_protocol);
  __pyx_v_self->_protocol = __pyx_v_protocol;

  /* "uvloop/handles/basetransport.pyx":208
 *         self._protocol = protocol
 *         # Store a reference to the bound method directly
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol_data_received = protocol.data_received
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/handles/basetransport.pyx":209
 *         # Store a reference to the bound method directly
 *         try:
 *             self._protocol_data_received = protocol.data_received             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             pass
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_protocol, __pyx_n_s_data_received); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 209, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_v_self->_protocol_data_received);
      __Pyx_DECREF(__pyx_v_self->_protocol_data_received);
      __pyx_v_self->_protocol_data_received = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "uvloop/handles/basetransport.pyx":208
 *         self._protocol = protocol
 *         # Store a reference to the bound method directly
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol_data_received = protocol.data_received
 *         except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/basetransport.pyx":210
 *         try:
 *             self._protocol_data_received = protocol.data_received
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             pass
 * 
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_5) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/handles/basetransport.pyx":208
 *         self._protocol = protocol
 *         # Store a reference to the bound method directly
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol_data_received = protocol.data_received
 *         except AttributeError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "uvloop/handles/basetransport.pyx":205
 *         self._waiter = waiter
 * 
 *     cdef _set_protocol(self, object protocol):             # <<<<<<<<<<<<<<
 *         self._protocol = protocol
 *         # Store a reference to the bound method directly
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._set_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":213
 *             pass
 * 
 *     cdef _clear_protocol(self):             # <<<<<<<<<<<<<<
 *         self._protocol = None
 *         self._protocol_data_received = None
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__clear_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_clear_protocol", 0);

  /* "uvloop/handles/basetransport.pyx":214
 * 
 *     cdef _clear_protocol(self):
 *         self._protocol = None             # <<<<<<<<<<<<<<
 *         self._protocol_data_received = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol);
  __Pyx_DECREF(__pyx_v_self->_protocol);
  __pyx_v_self->_protocol = Py_None;

  /* "uvloop/handles/basetransport.pyx":215
 *     cdef _clear_protocol(self):
 *         self._protocol = None
 *         self._protocol_data_received = None             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _init_protocol(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol_data_received);
  __Pyx_DECREF(__pyx_v_self->_protocol_data_received);
  __pyx_v_self->_protocol_data_received = Py_None;

  /* "uvloop/handles/basetransport.pyx":213
 *             pass
 * 
 *     cdef _clear_protocol(self):             # <<<<<<<<<<<<<<
 *         self._protocol = None
 *         self._protocol_data_received = None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":217
 *         self._protocol_data_received = None
 * 
 *     cdef inline _init_protocol(self):             # <<<<<<<<<<<<<<
 *         self._loop._track_transport(self)
 *         if self._protocol is None:
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__init_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("_init_protocol", 0);

  /* "uvloop/handles/basetransport.pyx":218
 * 
 *     cdef inline _init_protocol(self):
 *         self._loop._track_transport(self)             # <<<<<<<<<<<<<<
 *         if self._protocol is None:
 *             raise RuntimeError('invalid _init_protocol call')
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_base.__pyx_base._loop->__pyx_vtab)->_track_transport(__pyx_v_self->__pyx_base.__pyx_base._loop, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":219
 *     cdef inline _init_protocol(self):
 *         self._loop._track_transport(self)
 *         if self._protocol is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('invalid _init_protocol call')
 *         self._schedule_call_connection_made()
 */
  __pyx_t_2 = (__pyx_v_self->_protocol == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/handles/basetransport.pyx":220
 *         self._loop._track_transport(self)
 *         if self._protocol is None:
 *             raise RuntimeError('invalid _init_protocol call')             # <<<<<<<<<<<<<<
 *         self._schedule_call_connection_made()
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__163, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(16, 220, __pyx_L1_error)

    /* "uvloop/handles/basetransport.pyx":219
 *     cdef inline _init_protocol(self):
 *         self._loop._track_transport(self)
 *         if self._protocol is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('invalid _init_protocol call')
 *         self._schedule_call_connection_made()
 */
  }

  /* "uvloop/handles/basetransport.pyx":221
 *         if self._protocol is None:
 *             raise RuntimeError('invalid _init_protocol call')
 *         self._schedule_call_connection_made()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _add_extra_info(self, str name, object obj):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_made(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":217
 *         self._protocol_data_received = None
 * 
 *     cdef inline _init_protocol(self):             # <<<<<<<<<<<<<<
 *         self._loop._track_transport(self)
 *         if self._protocol is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._init_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":223
 *         self._schedule_call_connection_made()
 * 
 *     cdef inline _add_extra_info(self, str name, object obj):             # <<<<<<<<<<<<<<
 *         if self._extra_info is None:
 *             self._extra_info = {}
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__add_extra_info(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_add_extra_info", 0);

  /* "uvloop/handles/basetransport.pyx":224
 * 
 *     cdef inline _add_extra_info(self, str name, object obj):
 *         if self._extra_info is None:             # <<<<<<<<<<<<<<
 *             self._extra_info = {}
 *         self._extra_info[name] = obj
 */
  __pyx_t_1 = (__pyx_v_self->_extra_info == ((PyObject*)Py_None));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/basetransport.pyx":225
 *     cdef inline _add_extra_info(self, str name, object obj):
 *         if self._extra_info is None:
 *             self._extra_info = {}             # <<<<<<<<<<<<<<
 *         self._extra_info[name] = obj
 * 
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->_extra_info);
    __Pyx_DECREF(__pyx_v_self->_extra_info);
    __pyx_v_self->_extra_info = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/handles/basetransport.pyx":224
 * 
 *     cdef inline _add_extra_info(self, str name, object obj):
 *         if self._extra_info is None:             # <<<<<<<<<<<<<<
 *             self._extra_info = {}
 *         self._extra_info[name] = obj
 */
  }

  /* "uvloop/handles/basetransport.pyx":226
 *         if self._extra_info is None:
 *             self._extra_info = {}
 *         self._extra_info[name] = obj             # <<<<<<<<<<<<<<
 * 
 *     cdef bint _is_reading(self):
 */
  if (unlikely(__pyx_v_self->_extra_info == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(16, 226, __pyx_L1_error)
  }
  if (unlikely(PyDict_SetItem(__pyx_v_self->_extra_info, __pyx_v_name, __pyx_v_obj) < 0)) __PYX_ERR(16, 226, __pyx_L1_error)

  /* "uvloop/handles/basetransport.pyx":223
 *         self._schedule_call_connection_made()
 * 
 *     cdef inline _add_extra_info(self, str name, object obj):             # <<<<<<<<<<<<<<
 *         if self._extra_info is None:
 *             self._extra_info = {}
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._add_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":228
 *         self._extra_info[name] = obj
 * 
 *     cdef bint _is_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

static int __pyx_f_6uvloop_4loop_15UVBaseTransport__is_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_is_reading", 0);

  /* "uvloop/handles/basetransport.pyx":229
 * 
 *     cdef bint _is_reading(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     cdef _start_reading(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(16, 229, __pyx_L1_error)

  /* "uvloop/handles/basetransport.pyx":228
 *         self._extra_info[name] = obj
 * 
 *     cdef bint _is_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_WriteUnraisable("uvloop.loop.UVBaseTransport._is_reading", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":231
 *         raise NotImplementedError
 * 
 *     cdef _start_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__start_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_start_reading", 0);

  /* "uvloop/handles/basetransport.pyx":232
 * 
 *     cdef _start_reading(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     cdef _stop_reading(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(16, 232, __pyx_L1_error)

  /* "uvloop/handles/basetransport.pyx":231
 *         raise NotImplementedError
 * 
 *     cdef _start_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._start_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":234
 *         raise NotImplementedError
 * 
 *     cdef _stop_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_15UVBaseTransport__stop_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_stop_reading", 0);

  /* "uvloop/handles/basetransport.pyx":235
 * 
 *     cdef _stop_reading(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     # === Public API ===
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(16, 235, __pyx_L1_error)

  /* "uvloop/handles/basetransport.pyx":234
 *         raise NotImplementedError
 * 
 *     cdef _stop_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._stop_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":241
 *     property _paused:
 *         # Used by SSLProto.  Might be removed in the future.
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return bool(not self._is_reading())
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_7_paused_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_7_paused_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_7_paused___get__(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_7_paused___get__(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "uvloop/handles/basetransport.pyx":242
 *         # Used by SSLProto.  Might be removed in the future.
 *         def __get__(self):
 *             return bool(not self._is_reading())             # <<<<<<<<<<<<<<
 * 
 *     def get_protocol(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = (!(((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_is_reading(__pyx_v_self) != 0));
  __pyx_t_2 = __Pyx_PyBool_FromLong((!(!__pyx_t_1))); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/basetransport.pyx":241
 *     property _paused:
 *         # Used by SSLProto.  Might be removed in the future.
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return bool(not self._is_reading())
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._paused.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":244
 *             return bool(not self._is_reading())
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._protocol
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_3get_protocol(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_2get_protocol[] = "UVBaseTransport.get_protocol(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_3get_protocol(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_protocol (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_2get_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_2get_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_protocol", 0);

  /* "uvloop/handles/basetransport.pyx":245
 * 
 *     def get_protocol(self):
 *         return self._protocol             # <<<<<<<<<<<<<<
 * 
 *     def set_protocol(self, protocol):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_protocol);
  __pyx_r = __pyx_v_self->_protocol;
  goto __pyx_L0;

  /* "uvloop/handles/basetransport.pyx":244
 *             return bool(not self._is_reading())
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._protocol
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":247
 *         return self._protocol
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._set_protocol(protocol)
 *         if self._is_reading():
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_5set_protocol(PyObject *__pyx_v_self, PyObject *__pyx_v_protocol); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_4set_protocol[] = "UVBaseTransport.set_protocol(self, protocol)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_5set_protocol(PyObject *__pyx_v_self, PyObject *__pyx_v_protocol) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_protocol (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_4set_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), ((PyObject *)__pyx_v_protocol));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_4set_protocol(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_protocol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_protocol", 0);

  /* "uvloop/handles/basetransport.pyx":248
 * 
 *     def set_protocol(self, protocol):
 *         self._set_protocol(protocol)             # <<<<<<<<<<<<<<
 *         if self._is_reading():
 *             self._stop_reading()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_set_protocol(__pyx_v_self, __pyx_v_protocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":249
 *     def set_protocol(self, protocol):
 *         self._set_protocol(protocol)
 *         if self._is_reading():             # <<<<<<<<<<<<<<
 *             self._stop_reading()
 *             self._start_reading()
 */
  __pyx_t_2 = (((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_is_reading(__pyx_v_self) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/basetransport.pyx":250
 *         self._set_protocol(protocol)
 *         if self._is_reading():
 *             self._stop_reading()             # <<<<<<<<<<<<<<
 *             self._start_reading()
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_stop_reading(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/basetransport.pyx":251
 *         if self._is_reading():
 *             self._stop_reading()
 *             self._start_reading()             # <<<<<<<<<<<<<<
 * 
 *     def _force_close(self, exc):
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_start_reading(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/basetransport.pyx":249
 *     def set_protocol(self, protocol):
 *         self._set_protocol(protocol)
 *         if self._is_reading():             # <<<<<<<<<<<<<<
 *             self._stop_reading()
 *             self._start_reading()
 */
  }

  /* "uvloop/handles/basetransport.pyx":247
 *         return self._protocol
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._set_protocol(protocol)
 *         if self._is_reading():
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.set_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":253
 *             self._start_reading()
 * 
 *     def _force_close(self, exc):             # <<<<<<<<<<<<<<
 *         # Used by SSLProto.  Might be removed in the future.
 *         if self._conn_lost or self._closed:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_7_force_close(PyObject *__pyx_v_self, PyObject *__pyx_v_exc); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_6_force_close[] = "UVBaseTransport._force_close(self, exc)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_7_force_close(PyObject *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_force_close (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_6_force_close(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), ((PyObject *)__pyx_v_exc));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_6_force_close(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_force_close", 0);

  /* "uvloop/handles/basetransport.pyx":255
 *     def _force_close(self, exc):
 *         # Used by SSLProto.  Might be removed in the future.
 *         if self._conn_lost or self._closed:             # <<<<<<<<<<<<<<
 *             return
 *         if not self._closing:
 */
  __pyx_t_2 = (__pyx_v_self->_conn_lost != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->__pyx_base.__pyx_base._closed != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":256
 *         # Used by SSLProto.  Might be removed in the future.
 *         if self._conn_lost or self._closed:
 *             return             # <<<<<<<<<<<<<<
 *         if not self._closing:
 *             self._closing = 1
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":255
 *     def _force_close(self, exc):
 *         # Used by SSLProto.  Might be removed in the future.
 *         if self._conn_lost or self._closed:             # <<<<<<<<<<<<<<
 *             return
 *         if not self._closing:
 */
  }

  /* "uvloop/handles/basetransport.pyx":257
 *         if self._conn_lost or self._closed:
 *             return
 *         if not self._closing:             # <<<<<<<<<<<<<<
 *             self._closing = 1
 *             self._stop_reading()
 */
  __pyx_t_1 = ((!(__pyx_v_self->_closing != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":258
 *             return
 *         if not self._closing:
 *             self._closing = 1             # <<<<<<<<<<<<<<
 *             self._stop_reading()
 *         self._conn_lost += 1
 */
    __pyx_v_self->_closing = 1;

    /* "uvloop/handles/basetransport.pyx":259
 *         if not self._closing:
 *             self._closing = 1
 *             self._stop_reading()             # <<<<<<<<<<<<<<
 *         self._conn_lost += 1
 *         self._schedule_call_connection_lost(exc)
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_stop_reading(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/basetransport.pyx":257
 *         if self._conn_lost or self._closed:
 *             return
 *         if not self._closing:             # <<<<<<<<<<<<<<
 *             self._closing = 1
 *             self._stop_reading()
 */
  }

  /* "uvloop/handles/basetransport.pyx":260
 *             self._closing = 1
 *             self._stop_reading()
 *         self._conn_lost += 1             # <<<<<<<<<<<<<<
 *         self._schedule_call_connection_lost(exc)
 * 
 */
  __pyx_v_self->_conn_lost = (__pyx_v_self->_conn_lost + 1);

  /* "uvloop/handles/basetransport.pyx":261
 *             self._stop_reading()
 *         self._conn_lost += 1
 *         self._schedule_call_connection_lost(exc)             # <<<<<<<<<<<<<<
 * 
 *     def abort(self):
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_lost(__pyx_v_self, __pyx_v_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/basetransport.pyx":253
 *             self._start_reading()
 * 
 *     def _force_close(self, exc):             # <<<<<<<<<<<<<<
 *         # Used by SSLProto.  Might be removed in the future.
 *         if self._conn_lost or self._closed:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._force_close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":263
 *         self._schedule_call_connection_lost(exc)
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         self._force_close(None)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_9abort(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_8abort[] = "UVBaseTransport.abort(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_9abort(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("abort (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_8abort(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_8abort(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("abort", 0);

  /* "uvloop/handles/basetransport.pyx":264
 * 
 *     def abort(self):
 *         self._force_close(None)             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_force_close); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__164, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/basetransport.pyx":263
 *         self._schedule_call_connection_lost(exc)
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         self._force_close(None)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.abort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":266
 *         self._force_close(None)
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         if self._closing or self._closed:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_11close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_10close[] = "UVBaseTransport.close(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_11close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_10close(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_10close(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("close", 0);

  /* "uvloop/handles/basetransport.pyx":267
 * 
 *     def close(self):
 *         if self._closing or self._closed:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = (__pyx_v_self->_closing != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->__pyx_base.__pyx_base._closed != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":268
 *     def close(self):
 *         if self._closing or self._closed:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._closing = 1
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":267
 * 
 *     def close(self):
 *         if self._closing or self._closed:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/basetransport.pyx":270
 *             return
 * 
 *         self._closing = 1             # <<<<<<<<<<<<<<
 *         self._stop_reading()
 * 
 */
  __pyx_v_self->_closing = 1;

  /* "uvloop/handles/basetransport.pyx":271
 * 
 *         self._closing = 1
 *         self._stop_reading()             # <<<<<<<<<<<<<<
 * 
 *         if not self._get_write_buffer_size():
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_stop_reading(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/basetransport.pyx":273
 *         self._stop_reading()
 * 
 *         if not self._get_write_buffer_size():             # <<<<<<<<<<<<<<
 *             # The write buffer is empty
 *             self._conn_lost += 1
 */
  __pyx_t_1 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_get_write_buffer_size(__pyx_v_self) != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":275
 *         if not self._get_write_buffer_size():
 *             # The write buffer is empty
 *             self._conn_lost += 1             # <<<<<<<<<<<<<<
 *             self._schedule_call_connection_lost(None)
 * 
 */
    __pyx_v_self->_conn_lost = (__pyx_v_self->_conn_lost + 1);

    /* "uvloop/handles/basetransport.pyx":276
 *             # The write buffer is empty
 *             self._conn_lost += 1
 *             self._schedule_call_connection_lost(None)             # <<<<<<<<<<<<<<
 * 
 *     def is_closing(self):
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_lost(__pyx_v_self, Py_None); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/basetransport.pyx":273
 *         self._stop_reading()
 * 
 *         if not self._get_write_buffer_size():             # <<<<<<<<<<<<<<
 *             # The write buffer is empty
 *             self._conn_lost += 1
 */
  }

  /* "uvloop/handles/basetransport.pyx":266
 *         self._force_close(None)
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         if self._closing or self._closed:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":278
 *             self._schedule_call_connection_lost(None)
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closing
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_13is_closing(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_12is_closing[] = "UVBaseTransport.is_closing(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_13is_closing(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_closing (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_12is_closing(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_12is_closing(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("is_closing", 0);

  /* "uvloop/handles/basetransport.pyx":279
 * 
 *     def is_closing(self):
 *         return self._closing             # <<<<<<<<<<<<<<
 * 
 *     def get_write_buffer_size(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_closing); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/basetransport.pyx":278
 *             self._schedule_call_connection_lost(None)
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closing
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.is_closing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":281
 *         return self._closing
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         return self._get_write_buffer_size()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_15get_write_buffer_size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_14get_write_buffer_size[] = "UVBaseTransport.get_write_buffer_size(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_15get_write_buffer_size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_write_buffer_size (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_14get_write_buffer_size(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_14get_write_buffer_size(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("get_write_buffer_size", 0);

  /* "uvloop/handles/basetransport.pyx":282
 * 
 *     def get_write_buffer_size(self):
 *         return self._get_write_buffer_size()             # <<<<<<<<<<<<<<
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_get_write_buffer_size(__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/basetransport.pyx":281
 *         return self._closing
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         return self._get_write_buffer_size()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.get_write_buffer_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":284
 *         return self._get_write_buffer_size()
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_17set_write_buffer_limits(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_16set_write_buffer_limits[] = "UVBaseTransport.set_write_buffer_limits(self, high=None, low=None)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_17set_write_buffer_limits(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_high = 0;
  PyObject *__pyx_v_low = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_write_buffer_limits (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_high_2,&__pyx_n_s_low,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)Py_None);
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_high_2);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_low);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_write_buffer_limits") < 0)) __PYX_ERR(16, 284, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_high = values[0];
    __pyx_v_low = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_write_buffer_limits", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(16, 284, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.set_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_16set_write_buffer_limits(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), __pyx_v_high, __pyx_v_low);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_16set_write_buffer_limits(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_high, PyObject *__pyx_v_low) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits __pyx_t_6;
  __Pyx_RefNannySetupContext("set_write_buffer_limits", 0);
  __Pyx_INCREF(__pyx_v_high);
  __Pyx_INCREF(__pyx_v_low);

  /* "uvloop/handles/basetransport.pyx":285
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if high is None:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":287
 *         self._ensure_alive()
 * 
 *         if high is None:             # <<<<<<<<<<<<<<
 *             high = -1
 *         if low is None:
 */
  __pyx_t_2 = (__pyx_v_high == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/basetransport.pyx":288
 * 
 *         if high is None:
 *             high = -1             # <<<<<<<<<<<<<<
 *         if low is None:
 *             low = -1
 */
    __Pyx_INCREF(__pyx_int_neg_1);
    __Pyx_DECREF_SET(__pyx_v_high, __pyx_int_neg_1);

    /* "uvloop/handles/basetransport.pyx":287
 *         self._ensure_alive()
 * 
 *         if high is None:             # <<<<<<<<<<<<<<
 *             high = -1
 *         if low is None:
 */
  }

  /* "uvloop/handles/basetransport.pyx":289
 *         if high is None:
 *             high = -1
 *         if low is None:             # <<<<<<<<<<<<<<
 *             low = -1
 * 
 */
  __pyx_t_3 = (__pyx_v_low == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/basetransport.pyx":290
 *             high = -1
 *         if low is None:
 *             low = -1             # <<<<<<<<<<<<<<
 * 
 *         self._set_write_buffer_limits(high, low)
 */
    __Pyx_INCREF(__pyx_int_neg_1);
    __Pyx_DECREF_SET(__pyx_v_low, __pyx_int_neg_1);

    /* "uvloop/handles/basetransport.pyx":289
 *         if high is None:
 *             high = -1
 *         if low is None:             # <<<<<<<<<<<<<<
 *             low = -1
 * 
 */
  }

  /* "uvloop/handles/basetransport.pyx":292
 *             low = -1
 * 
 *         self._set_write_buffer_limits(high, low)             # <<<<<<<<<<<<<<
 * 
 *     def get_write_buffer_limits(self):
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_high); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(16, 292, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_v_low); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(16, 292, __pyx_L1_error)
  __pyx_t_6.__pyx_n = 2;
  __pyx_t_6.high = __pyx_t_4;
  __pyx_t_6.low = __pyx_t_5;
  __pyx_t_1 = __pyx_f_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits(__pyx_v_self, &__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 292, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/basetransport.pyx":284
 *         return self._get_write_buffer_size()
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.set_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_high);
  __Pyx_XDECREF(__pyx_v_low);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":294
 *         self._set_write_buffer_limits(high, low)
 * 
 *     def get_write_buffer_limits(self):             # <<<<<<<<<<<<<<
 *         return (self._low_water, self._high_water)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_19get_write_buffer_limits(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_18get_write_buffer_limits[] = "UVBaseTransport.get_write_buffer_limits(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_19get_write_buffer_limits(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_write_buffer_limits (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_18get_write_buffer_limits(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_18get_write_buffer_limits(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("get_write_buffer_limits", 0);

  /* "uvloop/handles/basetransport.pyx":295
 * 
 *     def get_write_buffer_limits(self):
 *         return (self._low_water, self._high_water)             # <<<<<<<<<<<<<<
 * 
 *     def get_extra_info(self, name, default=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(__pyx_v_self->_low_water); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->_high_water); if (unlikely(!__pyx_t_2)) __PYX_ERR(16, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(16, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/basetransport.pyx":294
 *         self._set_write_buffer_limits(high, low)
 * 
 *     def get_write_buffer_limits(self):             # <<<<<<<<<<<<<<
 *         return (self._low_water, self._high_water)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.get_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pyx":297
 *         return (self._low_water, self._high_water)
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if self._extra_info is not None and name in self._extra_info:
 *             return self._extra_info[name]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_21get_extra_info(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_20get_extra_info[] = "UVBaseTransport.get_extra_info(self, name, default=None)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_21get_extra_info(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_extra_info (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name_2,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_extra_info") < 0)) __PYX_ERR(16, 297, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_extra_info", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(16, 297, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_20get_extra_info(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_20get_extra_info(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("get_extra_info", 0);

  /* "uvloop/handles/basetransport.pyx":298
 * 
 *     def get_extra_info(self, name, default=None):
 *         if self._extra_info is not None and name in self._extra_info:             # <<<<<<<<<<<<<<
 *             return self._extra_info[name]
 *         if name == 'socket':
 */
  __pyx_t_2 = (__pyx_v_self->_extra_info != ((PyObject*)Py_None));
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  if (unlikely(__pyx_v_self->_extra_info == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(16, 298, __pyx_L1_error)
  }
  __pyx_t_3 = (__Pyx_PyDict_ContainsTF(__pyx_v_name, __pyx_v_self->_extra_info, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(16, 298, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":299
 *     def get_extra_info(self, name, default=None):
 *         if self._extra_info is not None and name in self._extra_info:
 *             return self._extra_info[name]             # <<<<<<<<<<<<<<
 *         if name == 'socket':
 *             return self._get_socket()
 */
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_self->_extra_info == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(16, 299, __pyx_L1_error)
    }
    __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_self->_extra_info, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":298
 * 
 *     def get_extra_info(self, name, default=None):
 *         if self._extra_info is not None and name in self._extra_info:             # <<<<<<<<<<<<<<
 *             return self._extra_info[name]
 *         if name == 'socket':
 */
  }

  /* "uvloop/handles/basetransport.pyx":300
 *         if self._extra_info is not None and name in self._extra_info:
 *             return self._extra_info[name]
 *         if name == 'socket':             # <<<<<<<<<<<<<<
 *             return self._get_socket()
 *         if name == 'sockname':
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_socket_2, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(16, 300, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":301
 *             return self._extra_info[name]
 *         if name == 'socket':
 *             return self._get_socket()             # <<<<<<<<<<<<<<
 *         if name == 'sockname':
 *             return self._get_socket().getsockname()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 301, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":300
 *         if self._extra_info is not None and name in self._extra_info:
 *             return self._extra_info[name]
 *         if name == 'socket':             # <<<<<<<<<<<<<<
 *             return self._get_socket()
 *         if name == 'sockname':
 */
  }

  /* "uvloop/handles/basetransport.pyx":302
 *         if name == 'socket':
 *             return self._get_socket()
 *         if name == 'sockname':             # <<<<<<<<<<<<<<
 *             return self._get_socket().getsockname()
 *         if name == 'peername':
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_sockname, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(16, 302, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":303
 *             return self._get_socket()
 *         if name == 'sockname':
 *             return self._get_socket().getsockname()             # <<<<<<<<<<<<<<
 *         if name == 'peername':
 *             try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_getsockname); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 303, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 303, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 303, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/handles/basetransport.pyx":302
 *         if name == 'socket':
 *             return self._get_socket()
 *         if name == 'sockname':             # <<<<<<<<<<<<<<
 *             return self._get_socket().getsockname()
 *         if name == 'peername':
 */
  }

  /* "uvloop/handles/basetransport.pyx":304
 *         if name == 'sockname':
 *             return self._get_socket().getsockname()
 *         if name == 'peername':             # <<<<<<<<<<<<<<
 *             try:
 *                 return self._get_socket().getpeername()
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_peername, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(16, 304, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/handles/basetransport.pyx":305
 *             return self._get_socket().getsockname()
 *         if name == 'peername':
 *             try:             # <<<<<<<<<<<<<<
 *                 return self._get_socket().getpeername()
 *             except socket_error:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "uvloop/handles/basetransport.pyx":306
 *         if name == 'peername':
 *             try:
 *                 return self._get_socket().getpeername()             # <<<<<<<<<<<<<<
 *             except socket_error:
 *                 return default
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_6)) __PYX_ERR(16, 306, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_getpeername); if (unlikely(!__pyx_t_5)) __PYX_ERR(16, 306, __pyx_L9_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (__pyx_t_6) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 306, __pyx_L9_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else {
          __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(16, 306, __pyx_L9_error)
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L13_try_return;

        /* "uvloop/handles/basetransport.pyx":305
 *             return self._get_socket().getsockname()
 *         if name == 'peername':
 *             try:             # <<<<<<<<<<<<<<
 *                 return self._get_socket().getpeername()
 *             except socket_error:
 */
      }
      __pyx_L9_error:;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/handles/basetransport.pyx":307
 *             try:
 *                 return self._get_socket().getpeername()
 *             except socket_error:             # <<<<<<<<<<<<<<
 *                 return default
 *         return default
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6uvloop_4loop_socket_error);
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(16, 307, __pyx_L11_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GOTREF(__pyx_t_6);

        /* "uvloop/handles/basetransport.pyx":308
 *                 return self._get_socket().getpeername()
 *             except socket_error:
 *                 return default             # <<<<<<<<<<<<<<
 *         return default
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_default);
        __pyx_r = __pyx_v_default;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        goto __pyx_L12_except_return;
      }
      goto __pyx_L11_except_error;
      __pyx_L11_except_error:;

      /* "uvloop/handles/basetransport.pyx":305
 *             return self._get_socket().getsockname()
 *         if name == 'peername':
 *             try:             # <<<<<<<<<<<<<<
 *                 return self._get_socket().getpeername()
 *             except socket_error:
 */
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L13_try_return:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L0;
      __pyx_L12_except_return:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L0;
    }

    /* "uvloop/handles/basetransport.pyx":304
 *         if name == 'sockname':
 *             return self._get_socket().getsockname()
 *         if name == 'peername':             # <<<<<<<<<<<<<<
 *             try:
 *                 return self._get_socket().getpeername()
 */
  }

  /* "uvloop/handles/basetransport.pyx":309
 *             except socket_error:
 *                 return default
 *         return default             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_default);
  __pyx_r = __pyx_v_default;
  goto __pyx_L0;

  /* "uvloop/handles/basetransport.pyx":297
 *         return (self._low_water, self._high_water)
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if self._extra_info is not None and name in self._extra_info:
 *             return self._extra_info[name]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/basetransport.pxd":4
 * 
 *     cdef:
 *         readonly bint _closing             # <<<<<<<<<<<<<<
 * 
 *         bint _protocol_connected
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_8_closing_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_8_closing_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_8_closing___get__(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_8_closing___get__(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_closing); if (unlikely(!__pyx_t_1)) __PYX_ERR(17, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport._closing.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_23__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_22__reduce_cython__[] = "UVBaseTransport.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_23__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_22__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_22__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__165, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_25__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_15UVBaseTransport_24__setstate_cython__[] = "UVBaseTransport.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_15UVBaseTransport_25__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15UVBaseTransport_24__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15UVBaseTransport_24__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVBaseTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__166, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVBaseTransport.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":28
 *         bint            closed
 * 
 *     cdef free_bufs(self):             # <<<<<<<<<<<<<<
 *         cdef size_t i
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_19_StreamWriteContext_free_bufs(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self) {
  size_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  __Pyx_RefNannySetupContext("free_bufs", 0);

  /* "uvloop/handles/stream.pyx":31
 *         cdef size_t i
 * 
 *         if self.uv_bufs is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_RawFree(self.uv_bufs)
 *             self.uv_bufs = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->uv_bufs != NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":32
 * 
 *         if self.uv_bufs is not NULL:
 *             PyMem_RawFree(self.uv_bufs)             # <<<<<<<<<<<<<<
 *             self.uv_bufs = NULL
 *             if UVLOOP_DEBUG:
 */
    PyMem_RawFree(__pyx_v_self->uv_bufs);

    /* "uvloop/handles/stream.pyx":33
 *         if self.uv_bufs is not NULL:
 *             PyMem_RawFree(self.uv_bufs)
 *             self.uv_bufs = NULL             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:
 */
    __pyx_v_self->uv_bufs = NULL;

    /* "uvloop/handles/stream.pyx":34
 *             PyMem_RawFree(self.uv_bufs)
 *             self.uv_bufs = NULL
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(
 */
    __pyx_t_1 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":35
 *             self.uv_bufs = NULL
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '_StreamWriteContext.close: uv_bufs != NULL and '
 */
      __pyx_t_1 = (__pyx_v_self->py_bufs_sml_inuse != 0);
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/handles/stream.pyx":36
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '_StreamWriteContext.close: uv_bufs != NULL and '
 *                         'py_bufs_sml_inuse is True')
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__167, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 36, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(18, 36, __pyx_L1_error)

        /* "uvloop/handles/stream.pyx":35
 *             self.uv_bufs = NULL
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '_StreamWriteContext.close: uv_bufs != NULL and '
 */
      }

      /* "uvloop/handles/stream.pyx":34
 *             PyMem_RawFree(self.uv_bufs)
 *             self.uv_bufs = NULL
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(
 */
    }

    /* "uvloop/handles/stream.pyx":31
 *         cdef size_t i
 * 
 *         if self.uv_bufs is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_RawFree(self.uv_bufs)
 *             self.uv_bufs = NULL
 */
  }

  /* "uvloop/handles/stream.pyx":40
 *                         'py_bufs_sml_inuse is True')
 * 
 *         if self.py_bufs is not NULL:             # <<<<<<<<<<<<<<
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs[i])
 */
  __pyx_t_1 = ((__pyx_v_self->py_bufs != NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":41
 * 
 *         if self.py_bufs is not NULL:
 *             for i from 0 <= i < self.py_bufs_len:             # <<<<<<<<<<<<<<
 *                 PyBuffer_Release(&self.py_bufs[i])
 *             PyMem_RawFree(self.py_bufs)
 */
    __pyx_t_3 = __pyx_v_self->py_bufs_len;
    for (__pyx_v_i = 0; __pyx_v_i < __pyx_t_3; __pyx_v_i++) {

      /* "uvloop/handles/stream.pyx":42
 *         if self.py_bufs is not NULL:
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs[i])             # <<<<<<<<<<<<<<
 *             PyMem_RawFree(self.py_bufs)
 *             self.py_bufs = NULL
 */
      PyBuffer_Release((&(__pyx_v_self->py_bufs[__pyx_v_i])));
    }

    /* "uvloop/handles/stream.pyx":43
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs[i])
 *             PyMem_RawFree(self.py_bufs)             # <<<<<<<<<<<<<<
 *             self.py_bufs = NULL
 *             if UVLOOP_DEBUG:
 */
    PyMem_RawFree(__pyx_v_self->py_bufs);

    /* "uvloop/handles/stream.pyx":44
 *                 PyBuffer_Release(&self.py_bufs[i])
 *             PyMem_RawFree(self.py_bufs)
 *             self.py_bufs = NULL             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:
 */
    __pyx_v_self->py_bufs = NULL;

    /* "uvloop/handles/stream.pyx":45
 *             PyMem_RawFree(self.py_bufs)
 *             self.py_bufs = NULL
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(
 */
    __pyx_t_1 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":46
 *             self.py_bufs = NULL
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '_StreamWriteContext.close: py_bufs != NULL and '
 */
      __pyx_t_1 = (__pyx_v_self->py_bufs_sml_inuse != 0);
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/handles/stream.pyx":47
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '_StreamWriteContext.close: py_bufs != NULL and '
 *                         'py_bufs_sml_inuse is True')
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__168, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 47, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(18, 47, __pyx_L1_error)

        /* "uvloop/handles/stream.pyx":46
 *             self.py_bufs = NULL
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '_StreamWriteContext.close: py_bufs != NULL and '
 */
      }

      /* "uvloop/handles/stream.pyx":45
 *             PyMem_RawFree(self.py_bufs)
 *             self.py_bufs = NULL
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(
 */
    }

    /* "uvloop/handles/stream.pyx":40
 *                         'py_bufs_sml_inuse is True')
 * 
 *         if self.py_bufs is not NULL:             # <<<<<<<<<<<<<<
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs[i])
 */
  }

  /* "uvloop/handles/stream.pyx":51
 *                         'py_bufs_sml_inuse is True')
 * 
 *         if self.py_bufs_sml_inuse:             # <<<<<<<<<<<<<<
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs_sml[i])
 */
  __pyx_t_1 = (__pyx_v_self->py_bufs_sml_inuse != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":52
 * 
 *         if self.py_bufs_sml_inuse:
 *             for i from 0 <= i < self.py_bufs_len:             # <<<<<<<<<<<<<<
 *                 PyBuffer_Release(&self.py_bufs_sml[i])
 *             self.py_bufs_sml_inuse = 0
 */
    __pyx_t_3 = __pyx_v_self->py_bufs_len;
    for (__pyx_v_i = 0; __pyx_v_i < __pyx_t_3; __pyx_v_i++) {

      /* "uvloop/handles/stream.pyx":53
 *         if self.py_bufs_sml_inuse:
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs_sml[i])             # <<<<<<<<<<<<<<
 *             self.py_bufs_sml_inuse = 0
 * 
 */
      PyBuffer_Release((&(__pyx_v_self->py_bufs_sml[__pyx_v_i])));
    }

    /* "uvloop/handles/stream.pyx":54
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs_sml[i])
 *             self.py_bufs_sml_inuse = 0             # <<<<<<<<<<<<<<
 * 
 *         self.py_bufs_len = 0
 */
    __pyx_v_self->py_bufs_sml_inuse = 0;

    /* "uvloop/handles/stream.pyx":51
 *                         'py_bufs_sml_inuse is True')
 * 
 *         if self.py_bufs_sml_inuse:             # <<<<<<<<<<<<<<
 *             for i from 0 <= i < self.py_bufs_len:
 *                 PyBuffer_Release(&self.py_bufs_sml[i])
 */
  }

  /* "uvloop/handles/stream.pyx":56
 *             self.py_bufs_sml_inuse = 0
 * 
 *         self.py_bufs_len = 0             # <<<<<<<<<<<<<<
 *         self.buffers = None
 * 
 */
  __pyx_v_self->py_bufs_len = 0;

  /* "uvloop/handles/stream.pyx":57
 * 
 *         self.py_bufs_len = 0
 *         self.buffers = None             # <<<<<<<<<<<<<<
 * 
 *     cdef close(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->buffers);
  __Pyx_DECREF(__pyx_v_self->buffers);
  __pyx_v_self->buffers = ((PyObject*)Py_None);

  /* "uvloop/handles/stream.pyx":28
 *         bint            closed
 * 
 *     cdef free_bufs(self):             # <<<<<<<<<<<<<<
 *         cdef size_t i
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop._StreamWriteContext.free_bufs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":59
 *         self.buffers = None
 * 
 *     cdef close(self):             # <<<<<<<<<<<<<<
 *         if self.closed:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_19_StreamWriteContext_close(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("close", 0);

  /* "uvloop/handles/stream.pyx":60
 * 
 *     cdef close(self):
 *         if self.closed:             # <<<<<<<<<<<<<<
 *             return
 *         self.closed = 1
 */
  __pyx_t_1 = (__pyx_v_self->closed != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":61
 *     cdef close(self):
 *         if self.closed:
 *             return             # <<<<<<<<<<<<<<
 *         self.closed = 1
 *         self.free_bufs()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":60
 * 
 *     cdef close(self):
 *         if self.closed:             # <<<<<<<<<<<<<<
 *             return
 *         self.closed = 1
 */
  }

  /* "uvloop/handles/stream.pyx":62
 *         if self.closed:
 *             return
 *         self.closed = 1             # <<<<<<<<<<<<<<
 *         self.free_bufs()
 *         Py_DECREF(self)
 */
  __pyx_v_self->closed = 1;

  /* "uvloop/handles/stream.pyx":63
 *             return
 *         self.closed = 1
 *         self.free_bufs()             # <<<<<<<<<<<<<<
 *         Py_DECREF(self)
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_self->__pyx_vtab)->free_bufs(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":64
 *         self.closed = 1
 *         self.free_bufs()
 *         Py_DECREF(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef advance_uv_buf(self, size_t sent):
 */
  Py_DECREF(((PyObject *)__pyx_v_self));

  /* "uvloop/handles/stream.pyx":59
 *         self.buffers = None
 * 
 *     cdef close(self):             # <<<<<<<<<<<<<<
 *         if self.closed:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop._StreamWriteContext.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":66
 *         Py_DECREF(self)
 * 
 *     cdef advance_uv_buf(self, size_t sent):             # <<<<<<<<<<<<<<
 *         # Advance the pointer to first uv_buf and the
 *         # pointer to first byte in that buffer.
 */

static PyObject *__pyx_f_6uvloop_4loop_19_StreamWriteContext_advance_uv_buf(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self, size_t __pyx_v_sent) {
  uv_buf_t *__pyx_v_buf;
  size_t __pyx_v_idx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  size_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("advance_uv_buf", 0);

  /* "uvloop/handles/stream.pyx":79
 *             size_t idx
 * 
 *         for idx from 0 <= idx < self.uv_bufs_len:             # <<<<<<<<<<<<<<
 *             buf = &self.uv_bufs_start[idx]
 *             if buf.len > sent:
 */
  __pyx_t_1 = __pyx_v_self->uv_bufs_len;
  for (__pyx_v_idx = 0; __pyx_v_idx < __pyx_t_1; __pyx_v_idx++) {

    /* "uvloop/handles/stream.pyx":80
 * 
 *         for idx from 0 <= idx < self.uv_bufs_len:
 *             buf = &self.uv_bufs_start[idx]             # <<<<<<<<<<<<<<
 *             if buf.len > sent:
 *                 buf.len -= sent
 */
    __pyx_v_buf = (&(__pyx_v_self->uv_bufs_start[__pyx_v_idx]));

    /* "uvloop/handles/stream.pyx":81
 *         for idx from 0 <= idx < self.uv_bufs_len:
 *             buf = &self.uv_bufs_start[idx]
 *             if buf.len > sent:             # <<<<<<<<<<<<<<
 *                 buf.len -= sent
 *                 buf.base = buf.base + sent
 */
    __pyx_t_2 = ((__pyx_v_buf->len > __pyx_v_sent) != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/stream.pyx":82
 *             buf = &self.uv_bufs_start[idx]
 *             if buf.len > sent:
 *                 buf.len -= sent             # <<<<<<<<<<<<<<
 *                 buf.base = buf.base + sent
 *                 self.uv_bufs_start = buf
 */
      __pyx_v_buf->len = (__pyx_v_buf->len - __pyx_v_sent);

      /* "uvloop/handles/stream.pyx":83
 *             if buf.len > sent:
 *                 buf.len -= sent
 *                 buf.base = buf.base + sent             # <<<<<<<<<<<<<<
 *                 self.uv_bufs_start = buf
 *                 self.uv_bufs_len -= idx
 */
      __pyx_v_buf->base = (__pyx_v_buf->base + __pyx_v_sent);

      /* "uvloop/handles/stream.pyx":84
 *                 buf.len -= sent
 *                 buf.base = buf.base + sent
 *                 self.uv_bufs_start = buf             # <<<<<<<<<<<<<<
 *                 self.uv_bufs_len -= idx
 *                 return
 */
      __pyx_v_self->uv_bufs_start = __pyx_v_buf;

      /* "uvloop/handles/stream.pyx":85
 *                 buf.base = buf.base + sent
 *                 self.uv_bufs_start = buf
 *                 self.uv_bufs_len -= idx             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
      __pyx_v_self->uv_bufs_len = (__pyx_v_self->uv_bufs_len - __pyx_v_idx);

      /* "uvloop/handles/stream.pyx":86
 *                 self.uv_bufs_start = buf
 *                 self.uv_bufs_len -= idx
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 sent -= self.uv_bufs_start[idx].len
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/handles/stream.pyx":81
 *         for idx from 0 <= idx < self.uv_bufs_len:
 *             buf = &self.uv_bufs_start[idx]
 *             if buf.len > sent:             # <<<<<<<<<<<<<<
 *                 buf.len -= sent
 *                 buf.base = buf.base + sent
 */
    }

    /* "uvloop/handles/stream.pyx":88
 *                 return
 *             else:
 *                 sent -= self.uv_bufs_start[idx].len             # <<<<<<<<<<<<<<
 * 
 *             if UVLOOP_DEBUG:
 */
    /*else*/ {
      __pyx_v_sent = (__pyx_v_sent - (__pyx_v_self->uv_bufs_start[__pyx_v_idx]).len);
    }

    /* "uvloop/handles/stream.pyx":90
 *                 sent -= self.uv_bufs_start[idx].len
 * 
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if sent < 0:
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')
 */
    __pyx_t_2 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/stream.pyx":91
 * 
 *             if UVLOOP_DEBUG:
 *                 if sent < 0:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')
 * 
 */
      __pyx_t_2 = ((__pyx_v_sent < 0) != 0);
      if (unlikely(__pyx_t_2)) {

        /* "uvloop/handles/stream.pyx":92
 *             if UVLOOP_DEBUG:
 *                 if sent < 0:
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')             # <<<<<<<<<<<<<<
 * 
 *         raise RuntimeError('fatal: Could not advance _StreamWriteContext')
 */
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__169, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 92, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(18, 92, __pyx_L1_error)

        /* "uvloop/handles/stream.pyx":91
 * 
 *             if UVLOOP_DEBUG:
 *                 if sent < 0:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')
 * 
 */
      }

      /* "uvloop/handles/stream.pyx":90
 *                 sent -= self.uv_bufs_start[idx].len
 * 
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if sent < 0:
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')
 */
    }
  }

  /* "uvloop/handles/stream.pyx":94
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')
 * 
 *         raise RuntimeError('fatal: Could not advance _StreamWriteContext')             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__170, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(18, 94, __pyx_L1_error)

  /* "uvloop/handles/stream.pyx":66
 *         Py_DECREF(self)
 * 
 *     cdef advance_uv_buf(self, size_t sent):             # <<<<<<<<<<<<<<
 *         # Advance the pointer to first uv_buf and the
 *         # pointer to first byte in that buffer.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop._StreamWriteContext.advance_uv_buf", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":97
 * 
 *     @staticmethod
 *     cdef _StreamWriteContext new(UVStream stream, list buffers):             # <<<<<<<<<<<<<<
 *         cdef:
 *             _StreamWriteContext ctx
 */

static struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_f_6uvloop_4loop_19_StreamWriteContext_new(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_stream, PyObject *__pyx_v_buffers) {
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_ctx = 0;
  int __pyx_v_uv_bufs_idx;
  size_t __pyx_v_py_bufs_len;
  Py_buffer *__pyx_v_p_pybufs;
  uv_buf_t *__pyx_v_p_uvbufs;
  PyObject *__pyx_v_buf = NULL;
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_buffer *__pyx_t_10;
  uv_buf_t *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_17 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/stream.pyx":100
 *         cdef:
 *             _StreamWriteContext ctx
 *             int uv_bufs_idx = 0             # <<<<<<<<<<<<<<
 *             size_t py_bufs_len = 0
 *             int i
 */
  __pyx_v_uv_bufs_idx = 0;

  /* "uvloop/handles/stream.pyx":101
 *             _StreamWriteContext ctx
 *             int uv_bufs_idx = 0
 *             size_t py_bufs_len = 0             # <<<<<<<<<<<<<<
 *             int i
 * 
 */
  __pyx_v_py_bufs_len = 0;

  /* "uvloop/handles/stream.pyx":107
 *             uv.uv_buf_t* p_uvbufs
 * 
 *         ctx = _StreamWriteContext.__new__(_StreamWriteContext)             # <<<<<<<<<<<<<<
 *         ctx.stream = None
 *         ctx.closed = 1
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop__StreamWriteContext(((PyTypeObject *)__pyx_ptype_6uvloop_4loop__StreamWriteContext), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 107, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_ctx = ((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":108
 * 
 *         ctx = _StreamWriteContext.__new__(_StreamWriteContext)
 *         ctx.stream = None             # <<<<<<<<<<<<<<
 *         ctx.closed = 1
 *         ctx.py_bufs_len = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_ctx->stream);
  __Pyx_DECREF(((PyObject *)__pyx_v_ctx->stream));
  __pyx_v_ctx->stream = ((struct __pyx_obj_6uvloop_4loop_UVStream *)Py_None);

  /* "uvloop/handles/stream.pyx":109
 *         ctx = _StreamWriteContext.__new__(_StreamWriteContext)
 *         ctx.stream = None
 *         ctx.closed = 1             # <<<<<<<<<<<<<<
 *         ctx.py_bufs_len = 0
 *         ctx.py_bufs_sml_inuse = 0
 */
  __pyx_v_ctx->closed = 1;

  /* "uvloop/handles/stream.pyx":110
 *         ctx.stream = None
 *         ctx.closed = 1
 *         ctx.py_bufs_len = 0             # <<<<<<<<<<<<<<
 *         ctx.py_bufs_sml_inuse = 0
 *         ctx.uv_bufs = NULL
 */
  __pyx_v_ctx->py_bufs_len = 0;

  /* "uvloop/handles/stream.pyx":111
 *         ctx.closed = 1
 *         ctx.py_bufs_len = 0
 *         ctx.py_bufs_sml_inuse = 0             # <<<<<<<<<<<<<<
 *         ctx.uv_bufs = NULL
 *         ctx.py_bufs = NULL
 */
  __pyx_v_ctx->py_bufs_sml_inuse = 0;

  /* "uvloop/handles/stream.pyx":112
 *         ctx.py_bufs_len = 0
 *         ctx.py_bufs_sml_inuse = 0
 *         ctx.uv_bufs = NULL             # <<<<<<<<<<<<<<
 *         ctx.py_bufs = NULL
 *         ctx.buffers = buffers
 */
  __pyx_v_ctx->uv_bufs = NULL;

  /* "uvloop/handles/stream.pyx":113
 *         ctx.py_bufs_sml_inuse = 0
 *         ctx.uv_bufs = NULL
 *         ctx.py_bufs = NULL             # <<<<<<<<<<<<<<
 *         ctx.buffers = buffers
 *         ctx.stream = stream
 */
  __pyx_v_ctx->py_bufs = NULL;

  /* "uvloop/handles/stream.pyx":114
 *         ctx.uv_bufs = NULL
 *         ctx.py_bufs = NULL
 *         ctx.buffers = buffers             # <<<<<<<<<<<<<<
 *         ctx.stream = stream
 * 
 */
  __Pyx_INCREF(__pyx_v_buffers);
  __Pyx_GIVEREF(__pyx_v_buffers);
  __Pyx_GOTREF(__pyx_v_ctx->buffers);
  __Pyx_DECREF(__pyx_v_ctx->buffers);
  __pyx_v_ctx->buffers = __pyx_v_buffers;

  /* "uvloop/handles/stream.pyx":115
 *         ctx.py_bufs = NULL
 *         ctx.buffers = buffers
 *         ctx.stream = stream             # <<<<<<<<<<<<<<
 * 
 *         if len(buffers) <= __PREALLOCED_BUFS:
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_stream));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_stream));
  __Pyx_GOTREF(__pyx_v_ctx->stream);
  __Pyx_DECREF(((PyObject *)__pyx_v_ctx->stream));
  __pyx_v_ctx->stream = __pyx_v_stream;

  /* "uvloop/handles/stream.pyx":117
 *         ctx.stream = stream
 * 
 *         if len(buffers) <= __PREALLOCED_BUFS:             # <<<<<<<<<<<<<<
 *             # We've got a small number of buffers to write, don't
 *             # need to use malloc.
 */
  if (unlikely(__pyx_v_buffers == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(18, 117, __pyx_L1_error)
  }
  __pyx_t_2 = PyList_GET_SIZE(__pyx_v_buffers); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(18, 117, __pyx_L1_error)
  __pyx_t_3 = ((__pyx_t_2 <= 4) != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/stream.pyx":120
 *             # We've got a small number of buffers to write, don't
 *             # need to use malloc.
 *             ctx.py_bufs_sml_inuse = 1             # <<<<<<<<<<<<<<
 *             p_pybufs = <Py_buffer*>&ctx.py_bufs_sml
 *             p_uvbufs = <uv.uv_buf_t*>&ctx.uv_bufs_sml
 */
    __pyx_v_ctx->py_bufs_sml_inuse = 1;

    /* "uvloop/handles/stream.pyx":121
 *             # need to use malloc.
 *             ctx.py_bufs_sml_inuse = 1
 *             p_pybufs = <Py_buffer*>&ctx.py_bufs_sml             # <<<<<<<<<<<<<<
 *             p_uvbufs = <uv.uv_buf_t*>&ctx.uv_bufs_sml
 * 
 */
    __pyx_v_p_pybufs = ((Py_buffer *)(&__pyx_v_ctx->py_bufs_sml));

    /* "uvloop/handles/stream.pyx":122
 *             ctx.py_bufs_sml_inuse = 1
 *             p_pybufs = <Py_buffer*>&ctx.py_bufs_sml
 *             p_uvbufs = <uv.uv_buf_t*>&ctx.uv_bufs_sml             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __pyx_v_p_uvbufs = ((uv_buf_t *)(&__pyx_v_ctx->uv_bufs_sml));

    /* "uvloop/handles/stream.pyx":117
 *         ctx.stream = stream
 * 
 *         if len(buffers) <= __PREALLOCED_BUFS:             # <<<<<<<<<<<<<<
 *             # We've got a small number of buffers to write, don't
 *             # need to use malloc.
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/stream.pyx":125
 * 
 *         else:
 *             for buf in buffers:             # <<<<<<<<<<<<<<
 *                 if UVLOOP_DEBUG:
 *                     if not isinstance(buf, (bytes, bytearray, memoryview)):
 */
  /*else*/ {
    if (unlikely(__pyx_v_buffers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(18, 125, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_buffers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    for (;;) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(18, 125, __pyx_L1_error)
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 125, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_buf, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "uvloop/handles/stream.pyx":126
 *         else:
 *             for buf in buffers:
 *                 if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                     if not isinstance(buf, (bytes, bytearray, memoryview)):
 *                         raise RuntimeError(
 */
      __pyx_t_3 = (UVLOOP_DEBUG != 0);
      if (__pyx_t_3) {

        /* "uvloop/handles/stream.pyx":127
 *             for buf in buffers:
 *                 if UVLOOP_DEBUG:
 *                     if not isinstance(buf, (bytes, bytearray, memoryview)):             # <<<<<<<<<<<<<<
 *                         raise RuntimeError(
 *                             'invalid data in writebuf: an instance of '
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 127, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyBytes_Check(__pyx_v_buf); 
        __pyx_t_6 = (__pyx_t_5 != 0);
        if (!__pyx_t_6) {
        } else {
          __pyx_t_3 = __pyx_t_6;
          goto __pyx_L8_bool_binop_done;
        }
        __pyx_t_6 = PyByteArray_Check(__pyx_v_buf); 
        __pyx_t_5 = (__pyx_t_6 != 0);
        if (!__pyx_t_5) {
        } else {
          __pyx_t_3 = __pyx_t_5;
          goto __pyx_L8_bool_binop_done;
        }
        __pyx_t_5 = PyObject_IsInstance(__pyx_v_buf, __pyx_t_4); 
        __pyx_t_6 = (__pyx_t_5 != 0);
        __pyx_t_3 = __pyx_t_6;
        __pyx_L8_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_6 = ((!(__pyx_t_3 != 0)) != 0);
        if (unlikely(__pyx_t_6)) {

          /* "uvloop/handles/stream.pyx":131
 *                             'invalid data in writebuf: an instance of '
 *                             'bytes, bytearray or memoryview was expected, '
 *                             'got {}'.format(type(buf)))             # <<<<<<<<<<<<<<
 * 
 *                 if not PyBytes_CheckExact(buf):
 */
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_invalid_data_in_writebuf_an_inst, __pyx_n_s_format); if (unlikely(!__pyx_t_7)) __PYX_ERR(18, 131, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          if (!__pyx_t_8) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)Py_TYPE(__pyx_v_buf))); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 131, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, ((PyObject *)Py_TYPE(__pyx_v_buf))};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 131, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, ((PyObject *)Py_TYPE(__pyx_v_buf))};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 131, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_4);
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(18, 131, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
              __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_buf)));
              __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_buf)));
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, ((PyObject *)Py_TYPE(__pyx_v_buf)));
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 131, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "uvloop/handles/stream.pyx":128
 *                 if UVLOOP_DEBUG:
 *                     if not isinstance(buf, (bytes, bytearray, memoryview)):
 *                         raise RuntimeError(             # <<<<<<<<<<<<<<
 *                             'invalid data in writebuf: an instance of '
 *                             'bytes, bytearray or memoryview was expected, '
 */
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(18, 128, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_Raise(__pyx_t_7, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __PYX_ERR(18, 128, __pyx_L1_error)

          /* "uvloop/handles/stream.pyx":127
 *             for buf in buffers:
 *                 if UVLOOP_DEBUG:
 *                     if not isinstance(buf, (bytes, bytearray, memoryview)):             # <<<<<<<<<<<<<<
 *                         raise RuntimeError(
 *                             'invalid data in writebuf: an instance of '
 */
        }

        /* "uvloop/handles/stream.pyx":126
 *         else:
 *             for buf in buffers:
 *                 if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                     if not isinstance(buf, (bytes, bytearray, memoryview)):
 *                         raise RuntimeError(
 */
      }

      /* "uvloop/handles/stream.pyx":133
 *                             'got {}'.format(type(buf)))
 * 
 *                 if not PyBytes_CheckExact(buf):             # <<<<<<<<<<<<<<
 *                     py_bufs_len += 1
 * 
 */
      __pyx_t_6 = ((!(PyBytes_CheckExact(__pyx_v_buf) != 0)) != 0);
      if (__pyx_t_6) {

        /* "uvloop/handles/stream.pyx":134
 * 
 *                 if not PyBytes_CheckExact(buf):
 *                     py_bufs_len += 1             # <<<<<<<<<<<<<<
 * 
 *             if py_bufs_len > 0:
 */
        __pyx_v_py_bufs_len = (__pyx_v_py_bufs_len + 1);

        /* "uvloop/handles/stream.pyx":133
 *                             'got {}'.format(type(buf)))
 * 
 *                 if not PyBytes_CheckExact(buf):             # <<<<<<<<<<<<<<
 *                     py_bufs_len += 1
 * 
 */
      }

      /* "uvloop/handles/stream.pyx":125
 * 
 *         else:
 *             for buf in buffers:             # <<<<<<<<<<<<<<
 *                 if UVLOOP_DEBUG:
 *                     if not isinstance(buf, (bytes, bytearray, memoryview)):
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":136
 *                     py_bufs_len += 1
 * 
 *             if py_bufs_len > 0:             # <<<<<<<<<<<<<<
 *                 ctx.py_bufs = <Py_buffer*>PyMem_RawMalloc(
 *                     py_bufs_len * sizeof(Py_buffer))
 */
    __pyx_t_6 = ((__pyx_v_py_bufs_len > 0) != 0);
    if (__pyx_t_6) {

      /* "uvloop/handles/stream.pyx":137
 * 
 *             if py_bufs_len > 0:
 *                 ctx.py_bufs = <Py_buffer*>PyMem_RawMalloc(             # <<<<<<<<<<<<<<
 *                     py_bufs_len * sizeof(Py_buffer))
 *                 if ctx.py_bufs is NULL:
 */
      __pyx_v_ctx->py_bufs = ((Py_buffer *)PyMem_RawMalloc((__pyx_v_py_bufs_len * (sizeof(Py_buffer)))));

      /* "uvloop/handles/stream.pyx":139
 *                 ctx.py_bufs = <Py_buffer*>PyMem_RawMalloc(
 *                     py_bufs_len * sizeof(Py_buffer))
 *                 if ctx.py_bufs is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError()
 * 
 */
      __pyx_t_6 = ((__pyx_v_ctx->py_bufs == NULL) != 0);
      if (unlikely(__pyx_t_6)) {

        /* "uvloop/handles/stream.pyx":140
 *                     py_bufs_len * sizeof(Py_buffer))
 *                 if ctx.py_bufs is NULL:
 *                     raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *             ctx.uv_bufs = <uv.uv_buf_t*>PyMem_RawMalloc(
 */
        PyErr_NoMemory(); __PYX_ERR(18, 140, __pyx_L1_error)

        /* "uvloop/handles/stream.pyx":139
 *                 ctx.py_bufs = <Py_buffer*>PyMem_RawMalloc(
 *                     py_bufs_len * sizeof(Py_buffer))
 *                 if ctx.py_bufs is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError()
 * 
 */
      }

      /* "uvloop/handles/stream.pyx":136
 *                     py_bufs_len += 1
 * 
 *             if py_bufs_len > 0:             # <<<<<<<<<<<<<<
 *                 ctx.py_bufs = <Py_buffer*>PyMem_RawMalloc(
 *                     py_bufs_len * sizeof(Py_buffer))
 */
    }

    /* "uvloop/handles/stream.pyx":143
 * 
 *             ctx.uv_bufs = <uv.uv_buf_t*>PyMem_RawMalloc(
 *                 len(buffers) * sizeof(uv.uv_buf_t))             # <<<<<<<<<<<<<<
 *             if ctx.uv_bufs is NULL:
 *                 raise MemoryError()
 */
    if (unlikely(__pyx_v_buffers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(18, 143, __pyx_L1_error)
    }
    __pyx_t_2 = PyList_GET_SIZE(__pyx_v_buffers); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(18, 143, __pyx_L1_error)

    /* "uvloop/handles/stream.pyx":142
 *                     raise MemoryError()
 * 
 *             ctx.uv_bufs = <uv.uv_buf_t*>PyMem_RawMalloc(             # <<<<<<<<<<<<<<
 *                 len(buffers) * sizeof(uv.uv_buf_t))
 *             if ctx.uv_bufs is NULL:
 */
    __pyx_v_ctx->uv_bufs = ((uv_buf_t *)PyMem_RawMalloc((__pyx_t_2 * (sizeof(uv_buf_t)))));

    /* "uvloop/handles/stream.pyx":144
 *             ctx.uv_bufs = <uv.uv_buf_t*>PyMem_RawMalloc(
 *                 len(buffers) * sizeof(uv.uv_buf_t))
 *             if ctx.uv_bufs is NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 * 
 */
    __pyx_t_6 = ((__pyx_v_ctx->uv_bufs == NULL) != 0);
    if (unlikely(__pyx_t_6)) {

      /* "uvloop/handles/stream.pyx":145
 *                 len(buffers) * sizeof(uv.uv_buf_t))
 *             if ctx.uv_bufs is NULL:
 *                 raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *             p_pybufs = ctx.py_bufs
 */
      PyErr_NoMemory(); __PYX_ERR(18, 145, __pyx_L1_error)

      /* "uvloop/handles/stream.pyx":144
 *             ctx.uv_bufs = <uv.uv_buf_t*>PyMem_RawMalloc(
 *                 len(buffers) * sizeof(uv.uv_buf_t))
 *             if ctx.uv_bufs is NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError()
 * 
 */
    }

    /* "uvloop/handles/stream.pyx":147
 *                 raise MemoryError()
 * 
 *             p_pybufs = ctx.py_bufs             # <<<<<<<<<<<<<<
 *             p_uvbufs = ctx.uv_bufs
 * 
 */
    __pyx_t_10 = __pyx_v_ctx->py_bufs;
    __pyx_v_p_pybufs = __pyx_t_10;

    /* "uvloop/handles/stream.pyx":148
 * 
 *             p_pybufs = ctx.py_bufs
 *             p_uvbufs = ctx.uv_bufs             # <<<<<<<<<<<<<<
 * 
 *         py_bufs_len = 0
 */
    __pyx_t_11 = __pyx_v_ctx->uv_bufs;
    __pyx_v_p_uvbufs = __pyx_t_11;
  }
  __pyx_L3:;

  /* "uvloop/handles/stream.pyx":150
 *             p_uvbufs = ctx.uv_bufs
 * 
 *         py_bufs_len = 0             # <<<<<<<<<<<<<<
 *         for buf in buffers:
 *             if PyBytes_CheckExact(buf):
 */
  __pyx_v_py_bufs_len = 0;

  /* "uvloop/handles/stream.pyx":151
 * 
 *         py_bufs_len = 0
 *         for buf in buffers:             # <<<<<<<<<<<<<<
 *             if PyBytes_CheckExact(buf):
 *                 # We can only use this hack for bytes since it's
 */
  if (unlikely(__pyx_v_buffers == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(18, 151, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_buffers; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_7); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(18, 151, __pyx_L1_error)
    #else
    __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_7)) __PYX_ERR(18, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_buf, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/handles/stream.pyx":152
 *         py_bufs_len = 0
 *         for buf in buffers:
 *             if PyBytes_CheckExact(buf):             # <<<<<<<<<<<<<<
 *                 # We can only use this hack for bytes since it's
 *                 # immutable.  For everything else it is only safe to
 */
    __pyx_t_6 = (PyBytes_CheckExact(__pyx_v_buf) != 0);
    if (__pyx_t_6) {

      /* "uvloop/handles/stream.pyx":156
 *                 # immutable.  For everything else it is only safe to
 *                 # use buffer protocol.
 *                 p_uvbufs[uv_bufs_idx].base = PyBytes_AS_STRING(buf)             # <<<<<<<<<<<<<<
 *                 p_uvbufs[uv_bufs_idx].len = Py_SIZE(buf)
 * 
 */
      (__pyx_v_p_uvbufs[__pyx_v_uv_bufs_idx]).base = PyBytes_AS_STRING(__pyx_v_buf);

      /* "uvloop/handles/stream.pyx":157
 *                 # use buffer protocol.
 *                 p_uvbufs[uv_bufs_idx].base = PyBytes_AS_STRING(buf)
 *                 p_uvbufs[uv_bufs_idx].len = Py_SIZE(buf)             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
      (__pyx_v_p_uvbufs[__pyx_v_uv_bufs_idx]).len = Py_SIZE(__pyx_v_buf);

      /* "uvloop/handles/stream.pyx":152
 *         py_bufs_len = 0
 *         for buf in buffers:
 *             if PyBytes_CheckExact(buf):             # <<<<<<<<<<<<<<
 *                 # We can only use this hack for bytes since it's
 *                 # immutable.  For everything else it is only safe to
 */
      goto __pyx_L17;
    }

    /* "uvloop/handles/stream.pyx":160
 * 
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     PyObject_GetBuffer(
 *                         buf, &p_pybufs[py_bufs_len], PyBUF_SIMPLE)
 */
    /*else*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_14);
        /*try:*/ {

          /* "uvloop/handles/stream.pyx":161
 *             else:
 *                 try:
 *                     PyObject_GetBuffer(             # <<<<<<<<<<<<<<
 *                         buf, &p_pybufs[py_bufs_len], PyBUF_SIMPLE)
 *                 except:
 */
          __pyx_t_15 = PyObject_GetBuffer(__pyx_v_buf, (&(__pyx_v_p_pybufs[__pyx_v_py_bufs_len])), PyBUF_SIMPLE); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(18, 161, __pyx_L18_error)

          /* "uvloop/handles/stream.pyx":160
 * 
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     PyObject_GetBuffer(
 *                         buf, &p_pybufs[py_bufs_len], PyBUF_SIMPLE)
 */
        }
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        goto __pyx_L25_try_end;
        __pyx_L18_error:;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "uvloop/handles/stream.pyx":163
 *                     PyObject_GetBuffer(
 *                         buf, &p_pybufs[py_bufs_len], PyBUF_SIMPLE)
 *                 except:             # <<<<<<<<<<<<<<
 *                     # This shouldn't ever happen, as `UVStream._write`
 *                     # casts non-bytes objects to `memoryviews`.
 */
        /*except:*/ {
          __Pyx_AddTraceback("uvloop.loop._StreamWriteContext.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_4, &__pyx_t_9) < 0) __PYX_ERR(18, 163, __pyx_L20_except_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_t_9);

          /* "uvloop/handles/stream.pyx":166
 *                     # This shouldn't ever happen, as `UVStream._write`
 *                     # casts non-bytes objects to `memoryviews`.
 *                     ctx.py_bufs_len = py_bufs_len             # <<<<<<<<<<<<<<
 *                     ctx.free_bufs()
 *                     raise
 */
          __pyx_v_ctx->py_bufs_len = __pyx_v_py_bufs_len;

          /* "uvloop/handles/stream.pyx":167
 *                     # casts non-bytes objects to `memoryviews`.
 *                     ctx.py_bufs_len = py_bufs_len
 *                     ctx.free_bufs()             # <<<<<<<<<<<<<<
 *                     raise
 * 
 */
          __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_ctx->__pyx_vtab)->free_bufs(__pyx_v_ctx); if (unlikely(!__pyx_t_8)) __PYX_ERR(18, 167, __pyx_L20_except_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "uvloop/handles/stream.pyx":168
 *                     ctx.py_bufs_len = py_bufs_len
 *                     ctx.free_bufs()
 *                     raise             # <<<<<<<<<<<<<<
 * 
 *                 p_uvbufs[uv_bufs_idx].base = <char*>p_pybufs[py_bufs_len].buf
 */
          __Pyx_GIVEREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_ErrRestoreWithState(__pyx_t_7, __pyx_t_4, __pyx_t_9);
          __pyx_t_7 = 0; __pyx_t_4 = 0; __pyx_t_9 = 0; 
          __PYX_ERR(18, 168, __pyx_L20_except_error)
        }
        __pyx_L20_except_error:;

        /* "uvloop/handles/stream.pyx":160
 * 
 *             else:
 *                 try:             # <<<<<<<<<<<<<<
 *                     PyObject_GetBuffer(
 *                         buf, &p_pybufs[py_bufs_len], PyBUF_SIMPLE)
 */
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
        goto __pyx_L1_error;
        __pyx_L25_try_end:;
      }

      /* "uvloop/handles/stream.pyx":170
 *                     raise
 * 
 *                 p_uvbufs[uv_bufs_idx].base = <char*>p_pybufs[py_bufs_len].buf             # <<<<<<<<<<<<<<
 *                 p_uvbufs[uv_bufs_idx].len = p_pybufs[py_bufs_len].len
 * 
 */
      (__pyx_v_p_uvbufs[__pyx_v_uv_bufs_idx]).base = ((char *)(__pyx_v_p_pybufs[__pyx_v_py_bufs_len]).buf);

      /* "uvloop/handles/stream.pyx":171
 * 
 *                 p_uvbufs[uv_bufs_idx].base = <char*>p_pybufs[py_bufs_len].buf
 *                 p_uvbufs[uv_bufs_idx].len = p_pybufs[py_bufs_len].len             # <<<<<<<<<<<<<<
 * 
 *                 py_bufs_len += 1
 */
      __pyx_t_16 = (__pyx_v_p_pybufs[__pyx_v_py_bufs_len]).len;
      (__pyx_v_p_uvbufs[__pyx_v_uv_bufs_idx]).len = __pyx_t_16;

      /* "uvloop/handles/stream.pyx":173
 *                 p_uvbufs[uv_bufs_idx].len = p_pybufs[py_bufs_len].len
 * 
 *                 py_bufs_len += 1             # <<<<<<<<<<<<<<
 * 
 *             uv_bufs_idx += 1
 */
      __pyx_v_py_bufs_len = (__pyx_v_py_bufs_len + 1);
    }
    __pyx_L17:;

    /* "uvloop/handles/stream.pyx":175
 *                 py_bufs_len += 1
 * 
 *             uv_bufs_idx += 1             # <<<<<<<<<<<<<<
 * 
 *         ctx.uv_bufs_start = p_uvbufs
 */
    __pyx_v_uv_bufs_idx = (__pyx_v_uv_bufs_idx + 1);

    /* "uvloop/handles/stream.pyx":151
 * 
 *         py_bufs_len = 0
 *         for buf in buffers:             # <<<<<<<<<<<<<<
 *             if PyBytes_CheckExact(buf):
 *                 # We can only use this hack for bytes since it's
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":177
 *             uv_bufs_idx += 1
 * 
 *         ctx.uv_bufs_start = p_uvbufs             # <<<<<<<<<<<<<<
 *         ctx.uv_bufs_len = uv_bufs_idx
 * 
 */
  __pyx_v_ctx->uv_bufs_start = __pyx_v_p_uvbufs;

  /* "uvloop/handles/stream.pyx":178
 * 
 *         ctx.uv_bufs_start = p_uvbufs
 *         ctx.uv_bufs_len = uv_bufs_idx             # <<<<<<<<<<<<<<
 * 
 *         ctx.py_bufs_len = py_bufs_len
 */
  __pyx_v_ctx->uv_bufs_len = __pyx_v_uv_bufs_idx;

  /* "uvloop/handles/stream.pyx":180
 *         ctx.uv_bufs_len = uv_bufs_idx
 * 
 *         ctx.py_bufs_len = py_bufs_len             # <<<<<<<<<<<<<<
 *         ctx.req.data = <void*> ctx
 * 
 */
  __pyx_v_ctx->py_bufs_len = __pyx_v_py_bufs_len;

  /* "uvloop/handles/stream.pyx":181
 * 
 *         ctx.py_bufs_len = py_bufs_len
 *         ctx.req.data = <void*> ctx             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
  __pyx_v_ctx->req.data = ((void *)__pyx_v_ctx);

  /* "uvloop/handles/stream.pyx":183
 *         ctx.req.data = <void*> ctx
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_write_ctx_total += 1
 *             stream._loop._debug_stream_write_ctx_cnt += 1
 */
  __pyx_t_6 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_6) {

    /* "uvloop/handles/stream.pyx":184
 * 
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_ctx_total += 1             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_write_ctx_cnt += 1
 * 
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop));
    __pyx_t_17 = __pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop;
    __pyx_t_17->_debug_stream_write_ctx_total = (__pyx_t_17->_debug_stream_write_ctx_total + 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_17)); __pyx_t_17 = 0;

    /* "uvloop/handles/stream.pyx":185
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_ctx_total += 1
 *             stream._loop._debug_stream_write_ctx_cnt += 1             # <<<<<<<<<<<<<<
 * 
 *         # Do incref after everything else is done.
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop));
    __pyx_t_17 = __pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop;
    __pyx_t_17->_debug_stream_write_ctx_cnt = (__pyx_t_17->_debug_stream_write_ctx_cnt + 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_17)); __pyx_t_17 = 0;

    /* "uvloop/handles/stream.pyx":183
 *         ctx.req.data = <void*> ctx
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_write_ctx_total += 1
 *             stream._loop._debug_stream_write_ctx_cnt += 1
 */
  }

  /* "uvloop/handles/stream.pyx":190
 *         # Under no circumstances we want `ctx` to be GCed while
 *         # libuv is still working with `ctx.uv_bufs`.
 *         Py_INCREF(ctx)             # <<<<<<<<<<<<<<
 *         ctx.closed = 0
 *         return ctx
 */
  Py_INCREF(((PyObject *)__pyx_v_ctx));

  /* "uvloop/handles/stream.pyx":191
 *         # libuv is still working with `ctx.uv_bufs`.
 *         Py_INCREF(ctx)
 *         ctx.closed = 0             # <<<<<<<<<<<<<<
 *         return ctx
 * 
 */
  __pyx_v_ctx->closed = 0;

  /* "uvloop/handles/stream.pyx":192
 *         Py_INCREF(ctx)
 *         ctx.closed = 0
 *         return ctx             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_ctx));
  __pyx_r = __pyx_v_ctx;
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":97
 * 
 *     @staticmethod
 *     cdef _StreamWriteContext new(UVStream stream, list buffers):             # <<<<<<<<<<<<<<
 *         cdef:
 *             _StreamWriteContext ctx
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(((PyObject *)__pyx_t_17));
  __Pyx_AddTraceback("uvloop.loop._StreamWriteContext.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_ctx);
  __Pyx_XDECREF(__pyx_v_buf);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":194
 *         return ctx
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if not self.closed:
 *             # Because we do an INCREF in _StreamWriteContext.new,
 */

/* Python wrapper */
static void __pyx_pw_6uvloop_4loop_19_StreamWriteContext_1__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6uvloop_4loop_19_StreamWriteContext_1__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_6uvloop_4loop_19_StreamWriteContext___dealloc__(((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6uvloop_4loop_19_StreamWriteContext___dealloc__(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "uvloop/handles/stream.pyx":195
 * 
 *     def __dealloc__(self):
 *         if not self.closed:             # <<<<<<<<<<<<<<
 *             # Because we do an INCREF in _StreamWriteContext.new,
 *             # __dealloc__ shouldn't ever happen with `self.closed == 1`
 */
  __pyx_t_1 = ((!(__pyx_v_self->closed != 0)) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/stream.pyx":198
 *             # Because we do an INCREF in _StreamWriteContext.new,
 *             # __dealloc__ shouldn't ever happen with `self.closed == 1`
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'open _StreamWriteContext is being deallocated')
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__171, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(18, 198, __pyx_L1_error)

    /* "uvloop/handles/stream.pyx":195
 * 
 *     def __dealloc__(self):
 *         if not self.closed:             # <<<<<<<<<<<<<<
 *             # Because we do an INCREF in _StreamWriteContext.new,
 *             # __dealloc__ shouldn't ever happen with `self.closed == 1`
 */
  }

  /* "uvloop/handles/stream.pyx":201
 *                 'open _StreamWriteContext is being deallocated')
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self.stream is not None:
 *                 self.stream._loop._debug_stream_write_ctx_cnt -= 1
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":202
 * 
 *         if UVLOOP_DEBUG:
 *             if self.stream is not None:             # <<<<<<<<<<<<<<
 *                 self.stream._loop._debug_stream_write_ctx_cnt -= 1
 *                 self.stream = None
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->stream) != Py_None);
    __pyx_t_3 = (__pyx_t_1 != 0);
    if (__pyx_t_3) {

      /* "uvloop/handles/stream.pyx":203
 *         if UVLOOP_DEBUG:
 *             if self.stream is not None:
 *                 self.stream._loop._debug_stream_write_ctx_cnt -= 1             # <<<<<<<<<<<<<<
 *                 self.stream = None
 * 
 */
      __Pyx_INCREF(((PyObject *)__pyx_v_self->stream->__pyx_base.__pyx_base.__pyx_base._loop));
      __pyx_t_4 = __pyx_v_self->stream->__pyx_base.__pyx_base.__pyx_base._loop;
      __pyx_t_4->_debug_stream_write_ctx_cnt = (__pyx_t_4->_debug_stream_write_ctx_cnt - 1);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;

      /* "uvloop/handles/stream.pyx":204
 *             if self.stream is not None:
 *                 self.stream._loop._debug_stream_write_ctx_cnt -= 1
 *                 self.stream = None             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_INCREF(Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_GOTREF(__pyx_v_self->stream);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->stream));
      __pyx_v_self->stream = ((struct __pyx_obj_6uvloop_4loop_UVStream *)Py_None);

      /* "uvloop/handles/stream.pyx":202
 * 
 *         if UVLOOP_DEBUG:
 *             if self.stream is not None:             # <<<<<<<<<<<<<<
 *                 self.stream._loop._debug_stream_write_ctx_cnt -= 1
 *                 self.stream = None
 */
    }

    /* "uvloop/handles/stream.pyx":201
 *                 'open _StreamWriteContext is being deallocated')
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self.stream is not None:
 *                 self.stream._loop._debug_stream_write_ctx_cnt -= 1
 */
  }

  /* "uvloop/handles/stream.pyx":194
 *         return ctx
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if not self.closed:
 *             # Because we do an INCREF in _StreamWriteContext.new,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(((PyObject *)__pyx_t_4));
  __Pyx_WriteUnraisable("uvloop.loop._StreamWriteContext.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_19_StreamWriteContext_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_19_StreamWriteContext_2__reduce_cython__[] = "_StreamWriteContext.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_19_StreamWriteContext_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_19_StreamWriteContext_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_19_StreamWriteContext_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__172, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._StreamWriteContext.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_19_StreamWriteContext_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_19_StreamWriteContext_4__setstate_cython__[] = "_StreamWriteContext.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_19_StreamWriteContext_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_19_StreamWriteContext_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_19_StreamWriteContext_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__173, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._StreamWriteContext.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":210
 * cdef class UVStream(UVBaseTransport):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.__shutting_down = 0
 *         self.__reading = 0
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_8UVStream_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_8UVStream_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream___cinit__(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_8UVStream___cinit__(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/stream.pyx":211
 * 
 *     def __cinit__(self):
 *         self.__shutting_down = 0             # <<<<<<<<<<<<<<
 *         self.__reading = 0
 *         self.__read_error_close = 0
 */
  __pyx_v_self->__pyx___shutting_down = 0;

  /* "uvloop/handles/stream.pyx":212
 *     def __cinit__(self):
 *         self.__shutting_down = 0
 *         self.__reading = 0             # <<<<<<<<<<<<<<
 *         self.__read_error_close = 0
 *         self.__buffered = 0
 */
  __pyx_v_self->__pyx___reading = 0;

  /* "uvloop/handles/stream.pyx":213
 *         self.__shutting_down = 0
 *         self.__reading = 0
 *         self.__read_error_close = 0             # <<<<<<<<<<<<<<
 *         self.__buffered = 0
 *         self._eof = 0
 */
  __pyx_v_self->__pyx___read_error_close = 0;

  /* "uvloop/handles/stream.pyx":214
 *         self.__reading = 0
 *         self.__read_error_close = 0
 *         self.__buffered = 0             # <<<<<<<<<<<<<<
 *         self._eof = 0
 *         self._buffer = []
 */
  __pyx_v_self->__pyx___buffered = 0;

  /* "uvloop/handles/stream.pyx":215
 *         self.__read_error_close = 0
 *         self.__buffered = 0
 *         self._eof = 0             # <<<<<<<<<<<<<<
 *         self._buffer = []
 *         self._buffer_size = 0
 */
  __pyx_v_self->_eof = 0;

  /* "uvloop/handles/stream.pyx":216
 *         self.__buffered = 0
 *         self._eof = 0
 *         self._buffer = []             # <<<<<<<<<<<<<<
 *         self._buffer_size = 0
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_buffer);
  __Pyx_DECREF(__pyx_v_self->_buffer);
  __pyx_v_self->_buffer = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":217
 *         self._eof = 0
 *         self._buffer = []
 *         self._buffer_size = 0             # <<<<<<<<<<<<<<
 * 
 *         self._protocol_get_buffer = None
 */
  __pyx_v_self->_buffer_size = 0;

  /* "uvloop/handles/stream.pyx":219
 *         self._buffer_size = 0
 * 
 *         self._protocol_get_buffer = None             # <<<<<<<<<<<<<<
 *         self._protocol_buffer_updated = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol_get_buffer);
  __Pyx_DECREF(__pyx_v_self->_protocol_get_buffer);
  __pyx_v_self->_protocol_get_buffer = Py_None;

  /* "uvloop/handles/stream.pyx":220
 * 
 *         self._protocol_get_buffer = None
 *         self._protocol_buffer_updated = None             # <<<<<<<<<<<<<<
 * 
 *         self._read_pybuf_acquired = False
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol_buffer_updated);
  __Pyx_DECREF(__pyx_v_self->_protocol_buffer_updated);
  __pyx_v_self->_protocol_buffer_updated = Py_None;

  /* "uvloop/handles/stream.pyx":222
 *         self._protocol_buffer_updated = None
 * 
 *         self._read_pybuf_acquired = False             # <<<<<<<<<<<<<<
 * 
 *     cdef _set_protocol(self, object protocol):
 */
  __pyx_v_self->_read_pybuf_acquired = 0;

  /* "uvloop/handles/stream.pyx":210
 * cdef class UVStream(UVBaseTransport):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.__shutting_down = 0
 *         self.__reading = 0
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":224
 *         self._read_pybuf_acquired = False
 * 
 *     cdef _set_protocol(self, object protocol):             # <<<<<<<<<<<<<<
 *         if protocol is None:
 *             raise TypeError('protocol is required')
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVStream__set_protocol(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_protocol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("_set_protocol", 0);

  /* "uvloop/handles/stream.pyx":225
 * 
 *     cdef _set_protocol(self, object protocol):
 *         if protocol is None:             # <<<<<<<<<<<<<<
 *             raise TypeError('protocol is required')
 * 
 */
  __pyx_t_1 = (__pyx_v_protocol == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/stream.pyx":226
 *     cdef _set_protocol(self, object protocol):
 *         if protocol is None:
 *             raise TypeError('protocol is required')             # <<<<<<<<<<<<<<
 * 
 *         UVBaseTransport._set_protocol(self, protocol)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__174, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(18, 226, __pyx_L1_error)

    /* "uvloop/handles/stream.pyx":225
 * 
 *     cdef _set_protocol(self, object protocol):
 *         if protocol is None:             # <<<<<<<<<<<<<<
 *             raise TypeError('protocol is required')
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":228
 *             raise TypeError('protocol is required')
 * 
 *         UVBaseTransport._set_protocol(self, protocol)             # <<<<<<<<<<<<<<
 * 
 *         if (hasattr(protocol, 'get_buffer') and
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_15UVBaseTransport__set_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), __pyx_v_protocol); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/stream.pyx":230
 *         UVBaseTransport._set_protocol(self, protocol)
 * 
 *         if (hasattr(protocol, 'get_buffer') and             # <<<<<<<<<<<<<<
 *                 not isinstance(protocol, aio_Protocol)):
 *             try:
 */
  __pyx_t_1 = __Pyx_HasAttr(__pyx_v_protocol, __pyx_n_u_get_buffer); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(18, 230, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_1 != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L5_bool_binop_done;
  }

  /* "uvloop/handles/stream.pyx":231
 * 
 *         if (hasattr(protocol, 'get_buffer') and
 *                 not isinstance(protocol, aio_Protocol)):             # <<<<<<<<<<<<<<
 *             try:
 *                 self._protocol_get_buffer = protocol.get_buffer
 */
  __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_Protocol;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = PyObject_IsInstance(__pyx_v_protocol, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(18, 231, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = ((!(__pyx_t_4 != 0)) != 0);
  __pyx_t_2 = __pyx_t_1;
  __pyx_L5_bool_binop_done:;

  /* "uvloop/handles/stream.pyx":230
 *         UVBaseTransport._set_protocol(self, protocol)
 * 
 *         if (hasattr(protocol, 'get_buffer') and             # <<<<<<<<<<<<<<
 *                 not isinstance(protocol, aio_Protocol)):
 *             try:
 */
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":232
 *         if (hasattr(protocol, 'get_buffer') and
 *                 not isinstance(protocol, aio_Protocol)):
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol_get_buffer = protocol.get_buffer
 *                 self._protocol_buffer_updated = protocol.buffer_updated
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "uvloop/handles/stream.pyx":233
 *                 not isinstance(protocol, aio_Protocol)):
 *             try:
 *                 self._protocol_get_buffer = protocol.get_buffer             # <<<<<<<<<<<<<<
 *                 self._protocol_buffer_updated = protocol.buffer_updated
 *                 self.__buffered = 1
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_protocol, __pyx_n_s_get_buffer); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 233, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_v_self->_protocol_get_buffer);
        __Pyx_DECREF(__pyx_v_self->_protocol_get_buffer);
        __pyx_v_self->_protocol_get_buffer = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "uvloop/handles/stream.pyx":234
 *             try:
 *                 self._protocol_get_buffer = protocol.get_buffer
 *                 self._protocol_buffer_updated = protocol.buffer_updated             # <<<<<<<<<<<<<<
 *                 self.__buffered = 1
 *             except AttributeError:
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_protocol, __pyx_n_s_buffer_updated); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 234, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_v_self->_protocol_buffer_updated);
        __Pyx_DECREF(__pyx_v_self->_protocol_buffer_updated);
        __pyx_v_self->_protocol_buffer_updated = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "uvloop/handles/stream.pyx":235
 *                 self._protocol_get_buffer = protocol.get_buffer
 *                 self._protocol_buffer_updated = protocol.buffer_updated
 *                 self.__buffered = 1             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 pass
 */
        __pyx_v_self->__pyx___buffered = 1;

        /* "uvloop/handles/stream.pyx":232
 *         if (hasattr(protocol, 'get_buffer') and
 *                 not isinstance(protocol, aio_Protocol)):
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol_get_buffer = protocol.get_buffer
 *                 self._protocol_buffer_updated = protocol.buffer_updated
 */
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/stream.pyx":236
 *                 self._protocol_buffer_updated = protocol.buffer_updated
 *                 self.__buffered = 1
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 pass
 *         else:
 */
      __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
      if (__pyx_t_8) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/handles/stream.pyx":232
 *         if (hasattr(protocol, 'get_buffer') and
 *                 not isinstance(protocol, aio_Protocol)):
 *             try:             # <<<<<<<<<<<<<<
 *                 self._protocol_get_buffer = protocol.get_buffer
 *                 self._protocol_buffer_updated = protocol.buffer_updated
 */
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L12_try_end:;
    }

    /* "uvloop/handles/stream.pyx":230
 *         UVBaseTransport._set_protocol(self, protocol)
 * 
 *         if (hasattr(protocol, 'get_buffer') and             # <<<<<<<<<<<<<<
 *                 not isinstance(protocol, aio_Protocol)):
 *             try:
 */
    goto __pyx_L4;
  }

  /* "uvloop/handles/stream.pyx":239
 *                 pass
 *         else:
 *             self.__buffered = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef _clear_protocol(self):
 */
  /*else*/ {
    __pyx_v_self->__pyx___buffered = 0;
  }
  __pyx_L4:;

  /* "uvloop/handles/stream.pyx":224
 *         self._read_pybuf_acquired = False
 * 
 *     cdef _set_protocol(self, object protocol):             # <<<<<<<<<<<<<<
 *         if protocol is None:
 *             raise TypeError('protocol is required')
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVStream._set_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":241
 *             self.__buffered = 0
 * 
 *     cdef _clear_protocol(self):             # <<<<<<<<<<<<<<
 *         UVBaseTransport._clear_protocol(self)
 *         self._protocol_get_buffer = None
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVStream__clear_protocol(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_clear_protocol", 0);

  /* "uvloop/handles/stream.pyx":242
 * 
 *     cdef _clear_protocol(self):
 *         UVBaseTransport._clear_protocol(self)             # <<<<<<<<<<<<<<
 *         self._protocol_get_buffer = None
 *         self._protocol_buffer_updated = None
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_15UVBaseTransport__clear_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":243
 *     cdef _clear_protocol(self):
 *         UVBaseTransport._clear_protocol(self)
 *         self._protocol_get_buffer = None             # <<<<<<<<<<<<<<
 *         self._protocol_buffer_updated = None
 *         self.__buffered = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol_get_buffer);
  __Pyx_DECREF(__pyx_v_self->_protocol_get_buffer);
  __pyx_v_self->_protocol_get_buffer = Py_None;

  /* "uvloop/handles/stream.pyx":244
 *         UVBaseTransport._clear_protocol(self)
 *         self._protocol_get_buffer = None
 *         self._protocol_buffer_updated = None             # <<<<<<<<<<<<<<
 *         self.__buffered = 0
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol_buffer_updated);
  __Pyx_DECREF(__pyx_v_self->_protocol_buffer_updated);
  __pyx_v_self->_protocol_buffer_updated = Py_None;

  /* "uvloop/handles/stream.pyx":245
 *         self._protocol_get_buffer = None
 *         self._protocol_buffer_updated = None
 *         self.__buffered = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _shutdown(self):
 */
  __pyx_v_self->__pyx___buffered = 0;

  /* "uvloop/handles/stream.pyx":241
 *             self.__buffered = 0
 * 
 *     cdef _clear_protocol(self):             # <<<<<<<<<<<<<<
 *         UVBaseTransport._clear_protocol(self)
 *         self._protocol_get_buffer = None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream._clear_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":247
 *         self.__buffered = 0
 * 
 *     cdef inline _shutdown(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__shutdown(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_shutdown", 0);

  /* "uvloop/handles/stream.pyx":250
 *         cdef int err
 * 
 *         if self.__shutting_down:             # <<<<<<<<<<<<<<
 *             return
 *         self.__shutting_down = 1
 */
  __pyx_t_1 = (__pyx_v_self->__pyx___shutting_down != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":251
 * 
 *         if self.__shutting_down:
 *             return             # <<<<<<<<<<<<<<
 *         self.__shutting_down = 1
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":250
 *         cdef int err
 * 
 *         if self.__shutting_down:             # <<<<<<<<<<<<<<
 *             return
 *         self.__shutting_down = 1
 */
  }

  /* "uvloop/handles/stream.pyx":252
 *         if self.__shutting_down:
 *             return
 *         self.__shutting_down = 1             # <<<<<<<<<<<<<<
 * 
 *         self._ensure_alive()
 */
  __pyx_v_self->__pyx___shutting_down = 1;

  /* "uvloop/handles/stream.pyx":254
 *         self.__shutting_down = 1
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         self._shutdown_req.data = <void*> self
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":256
 *         self._ensure_alive()
 * 
 *         self._shutdown_req.data = <void*> self             # <<<<<<<<<<<<<<
 *         err = uv.uv_shutdown(&self._shutdown_req,
 *                              <uv.uv_stream_t*> self._handle,
 */
  __pyx_v_self->_shutdown_req.data = ((void *)__pyx_v_self);

  /* "uvloop/handles/stream.pyx":257
 * 
 *         self._shutdown_req.data = <void*> self
 *         err = uv.uv_shutdown(&self._shutdown_req,             # <<<<<<<<<<<<<<
 *                              <uv.uv_stream_t*> self._handle,
 *                              __uv_stream_on_shutdown)
 */
  __pyx_v_err = uv_shutdown((&__pyx_v_self->_shutdown_req), ((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_f_6uvloop_4loop___uv_stream_on_shutdown);

  /* "uvloop/handles/stream.pyx":260
 *                              <uv.uv_stream_t*> self._handle,
 *                              __uv_stream_on_shutdown)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":261
 *                              __uv_stream_on_shutdown)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 261, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":262
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 262, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":263
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _accept(self, UVStream server):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":260
 *                              <uv.uv_stream_t*> self._handle,
 *                              __uv_stream_on_shutdown)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/stream.pyx":247
 *         self.__buffered = 0
 * 
 *     cdef inline _shutdown(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVStream._shutdown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":265
 *             return
 * 
 *     cdef inline _accept(self, UVStream server):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__accept(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_server) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_accept", 0);

  /* "uvloop/handles/stream.pyx":267
 *     cdef inline _accept(self, UVStream server):
 *         cdef int err
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_accept(<uv.uv_stream_t*>server._handle,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":269
 *         self._ensure_alive()
 * 
 *         err = uv.uv_accept(<uv.uv_stream_t*>server._handle,             # <<<<<<<<<<<<<<
 *                            <uv.uv_stream_t*>self._handle)
 *         if err < 0:
 */
  __pyx_v_err = uv_accept(((uv_stream_t *)__pyx_v_server->__pyx_base.__pyx_base.__pyx_base._handle), ((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle));

  /* "uvloop/handles/stream.pyx":271
 *         err = uv.uv_accept(<uv.uv_stream_t*>server._handle,
 *                            <uv.uv_stream_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":272
 *                            <uv.uv_stream_t*>self._handle)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":273
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":274
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._on_accept()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":271
 *         err = uv.uv_accept(<uv.uv_stream_t*>server._handle,
 *                            <uv.uv_stream_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/stream.pyx":276
 *             return
 * 
 *         self._on_accept()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _close_on_read_error(self):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_8UVStream__on_accept(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":265
 *             return
 * 
 *     cdef inline _accept(self, UVStream server):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream._accept", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":278
 *         self._on_accept()
 * 
 *     cdef inline _close_on_read_error(self):             # <<<<<<<<<<<<<<
 *         self.__read_error_close = 1
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__close_on_read_error(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_close_on_read_error", 0);

  /* "uvloop/handles/stream.pyx":279
 * 
 *     cdef inline _close_on_read_error(self):
 *         self.__read_error_close = 1             # <<<<<<<<<<<<<<
 * 
 *     cdef bint _is_reading(self):
 */
  __pyx_v_self->__pyx___read_error_close = 1;

  /* "uvloop/handles/stream.pyx":278
 *         self._on_accept()
 * 
 *     cdef inline _close_on_read_error(self):             # <<<<<<<<<<<<<<
 *         self.__read_error_close = 1
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":281
 *         self.__read_error_close = 1
 * 
 *     cdef bint _is_reading(self):             # <<<<<<<<<<<<<<
 *         return self.__reading
 * 
 */

static int __pyx_f_6uvloop_4loop_8UVStream__is_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_is_reading", 0);

  /* "uvloop/handles/stream.pyx":282
 * 
 *     cdef bint _is_reading(self):
 *         return self.__reading             # <<<<<<<<<<<<<<
 * 
 *     cdef _start_reading(self):
 */
  __pyx_r = __pyx_v_self->__pyx___reading;
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":281
 *         self.__read_error_close = 1
 * 
 *     cdef bint _is_reading(self):             # <<<<<<<<<<<<<<
 *         return self.__reading
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":284
 *         return self.__reading
 * 
 *     cdef _start_reading(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVStream__start_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_start_reading", 0);

  /* "uvloop/handles/stream.pyx":287
 *         cdef int err
 * 
 *         if self._closing:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base._closing != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":288
 * 
 *         if self._closing:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._ensure_alive()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":287
 *         cdef int err
 * 
 *         if self._closing:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":290
 *             return
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if self.__reading:
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":292
 *         self._ensure_alive()
 * 
 *         if self.__reading:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = (__pyx_v_self->__pyx___reading != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":293
 * 
 *         if self.__reading:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self.__buffered:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":292
 *         self._ensure_alive()
 * 
 *         if self.__reading:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":295
 *             return
 * 
 *         if self.__buffered:             # <<<<<<<<<<<<<<
 *             err = uv.uv_read_start(<uv.uv_stream_t*>self._handle,
 *                                    __uv_stream_buffered_alloc,
 */
  __pyx_t_1 = (__pyx_v_self->__pyx___buffered != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":296
 * 
 *         if self.__buffered:
 *             err = uv.uv_read_start(<uv.uv_stream_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                    __uv_stream_buffered_alloc,
 *                                    __uv_stream_buffered_on_read)
 */
    __pyx_v_err = uv_read_start(((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_f_6uvloop_4loop___uv_stream_buffered_alloc, __pyx_f_6uvloop_4loop___uv_stream_buffered_on_read);

    /* "uvloop/handles/stream.pyx":295
 *             return
 * 
 *         if self.__buffered:             # <<<<<<<<<<<<<<
 *             err = uv.uv_read_start(<uv.uv_stream_t*>self._handle,
 *                                    __uv_stream_buffered_alloc,
 */
    goto __pyx_L5;
  }

  /* "uvloop/handles/stream.pyx":300
 *                                    __uv_stream_buffered_on_read)
 *         else:
 *             err = uv.uv_read_start(<uv.uv_stream_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                    __loop_alloc_buffer,
 *                                    __uv_stream_on_read)
 */
  /*else*/ {

    /* "uvloop/handles/stream.pyx":302
 *             err = uv.uv_read_start(<uv.uv_stream_t*>self._handle,
 *                                    __loop_alloc_buffer,
 *                                    __uv_stream_on_read)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             exc = convert_error(err)
 */
    __pyx_v_err = uv_read_start(((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_f_6uvloop_4loop___loop_alloc_buffer, __pyx_f_6uvloop_4loop___uv_stream_on_read);
  }
  __pyx_L5:;

  /* "uvloop/handles/stream.pyx":303
 *                                    __loop_alloc_buffer,
 *                                    __uv_stream_on_read)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":304
 *                                    __uv_stream_on_read)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":305
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 *         else:
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":306
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 *         else:
 *             # UVStream must live until the read callback is called
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":303
 *                                    __loop_alloc_buffer,
 *                                    __uv_stream_on_read)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/stream.pyx":309
 *         else:
 *             # UVStream must live until the read callback is called
 *             self.__reading_started()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline __reading_started(self):
 */
  /*else*/ {
    __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVStream___reading_started(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "uvloop/handles/stream.pyx":284
 *         return self.__reading
 * 
 *     cdef _start_reading(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVStream._start_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":311
 *             self.__reading_started()
 * 
 *     cdef inline __reading_started(self):             # <<<<<<<<<<<<<<
 *         if self.__reading:
 *             return
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream___reading_started(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__reading_started", 0);

  /* "uvloop/handles/stream.pyx":312
 * 
 *     cdef inline __reading_started(self):
 *         if self.__reading:             # <<<<<<<<<<<<<<
 *             return
 *         self.__reading = 1
 */
  __pyx_t_1 = (__pyx_v_self->__pyx___reading != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":313
 *     cdef inline __reading_started(self):
 *         if self.__reading:
 *             return             # <<<<<<<<<<<<<<
 *         self.__reading = 1
 *         Py_INCREF(self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":312
 * 
 *     cdef inline __reading_started(self):
 *         if self.__reading:             # <<<<<<<<<<<<<<
 *             return
 *         self.__reading = 1
 */
  }

  /* "uvloop/handles/stream.pyx":314
 *         if self.__reading:
 *             return
 *         self.__reading = 1             # <<<<<<<<<<<<<<
 *         Py_INCREF(self)
 * 
 */
  __pyx_v_self->__pyx___reading = 1;

  /* "uvloop/handles/stream.pyx":315
 *             return
 *         self.__reading = 1
 *         Py_INCREF(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline __reading_stopped(self):
 */
  Py_INCREF(((PyObject *)__pyx_v_self));

  /* "uvloop/handles/stream.pyx":311
 *             self.__reading_started()
 * 
 *     cdef inline __reading_started(self):             # <<<<<<<<<<<<<<
 *         if self.__reading:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":317
 *         Py_INCREF(self)
 * 
 *     cdef inline __reading_stopped(self):             # <<<<<<<<<<<<<<
 *         if not self.__reading:
 *             return
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream___reading_stopped(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__reading_stopped", 0);

  /* "uvloop/handles/stream.pyx":318
 * 
 *     cdef inline __reading_stopped(self):
 *         if not self.__reading:             # <<<<<<<<<<<<<<
 *             return
 *         self.__reading = 0
 */
  __pyx_t_1 = ((!(__pyx_v_self->__pyx___reading != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":319
 *     cdef inline __reading_stopped(self):
 *         if not self.__reading:
 *             return             # <<<<<<<<<<<<<<
 *         self.__reading = 0
 *         Py_DECREF(self)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":318
 * 
 *     cdef inline __reading_stopped(self):
 *         if not self.__reading:             # <<<<<<<<<<<<<<
 *             return
 *         self.__reading = 0
 */
  }

  /* "uvloop/handles/stream.pyx":320
 *         if not self.__reading:
 *             return
 *         self.__reading = 0             # <<<<<<<<<<<<<<
 *         Py_DECREF(self)
 * 
 */
  __pyx_v_self->__pyx___reading = 0;

  /* "uvloop/handles/stream.pyx":321
 *             return
 *         self.__reading = 0
 *         Py_DECREF(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _stop_reading(self):
 */
  Py_DECREF(((PyObject *)__pyx_v_self));

  /* "uvloop/handles/stream.pyx":317
 *         Py_INCREF(self)
 * 
 *     cdef inline __reading_stopped(self):             # <<<<<<<<<<<<<<
 *         if not self.__reading:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":323
 *         Py_DECREF(self)
 * 
 *     cdef _stop_reading(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVStream__stop_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_stop_reading", 0);

  /* "uvloop/handles/stream.pyx":326
 *         cdef int err
 * 
 *         if not self.__reading:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(__pyx_v_self->__pyx___reading != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":327
 * 
 *         if not self.__reading:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._ensure_alive()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":326
 *         cdef int err
 * 
 *         if not self.__reading:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":329
 *             return
 * 
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         # From libuv docs:
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":334
 *         #    This function is idempotent and may be safely
 *         #    called on a stopped stream.
 *         err = uv.uv_read_stop(<uv.uv_stream_t*>self._handle)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             exc = convert_error(err)
 */
  __pyx_v_err = uv_read_stop(((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle));

  /* "uvloop/handles/stream.pyx":335
 *         #    called on a stopped stream.
 *         err = uv.uv_read_stop(<uv.uv_stream_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":336
 *         err = uv.uv_read_stop(<uv.uv_stream_t*>self._handle)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 336, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":337
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 *         else:
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":338
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 *         else:
 *             self.__reading_stopped()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":335
 *         #    called on a stopped stream.
 *         err = uv.uv_read_stop(<uv.uv_stream_t*>self._handle)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/stream.pyx":340
 *             return
 *         else:
 *             self.__reading_stopped()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _try_write(self, object data):
 */
  /*else*/ {
    __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVStream___reading_stopped(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "uvloop/handles/stream.pyx":323
 *         Py_DECREF(self)
 * 
 *     cdef _stop_reading(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVStream._stop_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":342
 *             self.__reading_stopped()
 * 
 *     cdef inline _try_write(self, object data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             ssize_t written
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__try_write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_data) {
  Py_ssize_t __pyx_v_written;
  int __pyx_v_used_buf;
  Py_buffer __pyx_v_py_buf;
  void *__pyx_v_buf;
  size_t __pyx_v_blen;
  int __pyx_v_saved_errno;
  int __pyx_v_fd;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  void *__pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_try_write", 0);

  /* "uvloop/handles/stream.pyx":345
 *         cdef:
 *             ssize_t written
 *             bint used_buf = 0             # <<<<<<<<<<<<<<
 *             Py_buffer py_buf
 *             void* buf
 */
  __pyx_v_used_buf = 0;

  /* "uvloop/handles/stream.pyx":352
 *             int fd
 * 
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'UVStream._try_write called with data in uv buffers')
 */
  __pyx_t_1 = ((((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle)->write_queue_size != 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/stream.pyx":353
 * 
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size != 0:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'UVStream._try_write called with data in uv buffers')
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__175, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 353, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(18, 353, __pyx_L1_error)

    /* "uvloop/handles/stream.pyx":352
 *             int fd
 * 
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size != 0:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'UVStream._try_write called with data in uv buffers')
 */
  }

  /* "uvloop/handles/stream.pyx":356
 *                 'UVStream._try_write called with data in uv buffers')
 * 
 *         if PyBytes_CheckExact(data):             # <<<<<<<<<<<<<<
 *             # We can only use this hack for bytes since it's
 *             # immutable.  For everything else it is only safe to
 */
  __pyx_t_1 = (PyBytes_CheckExact(__pyx_v_data) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":360
 *             # immutable.  For everything else it is only safe to
 *             # use buffer protocol.
 *             buf = <void*>PyBytes_AS_STRING(data)             # <<<<<<<<<<<<<<
 *             blen = Py_SIZE(data)
 *         else:
 */
    __pyx_v_buf = ((void *)PyBytes_AS_STRING(__pyx_v_data));

    /* "uvloop/handles/stream.pyx":361
 *             # use buffer protocol.
 *             buf = <void*>PyBytes_AS_STRING(data)
 *             blen = Py_SIZE(data)             # <<<<<<<<<<<<<<
 *         else:
 *             PyObject_GetBuffer(data, &py_buf, PyBUF_SIMPLE)
 */
    __pyx_v_blen = Py_SIZE(__pyx_v_data);

    /* "uvloop/handles/stream.pyx":356
 *                 'UVStream._try_write called with data in uv buffers')
 * 
 *         if PyBytes_CheckExact(data):             # <<<<<<<<<<<<<<
 *             # We can only use this hack for bytes since it's
 *             # immutable.  For everything else it is only safe to
 */
    goto __pyx_L4;
  }

  /* "uvloop/handles/stream.pyx":363
 *             blen = Py_SIZE(data)
 *         else:
 *             PyObject_GetBuffer(data, &py_buf, PyBUF_SIMPLE)             # <<<<<<<<<<<<<<
 *             used_buf = 1
 *             buf = py_buf.buf
 */
  /*else*/ {
    __pyx_t_3 = PyObject_GetBuffer(__pyx_v_data, (&__pyx_v_py_buf), PyBUF_SIMPLE); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(18, 363, __pyx_L1_error)

    /* "uvloop/handles/stream.pyx":364
 *         else:
 *             PyObject_GetBuffer(data, &py_buf, PyBUF_SIMPLE)
 *             used_buf = 1             # <<<<<<<<<<<<<<
 *             buf = py_buf.buf
 *             blen = py_buf.len
 */
    __pyx_v_used_buf = 1;

    /* "uvloop/handles/stream.pyx":365
 *             PyObject_GetBuffer(data, &py_buf, PyBUF_SIMPLE)
 *             used_buf = 1
 *             buf = py_buf.buf             # <<<<<<<<<<<<<<
 *             blen = py_buf.len
 * 
 */
    __pyx_t_4 = __pyx_v_py_buf.buf;
    __pyx_v_buf = __pyx_t_4;

    /* "uvloop/handles/stream.pyx":366
 *             used_buf = 1
 *             buf = py_buf.buf
 *             blen = py_buf.len             # <<<<<<<<<<<<<<
 * 
 *         if blen == 0:
 */
    __pyx_t_5 = __pyx_v_py_buf.len;
    __pyx_v_blen = __pyx_t_5;
  }
  __pyx_L4:;

  /* "uvloop/handles/stream.pyx":368
 *             blen = py_buf.len
 * 
 *         if blen == 0:             # <<<<<<<<<<<<<<
 *             # Empty data, do nothing.
 *             return 0
 */
  __pyx_t_1 = ((__pyx_v_blen == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":370
 *         if blen == 0:
 *             # Empty data, do nothing.
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         fd = self._fileno()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_0);
    __pyx_r = __pyx_int_0;
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":368
 *             blen = py_buf.len
 * 
 *         if blen == 0:             # <<<<<<<<<<<<<<
 *             # Empty data, do nothing.
 *             return 0
 */
  }

  /* "uvloop/handles/stream.pyx":372
 *             return 0
 * 
 *         fd = self._fileno()             # <<<<<<<<<<<<<<
 *         # Use `unistd.h/write` directly, it's faster than
 *         # uv_try_write -- less layers of code.  The error
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._fileno(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(18, 372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_fd = __pyx_t_3;

  /* "uvloop/handles/stream.pyx":376
 *         # uv_try_write -- less layers of code.  The error
 *         # checking logic is copied from libuv.
 *         written = system.write(fd, buf, blen)             # <<<<<<<<<<<<<<
 *         while written == -1 and (errno.errno == errno.EINTR or
 *                                  (system.PLATFORM_IS_APPLE and
 */
  __pyx_v_written = write(__pyx_v_fd, __pyx_v_buf, __pyx_v_blen);

  /* "uvloop/handles/stream.pyx":377
 *         # checking logic is copied from libuv.
 *         written = system.write(fd, buf, blen)
 *         while written == -1 and (errno.errno == errno.EINTR or             # <<<<<<<<<<<<<<
 *                                  (system.PLATFORM_IS_APPLE and
 *                                     errno.errno == errno.EPROTOTYPE)):
 */
  while (1) {
    __pyx_t_6 = ((__pyx_v_written == -1L) != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_6 = ((errno == EINTR) != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }

    /* "uvloop/handles/stream.pyx":378
 *         written = system.write(fd, buf, blen)
 *         while written == -1 and (errno.errno == errno.EINTR or
 *                                  (system.PLATFORM_IS_APPLE and             # <<<<<<<<<<<<<<
 *                                     errno.errno == errno.EPROTOTYPE)):
 *             # From libuv code (unix/stream.c):
 */
    __pyx_t_6 = (PLATFORM_IS_APPLE != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L8_bool_binop_done;
    }

    /* "uvloop/handles/stream.pyx":379
 *         while written == -1 and (errno.errno == errno.EINTR or
 *                                  (system.PLATFORM_IS_APPLE and
 *                                     errno.errno == errno.EPROTOTYPE)):             # <<<<<<<<<<<<<<
 *             # From libuv code (unix/stream.c):
 *             #   Due to a possible kernel bug at least in OS X 10.10 "Yosemite",
 */
    __pyx_t_6 = ((errno == EPROTOTYPE) != 0);
    __pyx_t_1 = __pyx_t_6;
    __pyx_L8_bool_binop_done:;
    if (!__pyx_t_1) break;

    /* "uvloop/handles/stream.pyx":385
 *             #   that is shutting down. If we retry the write, we should get
 *             #   the expected EPIPE instead.
 *             written = system.write(fd, buf, blen)             # <<<<<<<<<<<<<<
 *         saved_errno = errno.errno
 * 
 */
    __pyx_v_written = write(__pyx_v_fd, __pyx_v_buf, __pyx_v_blen);
  }

  /* "uvloop/handles/stream.pyx":386
 *             #   the expected EPIPE instead.
 *             written = system.write(fd, buf, blen)
 *         saved_errno = errno.errno             # <<<<<<<<<<<<<<
 * 
 *         if used_buf:
 */
  __pyx_v_saved_errno = errno;

  /* "uvloop/handles/stream.pyx":388
 *         saved_errno = errno.errno
 * 
 *         if used_buf:             # <<<<<<<<<<<<<<
 *             PyBuffer_Release(&py_buf)
 * 
 */
  __pyx_t_1 = (__pyx_v_used_buf != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":389
 * 
 *         if used_buf:
 *             PyBuffer_Release(&py_buf)             # <<<<<<<<<<<<<<
 * 
 *         if written < 0:
 */
    PyBuffer_Release((&__pyx_v_py_buf));

    /* "uvloop/handles/stream.pyx":388
 *         saved_errno = errno.errno
 * 
 *         if used_buf:             # <<<<<<<<<<<<<<
 *             PyBuffer_Release(&py_buf)
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":391
 *             PyBuffer_Release(&py_buf)
 * 
 *         if written < 0:             # <<<<<<<<<<<<<<
 *             if saved_errno == errno.EAGAIN or \
 *                     saved_errno == system.EWOULDBLOCK:
 */
  __pyx_t_1 = ((__pyx_v_written < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":392
 * 
 *         if written < 0:
 *             if saved_errno == errno.EAGAIN or \             # <<<<<<<<<<<<<<
 *                     saved_errno == system.EWOULDBLOCK:
 *                 return -1
 */
    __pyx_t_6 = ((__pyx_v_saved_errno == EAGAIN) != 0);
    if (!__pyx_t_6) {
    } else {
      __pyx_t_1 = __pyx_t_6;
      goto __pyx_L15_bool_binop_done;
    }

    /* "uvloop/handles/stream.pyx":393
 *         if written < 0:
 *             if saved_errno == errno.EAGAIN or \
 *                     saved_errno == system.EWOULDBLOCK:             # <<<<<<<<<<<<<<
 *                 return -1
 *             else:
 */
    __pyx_t_6 = ((__pyx_v_saved_errno == EWOULDBLOCK) != 0);
    __pyx_t_1 = __pyx_t_6;
    __pyx_L15_bool_binop_done:;

    /* "uvloop/handles/stream.pyx":392
 * 
 *         if written < 0:
 *             if saved_errno == errno.EAGAIN or \             # <<<<<<<<<<<<<<
 *                     saved_errno == system.EWOULDBLOCK:
 *                 return -1
 */
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":394
 *             if saved_errno == errno.EAGAIN or \
 *                     saved_errno == system.EWOULDBLOCK:
 *                 return -1             # <<<<<<<<<<<<<<
 *             else:
 *                 exc = convert_error(-saved_errno)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_int_neg_1);
      __pyx_r = __pyx_int_neg_1;
      goto __pyx_L0;

      /* "uvloop/handles/stream.pyx":392
 * 
 *         if written < 0:
 *             if saved_errno == errno.EAGAIN or \             # <<<<<<<<<<<<<<
 *                     saved_errno == system.EWOULDBLOCK:
 *                 return -1
 */
    }

    /* "uvloop/handles/stream.pyx":396
 *                 return -1
 *             else:
 *                 exc = convert_error(-saved_errno)             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, True)
 *                 return
 */
    /*else*/ {
      __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error((-__pyx_v_saved_errno)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 396, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_exc = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":397
 *             else:
 *                 exc = convert_error(-saved_errno)
 *                 self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                 return
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 397, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":398
 *                 exc = convert_error(-saved_errno)
 *                 self._fatal_error(exc, True)
 *                 return             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
    }

    /* "uvloop/handles/stream.pyx":391
 *             PyBuffer_Release(&py_buf)
 * 
 *         if written < 0:             # <<<<<<<<<<<<<<
 *             if saved_errno == errno.EAGAIN or \
 *                     saved_errno == system.EWOULDBLOCK:
 */
  }

  /* "uvloop/handles/stream.pyx":400
 *                 return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_stream_write_tries += 1
 * 
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":401
 * 
 *         if UVLOOP_DEBUG:
 *             self._loop._debug_stream_write_tries += 1             # <<<<<<<<<<<<<<
 * 
 *         if <size_t>written == blen:
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop));
    __pyx_t_7 = __pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop;
    __pyx_t_7->_debug_stream_write_tries = (__pyx_t_7->_debug_stream_write_tries + 1);
    __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;

    /* "uvloop/handles/stream.pyx":400
 *                 return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_stream_write_tries += 1
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":403
 *             self._loop._debug_stream_write_tries += 1
 * 
 *         if <size_t>written == blen:             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  __pyx_t_1 = ((((size_t)__pyx_v_written) == __pyx_v_blen) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":404
 * 
 *         if <size_t>written == blen:
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *         return written
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_0);
    __pyx_r = __pyx_int_0;
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":403
 *             self._loop._debug_stream_write_tries += 1
 * 
 *         if <size_t>written == blen:             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":406
 *             return 0
 * 
 *         return written             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _write(self, object data):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_written); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":342
 *             self.__reading_stopped()
 * 
 *     cdef inline _try_write(self, object data):             # <<<<<<<<<<<<<<
 *         cdef:
 *             ssize_t written
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(((PyObject *)__pyx_t_7));
  __Pyx_AddTraceback("uvloop.loop.UVStream._try_write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":408
 *         return written
 * 
 *     cdef inline _write(self, object data):             # <<<<<<<<<<<<<<
 *         cdef int dlen
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_data) {
  int __pyx_v_dlen;
  PyObject *__pyx_v_all_sent = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("_write", 0);
  __Pyx_INCREF(__pyx_v_data);

  /* "uvloop/handles/stream.pyx":411
 *         cdef int dlen
 * 
 *         if not PyBytes_CheckExact(data):             # <<<<<<<<<<<<<<
 *             data = memoryview(data).cast('b')
 * 
 */
  __pyx_t_1 = ((!(PyBytes_CheckExact(__pyx_v_data) != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":412
 * 
 *         if not PyBytes_CheckExact(data):
 *             data = memoryview(data).cast('b')             # <<<<<<<<<<<<<<
 * 
 *         dlen = len(data)
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_cast); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__176, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 412, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/handles/stream.pyx":411
 *         cdef int dlen
 * 
 *         if not PyBytes_CheckExact(data):             # <<<<<<<<<<<<<<
 *             data = memoryview(data).cast('b')
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":414
 *             data = memoryview(data).cast('b')
 * 
 *         dlen = len(data)             # <<<<<<<<<<<<<<
 *         if not dlen:
 *             return
 */
  __pyx_t_4 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(18, 414, __pyx_L1_error)
  __pyx_v_dlen = __pyx_t_4;

  /* "uvloop/handles/stream.pyx":415
 * 
 *         dlen = len(data)
 *         if not dlen:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(__pyx_v_dlen != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":416
 *         dlen = len(data)
 *         if not dlen:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._buffer_size += dlen
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":415
 * 
 *         dlen = len(data)
 *         if not dlen:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":418
 *             return
 * 
 *         self._buffer_size += dlen             # <<<<<<<<<<<<<<
 *         self._buffer.append(data)
 * 
 */
  __pyx_v_self->_buffer_size = (__pyx_v_self->_buffer_size + __pyx_v_dlen);

  /* "uvloop/handles/stream.pyx":419
 * 
 *         self._buffer_size += dlen
 *         self._buffer.append(data)             # <<<<<<<<<<<<<<
 * 
 *         if (not self._protocol_paused and
 */
  if (unlikely(__pyx_v_self->_buffer == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(18, 419, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->_buffer, __pyx_v_data); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(18, 419, __pyx_L1_error)

  /* "uvloop/handles/stream.pyx":421
 *         self._buffer.append(data)
 * 
 *         if (not self._protocol_paused and             # <<<<<<<<<<<<<<
 *                 (<uv.uv_stream_t*>self._handle).write_queue_size == 0 and
 *                 self._buffer_size > self._high_water):
 */
  __pyx_t_6 = ((!(__pyx_v_self->__pyx_base._protocol_paused != 0)) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }

  /* "uvloop/handles/stream.pyx":422
 * 
 *         if (not self._protocol_paused and
 *                 (<uv.uv_stream_t*>self._handle).write_queue_size == 0 and             # <<<<<<<<<<<<<<
 *                 self._buffer_size > self._high_water):
 *             # Fast-path.  If:
 */
  __pyx_t_6 = ((((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle)->write_queue_size == 0) != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_1 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }

  /* "uvloop/handles/stream.pyx":423
 *         if (not self._protocol_paused and
 *                 (<uv.uv_stream_t*>self._handle).write_queue_size == 0 and
 *                 self._buffer_size > self._high_water):             # <<<<<<<<<<<<<<
 *             # Fast-path.  If:
 *             #   - the protocol isn't yet paused,
 */
  __pyx_t_6 = ((__pyx_v_self->_buffer_size > __pyx_v_self->__pyx_base._high_water) != 0);
  __pyx_t_1 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;

  /* "uvloop/handles/stream.pyx":421
 *         self._buffer.append(data)
 * 
 *         if (not self._protocol_paused and             # <<<<<<<<<<<<<<
 *                 (<uv.uv_stream_t*>self._handle).write_queue_size == 0 and
 *                 self._buffer_size > self._high_water):
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":431
 *             # Then:
 *             #   - Try to write all buffered data right now.
 *             all_sent = self._exec_write()             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 if self._buffer_size != 0 or self._buffer != []:
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_8UVStream__exec_write(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 431, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_all_sent = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/handles/stream.pyx":432
 *             #   - Try to write all buffered data right now.
 *             all_sent = self._exec_write()
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self._buffer_size != 0 or self._buffer != []:
 *                     raise RuntimeError(
 */
    __pyx_t_1 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":433
 *             all_sent = self._exec_write()
 *             if UVLOOP_DEBUG:
 *                 if self._buffer_size != 0 or self._buffer != []:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '_buffer_size is not 0 after a successful _exec_write')
 */
      __pyx_t_6 = ((__pyx_v_self->_buffer_size != 0) != 0);
      if (!__pyx_t_6) {
      } else {
        __pyx_t_1 = __pyx_t_6;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_self->_buffer, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 433, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(18, 433, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_1 = __pyx_t_6;
      __pyx_L11_bool_binop_done:;
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/handles/stream.pyx":434
 *             if UVLOOP_DEBUG:
 *                 if self._buffer_size != 0 or self._buffer != []:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '_buffer_size is not 0 after a successful _exec_write')
 * 
 */
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__177, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 434, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(18, 434, __pyx_L1_error)

        /* "uvloop/handles/stream.pyx":433
 *             all_sent = self._exec_write()
 *             if UVLOOP_DEBUG:
 *                 if self._buffer_size != 0 or self._buffer != []:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         '_buffer_size is not 0 after a successful _exec_write')
 */
      }

      /* "uvloop/handles/stream.pyx":432
 *             #   - Try to write all buffered data right now.
 *             all_sent = self._exec_write()
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 if self._buffer_size != 0 or self._buffer != []:
 *                     raise RuntimeError(
 */
    }

    /* "uvloop/handles/stream.pyx":440
 *             # as `uv_write` should be called already.
 * 
 *             if not all_sent:             # <<<<<<<<<<<<<<
 *                 # If not all of the data was sent successfully,
 *                 # we might need to pause the protocol.
 */
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_all_sent); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(18, 440, __pyx_L1_error)
    __pyx_t_6 = ((!__pyx_t_1) != 0);
    if (__pyx_t_6) {

      /* "uvloop/handles/stream.pyx":443
 *                 # If not all of the data was sent successfully,
 *                 # we might need to pause the protocol.
 *                 self._maybe_pause_protocol()             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._maybe_pause_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 443, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":440
 *             # as `uv_write` should be called already.
 * 
 *             if not all_sent:             # <<<<<<<<<<<<<<
 *                 # If not all of the data was sent successfully,
 *                 # we might need to pause the protocol.
 */
    }

    /* "uvloop/handles/stream.pyx":444
 *                 # we might need to pause the protocol.
 *                 self._maybe_pause_protocol()
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._maybe_pause_protocol()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":421
 *         self._buffer.append(data)
 * 
 *         if (not self._protocol_paused and             # <<<<<<<<<<<<<<
 *                 (<uv.uv_stream_t*>self._handle).write_queue_size == 0 and
 *                 self._buffer_size > self._high_water):
 */
  }

  /* "uvloop/handles/stream.pyx":446
 *             return
 * 
 *         self._maybe_pause_protocol()             # <<<<<<<<<<<<<<
 *         self._loop._queue_write(self)
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._maybe_pause_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":447
 * 
 *         self._maybe_pause_protocol()
 *         self._loop._queue_write(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _exec_write(self):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_4Loop__queue_write(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop, __pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":408
 *         return written
 * 
 *     cdef inline _write(self, object data):             # <<<<<<<<<<<<<<
 *         cdef int dlen
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVStream._write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_all_sent);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":449
 *         self._loop._queue_write(self)
 * 
 *     cdef inline _exec_write(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int err
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__exec_write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  int __pyx_v_err;
  int __pyx_v_buf_len;
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_ctx = 0;
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_sent = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  __Pyx_RefNannySetupContext("_exec_write", 0);

  /* "uvloop/handles/stream.pyx":453
 *             int err
 *             int buf_len
 *             _StreamWriteContext ctx = None             # <<<<<<<<<<<<<<
 * 
 *         if self._closed:
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_ctx = ((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)Py_None);

  /* "uvloop/handles/stream.pyx":455
 *             _StreamWriteContext ctx = None
 * 
 *         if self._closed:             # <<<<<<<<<<<<<<
 *             # If the handle is closed, just return, it's too
 *             # late to do anything.
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._closed != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":458
 *             # If the handle is closed, just return, it's too
 *             # late to do anything.
 *             return             # <<<<<<<<<<<<<<
 * 
 *         buf_len = len(self._buffer)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":455
 *             _StreamWriteContext ctx = None
 * 
 *         if self._closed:             # <<<<<<<<<<<<<<
 *             # If the handle is closed, just return, it's too
 *             # late to do anything.
 */
  }

  /* "uvloop/handles/stream.pyx":460
 *             return
 * 
 *         buf_len = len(self._buffer)             # <<<<<<<<<<<<<<
 *         if not buf_len:
 *             return
 */
  __pyx_t_2 = __pyx_v_self->_buffer;
  __Pyx_INCREF(__pyx_t_2);
  if (unlikely(__pyx_t_2 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(18, 460, __pyx_L1_error)
  }
  __pyx_t_3 = PyList_GET_SIZE(__pyx_t_2); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(18, 460, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_buf_len = __pyx_t_3;

  /* "uvloop/handles/stream.pyx":461
 * 
 *         buf_len = len(self._buffer)
 *         if not buf_len:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((!(__pyx_v_buf_len != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":462
 *         buf_len = len(self._buffer)
 *         if not buf_len:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size == 0:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":461
 * 
 *         buf_len = len(self._buffer)
 *         if not buf_len:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":464
 *             return
 * 
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size == 0:             # <<<<<<<<<<<<<<
 *             # libuv internal write buffers for this stream are empty.
 *             if buf_len == 1:
 */
  __pyx_t_1 = ((((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle)->write_queue_size == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":466
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size == 0:
 *             # libuv internal write buffers for this stream are empty.
 *             if buf_len == 1:             # <<<<<<<<<<<<<<
 *                 # If we only have one piece of data to send, let's
 *                 # use our fast implementation of try_write.
 */
    __pyx_t_1 = ((__pyx_v_buf_len == 1) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":469
 *                 # If we only have one piece of data to send, let's
 *                 # use our fast implementation of try_write.
 *                 data = self._buffer[0]             # <<<<<<<<<<<<<<
 *                 sent = self._try_write(data)
 * 
 */
      if (unlikely(__pyx_v_self->_buffer == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(18, 469, __pyx_L1_error)
      }
      __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->_buffer, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_data = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":470
 *                 # use our fast implementation of try_write.
 *                 data = self._buffer[0]
 *                 sent = self._try_write(data)             # <<<<<<<<<<<<<<
 * 
 *                 if sent is None:
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVStream__try_write(__pyx_v_self, __pyx_v_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 470, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_v_sent = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":472
 *                 sent = self._try_write(data)
 * 
 *                 if sent is None:             # <<<<<<<<<<<<<<
 *                     # A `self._fatal_error` was called.
 *                     # It might not raise an exception under some
 */
      __pyx_t_1 = (__pyx_v_sent == Py_None);
      __pyx_t_4 = (__pyx_t_1 != 0);
      if (__pyx_t_4) {

        /* "uvloop/handles/stream.pyx":476
 *                     # It might not raise an exception under some
 *                     # conditions.
 *                     self._buffer_size = 0             # <<<<<<<<<<<<<<
 *                     self._buffer.clear()
 *                     if not self._closing:
 */
        __pyx_v_self->_buffer_size = 0;

        /* "uvloop/handles/stream.pyx":477
 *                     # conditions.
 *                     self._buffer_size = 0
 *                     self._buffer.clear()             # <<<<<<<<<<<<<<
 *                     if not self._closing:
 *                         # This should never happen.
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_buffer, __pyx_n_s_clear); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 477, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (__pyx_t_6) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 477, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else {
          __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 477, __pyx_L1_error)
        }
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/handles/stream.pyx":478
 *                     self._buffer_size = 0
 *                     self._buffer.clear()
 *                     if not self._closing:             # <<<<<<<<<<<<<<
 *                         # This should never happen.
 *                         raise RuntimeError(
 */
        __pyx_t_4 = ((!(__pyx_v_self->__pyx_base._closing != 0)) != 0);
        if (unlikely(__pyx_t_4)) {

          /* "uvloop/handles/stream.pyx":480
 *                     if not self._closing:
 *                         # This should never happen.
 *                         raise RuntimeError(             # <<<<<<<<<<<<<<
 *                             'stream is open after UVStream._try_write '
 *                             'returned None')
 */
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__178, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 480, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_Raise(__pyx_t_2, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __PYX_ERR(18, 480, __pyx_L1_error)

          /* "uvloop/handles/stream.pyx":478
 *                     self._buffer_size = 0
 *                     self._buffer.clear()
 *                     if not self._closing:             # <<<<<<<<<<<<<<
 *                         # This should never happen.
 *                         raise RuntimeError(
 */
        }

        /* "uvloop/handles/stream.pyx":483
 *                             'stream is open after UVStream._try_write '
 *                             'returned None')
 *                     return             # <<<<<<<<<<<<<<
 * 
 *                 if sent == 0:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L0;

        /* "uvloop/handles/stream.pyx":472
 *                 sent = self._try_write(data)
 * 
 *                 if sent is None:             # <<<<<<<<<<<<<<
 *                     # A `self._fatal_error` was called.
 *                     # It might not raise an exception under some
 */
      }

      /* "uvloop/handles/stream.pyx":485
 *                     return
 * 
 *                 if sent == 0:             # <<<<<<<<<<<<<<
 *                     # All data was successfully written.
 *                     self._buffer_size = 0
 */
      __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_v_sent, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 485, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(18, 485, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_4) {

        /* "uvloop/handles/stream.pyx":487
 *                 if sent == 0:
 *                     # All data was successfully written.
 *                     self._buffer_size = 0             # <<<<<<<<<<<<<<
 *                     self._buffer.clear()
 *                     # on_write will call "maybe_resume_protocol".
 */
        __pyx_v_self->_buffer_size = 0;

        /* "uvloop/handles/stream.pyx":488
 *                     # All data was successfully written.
 *                     self._buffer_size = 0
 *                     self._buffer.clear()             # <<<<<<<<<<<<<<
 *                     # on_write will call "maybe_resume_protocol".
 *                     self._on_write()
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_buffer, __pyx_n_s_clear); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 488, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (__pyx_t_6) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 488, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else {
          __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 488, __pyx_L1_error)
        }
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/handles/stream.pyx":490
 *                     self._buffer.clear()
 *                     # on_write will call "maybe_resume_protocol".
 *                     self._on_write()             # <<<<<<<<<<<<<<
 *                     return True
 * 
 */
        __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVStream__on_write(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 490, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/handles/stream.pyx":491
 *                     # on_write will call "maybe_resume_protocol".
 *                     self._on_write()
 *                     return True             # <<<<<<<<<<<<<<
 * 
 *                 if sent > 0:
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_True);
        __pyx_r = Py_True;
        goto __pyx_L0;

        /* "uvloop/handles/stream.pyx":485
 *                     return
 * 
 *                 if sent == 0:             # <<<<<<<<<<<<<<
 *                     # All data was successfully written.
 *                     self._buffer_size = 0
 */
      }

      /* "uvloop/handles/stream.pyx":493
 *                     return True
 * 
 *                 if sent > 0:             # <<<<<<<<<<<<<<
 *                     if UVLOOP_DEBUG:
 *                         if sent == len(data):
 */
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_sent, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 493, __pyx_L1_error)
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(18, 493, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_4) {

        /* "uvloop/handles/stream.pyx":494
 * 
 *                 if sent > 0:
 *                     if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                         if sent == len(data):
 *                             raise RuntimeError(
 */
        __pyx_t_4 = (UVLOOP_DEBUG != 0);
        if (__pyx_t_4) {

          /* "uvloop/handles/stream.pyx":495
 *                 if sent > 0:
 *                     if UVLOOP_DEBUG:
 *                         if sent == len(data):             # <<<<<<<<<<<<<<
 *                             raise RuntimeError(
 *                                 '_try_write sent all data and returned '
 */
          __pyx_t_3 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(18, 495, __pyx_L1_error)
          __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 495, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_5 = PyObject_RichCompare(__pyx_v_sent, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 495, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(18, 495, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(__pyx_t_4)) {

            /* "uvloop/handles/stream.pyx":496
 *                     if UVLOOP_DEBUG:
 *                         if sent == len(data):
 *                             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                                 '_try_write sent all data and returned '
 *                                 'non-zero')
 */
            __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__179, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 496, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_Raise(__pyx_t_5, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __PYX_ERR(18, 496, __pyx_L1_error)

            /* "uvloop/handles/stream.pyx":495
 *                 if sent > 0:
 *                     if UVLOOP_DEBUG:
 *                         if sent == len(data):             # <<<<<<<<<<<<<<
 *                             raise RuntimeError(
 *                                 '_try_write sent all data and returned '
 */
          }

          /* "uvloop/handles/stream.pyx":494
 * 
 *                 if sent > 0:
 *                     if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                         if sent == len(data):
 *                             raise RuntimeError(
 */
        }

        /* "uvloop/handles/stream.pyx":500
 *                                 'non-zero')
 * 
 *                     if PyBytes_CheckExact(data):             # <<<<<<<<<<<<<<
 *                         # Cast bytes to memoryview to avoid copying
 *                         # data that wasn't sent.
 */
        __pyx_t_4 = (PyBytes_CheckExact(__pyx_v_data) != 0);
        if (__pyx_t_4) {

          /* "uvloop/handles/stream.pyx":503
 *                         # Cast bytes to memoryview to avoid copying
 *                         # data that wasn't sent.
 *                         data = memoryview(data)             # <<<<<<<<<<<<<<
 *                     data = data[sent:]
 * 
 */
          __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 503, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 503, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "uvloop/handles/stream.pyx":500
 *                                 'non-zero')
 * 
 *                     if PyBytes_CheckExact(data):             # <<<<<<<<<<<<<<
 *                         # Cast bytes to memoryview to avoid copying
 *                         # data that wasn't sent.
 */
        }

        /* "uvloop/handles/stream.pyx":504
 *                         # data that wasn't sent.
 *                         data = memoryview(data)
 *                     data = data[sent:]             # <<<<<<<<<<<<<<
 * 
 *                     self._buffer_size -= sent
 */
        __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_data, 0, 0, &__pyx_v_sent, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 504, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "uvloop/handles/stream.pyx":506
 *                     data = data[sent:]
 * 
 *                     self._buffer_size -= sent             # <<<<<<<<<<<<<<
 *                     self._buffer[0] = data
 * 
 */
        __pyx_t_2 = __Pyx_PyInt_FromSize_t(__pyx_v_self->_buffer_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 506, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = PyNumber_InPlaceSubtract(__pyx_t_2, __pyx_v_sent); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 506, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_7 = __Pyx_PyInt_As_size_t(__pyx_t_5); if (unlikely((__pyx_t_7 == (size_t)-1) && PyErr_Occurred())) __PYX_ERR(18, 506, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_v_self->_buffer_size = __pyx_t_7;

        /* "uvloop/handles/stream.pyx":507
 * 
 *                     self._buffer_size -= sent
 *                     self._buffer[0] = data             # <<<<<<<<<<<<<<
 * 
 *                 # At this point it's either data was sent partially,
 */
        if (unlikely(__pyx_v_self->_buffer == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          __PYX_ERR(18, 507, __pyx_L1_error)
        }
        if (unlikely(__Pyx_SetItemInt(__pyx_v_self->_buffer, 0, __pyx_v_data, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(18, 507, __pyx_L1_error)

        /* "uvloop/handles/stream.pyx":493
 *                     return True
 * 
 *                 if sent > 0:             # <<<<<<<<<<<<<<
 *                     if UVLOOP_DEBUG:
 *                         if sent == len(data):
 */
      }

      /* "uvloop/handles/stream.pyx":466
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size == 0:
 *             # libuv internal write buffers for this stream are empty.
 *             if buf_len == 1:             # <<<<<<<<<<<<<<
 *                 # If we only have one piece of data to send, let's
 *                 # use our fast implementation of try_write.
 */
      goto __pyx_L6;
    }

    /* "uvloop/handles/stream.pyx":513
 * 
 *             else:
 *                 ctx = _StreamWriteContext.new(self, self._buffer)             # <<<<<<<<<<<<<<
 * 
 *                 err = uv.uv_try_write(<uv.uv_stream_t*>self._handle,
 */
    /*else*/ {
      __pyx_t_5 = __pyx_v_self->_buffer;
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_2 = ((PyObject *)__pyx_f_6uvloop_4loop_19_StreamWriteContext_new(__pyx_v_self, ((PyObject*)__pyx_t_5))); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF_SET(__pyx_v_ctx, ((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":515
 *                 ctx = _StreamWriteContext.new(self, self._buffer)
 * 
 *                 err = uv.uv_try_write(<uv.uv_stream_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                       ctx.uv_bufs_start,
 *                                       ctx.uv_bufs_len)
 */
      __pyx_v_err = uv_try_write(((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_v_ctx->uv_bufs_start, __pyx_v_ctx->uv_bufs_len);

      /* "uvloop/handles/stream.pyx":519
 *                                       ctx.uv_bufs_len)
 * 
 *                 if err > 0:             # <<<<<<<<<<<<<<
 *                     # Some data was successfully sent.
 * 
 */
      __pyx_t_4 = ((__pyx_v_err > 0) != 0);
      if (__pyx_t_4) {

        /* "uvloop/handles/stream.pyx":522
 *                     # Some data was successfully sent.
 * 
 *                     if <size_t>err == self._buffer_size:             # <<<<<<<<<<<<<<
 *                         # Everything was sent.
 *                         ctx.close()
 */
        __pyx_t_4 = ((((size_t)__pyx_v_err) == __pyx_v_self->_buffer_size) != 0);
        if (__pyx_t_4) {

          /* "uvloop/handles/stream.pyx":524
 *                     if <size_t>err == self._buffer_size:
 *                         # Everything was sent.
 *                         ctx.close()             # <<<<<<<<<<<<<<
 *                         self._buffer.clear()
 *                         self._buffer_size = 0
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_ctx->__pyx_vtab)->close(__pyx_v_ctx); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 524, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/handles/stream.pyx":525
 *                         # Everything was sent.
 *                         ctx.close()
 *                         self._buffer.clear()             # <<<<<<<<<<<<<<
 *                         self._buffer_size = 0
 *                         # on_write will call "maybe_resume_protocol".
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_buffer, __pyx_n_s_clear); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 525, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_6 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_6)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_6);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          if (__pyx_t_6) {
            __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 525, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else {
            __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 525, __pyx_L1_error)
          }
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/handles/stream.pyx":526
 *                         ctx.close()
 *                         self._buffer.clear()
 *                         self._buffer_size = 0             # <<<<<<<<<<<<<<
 *                         # on_write will call "maybe_resume_protocol".
 *                         self._on_write()
 */
          __pyx_v_self->_buffer_size = 0;

          /* "uvloop/handles/stream.pyx":528
 *                         self._buffer_size = 0
 *                         # on_write will call "maybe_resume_protocol".
 *                         self._on_write()             # <<<<<<<<<<<<<<
 *                         return True
 * 
 */
          __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVStream__on_write(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 528, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/handles/stream.pyx":529
 *                         # on_write will call "maybe_resume_protocol".
 *                         self._on_write()
 *                         return True             # <<<<<<<<<<<<<<
 * 
 *                     try:
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_INCREF(Py_True);
          __pyx_r = Py_True;
          goto __pyx_L0;

          /* "uvloop/handles/stream.pyx":522
 *                     # Some data was successfully sent.
 * 
 *                     if <size_t>err == self._buffer_size:             # <<<<<<<<<<<<<<
 *                         # Everything was sent.
 *                         ctx.close()
 */
        }

        /* "uvloop/handles/stream.pyx":531
 *                         return True
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         # Advance pointers to uv_bufs in `ctx`,
 *                         # we will reuse it soon for a uv_write
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);
          /*try:*/ {

            /* "uvloop/handles/stream.pyx":535
 *                         # we will reuse it soon for a uv_write
 *                         # call.
 *                         ctx.advance_uv_buf(<ssize_t>err)             # <<<<<<<<<<<<<<
 *                     except Exception as ex:  # This should never happen.
 *                         # Let's try to close the `ctx` anyways.
 */
            __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_ctx->__pyx_vtab)->advance_uv_buf(__pyx_v_ctx, ((Py_ssize_t)__pyx_v_err)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 535, __pyx_L16_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "uvloop/handles/stream.pyx":531
 *                         return True
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         # Advance pointers to uv_bufs in `ctx`,
 *                         # we will reuse it soon for a uv_write
 */
          }
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L21_try_end;
          __pyx_L16_error:;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/handles/stream.pyx":536
 *                         # call.
 *                         ctx.advance_uv_buf(<ssize_t>err)
 *                     except Exception as ex:  # This should never happen.             # <<<<<<<<<<<<<<
 *                         # Let's try to close the `ctx` anyways.
 *                         ctx.close()
 */
          __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
          if (__pyx_t_11) {
            __Pyx_AddTraceback("uvloop.loop.UVStream._exec_write", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(18, 536, __pyx_L18_except_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_5);
            __pyx_v_ex = __pyx_t_5;
            /*try:*/ {

              /* "uvloop/handles/stream.pyx":538
 *                     except Exception as ex:  # This should never happen.
 *                         # Let's try to close the `ctx` anyways.
 *                         ctx.close()             # <<<<<<<<<<<<<<
 *                         self._fatal_error(ex, True)
 *                         self._buffer.clear()
 */
              __pyx_t_12 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_ctx->__pyx_vtab)->close(__pyx_v_ctx); if (unlikely(!__pyx_t_12)) __PYX_ERR(18, 538, __pyx_L27_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "uvloop/handles/stream.pyx":539
 *                         # Let's try to close the `ctx` anyways.
 *                         ctx.close()
 *                         self._fatal_error(ex, True)             # <<<<<<<<<<<<<<
 *                         self._buffer.clear()
 *                         self._buffer_size = 0
 */
              __pyx_t_12 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_ex, Py_True, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(18, 539, __pyx_L27_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "uvloop/handles/stream.pyx":540
 *                         ctx.close()
 *                         self._fatal_error(ex, True)
 *                         self._buffer.clear()             # <<<<<<<<<<<<<<
 *                         self._buffer_size = 0
 *                         return
 */
              __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_buffer, __pyx_n_s_clear); if (unlikely(!__pyx_t_13)) __PYX_ERR(18, 540, __pyx_L27_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_14 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
                __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
                if (likely(__pyx_t_14)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                  __Pyx_INCREF(__pyx_t_14);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_13, function);
                }
              }
              if (__pyx_t_14) {
                __pyx_t_12 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_14); if (unlikely(!__pyx_t_12)) __PYX_ERR(18, 540, __pyx_L27_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              } else {
                __pyx_t_12 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(18, 540, __pyx_L27_error)
              }
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

              /* "uvloop/handles/stream.pyx":541
 *                         self._fatal_error(ex, True)
 *                         self._buffer.clear()
 *                         self._buffer_size = 0             # <<<<<<<<<<<<<<
 *                         return
 * 
 */
              __pyx_v_self->_buffer_size = 0;

              /* "uvloop/handles/stream.pyx":542
 *                         self._buffer.clear()
 *                         self._buffer_size = 0
 *                         return             # <<<<<<<<<<<<<<
 * 
 *                 elif err != uv.UV_EAGAIN:
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_r = Py_None; __Pyx_INCREF(Py_None);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
              goto __pyx_L26_return;
            }

            /* "uvloop/handles/stream.pyx":536
 *                         # call.
 *                         ctx.advance_uv_buf(<ssize_t>err)
 *                     except Exception as ex:  # This should never happen.             # <<<<<<<<<<<<<<
 *                         # Let's try to close the `ctx` anyways.
 *                         ctx.close()
 */
            /*finally:*/ {
              __pyx_L27_error:;
              /*exception exit:*/{
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
                if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_17);
                __Pyx_XGOTREF(__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_21);
                __Pyx_XGOTREF(__pyx_t_22);
                __pyx_t_11 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
                {
                  __Pyx_DECREF(__pyx_v_ex);
                  __pyx_v_ex = NULL;
                }
                if (PY_MAJOR_VERSION >= 3) {
                  __Pyx_XGIVEREF(__pyx_t_20);
                  __Pyx_XGIVEREF(__pyx_t_21);
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
                }
                __Pyx_XGIVEREF(__pyx_t_17);
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
                __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
                __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
                goto __pyx_L18_except_error;
              }
              __pyx_L26_return: {
                __pyx_t_22 = __pyx_r;
                __pyx_r = 0;
                __Pyx_DECREF(__pyx_v_ex);
                __pyx_v_ex = NULL;
                __pyx_r = __pyx_t_22;
                __pyx_t_22 = 0;
                goto __pyx_L19_except_return;
              }
            }
          }
          goto __pyx_L18_except_error;
          __pyx_L18_except_error:;

          /* "uvloop/handles/stream.pyx":531
 *                         return True
 * 
 *                     try:             # <<<<<<<<<<<<<<
 *                         # Advance pointers to uv_bufs in `ctx`,
 *                         # we will reuse it soon for a uv_write
 */
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          goto __pyx_L1_error;
          __pyx_L19_except_return:;
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          goto __pyx_L0;
          __pyx_L21_try_end:;
        }

        /* "uvloop/handles/stream.pyx":519
 *                                       ctx.uv_bufs_len)
 * 
 *                 if err > 0:             # <<<<<<<<<<<<<<
 *                     # Some data was successfully sent.
 * 
 */
        goto __pyx_L14;
      }

      /* "uvloop/handles/stream.pyx":544
 *                         return
 * 
 *                 elif err != uv.UV_EAGAIN:             # <<<<<<<<<<<<<<
 *                     ctx.close()
 *                     exc = convert_error(err)
 */
      __pyx_t_4 = ((__pyx_v_err != UV_EAGAIN) != 0);
      if (__pyx_t_4) {

        /* "uvloop/handles/stream.pyx":545
 * 
 *                 elif err != uv.UV_EAGAIN:
 *                     ctx.close()             # <<<<<<<<<<<<<<
 *                     exc = convert_error(err)
 *                     self._fatal_error(exc, True)
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_ctx->__pyx_vtab)->close(__pyx_v_ctx); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 545, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/handles/stream.pyx":546
 *                 elif err != uv.UV_EAGAIN:
 *                     ctx.close()
 *                     exc = convert_error(err)             # <<<<<<<<<<<<<<
 *                     self._fatal_error(exc, True)
 *                     self._buffer.clear()
 */
        __pyx_t_6 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 546, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_exc = __pyx_t_6;
        __pyx_t_6 = 0;

        /* "uvloop/handles/stream.pyx":547
 *                     ctx.close()
 *                     exc = convert_error(err)
 *                     self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *                     self._buffer.clear()
 *                     self._buffer_size = 0
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 547, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/handles/stream.pyx":548
 *                     exc = convert_error(err)
 *                     self._fatal_error(exc, True)
 *                     self._buffer.clear()             # <<<<<<<<<<<<<<
 *                     self._buffer_size = 0
 *                     return
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_buffer, __pyx_n_s_clear); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 548, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_2 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (__pyx_t_2) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 548, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        } else {
          __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 548, __pyx_L1_error)
        }
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "uvloop/handles/stream.pyx":549
 *                     self._fatal_error(exc, True)
 *                     self._buffer.clear()
 *                     self._buffer_size = 0             # <<<<<<<<<<<<<<
 *                     return
 * 
 */
        __pyx_v_self->_buffer_size = 0;

        /* "uvloop/handles/stream.pyx":550
 *                     self._buffer.clear()
 *                     self._buffer_size = 0
 *                     return             # <<<<<<<<<<<<<<
 * 
 *                 # fall through
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L0;

        /* "uvloop/handles/stream.pyx":544
 *                         return
 * 
 *                 elif err != uv.UV_EAGAIN:             # <<<<<<<<<<<<<<
 *                     ctx.close()
 *                     exc = convert_error(err)
 */
      }
      __pyx_L14:;
    }
    __pyx_L6:;

    /* "uvloop/handles/stream.pyx":464
 *             return
 * 
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size == 0:             # <<<<<<<<<<<<<<
 *             # libuv internal write buffers for this stream are empty.
 *             if buf_len == 1:
 */
  }

  /* "uvloop/handles/stream.pyx":554
 *                 # fall through
 * 
 *         if ctx is None:             # <<<<<<<<<<<<<<
 *             ctx = _StreamWriteContext.new(self, self._buffer)
 * 
 */
  __pyx_t_4 = (((PyObject *)__pyx_v_ctx) == Py_None);
  __pyx_t_1 = (__pyx_t_4 != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":555
 * 
 *         if ctx is None:
 *             ctx = _StreamWriteContext.new(self, self._buffer)             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_write(&ctx.req,
 */
    __pyx_t_6 = __pyx_v_self->_buffer;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_5 = ((PyObject *)__pyx_f_6uvloop_4loop_19_StreamWriteContext_new(__pyx_v_self, ((PyObject*)__pyx_t_6))); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_ctx, ((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)__pyx_t_5));
    __pyx_t_5 = 0;

    /* "uvloop/handles/stream.pyx":554
 *                 # fall through
 * 
 *         if ctx is None:             # <<<<<<<<<<<<<<
 *             ctx = _StreamWriteContext.new(self, self._buffer)
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":557
 *             ctx = _StreamWriteContext.new(self, self._buffer)
 * 
 *         err = uv.uv_write(&ctx.req,             # <<<<<<<<<<<<<<
 *                           <uv.uv_stream_t*>self._handle,
 *                           ctx.uv_bufs_start,
 */
  __pyx_v_err = uv_write((&__pyx_v_ctx->req), ((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_v_ctx->uv_bufs_start, __pyx_v_ctx->uv_bufs_len, __pyx_f_6uvloop_4loop___uv_stream_on_write);

  /* "uvloop/handles/stream.pyx":563
 *                           __uv_stream_on_write)
 * 
 *         self._buffer_size = 0             # <<<<<<<<<<<<<<
 *         # Can't use `_buffer.clear()` here: `ctx` holds a reference to
 *         # the `_buffer`.
 */
  __pyx_v_self->_buffer_size = 0;

  /* "uvloop/handles/stream.pyx":566
 *         # Can't use `_buffer.clear()` here: `ctx` holds a reference to
 *         # the `_buffer`.
 *         self._buffer = []             # <<<<<<<<<<<<<<
 * 
 *         if err < 0:
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->_buffer);
  __Pyx_DECREF(__pyx_v_self->_buffer);
  __pyx_v_self->_buffer = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "uvloop/handles/stream.pyx":568
 *         self._buffer = []
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             # close write context
 *             ctx.close()
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":570
 *         if err < 0:
 *             # close write context
 *             ctx.close()             # <<<<<<<<<<<<<<
 * 
 *             exc = convert_error(err)
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_ctx->__pyx_vtab)->close(__pyx_v_ctx); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 570, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/stream.pyx":572
 *             ctx.close()
 * 
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_5 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 572, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_exc = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "uvloop/handles/stream.pyx":573
 * 
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/stream.pyx":574
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._maybe_resume_protocol()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":568
 *         self._buffer = []
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             # close write context
 *             ctx.close()
 */
  }

  /* "uvloop/handles/stream.pyx":576
 *             return
 * 
 *         self._maybe_resume_protocol()             # <<<<<<<<<<<<<<
 * 
 *     cdef size_t _get_write_buffer_size(self):
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._maybe_resume_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/handles/stream.pyx":449
 *         self._loop._queue_write(self)
 * 
 *     cdef inline _exec_write(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int err
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("uvloop.loop.UVStream._exec_write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_ctx);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_sent);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":578
 *         self._maybe_resume_protocol()
 * 
 *     cdef size_t _get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         if self._handle is NULL:
 *             return 0
 */

static size_t __pyx_f_6uvloop_4loop_8UVStream__get_write_buffer_size(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_get_write_buffer_size", 0);

  /* "uvloop/handles/stream.pyx":579
 * 
 *     cdef size_t _get_write_buffer_size(self):
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             return 0
 *         return ((<uv.uv_stream_t*>self._handle).write_queue_size +
 */
  __pyx_t_1 = ((__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":580
 *     cdef size_t _get_write_buffer_size(self):
 *         if self._handle is NULL:
 *             return 0             # <<<<<<<<<<<<<<
 *         return ((<uv.uv_stream_t*>self._handle).write_queue_size +
 *                 self._buffer_size)
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":579
 * 
 *     cdef size_t _get_write_buffer_size(self):
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             return 0
 *         return ((<uv.uv_stream_t*>self._handle).write_queue_size +
 */
  }

  /* "uvloop/handles/stream.pyx":581
 *         if self._handle is NULL:
 *             return 0
 *         return ((<uv.uv_stream_t*>self._handle).write_queue_size +             # <<<<<<<<<<<<<<
 *                 self._buffer_size)
 * 
 */
  __pyx_r = (((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle)->write_queue_size + __pyx_v_self->_buffer_size);
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":578
 *         self._maybe_resume_protocol()
 * 
 *     cdef size_t _get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         if self._handle is NULL:
 *             return 0
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":584
 *                 self._buffer_size)
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._read_pybuf_acquired:
 */

static PyObject *__pyx_f_6uvloop_4loop_8UVStream__close(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "uvloop/handles/stream.pyx":585
 * 
 *     cdef _close(self):
 *         try:             # <<<<<<<<<<<<<<
 *             if self._read_pybuf_acquired:
 *                 # Should never happen. libuv always calls uv_alloc/uv_read
 */
  /*try:*/ {

    /* "uvloop/handles/stream.pyx":586
 *     cdef _close(self):
 *         try:
 *             if self._read_pybuf_acquired:             # <<<<<<<<<<<<<<
 *                 # Should never happen. libuv always calls uv_alloc/uv_read
 *                 # in pairs.
 */
    __pyx_t_1 = (__pyx_v_self->_read_pybuf_acquired != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":589
 *                 # Should never happen. libuv always calls uv_alloc/uv_read
 *                 # in pairs.
 *                 self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                     'transport': self,
 *                     'message': 'XXX: an allocated buffer in transport._close()'
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 589, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/handles/stream.pyx":590
 *                 # in pairs.
 *                 self._loop.call_exception_handler({
 *                     'transport': self,             # <<<<<<<<<<<<<<
 *                     'message': 'XXX: an allocated buffer in transport._close()'
 *                 })
 */
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 590, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_transport, ((PyObject *)__pyx_v_self)) < 0) __PYX_ERR(18, 590, __pyx_L4_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_message, __pyx_kp_u_XXX_an_allocated_buffer_in_trans) < 0) __PYX_ERR(18, 590, __pyx_L4_error)
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 589, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 589, __pyx_L4_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 589, __pyx_L4_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 589, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_GIVEREF(__pyx_t_4);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
          __pyx_t_4 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 589, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":593
 *                     'message': 'XXX: an allocated buffer in transport._close()'
 *                 })
 *                 self._read_pybuf_acquired = 0             # <<<<<<<<<<<<<<
 *                 PyBuffer_Release(&self._read_pybuf)
 * 
 */
      __pyx_v_self->_read_pybuf_acquired = 0;

      /* "uvloop/handles/stream.pyx":594
 *                 })
 *                 self._read_pybuf_acquired = 0
 *                 PyBuffer_Release(&self._read_pybuf)             # <<<<<<<<<<<<<<
 * 
 *             self._stop_reading()
 */
      PyBuffer_Release((&__pyx_v_self->_read_pybuf));

      /* "uvloop/handles/stream.pyx":586
 *     cdef _close(self):
 *         try:
 *             if self._read_pybuf_acquired:             # <<<<<<<<<<<<<<
 *                 # Should never happen. libuv always calls uv_alloc/uv_read
 *                 # in pairs.
 */
    }

    /* "uvloop/handles/stream.pyx":596
 *                 PyBuffer_Release(&self._read_pybuf)
 * 
 *             self._stop_reading()             # <<<<<<<<<<<<<<
 *         finally:
 *             UVSocketHandle._close(<UVHandle>self)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._stop_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 596, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "uvloop/handles/stream.pyx":598
 *             self._stop_reading()
 *         finally:
 *             UVSocketHandle._close(<UVHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _on_accept(self):
 */
  /*finally:*/ {
    /*normal exit:*/{
      if (!(likely(((((PyObject *)__pyx_v_self)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_self), __pyx_ptype_6uvloop_4loop_UVSocketHandle))))) __PYX_ERR(18, 598, __pyx_L1_error)
      __pyx_t_2 = __pyx_f_6uvloop_4loop_14UVSocketHandle__close(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self))); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 598, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_7 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
      {
        if (!(likely(((((PyObject *)__pyx_v_self)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_self), __pyx_ptype_6uvloop_4loop_UVSocketHandle))))) __PYX_ERR(18, 598, __pyx_L8_error)
        __pyx_t_2 = __pyx_f_6uvloop_4loop_14UVSocketHandle__close(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self))); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 598, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "uvloop/handles/stream.pyx":584
 *                 self._buffer_size)
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._read_pybuf_acquired:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVStream._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":600
 *             UVSocketHandle._close(<UVHandle>self)
 * 
 *     cdef inline _on_accept(self):             # <<<<<<<<<<<<<<
 *         # Ultimately called by __uv_stream_on_listen.
 *         self._init_protocol()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_accept(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_on_accept", 0);

  /* "uvloop/handles/stream.pyx":602
 *     cdef inline _on_accept(self):
 *         # Ultimately called by __uv_stream_on_listen.
 *         self._init_protocol()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _on_eof(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":600
 *             UVSocketHandle._close(<UVHandle>self)
 * 
 *     cdef inline _on_accept(self):             # <<<<<<<<<<<<<<
 *         # Ultimately called by __uv_stream_on_listen.
 *         self._init_protocol()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream._on_accept", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":604
 *         self._init_protocol()
 * 
 *     cdef inline _on_eof(self):             # <<<<<<<<<<<<<<
 *         # Any exception raised here will be caught in
 *         # __uv_stream_on_read.
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_eof(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_v_meth = NULL;
  PyObject *__pyx_v_keep_open = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("_on_eof", 0);

  /* "uvloop/handles/stream.pyx":608
 *         # __uv_stream_on_read.
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             meth = self._protocol.eof_received
 *         except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/handles/stream.pyx":609
 * 
 *         try:
 *             meth = self._protocol.eof_received             # <<<<<<<<<<<<<<
 *         except AttributeError:
 *             keep_open = False
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._protocol, __pyx_n_s_eof_received); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_meth = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "uvloop/handles/stream.pyx":608
 *         # __uv_stream_on_read.
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             meth = self._protocol.eof_received
 *         except AttributeError:
 */
    }

    /* "uvloop/handles/stream.pyx":613
 *             keep_open = False
 *         else:
 *             keep_open = meth()             # <<<<<<<<<<<<<<
 * 
 *         if keep_open:
 */
    /*else:*/ {
      __Pyx_INCREF(__pyx_v_meth);
      __pyx_t_5 = __pyx_v_meth; __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 613, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 613, __pyx_L5_except_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_keep_open = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/stream.pyx":610
 *         try:
 *             meth = self._protocol.eof_received
 *         except AttributeError:             # <<<<<<<<<<<<<<
 *             keep_open = False
 *         else:
 */
    __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_7) {
      __Pyx_AddTraceback("uvloop.loop.UVStream._on_eof", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(18, 610, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);

      /* "uvloop/handles/stream.pyx":611
 *             meth = self._protocol.eof_received
 *         except AttributeError:
 *             keep_open = False             # <<<<<<<<<<<<<<
 *         else:
 *             keep_open = meth()
 */
      __Pyx_INCREF(Py_False);
      __pyx_v_keep_open = Py_False;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/handles/stream.pyx":608
 *         # __uv_stream_on_read.
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             meth = self._protocol.eof_received
 *         except AttributeError:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "uvloop/handles/stream.pyx":615
 *             keep_open = meth()
 * 
 *         if keep_open:             # <<<<<<<<<<<<<<
 *             # We're keeping the connection open so the
 *             # protocol can write more, but we still can't
 */
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_keep_open); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(18, 615, __pyx_L1_error)
  if (__pyx_t_8) {

    /* "uvloop/handles/stream.pyx":619
 *             # protocol can write more, but we still can't
 *             # receive more, so remove the reader callback.
 *             self._stop_reading()             # <<<<<<<<<<<<<<
 *         else:
 *             self.close()
 */
    __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._stop_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 619, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/handles/stream.pyx":615
 *             keep_open = meth()
 * 
 *         if keep_open:             # <<<<<<<<<<<<<<
 *             # We're keeping the connection open so the
 *             # protocol can write more, but we still can't
 */
    goto __pyx_L11;
  }

  /* "uvloop/handles/stream.pyx":621
 *             self._stop_reading()
 *         else:
 *             self.close()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _on_write(self):
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_close); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 621, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 621, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L11:;

  /* "uvloop/handles/stream.pyx":604
 *         self._init_protocol()
 * 
 *     cdef inline _on_eof(self):             # <<<<<<<<<<<<<<
 *         # Any exception raised here will be caught in
 *         # __uv_stream_on_read.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVStream._on_eof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_meth);
  __Pyx_XDECREF(__pyx_v_keep_open);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":623
 *             self.close()
 * 
 *     cdef inline _on_write(self):             # <<<<<<<<<<<<<<
 *         self._maybe_resume_protocol()
 *         if not self._get_write_buffer_size():
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_on_write", 0);

  /* "uvloop/handles/stream.pyx":624
 * 
 *     cdef inline _on_write(self):
 *         self._maybe_resume_protocol()             # <<<<<<<<<<<<<<
 *         if not self._get_write_buffer_size():
 *             if self._closing:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._maybe_resume_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":625
 *     cdef inline _on_write(self):
 *         self._maybe_resume_protocol()
 *         if not self._get_write_buffer_size():             # <<<<<<<<<<<<<<
 *             if self._closing:
 *                 self._schedule_call_connection_lost(None)
 */
  __pyx_t_2 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._get_write_buffer_size(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":626
 *         self._maybe_resume_protocol()
 *         if not self._get_write_buffer_size():
 *             if self._closing:             # <<<<<<<<<<<<<<
 *                 self._schedule_call_connection_lost(None)
 *             elif self._eof:
 */
    __pyx_t_2 = (__pyx_v_self->__pyx_base._closing != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/stream.pyx":627
 *         if not self._get_write_buffer_size():
 *             if self._closing:
 *                 self._schedule_call_connection_lost(None)             # <<<<<<<<<<<<<<
 *             elif self._eof:
 *                 self._shutdown()
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._schedule_call_connection_lost(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/stream.pyx":626
 *         self._maybe_resume_protocol()
 *         if not self._get_write_buffer_size():
 *             if self._closing:             # <<<<<<<<<<<<<<
 *                 self._schedule_call_connection_lost(None)
 *             elif self._eof:
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/stream.pyx":628
 *             if self._closing:
 *                 self._schedule_call_connection_lost(None)
 *             elif self._eof:             # <<<<<<<<<<<<<<
 *                 self._shutdown()
 * 
 */
    __pyx_t_2 = (__pyx_v_self->_eof != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/stream.pyx":629
 *                 self._schedule_call_connection_lost(None)
 *             elif self._eof:
 *                 self._shutdown()             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _init(self, Loop loop, object protocol, Server server,
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop_8UVStream__shutdown(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 629, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/stream.pyx":628
 *             if self._closing:
 *                 self._schedule_call_connection_lost(None)
 *             elif self._eof:             # <<<<<<<<<<<<<<
 *                 self._shutdown()
 * 
 */
    }
    __pyx_L4:;

    /* "uvloop/handles/stream.pyx":625
 *     cdef inline _on_write(self):
 *         self._maybe_resume_protocol()
 *         if not self._get_write_buffer_size():             # <<<<<<<<<<<<<<
 *             if self._closing:
 *                 self._schedule_call_connection_lost(None)
 */
  }

  /* "uvloop/handles/stream.pyx":623
 *             self.close()
 * 
 *     cdef inline _on_write(self):             # <<<<<<<<<<<<<<
 *         self._maybe_resume_protocol()
 *         if not self._get_write_buffer_size():
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream._on_write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":631
 *                 self._shutdown()
 * 
 *     cdef inline _init(self, Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                       object waiter):
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__init(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/stream.pyx":634
 *                       object waiter):
 * 
 *         self._set_protocol(protocol)             # <<<<<<<<<<<<<<
 *         self._start_init(loop)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._set_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), __pyx_v_protocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":635
 * 
 *         self._set_protocol(protocol)
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 * 
 *         if server is not None:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":637
 *         self._start_init(loop)
 * 
 *         if server is not None:             # <<<<<<<<<<<<<<
 *             self._set_server(server)
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_server) != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/stream.pyx":638
 * 
 *         if server is not None:
 *             self._set_server(server)             # <<<<<<<<<<<<<<
 * 
 *         if waiter is not None:
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._set_server(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), __pyx_v_server); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":637
 *         self._start_init(loop)
 * 
 *         if server is not None:             # <<<<<<<<<<<<<<
 *             self._set_server(server)
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":640
 *             self._set_server(server)
 * 
 *         if waiter is not None:             # <<<<<<<<<<<<<<
 *             self._set_waiter(waiter)
 * 
 */
  __pyx_t_3 = (__pyx_v_waiter != Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":641
 * 
 *         if waiter is not None:
 *             self._set_waiter(waiter)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _on_connect(self, object exc):
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._set_waiter(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), __pyx_v_waiter); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":640
 *             self._set_server(server)
 * 
 *         if waiter is not None:             # <<<<<<<<<<<<<<
 *             self._set_waiter(waiter)
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":631
 *                 self._shutdown()
 * 
 *     cdef inline _init(self, Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                       object waiter):
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":643
 *             self._set_waiter(waiter)
 * 
 *     cdef inline _on_connect(self, object exc):             # <<<<<<<<<<<<<<
 *         # Called from __tcp_connect_callback (tcp.pyx) and
 *         # __pipe_connect_callback (pipe.pyx).
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_8UVStream__on_connect(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_on_connect", 0);

  /* "uvloop/handles/stream.pyx":646
 *         # Called from __tcp_connect_callback (tcp.pyx) and
 *         # __pipe_connect_callback (pipe.pyx).
 *         if exc is None:             # <<<<<<<<<<<<<<
 *             self._init_protocol()
 *         else:
 */
  __pyx_t_1 = (__pyx_v_exc == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":647
 *         # __pipe_connect_callback (pipe.pyx).
 *         if exc is None:
 *             self._init_protocol()             # <<<<<<<<<<<<<<
 *         else:
 *             if self._waiter is None:
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 647, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/stream.pyx":646
 *         # Called from __tcp_connect_callback (tcp.pyx) and
 *         # __pipe_connect_callback (pipe.pyx).
 *         if exc is None:             # <<<<<<<<<<<<<<
 *             self._init_protocol()
 *         else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/stream.pyx":649
 *             self._init_protocol()
 *         else:
 *             if self._waiter is None:             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, False, "connect failed")
 *             elif self._waiter.cancelled():
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->__pyx_base._waiter == Py_None);
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":650
 *         else:
 *             if self._waiter is None:
 *                 self._fatal_error(exc, False, "connect failed")             # <<<<<<<<<<<<<<
 *             elif self._waiter.cancelled():
 *                 # Connect call was cancelled; just close the transport
 */
      __pyx_t_4.__pyx_n = 1;
      __pyx_t_4.reason = __pyx_kp_u_connect_failed;
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_False, &__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 650, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/stream.pyx":649
 *             self._init_protocol()
 *         else:
 *             if self._waiter is None:             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, False, "connect failed")
 *             elif self._waiter.cancelled():
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/stream.pyx":651
 *             if self._waiter is None:
 *                 self._fatal_error(exc, False, "connect failed")
 *             elif self._waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 # Connect call was cancelled; just close the transport
 *                 # silently.
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._waiter, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 651, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 651, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 651, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(18, 651, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":654
 *                 # Connect call was cancelled; just close the transport
 *                 # silently.
 *                 self._close()             # <<<<<<<<<<<<<<
 *             elif self._waiter.done():
 *                 self._fatal_error(exc, False, "connect failed")
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/stream.pyx":651
 *             if self._waiter is None:
 *                 self._fatal_error(exc, False, "connect failed")
 *             elif self._waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 # Connect call was cancelled; just close the transport
 *                 # silently.
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/stream.pyx":655
 *                 # silently.
 *                 self._close()
 *             elif self._waiter.done():             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, False, "connect failed")
 *             else:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._waiter, __pyx_n_s_done); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 655, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 655, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(18, 655, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":656
 *                 self._close()
 *             elif self._waiter.done():
 *                 self._fatal_error(exc, False, "connect failed")             # <<<<<<<<<<<<<<
 *             else:
 *                 self._waiter.set_exception(exc)
 */
      __pyx_t_4.__pyx_n = 1;
      __pyx_t_4.reason = __pyx_kp_u_connect_failed;
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_False, &__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 656, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/stream.pyx":655
 *                 # silently.
 *                 self._close()
 *             elif self._waiter.done():             # <<<<<<<<<<<<<<
 *                 self._fatal_error(exc, False, "connect failed")
 *             else:
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/stream.pyx":658
 *                 self._fatal_error(exc, False, "connect failed")
 *             else:
 *                 self._waiter.set_exception(exc)             # <<<<<<<<<<<<<<
 *                 self._close()
 * 
 */
    /*else*/ {
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._waiter, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 658, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 658, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_exc};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 658, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_exc};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 658, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(18, 658, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_GIVEREF(__pyx_v_exc);
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_exc);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 658, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/stream.pyx":659
 *             else:
 *                 self._waiter.set_exception(exc)
 *                 self._close()             # <<<<<<<<<<<<<<
 * 
 *     # === Public API ===
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 659, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L4:;
  }
  __pyx_L3:;

  /* "uvloop/handles/stream.pyx":643
 *             self._set_waiter(waiter)
 * 
 *     cdef inline _on_connect(self, object exc):             # <<<<<<<<<<<<<<
 *         # Called from __tcp_connect_callback (tcp.pyx) and
 *         # __pipe_connect_callback (pipe.pyx).
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.UVStream._on_connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":663
 *     # === Public API ===
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<{} closed={} reading={} {:#x}>'.format(
 *             self.__class__.__name__,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_2__repr__(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_2__repr__(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/handles/stream.pyx":664
 * 
 *     def __repr__(self):
 *         return '<{} closed={} reading={} {:#x}>'.format(             # <<<<<<<<<<<<<<
 *             self.__class__.__name__,
 *             self._closed,
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_closed_reading_x, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/handles/stream.pyx":665
 *     def __repr__(self):
 *         return '<{} closed={} reading={} {:#x}>'.format(
 *             self.__class__.__name__,             # <<<<<<<<<<<<<<
 *             self._closed,
 *             self.__reading,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/stream.pyx":666
 *         return '<{} closed={} reading={} {:#x}>'.format(
 *             self.__class__.__name__,
 *             self._closed,             # <<<<<<<<<<<<<<
 *             self.__reading,
 *             id(self))
 */
  __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._closed); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/handles/stream.pyx":667
 *             self.__class__.__name__,
 *             self._closed,
 *             self.__reading,             # <<<<<<<<<<<<<<
 *             id(self))
 * 
 */
  __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_v_self->__pyx___reading); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/handles/stream.pyx":668
 *             self._closed,
 *             self.__reading,
 *             id(self))             # <<<<<<<<<<<<<<
 * 
 *     def write(self, object buf):
 */
  __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = NULL;
  __pyx_t_8 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_8 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_4, __pyx_t_3, __pyx_t_5, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 664, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[5] = {__pyx_t_7, __pyx_t_4, __pyx_t_3, __pyx_t_5, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_8, 4+__pyx_t_8); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 664, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(4+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(18, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_7) {
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_8, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 3+__pyx_t_8, __pyx_t_6);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_t_6 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":663
 *     # === Public API ===
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<{} closed={} reading={} {:#x}>'.format(
 *             self.__class__.__name__,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.UVStream.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":670
 *             id(self))
 * 
 *     def write(self, object buf):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_5write(PyObject *__pyx_v_self, PyObject *__pyx_v_buf); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_4write[] = "UVStream.write(self, buf)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_5write(PyObject *__pyx_v_self, PyObject *__pyx_v_buf) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_4write(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), ((PyObject *)__pyx_v_buf));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_4write(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_buf) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("write", 0);

  /* "uvloop/handles/stream.pyx":671
 * 
 *     def write(self, object buf):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if self._eof:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":673
 *         self._ensure_alive()
 * 
 *         if self._eof:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Cannot call write() after write_eof()')
 *         if not buf:
 */
  __pyx_t_2 = (__pyx_v_self->_eof != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/stream.pyx":674
 * 
 *         if self._eof:
 *             raise RuntimeError('Cannot call write() after write_eof()')             # <<<<<<<<<<<<<<
 *         if not buf:
 *             return
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__180, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(18, 674, __pyx_L1_error)

    /* "uvloop/handles/stream.pyx":673
 *         self._ensure_alive()
 * 
 *         if self._eof:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Cannot call write() after write_eof()')
 *         if not buf:
 */
  }

  /* "uvloop/handles/stream.pyx":675
 *         if self._eof:
 *             raise RuntimeError('Cannot call write() after write_eof()')
 *         if not buf:             # <<<<<<<<<<<<<<
 *             return
 *         if self._conn_lost:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_buf); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(18, 675, __pyx_L1_error)
  __pyx_t_3 = ((!__pyx_t_2) != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/stream.pyx":676
 *             raise RuntimeError('Cannot call write() after write_eof()')
 *         if not buf:
 *             return             # <<<<<<<<<<<<<<
 *         if self._conn_lost:
 *             self._conn_lost += 1
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":675
 *         if self._eof:
 *             raise RuntimeError('Cannot call write() after write_eof()')
 *         if not buf:             # <<<<<<<<<<<<<<
 *             return
 *         if self._conn_lost:
 */
  }

  /* "uvloop/handles/stream.pyx":677
 *         if not buf:
 *             return
 *         if self._conn_lost:             # <<<<<<<<<<<<<<
 *             self._conn_lost += 1
 *             return
 */
  __pyx_t_3 = (__pyx_v_self->__pyx_base._conn_lost != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/stream.pyx":678
 *             return
 *         if self._conn_lost:
 *             self._conn_lost += 1             # <<<<<<<<<<<<<<
 *             return
 *         self._write(buf)
 */
    __pyx_v_self->__pyx_base._conn_lost = (__pyx_v_self->__pyx_base._conn_lost + 1);

    /* "uvloop/handles/stream.pyx":679
 *         if self._conn_lost:
 *             self._conn_lost += 1
 *             return             # <<<<<<<<<<<<<<
 *         self._write(buf)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":677
 *         if not buf:
 *             return
 *         if self._conn_lost:             # <<<<<<<<<<<<<<
 *             self._conn_lost += 1
 *             return
 */
  }

  /* "uvloop/handles/stream.pyx":680
 *             self._conn_lost += 1
 *             return
 *         self._write(buf)             # <<<<<<<<<<<<<<
 * 
 *     def writelines(self, bufs):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_8UVStream__write(__pyx_v_self, __pyx_v_buf); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":670
 *             id(self))
 * 
 *     def write(self, object buf):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":682
 *         self._write(buf)
 * 
 *     def writelines(self, bufs):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_7writelines(PyObject *__pyx_v_self, PyObject *__pyx_v_bufs); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_6writelines[] = "UVStream.writelines(self, bufs)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_7writelines(PyObject *__pyx_v_self, PyObject *__pyx_v_bufs) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("writelines (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_6writelines(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), ((PyObject *)__pyx_v_bufs));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_6writelines(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, PyObject *__pyx_v_bufs) {
  PyObject *__pyx_v_buf = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("writelines", 0);

  /* "uvloop/handles/stream.pyx":683
 * 
 *     def writelines(self, bufs):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if self._eof:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":685
 *         self._ensure_alive()
 * 
 *         if self._eof:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Cannot call writelines() after write_eof()')
 *         if self._conn_lost:
 */
  __pyx_t_2 = (__pyx_v_self->_eof != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/stream.pyx":686
 * 
 *         if self._eof:
 *             raise RuntimeError('Cannot call writelines() after write_eof()')             # <<<<<<<<<<<<<<
 *         if self._conn_lost:
 *             self._conn_lost += 1
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__181, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(18, 686, __pyx_L1_error)

    /* "uvloop/handles/stream.pyx":685
 *         self._ensure_alive()
 * 
 *         if self._eof:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('Cannot call writelines() after write_eof()')
 *         if self._conn_lost:
 */
  }

  /* "uvloop/handles/stream.pyx":687
 *         if self._eof:
 *             raise RuntimeError('Cannot call writelines() after write_eof()')
 *         if self._conn_lost:             # <<<<<<<<<<<<<<
 *             self._conn_lost += 1
 *             return
 */
  __pyx_t_2 = (__pyx_v_self->__pyx_base._conn_lost != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":688
 *             raise RuntimeError('Cannot call writelines() after write_eof()')
 *         if self._conn_lost:
 *             self._conn_lost += 1             # <<<<<<<<<<<<<<
 *             return
 *         for buf in bufs:
 */
    __pyx_v_self->__pyx_base._conn_lost = (__pyx_v_self->__pyx_base._conn_lost + 1);

    /* "uvloop/handles/stream.pyx":689
 *         if self._conn_lost:
 *             self._conn_lost += 1
 *             return             # <<<<<<<<<<<<<<
 *         for buf in bufs:
 *             self._write(buf)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":687
 *         if self._eof:
 *             raise RuntimeError('Cannot call writelines() after write_eof()')
 *         if self._conn_lost:             # <<<<<<<<<<<<<<
 *             self._conn_lost += 1
 *             return
 */
  }

  /* "uvloop/handles/stream.pyx":690
 *             self._conn_lost += 1
 *             return
 *         for buf in bufs:             # <<<<<<<<<<<<<<
 *             self._write(buf)
 * 
 */
  if (likely(PyList_CheckExact(__pyx_v_bufs)) || PyTuple_CheckExact(__pyx_v_bufs)) {
    __pyx_t_1 = __pyx_v_bufs; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_bufs); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 690, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 690, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(18, 690, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 690, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(18, 690, __pyx_L1_error)
        #else
        __pyx_t_5 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 690, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(18, 690, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_buf, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "uvloop/handles/stream.pyx":691
 *             return
 *         for buf in bufs:
 *             self._write(buf)             # <<<<<<<<<<<<<<
 * 
 *     def write_eof(self):
 */
    __pyx_t_5 = __pyx_f_6uvloop_4loop_8UVStream__write(__pyx_v_self, __pyx_v_buf); if (unlikely(!__pyx_t_5)) __PYX_ERR(18, 691, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/stream.pyx":690
 *             self._conn_lost += 1
 *             return
 *         for buf in bufs:             # <<<<<<<<<<<<<<
 *             self._write(buf)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":682
 *         self._write(buf)
 * 
 *     def writelines(self, bufs):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVStream.writelines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_buf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":693
 *             self._write(buf)
 * 
 *     def write_eof(self):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_9write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_8write_eof[] = "UVStream.write_eof(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_9write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write_eof (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_8write_eof(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_8write_eof(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("write_eof", 0);

  /* "uvloop/handles/stream.pyx":694
 * 
 *     def write_eof(self):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if self._eof:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":696
 *         self._ensure_alive()
 * 
 *         if self._eof:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = (__pyx_v_self->_eof != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":697
 * 
 *         if self._eof:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._eof = 1
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":696
 *         self._ensure_alive()
 * 
 *         if self._eof:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":699
 *             return
 * 
 *         self._eof = 1             # <<<<<<<<<<<<<<
 *         if not self._get_write_buffer_size():
 *             self._shutdown()
 */
  __pyx_v_self->_eof = 1;

  /* "uvloop/handles/stream.pyx":700
 * 
 *         self._eof = 1
 *         if not self._get_write_buffer_size():             # <<<<<<<<<<<<<<
 *             self._shutdown()
 * 
 */
  __pyx_t_2 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._get_write_buffer_size(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)) != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":701
 *         self._eof = 1
 *         if not self._get_write_buffer_size():
 *             self._shutdown()             # <<<<<<<<<<<<<<
 * 
 *     def can_write_eof(self):
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_8UVStream__shutdown(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":700
 * 
 *         self._eof = 1
 *         if not self._get_write_buffer_size():             # <<<<<<<<<<<<<<
 *             self._shutdown()
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":693
 *             self._write(buf)
 * 
 *     def write_eof(self):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream.write_eof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":703
 *             self._shutdown()
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         return True
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_11can_write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_10can_write_eof[] = "UVStream.can_write_eof(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_11can_write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("can_write_eof (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_10can_write_eof(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_10can_write_eof(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("can_write_eof", 0);

  /* "uvloop/handles/stream.pyx":704
 * 
 *     def can_write_eof(self):
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def is_reading(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":703
 *             self._shutdown()
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         return True
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":706
 *         return True
 * 
 *     def is_reading(self):             # <<<<<<<<<<<<<<
 *         return self._is_reading()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_13is_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_12is_reading[] = "UVStream.is_reading(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_13is_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_12is_reading(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_12is_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("is_reading", 0);

  /* "uvloop/handles/stream.pyx":707
 * 
 *     def is_reading(self):
 *         return self._is_reading()             # <<<<<<<<<<<<<<
 * 
 *     def pause_reading(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._is_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self))); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":706
 *         return True
 * 
 *     def is_reading(self):             # <<<<<<<<<<<<<<
 *         return self._is_reading()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream.is_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":709
 *         return self._is_reading()
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         if self._closing or not self._is_reading():
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_15pause_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_14pause_reading[] = "UVStream.pause_reading(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_15pause_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pause_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_14pause_reading(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_14pause_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("pause_reading", 0);

  /* "uvloop/handles/stream.pyx":710
 * 
 *     def pause_reading(self):
 *         if self._closing or not self._is_reading():             # <<<<<<<<<<<<<<
 *             return
 *         self._stop_reading()
 */
  __pyx_t_2 = (__pyx_v_self->__pyx_base._closing != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._is_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":711
 *     def pause_reading(self):
 *         if self._closing or not self._is_reading():
 *             return             # <<<<<<<<<<<<<<
 *         self._stop_reading()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":710
 * 
 *     def pause_reading(self):
 *         if self._closing or not self._is_reading():             # <<<<<<<<<<<<<<
 *             return
 *         self._stop_reading()
 */
  }

  /* "uvloop/handles/stream.pyx":712
 *         if self._closing or not self._is_reading():
 *             return
 *         self._stop_reading()             # <<<<<<<<<<<<<<
 * 
 *     def resume_reading(self):
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._stop_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 712, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/stream.pyx":709
 *         return self._is_reading()
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         if self._closing or not self._is_reading():
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVStream.pause_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":714
 *         self._stop_reading()
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         if self._is_reading() or self._closing:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_17resume_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_16resume_reading[] = "UVStream.resume_reading(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_17resume_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resume_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_16resume_reading(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_16resume_reading(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("resume_reading", 0);

  /* "uvloop/handles/stream.pyx":715
 * 
 *     def resume_reading(self):
 *         if self._is_reading() or self._closing:             # <<<<<<<<<<<<<<
 *             return
 *         self._start_reading()
 */
  __pyx_t_2 = (((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._is_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->__pyx_base._closing != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":716
 *     def resume_reading(self):
 *         if self._is_reading() or self._closing:
 *             return             # <<<<<<<<<<<<<<
 *         self._start_reading()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":715
 * 
 *     def resume_reading(self):
 *         if self._is_reading() or self._closing:             # <<<<<<<<<<<<<<
 *             return
 *         self._start_reading()
 */
  }

  /* "uvloop/handles/stream.pyx":717
 *         if self._is_reading() or self._closing:
 *             return
 *         self._start_reading()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._start_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/stream.pyx":714
 *         self._stop_reading()
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         if self._is_reading() or self._closing:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVStream.resume_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_19__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_18__reduce_cython__[] = "UVStream.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_19__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_18__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_18__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__182, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_21__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_8UVStream_20__setstate_cython__[] = "UVStream.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_8UVStream_21__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8UVStream_20__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8UVStream_20__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__183, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStream.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":720
 * 
 * 
 * cdef void __uv_stream_on_shutdown(uv.uv_shutdown_t* req,             # <<<<<<<<<<<<<<
 *                                   int status) with gil:
 * 
 */

static void __pyx_f_6uvloop_4loop___uv_stream_on_shutdown(uv_shutdown_t *__pyx_v_req, int __pyx_v_status) {
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_stream = 0;
  PyObject *__pyx_v_exc = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_9 = NULL;
  struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error __pyx_t_10;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_stream_on_shutdown", 0);

  /* "uvloop/handles/stream.pyx":725
 *     # callback for uv_shutdown
 * 
 *     if req.data is NULL:             # <<<<<<<<<<<<<<
 *         aio_logger.error(
 *             'UVStream.shutdown callback called with NULL req.data, status=%r',
 */
  __pyx_t_1 = ((__pyx_v_req->data == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":726
 * 
 *     if req.data is NULL:
 *         aio_logger.error(             # <<<<<<<<<<<<<<
 *             'UVStream.shutdown callback called with NULL req.data, status=%r',
 *             status)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 726, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/handles/stream.pyx":728
 *         aio_logger.error(
 *             'UVStream.shutdown callback called with NULL req.data, status=%r',
 *             status)             # <<<<<<<<<<<<<<
 *         return
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_status); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 728, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_kp_u_UVStream_shutdown_callback_calle, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 726, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_kp_u_UVStream_shutdown_callback_calle, __pyx_t_4};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 726, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(18, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_u_UVStream_shutdown_callback_calle);
      __Pyx_GIVEREF(__pyx_kp_u_UVStream_shutdown_callback_calle);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_kp_u_UVStream_shutdown_callback_calle);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":729
 *             'UVStream.shutdown callback called with NULL req.data, status=%r',
 *             status)
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef UVStream stream = <UVStream> req.data
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":725
 *     # callback for uv_shutdown
 * 
 *     if req.data is NULL:             # <<<<<<<<<<<<<<
 *         aio_logger.error(
 *             'UVStream.shutdown callback called with NULL req.data, status=%r',
 */
  }

  /* "uvloop/handles/stream.pyx":731
 *         return
 * 
 *     cdef UVStream stream = <UVStream> req.data             # <<<<<<<<<<<<<<
 * 
 *     if status < 0 and status != uv.UV_ECANCELED:
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_req->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_stream = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":733
 *     cdef UVStream stream = <UVStream> req.data
 * 
 *     if status < 0 and status != uv.UV_ECANCELED:             # <<<<<<<<<<<<<<
 *         # From libuv source code:
 *         #     The ECANCELED error code is a lie, the shutdown(2) syscall is a
 */
  __pyx_t_8 = ((__pyx_v_status < 0) != 0);
  if (__pyx_t_8) {
  } else {
    __pyx_t_1 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_8 = ((__pyx_v_status != UV_ECANCELED) != 0);
  __pyx_t_1 = __pyx_t_8;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":740
 *         #     informs the callee that the handle has been destroyed.
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_shutdown_errors_total += 1
 * 
 */
    __pyx_t_1 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":741
 * 
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_shutdown_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *         exc = convert_error(status)
 */
      __Pyx_INCREF(((PyObject *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop));
      __pyx_t_9 = __pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop;
      __pyx_t_9->_debug_stream_shutdown_errors_total = (__pyx_t_9->_debug_stream_shutdown_errors_total + 1);
      __Pyx_DECREF(((PyObject *)__pyx_t_9)); __pyx_t_9 = 0;

      /* "uvloop/handles/stream.pyx":740
 *         #     informs the callee that the handle has been destroyed.
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_shutdown_errors_total += 1
 * 
 */
    }

    /* "uvloop/handles/stream.pyx":743
 *             stream._loop._debug_stream_shutdown_errors_total += 1
 * 
 *         exc = convert_error(status)             # <<<<<<<<<<<<<<
 *         stream._fatal_error(exc, False,
 *             "error status in uv_stream_t.shutdown callback")
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":744
 * 
 *         exc = convert_error(status)
 *         stream._fatal_error(exc, False,             # <<<<<<<<<<<<<<
 *             "error status in uv_stream_t.shutdown callback")
 *         return
 */
    __pyx_t_10.__pyx_n = 1;
    __pyx_t_10.reason = __pyx_kp_u_error_status_in_uv_stream_t_shut;
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_stream), __pyx_v_exc, Py_False, &__pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":746
 *         stream._fatal_error(exc, False,
 *             "error status in uv_stream_t.shutdown callback")
 *         return             # <<<<<<<<<<<<<<
 * 
 * 
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":733
 *     cdef UVStream stream = <UVStream> req.data
 * 
 *     if status < 0 and status != uv.UV_ECANCELED:             # <<<<<<<<<<<<<<
 *         # From libuv source code:
 *         #     The ECANCELED error code is a lie, the shutdown(2) syscall is a
 */
  }

  /* "uvloop/handles/stream.pyx":720
 * 
 * 
 * cdef void __uv_stream_on_shutdown(uv.uv_shutdown_t* req,             # <<<<<<<<<<<<<<
 *                                   int status) with gil:
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(((PyObject *)__pyx_t_9));
  __Pyx_WriteUnraisable("uvloop.loop.__uv_stream_on_shutdown", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_stream);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/stream.pyx":749
 * 
 * 
 * cdef inline bint __uv_stream_on_read_common(UVStream sc, Loop loop,             # <<<<<<<<<<<<<<
 *                                             ssize_t nread):
 *     if sc._closed:
 */

static CYTHON_INLINE int __pyx_f_6uvloop_4loop___uv_stream_on_read_common(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_sc, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, Py_ssize_t __pyx_v_nread) {
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_exc = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error __pyx_t_18;
  __Pyx_RefNannySetupContext("__uv_stream_on_read_common", 0);

  /* "uvloop/handles/stream.pyx":751
 * cdef inline bint __uv_stream_on_read_common(UVStream sc, Loop loop,
 *                                             ssize_t nread):
 *     if sc._closed:             # <<<<<<<<<<<<<<
 *         # The stream was closed, there is no reason to
 *         # do any work now.
 */
  __pyx_t_1 = (__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base._closed != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":754
 *         # The stream was closed, there is no reason to
 *         # do any work now.
 *         sc.__reading_stopped()  # Just in case.             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVStream___reading_stopped(__pyx_v_sc); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":755
 *         # do any work now.
 *         sc.__reading_stopped()  # Just in case.
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     if nread == uv.UV_EOF:
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":751
 * cdef inline bint __uv_stream_on_read_common(UVStream sc, Loop loop,
 *                                             ssize_t nread):
 *     if sc._closed:             # <<<<<<<<<<<<<<
 *         # The stream was closed, there is no reason to
 *         # do any work now.
 */
  }

  /* "uvloop/handles/stream.pyx":757
 *         return True
 * 
 *     if nread == uv.UV_EOF:             # <<<<<<<<<<<<<<
 *         # From libuv docs:
 *         #     The callee is responsible for stopping closing the stream
 */
  __pyx_t_1 = ((__pyx_v_nread == UV_EOF) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":762
 *         #     when an error happens by calling uv_read_stop() or uv_close().
 *         #     Trying to read from the stream again is undefined.
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 loop._debug_stream_read_eof_total += 1
 */
    /*try:*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_5);
        /*try:*/ {

          /* "uvloop/handles/stream.pyx":763
 *         #     Trying to read from the stream again is undefined.
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 loop._debug_stream_read_eof_total += 1
 * 
 */
          __pyx_t_1 = (UVLOOP_DEBUG != 0);
          if (__pyx_t_1) {

            /* "uvloop/handles/stream.pyx":764
 *         try:
 *             if UVLOOP_DEBUG:
 *                 loop._debug_stream_read_eof_total += 1             # <<<<<<<<<<<<<<
 * 
 *             sc._stop_reading()
 */
            __pyx_v_loop->_debug_stream_read_eof_total = (__pyx_v_loop->_debug_stream_read_eof_total + 1);

            /* "uvloop/handles/stream.pyx":763
 *         #     Trying to read from the stream again is undefined.
 *         try:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 loop._debug_stream_read_eof_total += 1
 * 
 */
          }

          /* "uvloop/handles/stream.pyx":766
 *                 loop._debug_stream_read_eof_total += 1
 * 
 *             sc._stop_reading()             # <<<<<<<<<<<<<<
 *             sc._on_eof()
 *         except BaseException as ex:
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._stop_reading(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_sc)); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 766, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/handles/stream.pyx":767
 * 
 *             sc._stop_reading()
 *             sc._on_eof()             # <<<<<<<<<<<<<<
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:
 */
          __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVStream__on_eof(__pyx_v_sc); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 767, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/handles/stream.pyx":762
 *         #     when an error happens by calling uv_read_stop() or uv_close().
 *         #     Trying to read from the stream again is undefined.
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 loop._debug_stream_read_eof_total += 1
 */
        }
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L13_try_end;
        __pyx_L8_error:;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/handles/stream.pyx":768
 *             sc._stop_reading()
 *             sc._on_eof()
 *         except BaseException as ex:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 loop._debug_stream_read_eof_cb_errors_total += 1
 */
        __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
        if (__pyx_t_6) {
          __Pyx_AddTraceback("uvloop.loop.__uv_stream_on_read_common", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(18, 768, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_7);
          __pyx_v_ex = __pyx_t_7;
          /*try:*/ {

            /* "uvloop/handles/stream.pyx":769
 *             sc._on_eof()
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 loop._debug_stream_read_eof_cb_errors_total += 1
 * 
 */
            __pyx_t_1 = (UVLOOP_DEBUG != 0);
            if (__pyx_t_1) {

              /* "uvloop/handles/stream.pyx":770
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:
 *                 loop._debug_stream_read_eof_cb_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *             sc._fatal_error(ex, False)
 */
              __pyx_v_loop->_debug_stream_read_eof_cb_errors_total = (__pyx_v_loop->_debug_stream_read_eof_cb_errors_total + 1);

              /* "uvloop/handles/stream.pyx":769
 *             sc._on_eof()
 *         except BaseException as ex:
 *             if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *                 loop._debug_stream_read_eof_cb_errors_total += 1
 * 
 */
            }

            /* "uvloop/handles/stream.pyx":772
 *                 loop._debug_stream_read_eof_cb_errors_total += 1
 * 
 *             sc._fatal_error(ex, False)             # <<<<<<<<<<<<<<
 *         finally:
 *             return True
 */
            __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_sc), __pyx_v_ex, Py_False, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(18, 772, __pyx_L20_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }

          /* "uvloop/handles/stream.pyx":768
 *             sc._stop_reading()
 *             sc._on_eof()
 *         except BaseException as ex:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 loop._debug_stream_read_eof_cb_errors_total += 1
 */
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
              goto __pyx_L21;
            }
            __pyx_L20_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
              __Pyx_XGOTREF(__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_XGOTREF(__pyx_t_14);
              __Pyx_XGOTREF(__pyx_t_15);
              __Pyx_XGOTREF(__pyx_t_16);
              __Pyx_XGOTREF(__pyx_t_17);
              __pyx_t_6 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_ex);
                __pyx_v_ex = NULL;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_15);
                __Pyx_XGIVEREF(__pyx_t_16);
                __Pyx_XGIVEREF(__pyx_t_17);
                __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
              }
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_13);
              __Pyx_XGIVEREF(__pyx_t_14);
              __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
              __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
              __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
              goto __pyx_L10_except_error;
            }
            __pyx_L21:;
          }
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L9_exception_handled;
        }
        goto __pyx_L10_except_error;
        __pyx_L10_except_error:;

        /* "uvloop/handles/stream.pyx":762
 *         #     when an error happens by calling uv_read_stop() or uv_close().
 *         #     Trying to read from the stream again is undefined.
 *         try:             # <<<<<<<<<<<<<<
 *             if UVLOOP_DEBUG:
 *                 loop._debug_stream_read_eof_total += 1
 */
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
        goto __pyx_L6_error;
        __pyx_L9_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
        __pyx_L13_try_end:;
      }
    }

    /* "uvloop/handles/stream.pyx":774
 *             sc._fatal_error(ex, False)
 *         finally:
 *             return True             # <<<<<<<<<<<<<<
 * 
 *     if nread == 0:
 */
    /*finally:*/ {
      /*normal exit:*/{
        __pyx_r = 1;
        goto __pyx_L0;
      }
      __pyx_L6_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
        if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3) < 0)) __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_15);
        {
          __pyx_r = 1;
          goto __pyx_L27_return;
        }
        __pyx_L27_return:;
        if (PY_MAJOR_VERSION >= 3) {
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
        }
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
        goto __pyx_L0;
      }
    }

    /* "uvloop/handles/stream.pyx":757
 *         return True
 * 
 *     if nread == uv.UV_EOF:             # <<<<<<<<<<<<<<
 *         # From libuv docs:
 *         #     The callee is responsible for stopping closing the stream
 */
  }

  /* "uvloop/handles/stream.pyx":776
 *             return True
 * 
 *     if nread == 0:             # <<<<<<<<<<<<<<
 *         # From libuv docs:
 *         #     nread might be 0, which does not indicate an error or EOF.
 */
  __pyx_t_1 = ((__pyx_v_nread == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":780
 *         #     nread might be 0, which does not indicate an error or EOF.
 *         #     This is equivalent to EAGAIN or EWOULDBLOCK under read(2).
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     if nread < 0:
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":776
 *             return True
 * 
 *     if nread == 0:             # <<<<<<<<<<<<<<
 *         # From libuv docs:
 *         #     nread might be 0, which does not indicate an error or EOF.
 */
  }

  /* "uvloop/handles/stream.pyx":782
 *         return True
 * 
 *     if nread < 0:             # <<<<<<<<<<<<<<
 *         # From libuv docs:
 *         #     The callee is responsible for stopping closing the stream
 */
  __pyx_t_1 = ((__pyx_v_nread < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":792
 *         # we don't need try...finally here.
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_errors_total += 1
 * 
 */
    __pyx_t_1 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":793
 * 
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *         if sc.__read_error_close:
 */
      __pyx_v_loop->_debug_stream_read_errors_total = (__pyx_v_loop->_debug_stream_read_errors_total + 1);

      /* "uvloop/handles/stream.pyx":792
 *         # we don't need try...finally here.
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_errors_total += 1
 * 
 */
    }

    /* "uvloop/handles/stream.pyx":795
 *             loop._debug_stream_read_errors_total += 1
 * 
 *         if sc.__read_error_close:             # <<<<<<<<<<<<<<
 *             # Used for getting notified when a pipe is closed.
 *             # See WriteUnixTransport for the explanation.
 */
    __pyx_t_1 = (__pyx_v_sc->__pyx___read_error_close != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":798
 *             # Used for getting notified when a pipe is closed.
 *             # See WriteUnixTransport for the explanation.
 *             sc._on_eof()             # <<<<<<<<<<<<<<
 *             return True
 * 
 */
      __pyx_t_8 = __pyx_f_6uvloop_4loop_8UVStream__on_eof(__pyx_v_sc); if (unlikely(!__pyx_t_8)) __PYX_ERR(18, 798, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/handles/stream.pyx":799
 *             # See WriteUnixTransport for the explanation.
 *             sc._on_eof()
 *             return True             # <<<<<<<<<<<<<<
 * 
 *         exc = convert_error(nread)
 */
      __pyx_r = 1;
      goto __pyx_L0;

      /* "uvloop/handles/stream.pyx":795
 *             loop._debug_stream_read_errors_total += 1
 * 
 *         if sc.__read_error_close:             # <<<<<<<<<<<<<<
 *             # Used for getting notified when a pipe is closed.
 *             # See WriteUnixTransport for the explanation.
 */
    }

    /* "uvloop/handles/stream.pyx":801
 *             return True
 * 
 *         exc = convert_error(nread)             # <<<<<<<<<<<<<<
 *         sc._fatal_error(exc, False,
 *             "error status in uv_stream_t.read callback")
 */
    __pyx_t_8 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_nread); if (unlikely(!__pyx_t_8)) __PYX_ERR(18, 801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_v_exc = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "uvloop/handles/stream.pyx":802
 * 
 *         exc = convert_error(nread)
 *         sc._fatal_error(exc, False,             # <<<<<<<<<<<<<<
 *             "error status in uv_stream_t.read callback")
 *         return True
 */
    __pyx_t_18.__pyx_n = 1;
    __pyx_t_18.reason = __pyx_kp_u_error_status_in_uv_stream_t_read;
    __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_sc), __pyx_v_exc, Py_False, &__pyx_t_18); if (unlikely(!__pyx_t_8)) __PYX_ERR(18, 802, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "uvloop/handles/stream.pyx":804
 *         sc._fatal_error(exc, False,
 *             "error status in uv_stream_t.read callback")
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     return False
 */
    __pyx_r = 1;
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":782
 *         return True
 * 
 *     if nread < 0:             # <<<<<<<<<<<<<<
 *         # From libuv docs:
 *         #     The callee is responsible for stopping closing the stream
 */
  }

  /* "uvloop/handles/stream.pyx":806
 *         return True
 * 
 *     return False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "uvloop/handles/stream.pyx":749
 * 
 * 
 * cdef inline bint __uv_stream_on_read_common(UVStream sc, Loop loop,             # <<<<<<<<<<<<<<
 *                                             ssize_t nread):
 *     if sc._closed:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_stream_on_read_common", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/stream.pyx":809
 * 
 * 
 * cdef inline void __uv_stream_on_read_impl(uv.uv_stream_t* stream,             # <<<<<<<<<<<<<<
 *                                           ssize_t nread,
 *                                           const uv.uv_buf_t* buf):
 */

static CYTHON_INLINE void __pyx_f_6uvloop_4loop___uv_stream_on_read_impl(uv_stream_t *__pyx_v_stream, Py_ssize_t __pyx_v_nread, CYTHON_UNUSED uv_buf_t const *__pyx_v_buf) {
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_sc = 0;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  PyObject *__pyx_v_exc = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  char const *__pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  __Pyx_RefNannySetupContext("__uv_stream_on_read_impl", 0);

  /* "uvloop/handles/stream.pyx":813
 *                                           const uv.uv_buf_t* buf):
 *     cdef:
 *         UVStream sc = <UVStream>stream.data             # <<<<<<<<<<<<<<
 *         Loop loop = sc._loop
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_stream->data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_sc = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":814
 *     cdef:
 *         UVStream sc = <UVStream>stream.data
 *         Loop loop = sc._loop             # <<<<<<<<<<<<<<
 * 
 *     # It's OK to free the buffer early, since nothing will
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":818
 *     # It's OK to free the buffer early, since nothing will
 *     # be able to touch it until this method is done.
 *     __loop_free_buffer(loop)             # <<<<<<<<<<<<<<
 * 
 *     if __uv_stream_on_read_common(sc, loop, nread):
 */
  __pyx_f_6uvloop_4loop___loop_free_buffer(__pyx_v_loop);

  /* "uvloop/handles/stream.pyx":820
 *     __loop_free_buffer(loop)
 * 
 *     if __uv_stream_on_read_common(sc, loop, nread):             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_2 = (__pyx_f_6uvloop_4loop___uv_stream_on_read_common(__pyx_v_sc, __pyx_v_loop, __pyx_v_nread) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":821
 * 
 *     if __uv_stream_on_read_common(sc, loop, nread):
 *         return             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":820
 *     __loop_free_buffer(loop)
 * 
 *     if __uv_stream_on_read_common(sc, loop, nread):             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/handles/stream.pyx":823
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_total += 1
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "uvloop/handles/stream.pyx":824
 * 
 *     try:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_total += 1
 * 
 */
      __pyx_t_2 = (UVLOOP_DEBUG != 0);
      if (__pyx_t_2) {

        /* "uvloop/handles/stream.pyx":825
 *     try:
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_total += 1             # <<<<<<<<<<<<<<
 * 
 *         sc._protocol_data_received(loop._recv_buffer[:nread])
 */
        __pyx_v_loop->_debug_stream_read_cb_total = (__pyx_v_loop->_debug_stream_read_cb_total + 1);

        /* "uvloop/handles/stream.pyx":824
 * 
 *     try:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_total += 1
 * 
 */
      }

      /* "uvloop/handles/stream.pyx":827
 *             loop._debug_stream_read_cb_total += 1
 * 
 *         sc._protocol_data_received(loop._recv_buffer[:nread])             # <<<<<<<<<<<<<<
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:
 */
      __pyx_t_6 = __Pyx_PyBytes_FromStringAndSize(((const char*)__pyx_v_loop->_recv_buffer) + 0, __pyx_v_nread - 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 827, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_sc->__pyx_base._protocol_data_received);
      __pyx_t_7 = __pyx_v_sc->__pyx_base._protocol_data_received; __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_8) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 827, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 827, __pyx_L4_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 827, __pyx_L4_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(18, 827, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 827, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/stream.pyx":823
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_total += 1
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":828
 * 
 *         sc._protocol_data_received(loop._recv_buffer[:nread])
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_errors_total += 1
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.__uv_stream_on_read_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(18, 828, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_exc = __pyx_t_7;
      /*try:*/ {

        /* "uvloop/handles/stream.pyx":829
 *         sc._protocol_data_received(loop._recv_buffer[:nread])
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_errors_total += 1
 * 
 */
        __pyx_t_2 = (UVLOOP_DEBUG != 0);
        if (__pyx_t_2) {

          /* "uvloop/handles/stream.pyx":830
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *         sc._fatal_error(exc, False)
 */
          __pyx_v_loop->_debug_stream_read_cb_errors_total = (__pyx_v_loop->_debug_stream_read_cb_errors_total + 1);

          /* "uvloop/handles/stream.pyx":829
 *         sc._protocol_data_received(loop._recv_buffer[:nread])
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_errors_total += 1
 * 
 */
        }

        /* "uvloop/handles/stream.pyx":832
 *             loop._debug_stream_read_cb_errors_total += 1
 * 
 *         sc._fatal_error(exc, False)             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_sc), __pyx_v_exc, Py_False, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 832, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }

      /* "uvloop/handles/stream.pyx":828
 * 
 *         sc._protocol_data_received(loop._recv_buffer[:nread])
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_errors_total += 1
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L17;
        }
        __pyx_L16_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __pyx_t_10 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_12 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          }
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ErrRestore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0;
          __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_12;
          goto __pyx_L6_except_error;
        }
        __pyx_L17:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/handles/stream.pyx":823
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_total += 1
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/stream.pyx":809
 * 
 * 
 * cdef inline void __uv_stream_on_read_impl(uv.uv_stream_t* stream,             # <<<<<<<<<<<<<<
 *                                           ssize_t nread,
 *                                           const uv.uv_buf_t* buf):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_stream_on_read_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sc);
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/handles/stream.pyx":835
 * 
 * 
 * cdef inline void __uv_stream_on_write_impl(uv.uv_write_t* req, int status):             # <<<<<<<<<<<<<<
 *     cdef:
 *         _StreamWriteContext ctx = <_StreamWriteContext> req.data
 */

static CYTHON_INLINE void __pyx_f_6uvloop_4loop___uv_stream_on_write_impl(uv_write_t *__pyx_v_req, int __pyx_v_status) {
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_v_ctx = 0;
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_stream = 0;
  PyObject *__pyx_v_exc = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_3 = NULL;
  struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  __Pyx_RefNannySetupContext("__uv_stream_on_write_impl", 0);

  /* "uvloop/handles/stream.pyx":837
 * cdef inline void __uv_stream_on_write_impl(uv.uv_write_t* req, int status):
 *     cdef:
 *         _StreamWriteContext ctx = <_StreamWriteContext> req.data             # <<<<<<<<<<<<<<
 *         UVStream stream = <UVStream>ctx.stream
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_req->data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_ctx = ((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":838
 *     cdef:
 *         _StreamWriteContext ctx = <_StreamWriteContext> req.data
 *         UVStream stream = <UVStream>ctx.stream             # <<<<<<<<<<<<<<
 * 
 *     ctx.close()
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_ctx->stream);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_stream = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":840
 *         UVStream stream = <UVStream>ctx.stream
 * 
 *     ctx.close()             # <<<<<<<<<<<<<<
 * 
 *     if stream._closed:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext *)__pyx_v_ctx->__pyx_vtab)->close(__pyx_v_ctx); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/stream.pyx":842
 *     ctx.close()
 * 
 *     if stream._closed:             # <<<<<<<<<<<<<<
 *         # The stream was closed, there is nothing to do.
 *         # Even if there is an error, like EPIPE, there
 */
  __pyx_t_2 = (__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._closed != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":846
 *         # Even if there is an error, like EPIPE, there
 *         # is no reason to report it.
 *         return             # <<<<<<<<<<<<<<
 * 
 *     if status < 0:
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":842
 *     ctx.close()
 * 
 *     if stream._closed:             # <<<<<<<<<<<<<<
 *         # The stream was closed, there is nothing to do.
 *         # Even if there is an error, like EPIPE, there
 */
  }

  /* "uvloop/handles/stream.pyx":848
 *         return
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_errors_total += 1
 */
  __pyx_t_2 = ((__pyx_v_status < 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/stream.pyx":849
 * 
 *     if status < 0:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_write_errors_total += 1
 * 
 */
    __pyx_t_2 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/stream.pyx":850
 *     if status < 0:
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *         exc = convert_error(status)
 */
      __Pyx_INCREF(((PyObject *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop));
      __pyx_t_3 = __pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop;
      __pyx_t_3->_debug_stream_write_errors_total = (__pyx_t_3->_debug_stream_write_errors_total + 1);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;

      /* "uvloop/handles/stream.pyx":849
 * 
 *     if status < 0:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_write_errors_total += 1
 * 
 */
    }

    /* "uvloop/handles/stream.pyx":852
 *             stream._loop._debug_stream_write_errors_total += 1
 * 
 *         exc = convert_error(status)             # <<<<<<<<<<<<<<
 *         stream._fatal_error(exc, False,
 *             "error status in uv_stream_t.write callback")
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":853
 * 
 *         exc = convert_error(status)
 *         stream._fatal_error(exc, False,             # <<<<<<<<<<<<<<
 *             "error status in uv_stream_t.write callback")
 *         return
 */
    __pyx_t_4.__pyx_n = 1;
    __pyx_t_4.reason = __pyx_kp_u_error_status_in_uv_stream_t_writ;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_stream), __pyx_v_exc, Py_False, &__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 853, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":855
 *         stream._fatal_error(exc, False,
 *             "error status in uv_stream_t.write callback")
 *         return             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":848
 *         return
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_errors_total += 1
 */
  }

  /* "uvloop/handles/stream.pyx":857
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         stream._on_write()
 *     except BaseException as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "uvloop/handles/stream.pyx":858
 * 
 *     try:
 *         stream._on_write()             # <<<<<<<<<<<<<<
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop_8UVStream__on_write(__pyx_v_stream); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 858, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/stream.pyx":857
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         stream._on_write()
 *     except BaseException as exc:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/stream.pyx":859
 *     try:
 *         stream._on_write()
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_cb_errors_total += 1
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("uvloop.loop.__uv_stream_on_write_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_9, &__pyx_t_10) < 0) __PYX_ERR(18, 859, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __pyx_v_exc = __pyx_t_9;
      /*try:*/ {

        /* "uvloop/handles/stream.pyx":860
 *         stream._on_write()
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_write_cb_errors_total += 1
 * 
 */
        __pyx_t_2 = (UVLOOP_DEBUG != 0);
        if (__pyx_t_2) {

          /* "uvloop/handles/stream.pyx":861
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_cb_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *         stream._fatal_error(exc, False)
 */
          __Pyx_INCREF(((PyObject *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop));
          __pyx_t_3 = __pyx_v_stream->__pyx_base.__pyx_base.__pyx_base._loop;
          __pyx_t_3->_debug_stream_write_cb_errors_total = (__pyx_t_3->_debug_stream_write_cb_errors_total + 1);
          __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;

          /* "uvloop/handles/stream.pyx":860
 *         stream._on_write()
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_write_cb_errors_total += 1
 * 
 */
        }

        /* "uvloop/handles/stream.pyx":863
 *             stream._loop._debug_stream_write_cb_errors_total += 1
 * 
 *         stream._fatal_error(exc, False)             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_t_11 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_stream), __pyx_v_exc, Py_False, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(18, 863, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }

      /* "uvloop/handles/stream.pyx":859
 *     try:
 *         stream._on_write()
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_write_cb_errors_total += 1
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L18;
        }
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_8 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          }
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
          goto __pyx_L8_except_error;
        }
        __pyx_L18:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/handles/stream.pyx":857
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         stream._on_write()
 *     except BaseException as exc:
 */
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L11_try_end:;
  }

  /* "uvloop/handles/stream.pyx":835
 * 
 * 
 * cdef inline void __uv_stream_on_write_impl(uv.uv_write_t* req, int status):             # <<<<<<<<<<<<<<
 *     cdef:
 *         _StreamWriteContext ctx = <_StreamWriteContext> req.data
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(((PyObject *)__pyx_t_3));
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_stream_on_write_impl", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_ctx);
  __Pyx_XDECREF((PyObject *)__pyx_v_stream);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/handles/stream.pyx":866
 * 
 * 
 * cdef void __uv_stream_on_read(uv.uv_stream_t* stream,             # <<<<<<<<<<<<<<
 *                               ssize_t nread,
 *                               const uv.uv_buf_t* buf) with gil:
 */

static void __pyx_f_6uvloop_4loop___uv_stream_on_read(uv_stream_t *__pyx_v_stream, Py_ssize_t __pyx_v_nread, uv_buf_t const *__pyx_v_buf) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_stream_on_read", 0);

  /* "uvloop/handles/stream.pyx":871
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,
 *                             "UVStream read callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_stream), ((char const *)"UVStream read callback")) == 0) != 0);

  /* "uvloop/handles/stream.pyx":870
 *                               const uv.uv_buf_t* buf) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,             # <<<<<<<<<<<<<<
 *                             "UVStream read callback") == 0:
 *         return
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":872
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,
 *                             "UVStream read callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     # Don't need try-finally, __uv_stream_on_read_impl is void
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":870
 *                               const uv.uv_buf_t* buf) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,             # <<<<<<<<<<<<<<
 *                             "UVStream read callback") == 0:
 *         return
 */
  }

  /* "uvloop/handles/stream.pyx":875
 * 
 *     # Don't need try-finally, __uv_stream_on_read_impl is void
 *     __uv_stream_on_read_impl(stream, nread, buf)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_f_6uvloop_4loop___uv_stream_on_read_impl(__pyx_v_stream, __pyx_v_nread, __pyx_v_buf);

  /* "uvloop/handles/stream.pyx":866
 * 
 * 
 * cdef void __uv_stream_on_read(uv.uv_stream_t* stream,             # <<<<<<<<<<<<<<
 *                               ssize_t nread,
 *                               const uv.uv_buf_t* buf) with gil:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/stream.pyx":878
 * 
 * 
 * cdef void __uv_stream_on_write(uv.uv_write_t* req, int status) with gil:             # <<<<<<<<<<<<<<
 * 
 *     if UVLOOP_DEBUG:
 */

static void __pyx_f_6uvloop_4loop___uv_stream_on_write(uv_write_t *__pyx_v_req, int __pyx_v_status) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_stream_on_write", 0);

  /* "uvloop/handles/stream.pyx":880
 * cdef void __uv_stream_on_write(uv.uv_write_t* req, int status) with gil:
 * 
 *     if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *         if req.data is NULL:
 *             aio_logger.error(
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":881
 * 
 *     if UVLOOP_DEBUG:
 *         if req.data is NULL:             # <<<<<<<<<<<<<<
 *             aio_logger.error(
 *                 'UVStream.write callback called with NULL req.data, status=%r',
 */
    __pyx_t_1 = ((__pyx_v_req->data == NULL) != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":882
 *     if UVLOOP_DEBUG:
 *         if req.data is NULL:
 *             aio_logger.error(             # <<<<<<<<<<<<<<
 *                 'UVStream.write callback called with NULL req.data, status=%r',
 *                 status)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 882, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/handles/stream.pyx":884
 *             aio_logger.error(
 *                 'UVStream.write callback called with NULL req.data, status=%r',
 *                 status)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_status); if (unlikely(!__pyx_t_4)) __PYX_ERR(18, 884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_6 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_6 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_kp_u_UVStream_write_callback_called_w, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 882, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_kp_u_UVStream_write_callback_called_w, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 882, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(18, 882, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_UVStream_write_callback_called_w);
        __Pyx_GIVEREF(__pyx_kp_u_UVStream_write_callback_called_w);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_kp_u_UVStream_write_callback_called_w);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 882, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":885
 *                 'UVStream.write callback called with NULL req.data, status=%r',
 *                 status)
 *             return             # <<<<<<<<<<<<<<
 * 
 *     # Don't need try-finally, __uv_stream_on_write_impl is void
 */
      goto __pyx_L0;

      /* "uvloop/handles/stream.pyx":881
 * 
 *     if UVLOOP_DEBUG:
 *         if req.data is NULL:             # <<<<<<<<<<<<<<
 *             aio_logger.error(
 *                 'UVStream.write callback called with NULL req.data, status=%r',
 */
    }

    /* "uvloop/handles/stream.pyx":880
 * cdef void __uv_stream_on_write(uv.uv_write_t* req, int status) with gil:
 * 
 *     if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *         if req.data is NULL:
 *             aio_logger.error(
 */
  }

  /* "uvloop/handles/stream.pyx":888
 * 
 *     # Don't need try-finally, __uv_stream_on_write_impl is void
 *     __uv_stream_on_write_impl(req, status)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_f_6uvloop_4loop___uv_stream_on_write_impl(__pyx_v_req, __pyx_v_status);

  /* "uvloop/handles/stream.pyx":878
 * 
 * 
 * cdef void __uv_stream_on_write(uv.uv_write_t* req, int status) with gil:             # <<<<<<<<<<<<<<
 * 
 *     if UVLOOP_DEBUG:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_stream_on_write", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/stream.pyx":891
 * 
 * 
 * cdef void __uv_stream_buffered_alloc(uv.uv_handle_t* stream,             # <<<<<<<<<<<<<<
 *                                      size_t suggested_size,
 *                                      uv.uv_buf_t* uvbuf) with gil:
 */

static void __pyx_f_6uvloop_4loop___uv_stream_buffered_alloc(uv_handle_t *__pyx_v_stream, size_t __pyx_v_suggested_size, uv_buf_t *__pyx_v_uvbuf) {
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_sc = 0;
  CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  Py_buffer *__pyx_v_pybuf;
  int __pyx_v_got_buf;
  PyObject *__pyx_v_buf = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_exc = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_stream_buffered_alloc", 0);

  /* "uvloop/handles/stream.pyx":896
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,
 *                             "UVStream alloc buffer callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_stream), ((char const *)"UVStream alloc buffer callback")) == 0) != 0);

  /* "uvloop/handles/stream.pyx":895
 *                                      uv.uv_buf_t* uvbuf) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,             # <<<<<<<<<<<<<<
 *                             "UVStream alloc buffer callback") == 0:
 *         return
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":897
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,
 *                             "UVStream alloc buffer callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":895
 *                                      uv.uv_buf_t* uvbuf) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,             # <<<<<<<<<<<<<<
 *                             "UVStream alloc buffer callback") == 0:
 *         return
 */
  }

  /* "uvloop/handles/stream.pyx":900
 * 
 *     cdef:
 *         UVStream sc = <UVStream>stream.data             # <<<<<<<<<<<<<<
 *         Loop loop = sc._loop
 *         Py_buffer* pybuf = &sc._read_pybuf
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_stream->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_sc = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":901
 *     cdef:
 *         UVStream sc = <UVStream>stream.data
 *         Loop loop = sc._loop             # <<<<<<<<<<<<<<
 *         Py_buffer* pybuf = &sc._read_pybuf
 *         int got_buf = 0
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":902
 *         UVStream sc = <UVStream>stream.data
 *         Loop loop = sc._loop
 *         Py_buffer* pybuf = &sc._read_pybuf             # <<<<<<<<<<<<<<
 *         int got_buf = 0
 * 
 */
  __pyx_v_pybuf = (&__pyx_v_sc->_read_pybuf);

  /* "uvloop/handles/stream.pyx":903
 *         Loop loop = sc._loop
 *         Py_buffer* pybuf = &sc._read_pybuf
 *         int got_buf = 0             # <<<<<<<<<<<<<<
 * 
 *     if sc._read_pybuf_acquired:
 */
  __pyx_v_got_buf = 0;

  /* "uvloop/handles/stream.pyx":905
 *         int got_buf = 0
 * 
 *     if sc._read_pybuf_acquired:             # <<<<<<<<<<<<<<
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 */
  __pyx_t_1 = (__pyx_v_sc->_read_pybuf_acquired != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":906
 * 
 *     if sc._read_pybuf_acquired:
 *         uvbuf.len = 0             # <<<<<<<<<<<<<<
 *         uvbuf.base = NULL
 *         return
 */
    __pyx_v_uvbuf->len = 0;

    /* "uvloop/handles/stream.pyx":907
 *     if sc._read_pybuf_acquired:
 *         uvbuf.len = 0
 *         uvbuf.base = NULL             # <<<<<<<<<<<<<<
 *         return
 * 
 */
    __pyx_v_uvbuf->base = NULL;

    /* "uvloop/handles/stream.pyx":908
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 *         return             # <<<<<<<<<<<<<<
 * 
 *     sc._read_pybuf_acquired = 0
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":905
 *         int got_buf = 0
 * 
 *     if sc._read_pybuf_acquired:             # <<<<<<<<<<<<<<
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 */
  }

  /* "uvloop/handles/stream.pyx":910
 *         return
 * 
 *     sc._read_pybuf_acquired = 0             # <<<<<<<<<<<<<<
 *     try:
 *         buf = sc._protocol_get_buffer(suggested_size)
 */
  __pyx_v_sc->_read_pybuf_acquired = 0;

  /* "uvloop/handles/stream.pyx":911
 * 
 *     sc._read_pybuf_acquired = 0
 *     try:             # <<<<<<<<<<<<<<
 *         buf = sc._protocol_get_buffer(suggested_size)
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "uvloop/handles/stream.pyx":912
 *     sc._read_pybuf_acquired = 0
 *     try:
 *         buf = sc._protocol_get_buffer(suggested_size)             # <<<<<<<<<<<<<<
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)
 *         got_buf = 1
 */
      __pyx_t_6 = __Pyx_PyInt_FromSize_t(__pyx_v_suggested_size); if (unlikely(!__pyx_t_6)) __PYX_ERR(18, 912, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_v_sc->_protocol_get_buffer);
      __pyx_t_7 = __pyx_v_sc->_protocol_get_buffer; __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (!__pyx_t_8) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 912, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 912, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
          PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 912, __pyx_L5_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(18, 912, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 912, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_buf = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "uvloop/handles/stream.pyx":913
 *     try:
 *         buf = sc._protocol_get_buffer(suggested_size)
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)             # <<<<<<<<<<<<<<
 *         got_buf = 1
 *     except BaseException as exc:
 */
      __pyx_t_10 = PyObject_GetBuffer(__pyx_v_buf, __pyx_v_pybuf, PyBUF_WRITABLE); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(18, 913, __pyx_L5_error)

      /* "uvloop/handles/stream.pyx":914
 *         buf = sc._protocol_get_buffer(suggested_size)
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)
 *         got_buf = 1             # <<<<<<<<<<<<<<
 *     except BaseException as exc:
 *         # Can't call 'sc._fatal_error' or 'sc._close', libuv will SF.
 */
      __pyx_v_got_buf = 1;

      /* "uvloop/handles/stream.pyx":911
 * 
 *     sc._read_pybuf_acquired = 0
 *     try:             # <<<<<<<<<<<<<<
 *         buf = sc._protocol_get_buffer(suggested_size)
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/stream.pyx":915
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)
 *         got_buf = 1
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         # Can't call 'sc._fatal_error' or 'sc._close', libuv will SF.
 *         # We'll do it later in __uv_stream_buffered_on_read when we
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.__uv_stream_buffered_alloc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(18, 915, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_exc = __pyx_t_7;
      /*try:*/ {

        /* "uvloop/handles/stream.pyx":919
 *         # We'll do it later in __uv_stream_buffered_on_read when we
 *         # receive UV_ENOBUFS.
 *         uvbuf.len = 0             # <<<<<<<<<<<<<<
 *         uvbuf.base = NULL
 *         return
 */
        __pyx_v_uvbuf->len = 0;

        /* "uvloop/handles/stream.pyx":920
 *         # receive UV_ENOBUFS.
 *         uvbuf.len = 0
 *         uvbuf.base = NULL             # <<<<<<<<<<<<<<
 *         return
 * 
 */
        __pyx_v_uvbuf->base = NULL;

        /* "uvloop/handles/stream.pyx":921
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 *         return             # <<<<<<<<<<<<<<
 * 
 *     if not pybuf.len:
 */
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L15_return;
      }

      /* "uvloop/handles/stream.pyx":915
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)
 *         got_buf = 1
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         # Can't call 'sc._fatal_error' or 'sc._close', libuv will SF.
 *         # We'll do it later in __uv_stream_buffered_on_read when we
 */
      /*finally:*/ {
        __pyx_L15_return: {
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L8_except_return;
        }
      }
    }
    goto __pyx_L7_except_error;
    __pyx_L7_except_error:;

    /* "uvloop/handles/stream.pyx":911
 * 
 *     sc._read_pybuf_acquired = 0
 *     try:             # <<<<<<<<<<<<<<
 *         buf = sc._protocol_get_buffer(suggested_size)
 *         PyObject_GetBuffer(buf, pybuf, PyBUF_WRITABLE)
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L8_except_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L0;
    __pyx_L10_try_end:;
  }

  /* "uvloop/handles/stream.pyx":923
 *         return
 * 
 *     if not pybuf.len:             # <<<<<<<<<<<<<<
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 */
  __pyx_t_1 = ((!(__pyx_v_pybuf->len != 0)) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":924
 * 
 *     if not pybuf.len:
 *         uvbuf.len = 0             # <<<<<<<<<<<<<<
 *         uvbuf.base = NULL
 *         if got_buf:
 */
    __pyx_v_uvbuf->len = 0;

    /* "uvloop/handles/stream.pyx":925
 *     if not pybuf.len:
 *         uvbuf.len = 0
 *         uvbuf.base = NULL             # <<<<<<<<<<<<<<
 *         if got_buf:
 *             PyBuffer_Release(pybuf)
 */
    __pyx_v_uvbuf->base = NULL;

    /* "uvloop/handles/stream.pyx":926
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 *         if got_buf:             # <<<<<<<<<<<<<<
 *             PyBuffer_Release(pybuf)
 *         return
 */
    __pyx_t_1 = (__pyx_v_got_buf != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/stream.pyx":927
 *         uvbuf.base = NULL
 *         if got_buf:
 *             PyBuffer_Release(pybuf)             # <<<<<<<<<<<<<<
 *         return
 * 
 */
      PyBuffer_Release(__pyx_v_pybuf);

      /* "uvloop/handles/stream.pyx":926
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 *         if got_buf:             # <<<<<<<<<<<<<<
 *             PyBuffer_Release(pybuf)
 *         return
 */
    }

    /* "uvloop/handles/stream.pyx":928
 *         if got_buf:
 *             PyBuffer_Release(pybuf)
 *         return             # <<<<<<<<<<<<<<
 * 
 *     sc._read_pybuf_acquired = 1
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":923
 *         return
 * 
 *     if not pybuf.len:             # <<<<<<<<<<<<<<
 *         uvbuf.len = 0
 *         uvbuf.base = NULL
 */
  }

  /* "uvloop/handles/stream.pyx":930
 *         return
 * 
 *     sc._read_pybuf_acquired = 1             # <<<<<<<<<<<<<<
 *     uvbuf.base = <char*>pybuf.buf
 *     uvbuf.len = pybuf.len
 */
  __pyx_v_sc->_read_pybuf_acquired = 1;

  /* "uvloop/handles/stream.pyx":931
 * 
 *     sc._read_pybuf_acquired = 1
 *     uvbuf.base = <char*>pybuf.buf             # <<<<<<<<<<<<<<
 *     uvbuf.len = pybuf.len
 * 
 */
  __pyx_v_uvbuf->base = ((char *)__pyx_v_pybuf->buf);

  /* "uvloop/handles/stream.pyx":932
 *     sc._read_pybuf_acquired = 1
 *     uvbuf.base = <char*>pybuf.buf
 *     uvbuf.len = pybuf.len             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_11 = __pyx_v_pybuf->len;
  __pyx_v_uvbuf->len = __pyx_t_11;

  /* "uvloop/handles/stream.pyx":891
 * 
 * 
 * cdef void __uv_stream_buffered_alloc(uv.uv_handle_t* stream,             # <<<<<<<<<<<<<<
 *                                      size_t suggested_size,
 *                                      uv.uv_buf_t* uvbuf) with gil:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_stream_buffered_alloc", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sc);
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_buf);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/stream.pyx":935
 * 
 * 
 * cdef void __uv_stream_buffered_on_read(uv.uv_stream_t* stream,             # <<<<<<<<<<<<<<
 *                                        ssize_t nread,
 *                                        const uv.uv_buf_t* buf) with gil:
 */

static void __pyx_f_6uvloop_4loop___uv_stream_buffered_on_read(uv_stream_t *__pyx_v_stream, Py_ssize_t __pyx_v_nread, CYTHON_UNUSED uv_buf_t const *__pyx_v_buf) {
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_sc = 0;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  Py_buffer *__pyx_v_pybuf;
  PyObject *__pyx_v_exc = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  char const *__pyx_t_20;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_stream_buffered_on_read", 0);

  /* "uvloop/handles/stream.pyx":940
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,
 *                             "UVStream buffered read callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_stream), ((char const *)"UVStream buffered read callback")) == 0) != 0);

  /* "uvloop/handles/stream.pyx":939
 *                                        const uv.uv_buf_t* buf) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,             # <<<<<<<<<<<<<<
 *                             "UVStream buffered read callback") == 0:
 *         return
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":941
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,
 *                             "UVStream buffered read callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":939
 *                                        const uv.uv_buf_t* buf) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>stream,             # <<<<<<<<<<<<<<
 *                             "UVStream buffered read callback") == 0:
 *         return
 */
  }

  /* "uvloop/handles/stream.pyx":944
 * 
 *     cdef:
 *         UVStream sc = <UVStream>stream.data             # <<<<<<<<<<<<<<
 *         Loop loop = sc._loop
 *         Py_buffer* pybuf = &sc._read_pybuf
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_stream->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_sc = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":945
 *     cdef:
 *         UVStream sc = <UVStream>stream.data
 *         Loop loop = sc._loop             # <<<<<<<<<<<<<<
 *         Py_buffer* pybuf = &sc._read_pybuf
 * 
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/stream.pyx":946
 *         UVStream sc = <UVStream>stream.data
 *         Loop loop = sc._loop
 *         Py_buffer* pybuf = &sc._read_pybuf             # <<<<<<<<<<<<<<
 * 
 *     if nread == uv.UV_ENOBUFS:
 */
  __pyx_v_pybuf = (&__pyx_v_sc->_read_pybuf);

  /* "uvloop/handles/stream.pyx":948
 *         Py_buffer* pybuf = &sc._read_pybuf
 * 
 *     if nread == uv.UV_ENOBUFS:             # <<<<<<<<<<<<<<
 *         sc._fatal_error(
 *             RuntimeError(
 */
  __pyx_t_1 = ((__pyx_v_nread == UV_ENOBUFS) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/stream.pyx":950
 *     if nread == uv.UV_ENOBUFS:
 *         sc._fatal_error(
 *             RuntimeError(             # <<<<<<<<<<<<<<
 *                 'unhandled error (or an empty buffer) in get_buffer()'),
 *             False)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__184, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 950, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "uvloop/handles/stream.pyx":949
 * 
 *     if nread == uv.UV_ENOBUFS:
 *         sc._fatal_error(             # <<<<<<<<<<<<<<
 *             RuntimeError(
 *                 'unhandled error (or an empty buffer) in get_buffer()'),
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_sc), __pyx_t_2, Py_False, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/stream.pyx":953
 *                 'unhandled error (or an empty buffer) in get_buffer()'),
 *             False)
 *         return             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    goto __pyx_L0;

    /* "uvloop/handles/stream.pyx":948
 *         Py_buffer* pybuf = &sc._read_pybuf
 * 
 *     if nread == uv.UV_ENOBUFS:             # <<<<<<<<<<<<<<
 *         sc._fatal_error(
 *             RuntimeError(
 */
  }

  /* "uvloop/handles/stream.pyx":955
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if nread > 0 and not sc._read_pybuf_acquired:
 *             # From libuv docs:
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/handles/stream.pyx":956
 * 
 *     try:
 *         if nread > 0 and not sc._read_pybuf_acquired:             # <<<<<<<<<<<<<<
 *             # From libuv docs:
 *             #     nread is > 0 if there is data available or < 0 on error. When
 */
        __pyx_t_7 = ((__pyx_v_nread > 0) != 0);
        if (__pyx_t_7) {
        } else {
          __pyx_t_1 = __pyx_t_7;
          goto __pyx_L15_bool_binop_done;
        }
        __pyx_t_7 = ((!(__pyx_v_sc->_read_pybuf_acquired != 0)) != 0);
        __pyx_t_1 = __pyx_t_7;
        __pyx_L15_bool_binop_done:;
        if (unlikely(__pyx_t_1)) {

          /* "uvloop/handles/stream.pyx":963
 *             #     buffer; in that case buf.len and buf.base are both set to 0.
 *             raise RuntimeError(
 *                 f'no python buffer is allocated in on_read; nread={nread}')             # <<<<<<<<<<<<<<
 * 
 *         if nread == 0:
 */
          __pyx_t_3 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_nread, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 963, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_kp_u_no_python_buffer_is_allocated_in, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 963, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "uvloop/handles/stream.pyx":962
 *             #     nread < 0, the buf parameter might not point to a valid
 *             #     buffer; in that case buf.len and buf.base are both set to 0.
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 f'no python buffer is allocated in on_read; nread={nread}')
 * 
 */
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 962, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_Raise(__pyx_t_3, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __PYX_ERR(18, 962, __pyx_L8_error)

          /* "uvloop/handles/stream.pyx":956
 * 
 *     try:
 *         if nread > 0 and not sc._read_pybuf_acquired:             # <<<<<<<<<<<<<<
 *             # From libuv docs:
 *             #     nread is > 0 if there is data available or < 0 on error. When
 */
        }

        /* "uvloop/handles/stream.pyx":965
 *                 f'no python buffer is allocated in on_read; nread={nread}')
 * 
 *         if nread == 0:             # <<<<<<<<<<<<<<
 *             # From libuv docs:
 *             #     nread might be 0, which does not indicate an error or EOF.
 */
        __pyx_t_1 = ((__pyx_v_nread == 0) != 0);
        if (__pyx_t_1) {

          /* "uvloop/handles/stream.pyx":969
 *             #     nread might be 0, which does not indicate an error or EOF.
 *             #     This is equivalent to EAGAIN or EWOULDBLOCK under read(2).
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if __uv_stream_on_read_common(sc, loop, nread):
 */
          goto __pyx_L12_try_return;

          /* "uvloop/handles/stream.pyx":965
 *                 f'no python buffer is allocated in on_read; nread={nread}')
 * 
 *         if nread == 0:             # <<<<<<<<<<<<<<
 *             # From libuv docs:
 *             #     nread might be 0, which does not indicate an error or EOF.
 */
        }

        /* "uvloop/handles/stream.pyx":971
 *             return
 * 
 *         if __uv_stream_on_read_common(sc, loop, nread):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
        __pyx_t_1 = (__pyx_f_6uvloop_4loop___uv_stream_on_read_common(__pyx_v_sc, __pyx_v_loop, __pyx_v_nread) != 0);
        if (__pyx_t_1) {

          /* "uvloop/handles/stream.pyx":972
 * 
 *         if __uv_stream_on_read_common(sc, loop, nread):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
          goto __pyx_L12_try_return;

          /* "uvloop/handles/stream.pyx":971
 *             return
 * 
 *         if __uv_stream_on_read_common(sc, loop, nread):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
        }

        /* "uvloop/handles/stream.pyx":974
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_total += 1
 * 
 */
        __pyx_t_1 = (UVLOOP_DEBUG != 0);
        if (__pyx_t_1) {

          /* "uvloop/handles/stream.pyx":975
 * 
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_total += 1             # <<<<<<<<<<<<<<
 * 
 *         sc._protocol_buffer_updated(nread)
 */
          __pyx_v_loop->_debug_stream_read_cb_total = (__pyx_v_loop->_debug_stream_read_cb_total + 1);

          /* "uvloop/handles/stream.pyx":974
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_total += 1
 * 
 */
        }

        /* "uvloop/handles/stream.pyx":977
 *             loop._debug_stream_read_cb_total += 1
 * 
 *         sc._protocol_buffer_updated(nread)             # <<<<<<<<<<<<<<
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:
 */
        __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_nread); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 977, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_v_sc->_protocol_buffer_updated);
        __pyx_t_8 = __pyx_v_sc->_protocol_buffer_updated; __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_8, function);
          }
        }
        if (!__pyx_t_9) {
          __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 977, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_2};
            __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 977, __pyx_L8_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
            PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_2};
            __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 977, __pyx_L8_error)
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          } else
          #endif
          {
            __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(18, 977, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
            __Pyx_GIVEREF(__pyx_t_2);
            PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_2);
            __pyx_t_2 = 0;
            __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(18, 977, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/handles/stream.pyx":955
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if nread > 0 and not sc._read_pybuf_acquired:
 *             # From libuv docs:
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L13_try_end;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/stream.pyx":978
 * 
 *         sc._protocol_buffer_updated(nread)
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_errors_total += 1
 */
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
      if (__pyx_t_11) {
        __Pyx_AddTraceback("uvloop.loop.__uv_stream_buffered_on_read", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_8, &__pyx_t_10) < 0) __PYX_ERR(18, 978, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_v_exc = __pyx_t_8;
        /*try:*/ {

          /* "uvloop/handles/stream.pyx":979
 *         sc._protocol_buffer_updated(nread)
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_errors_total += 1
 * 
 */
          __pyx_t_1 = (UVLOOP_DEBUG != 0);
          if (__pyx_t_1) {

            /* "uvloop/handles/stream.pyx":980
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *         sc._fatal_error(exc, False)
 */
            __pyx_v_loop->_debug_stream_read_cb_errors_total = (__pyx_v_loop->_debug_stream_read_cb_errors_total + 1);

            /* "uvloop/handles/stream.pyx":979
 *         sc._protocol_buffer_updated(nread)
 *     except BaseException as exc:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             loop._debug_stream_read_cb_errors_total += 1
 * 
 */
          }

          /* "uvloop/handles/stream.pyx":982
 *             loop._debug_stream_read_cb_errors_total += 1
 * 
 *         sc._fatal_error(exc, False)             # <<<<<<<<<<<<<<
 *     finally:
 *         sc._read_pybuf_acquired = 0
 */
          __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_sc->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_sc), __pyx_v_exc, Py_False, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(18, 982, __pyx_L25_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }

        /* "uvloop/handles/stream.pyx":978
 * 
 *         sc._protocol_buffer_updated(nread)
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             loop._debug_stream_read_cb_errors_total += 1
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            goto __pyx_L26;
          }
          __pyx_L25_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __pyx_t_11 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            }
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
            __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
            __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
            goto __pyx_L10_except_error;
          }
          __pyx_L26:;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L9_exception_handled;
      }
      goto __pyx_L10_except_error;
      __pyx_L10_except_error:;

      /* "uvloop/handles/stream.pyx":955
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if nread > 0 and not sc._read_pybuf_acquired:
 *             # From libuv docs:
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L6_error;
      __pyx_L12_try_return:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L5_return;
      __pyx_L9_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_L13_try_end:;
    }
  }

  /* "uvloop/handles/stream.pyx":984
 *         sc._fatal_error(exc, False)
 *     finally:
 *         sc._read_pybuf_acquired = 0             # <<<<<<<<<<<<<<
 *         PyBuffer_Release(pybuf)
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_v_sc->_read_pybuf_acquired = 0;

      /* "uvloop/handles/stream.pyx":985
 *     finally:
 *         sc._read_pybuf_acquired = 0
 *         PyBuffer_Release(pybuf)             # <<<<<<<<<<<<<<
 */
      PyBuffer_Release(__pyx_v_pybuf);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_19);
      __Pyx_XGOTREF(__pyx_t_18);
      __Pyx_XGOTREF(__pyx_t_17);
      __pyx_t_12 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
      {

        /* "uvloop/handles/stream.pyx":984
 *         sc._fatal_error(exc, False)
 *     finally:
 *         sc._read_pybuf_acquired = 0             # <<<<<<<<<<<<<<
 *         PyBuffer_Release(pybuf)
 */
        __pyx_v_sc->_read_pybuf_acquired = 0;

        /* "uvloop/handles/stream.pyx":985
 *     finally:
 *         sc._read_pybuf_acquired = 0
 *         PyBuffer_Release(pybuf)             # <<<<<<<<<<<<<<
 */
        PyBuffer_Release(__pyx_v_pybuf);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_18, __pyx_t_17);
      }
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
      __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_20;
      goto __pyx_L1_error;
    }
    __pyx_L5_return: {

      /* "uvloop/handles/stream.pyx":984
 *         sc._fatal_error(exc, False)
 *     finally:
 *         sc._read_pybuf_acquired = 0             # <<<<<<<<<<<<<<
 *         PyBuffer_Release(pybuf)
 */
      __pyx_v_sc->_read_pybuf_acquired = 0;

      /* "uvloop/handles/stream.pyx":985
 *     finally:
 *         sc._read_pybuf_acquired = 0
 *         PyBuffer_Release(pybuf)             # <<<<<<<<<<<<<<
 */
      PyBuffer_Release(__pyx_v_pybuf);
      goto __pyx_L0;
    }
    __pyx_L7:;
  }

  /* "uvloop/handles/stream.pyx":935
 * 
 * 
 * cdef void __uv_stream_buffered_on_read(uv.uv_stream_t* stream,             # <<<<<<<<<<<<<<
 *                                        ssize_t nread,
 *                                        const uv.uv_buf_t* buf) with gil:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_stream_buffered_on_read", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sc);
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/streamserver.pyx":4
 * cdef class UVStreamServer(UVSocketHandle):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.opened = 0
 *         self._server = None
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_14UVStreamServer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_14UVStreamServer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_14UVStreamServer___cinit__(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_14UVStreamServer___cinit__(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/streamserver.pyx":5
 * 
 *     def __cinit__(self):
 *         self.opened = 0             # <<<<<<<<<<<<<<
 *         self._server = None
 *         self.ssl = None
 */
  __pyx_v_self->opened = 0;

  /* "uvloop/handles/streamserver.pyx":6
 *     def __cinit__(self):
 *         self.opened = 0
 *         self._server = None             # <<<<<<<<<<<<<<
 *         self.ssl = None
 *         self.ssl_handshake_timeout = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_server);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_server));
  __pyx_v_self->_server = ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None);

  /* "uvloop/handles/streamserver.pyx":7
 *         self.opened = 0
 *         self._server = None
 *         self.ssl = None             # <<<<<<<<<<<<<<
 *         self.ssl_handshake_timeout = None
 *         self.protocol_factory = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->ssl);
  __Pyx_DECREF(__pyx_v_self->ssl);
  __pyx_v_self->ssl = Py_None;

  /* "uvloop/handles/streamserver.pyx":8
 *         self._server = None
 *         self.ssl = None
 *         self.ssl_handshake_timeout = None             # <<<<<<<<<<<<<<
 *         self.protocol_factory = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->ssl_handshake_timeout);
  __Pyx_DECREF(__pyx_v_self->ssl_handshake_timeout);
  __pyx_v_self->ssl_handshake_timeout = Py_None;

  /* "uvloop/handles/streamserver.pyx":9
 *         self.ssl = None
 *         self.ssl_handshake_timeout = None
 *         self.protocol_factory = None             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _init(self, Loop loop, object protocol_factory,
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->protocol_factory);
  __Pyx_DECREF(__pyx_v_self->protocol_factory);
  __pyx_v_self->protocol_factory = Py_None;

  /* "uvloop/handles/streamserver.pyx":4
 * cdef class UVStreamServer(UVSocketHandle):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.opened = 0
 *         self._server = None
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":11
 *         self.protocol_factory = None
 * 
 *     cdef inline _init(self, Loop loop, object protocol_factory,             # <<<<<<<<<<<<<<
 *                       Server server, object ssl, object ssl_handshake_timeout):
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__init(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/streamserver.pyx":14
 *                       Server server, object ssl, object ssl_handshake_timeout):
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError(
 */
  __pyx_t_1 = (__pyx_v_ssl != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/streamserver.pyx":15
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     'ssl is expected to be None or an instance of '
 */
    __pyx_t_3 = __pyx_v_6uvloop_4loop_ssl_SSLContext;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_2 = PyObject_IsInstance(__pyx_v_ssl, __pyx_t_3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(19, 15, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = ((!(__pyx_t_2 != 0)) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/handles/streamserver.pyx":18
 *                 raise TypeError(
 *                     'ssl is expected to be None or an instance of '
 *                     'ssl.SSLContext, got {!r}'.format(ssl))             # <<<<<<<<<<<<<<
 *         else:
 *             if ssl_handshake_timeout is not None:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_ssl_is_expected_to_be_None_or_an, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 18, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_ssl); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 18, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_ssl};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 18, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_ssl};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 18, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 18, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_v_ssl);
          __Pyx_GIVEREF(__pyx_v_ssl);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_ssl);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 18, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/handles/streamserver.pyx":16
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError(             # <<<<<<<<<<<<<<
 *                     'ssl is expected to be None or an instance of '
 *                     'ssl.SSLContext, got {!r}'.format(ssl))
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(19, 16, __pyx_L1_error)

      /* "uvloop/handles/streamserver.pyx":15
 * 
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):             # <<<<<<<<<<<<<<
 *                 raise TypeError(
 *                     'ssl is expected to be None or an instance of '
 */
    }

    /* "uvloop/handles/streamserver.pyx":14
 *                       Server server, object ssl, object ssl_handshake_timeout):
 * 
 *         if ssl is not None:             # <<<<<<<<<<<<<<
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError(
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/streamserver.pyx":20
 *                     'ssl.SSLContext, got {!r}'.format(ssl))
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
  /*else*/ {
    __pyx_t_1 = (__pyx_v_ssl_handshake_timeout != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/handles/streamserver.pyx":21
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__185, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 21, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(19, 21, __pyx_L1_error)

      /* "uvloop/handles/streamserver.pyx":20
 *                     'ssl.SSLContext, got {!r}'.format(ssl))
 *         else:
 *             if ssl_handshake_timeout is not None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 */
    }
  }
  __pyx_L3:;

  /* "uvloop/handles/streamserver.pyx":24
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 *         self.ssl = ssl             # <<<<<<<<<<<<<<
 *         self.ssl_handshake_timeout = ssl_handshake_timeout
 * 
 */
  __Pyx_INCREF(__pyx_v_ssl);
  __Pyx_GIVEREF(__pyx_v_ssl);
  __Pyx_GOTREF(__pyx_v_self->ssl);
  __Pyx_DECREF(__pyx_v_self->ssl);
  __pyx_v_self->ssl = __pyx_v_ssl;

  /* "uvloop/handles/streamserver.pyx":25
 * 
 *         self.ssl = ssl
 *         self.ssl_handshake_timeout = ssl_handshake_timeout             # <<<<<<<<<<<<<<
 * 
 *         self._start_init(loop)
 */
  __Pyx_INCREF(__pyx_v_ssl_handshake_timeout);
  __Pyx_GIVEREF(__pyx_v_ssl_handshake_timeout);
  __Pyx_GOTREF(__pyx_v_self->ssl_handshake_timeout);
  __Pyx_DECREF(__pyx_v_self->ssl_handshake_timeout);
  __pyx_v_self->ssl_handshake_timeout = __pyx_v_ssl_handshake_timeout;

  /* "uvloop/handles/streamserver.pyx":27
 *         self.ssl_handshake_timeout = ssl_handshake_timeout
 * 
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 *         self.protocol_factory = protocol_factory
 *         self._server = server
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/handles/streamserver.pyx":28
 * 
 *         self._start_init(loop)
 *         self.protocol_factory = protocol_factory             # <<<<<<<<<<<<<<
 *         self._server = server
 * 
 */
  __Pyx_INCREF(__pyx_v_protocol_factory);
  __Pyx_GIVEREF(__pyx_v_protocol_factory);
  __Pyx_GOTREF(__pyx_v_self->protocol_factory);
  __Pyx_DECREF(__pyx_v_self->protocol_factory);
  __pyx_v_self->protocol_factory = __pyx_v_protocol_factory;

  /* "uvloop/handles/streamserver.pyx":29
 *         self._start_init(loop)
 *         self.protocol_factory = protocol_factory
 *         self._server = server             # <<<<<<<<<<<<<<
 * 
 *     cdef inline listen(self, backlog):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_server));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_server));
  __Pyx_GOTREF(__pyx_v_self->_server);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_server));
  __pyx_v_self->_server = __pyx_v_server;

  /* "uvloop/handles/streamserver.pyx":11
 *         self.protocol_factory = None
 * 
 *     cdef inline _init(self, Loop loop, object protocol_factory,             # <<<<<<<<<<<<<<
 *                       Server server, object ssl, object ssl_handshake_timeout):
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":31
 *         self._server = server
 * 
 *     cdef inline listen(self, backlog):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer_listen(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, PyObject *__pyx_v_backlog) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  __Pyx_RefNannySetupContext("listen", 0);

  /* "uvloop/handles/streamserver.pyx":33
 *     cdef inline listen(self, backlog):
 *         cdef int err
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(backlog, int):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/streamserver.pyx":35
 *         self._ensure_alive()
 * 
 *         if not isinstance(backlog, int):             # <<<<<<<<<<<<<<
 *             # Don't allow floats
 *             raise TypeError('integer argument expected, got {}'.format(
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_backlog); 
  __pyx_t_3 = ((!(__pyx_t_2 != 0)) != 0);
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/handles/streamserver.pyx":37
 *         if not isinstance(backlog, int):
 *             # Don't allow floats
 *             raise TypeError('integer argument expected, got {}'.format(             # <<<<<<<<<<<<<<
 *                 type(backlog).__name__))
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_integer_argument_expected_got, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "uvloop/handles/streamserver.pyx":38
 *             # Don't allow floats
 *             raise TypeError('integer argument expected, got {}'.format(
 *                 type(backlog).__name__))             # <<<<<<<<<<<<<<
 * 
 *         if self.protocol_factory is None:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_backlog)), __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(19, 38, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 37, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 37, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 37, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(19, 37, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 37, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/streamserver.pyx":37
 *         if not isinstance(backlog, int):
 *             # Don't allow floats
 *             raise TypeError('integer argument expected, got {}'.format(             # <<<<<<<<<<<<<<
 *                 type(backlog).__name__))
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(19, 37, __pyx_L1_error)

    /* "uvloop/handles/streamserver.pyx":35
 *         self._ensure_alive()
 * 
 *         if not isinstance(backlog, int):             # <<<<<<<<<<<<<<
 *             # Don't allow floats
 *             raise TypeError('integer argument expected, got {}'.format(
 */
  }

  /* "uvloop/handles/streamserver.pyx":40
 *                 type(backlog).__name__))
 * 
 *         if self.protocol_factory is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('unable to listen(); no protocol_factory')
 * 
 */
  __pyx_t_3 = (__pyx_v_self->protocol_factory == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/streamserver.pyx":41
 * 
 *         if self.protocol_factory is None:
 *             raise RuntimeError('unable to listen(); no protocol_factory')             # <<<<<<<<<<<<<<
 * 
 *         if self.opened != 1:
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__186, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(19, 41, __pyx_L1_error)

    /* "uvloop/handles/streamserver.pyx":40
 *                 type(backlog).__name__))
 * 
 *         if self.protocol_factory is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('unable to listen(); no protocol_factory')
 * 
 */
  }

  /* "uvloop/handles/streamserver.pyx":43
 *             raise RuntimeError('unable to listen(); no protocol_factory')
 * 
 *         if self.opened != 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('unopened TCPServer')
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->opened != 1) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/streamserver.pyx":44
 * 
 *         if self.opened != 1:
 *             raise RuntimeError('unopened TCPServer')             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_listen(<uv.uv_stream_t*> self._handle,
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__187, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(19, 44, __pyx_L1_error)

    /* "uvloop/handles/streamserver.pyx":43
 *             raise RuntimeError('unable to listen(); no protocol_factory')
 * 
 *         if self.opened != 1:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('unopened TCPServer')
 * 
 */
  }

  /* "uvloop/handles/streamserver.pyx":47
 * 
 *         err = uv.uv_listen(<uv.uv_stream_t*> self._handle,
 *                            backlog,             # <<<<<<<<<<<<<<
 *                            __uv_streamserver_on_listen)
 *         if err < 0:
 */
  __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_backlog); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(19, 47, __pyx_L1_error)

  /* "uvloop/handles/streamserver.pyx":46
 *             raise RuntimeError('unopened TCPServer')
 * 
 *         err = uv.uv_listen(<uv.uv_stream_t*> self._handle,             # <<<<<<<<<<<<<<
 *                            backlog,
 *                            __uv_streamserver_on_listen)
 */
  __pyx_v_err = uv_listen(((uv_stream_t *)__pyx_v_self->__pyx_base.__pyx_base._handle), __pyx_t_8, __pyx_f_6uvloop_4loop___uv_streamserver_on_listen);

  /* "uvloop/handles/streamserver.pyx":49
 *                            backlog,
 *                            __uv_streamserver_on_listen)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/streamserver.pyx":50
 *                            __uv_streamserver_on_listen)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_4 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_exc = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "uvloop/handles/streamserver.pyx":51
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(19, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/streamserver.pyx":52
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _on_listen(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/streamserver.pyx":49
 *                            backlog,
 *                            __uv_streamserver_on_listen)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/streamserver.pyx":31
 *         self._server = server
 * 
 *     cdef inline listen(self, backlog):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer.listen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":54
 *             return
 * 
 *     cdef inline _on_listen(self):             # <<<<<<<<<<<<<<
 *         cdef UVStream client
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__on_listen(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self) {
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_client = 0;
  PyObject *__pyx_v_protocol = NULL;
  PyObject *__pyx_v_waiter = NULL;
  PyObject *__pyx_v_ssl_protocol = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("_on_listen", 0);

  /* "uvloop/handles/streamserver.pyx":57
 *         cdef UVStream client
 * 
 *         protocol = self.protocol_factory()             # <<<<<<<<<<<<<<
 * 
 *         if self.ssl is None:
 */
  __Pyx_INCREF(__pyx_v_self->protocol_factory);
  __pyx_t_2 = __pyx_v_self->protocol_factory; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 57, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 57, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_protocol = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/streamserver.pyx":59
 *         protocol = self.protocol_factory()
 * 
 *         if self.ssl is None:             # <<<<<<<<<<<<<<
 *             client = self._make_new_transport(protocol, None)
 * 
 */
  __pyx_t_4 = (__pyx_v_self->ssl == Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "uvloop/handles/streamserver.pyx":60
 * 
 *         if self.ssl is None:
 *             client = self._make_new_transport(protocol, None)             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_make_new_transport(__pyx_v_self, __pyx_v_protocol, Py_None)); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_client = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "uvloop/handles/streamserver.pyx":59
 *         protocol = self.protocol_factory()
 * 
 *         if self.ssl is None:             # <<<<<<<<<<<<<<
 *             client = self._make_new_transport(protocol, None)
 * 
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/streamserver.pyx":63
 * 
 *         else:
 *             waiter = self._loop._new_future()             # <<<<<<<<<<<<<<
 * 
 *             ssl_protocol = SSLProtocol(
 */
  /*else*/ {
    __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self->__pyx_base.__pyx_base._loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 63, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_waiter = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/streamserver.pyx":65
 *             waiter = self._loop._new_future()
 * 
 *             ssl_protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self._loop, protocol, self.ssl,
 *                 waiter,
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_SSLProtocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "uvloop/handles/streamserver.pyx":67
 *             ssl_protocol = SSLProtocol(
 *                 self._loop, protocol, self.ssl,
 *                 waiter,             # <<<<<<<<<<<<<<
 *                 server_side=True,
 *                 server_hostname=None,
 */
    __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop));
    __Pyx_INCREF(__pyx_v_protocol);
    __Pyx_GIVEREF(__pyx_v_protocol);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_protocol);
    __Pyx_INCREF(__pyx_v_self->ssl);
    __Pyx_GIVEREF(__pyx_v_self->ssl);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_self->ssl);
    __Pyx_INCREF(__pyx_v_waiter);
    __Pyx_GIVEREF(__pyx_v_waiter);
    PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_waiter);

    /* "uvloop/handles/streamserver.pyx":68
 *                 self._loop, protocol, self.ssl,
 *                 waiter,
 *                 server_side=True,             # <<<<<<<<<<<<<<
 *                 server_hostname=None,
 *                 ssl_handshake_timeout=self.ssl_handshake_timeout)
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 68, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_server_side, Py_True) < 0) __PYX_ERR(19, 68, __pyx_L1_error)

    /* "uvloop/handles/streamserver.pyx":69
 *                 waiter,
 *                 server_side=True,
 *                 server_hostname=None,             # <<<<<<<<<<<<<<
 *                 ssl_handshake_timeout=self.ssl_handshake_timeout)
 * 
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_server_hostname, Py_None) < 0) __PYX_ERR(19, 68, __pyx_L1_error)

    /* "uvloop/handles/streamserver.pyx":70
 *                 server_side=True,
 *                 server_hostname=None,
 *                 ssl_handshake_timeout=self.ssl_handshake_timeout)             # <<<<<<<<<<<<<<
 * 
 *             client = self._make_new_transport(ssl_protocol, None)
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ssl_handshake_timeout, __pyx_v_self->ssl_handshake_timeout) < 0) __PYX_ERR(19, 68, __pyx_L1_error)

    /* "uvloop/handles/streamserver.pyx":65
 *             waiter = self._loop._new_future()
 * 
 *             ssl_protocol = SSLProtocol(             # <<<<<<<<<<<<<<
 *                 self._loop, protocol, self.ssl,
 *                 waiter,
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_ssl_protocol = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "uvloop/handles/streamserver.pyx":72
 *                 ssl_handshake_timeout=self.ssl_handshake_timeout)
 * 
 *             client = self._make_new_transport(ssl_protocol, None)             # <<<<<<<<<<<<<<
 * 
 *             waiter.add_done_callback(
 */
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_make_new_transport(__pyx_v_self, __pyx_v_ssl_protocol, Py_None)); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_client = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/handles/streamserver.pyx":74
 *             client = self._make_new_transport(ssl_protocol, None)
 * 
 *             waiter.add_done_callback(             # <<<<<<<<<<<<<<
 *                 ft_partial(self.__on_ssl_connected, client))
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_add_done_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/handles/streamserver.pyx":75
 * 
 *             waiter.add_done_callback(
 *                 ft_partial(self.__on_ssl_connected, client))             # <<<<<<<<<<<<<<
 * 
 *         client._accept(<UVStream>self)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_on_ssl_connected); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 75, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_ft_partial);
    __pyx_t_7 = __pyx_v_6uvloop_4loop_ft_partial; __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_9 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_1, ((PyObject *)__pyx_v_client)};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 75, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_1, ((PyObject *)__pyx_v_client)};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 75, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(19, 75, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_t_1);
      __Pyx_INCREF(((PyObject *)__pyx_v_client));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_client));
      PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, ((PyObject *)__pyx_v_client));
      __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 75, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 74, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 74, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_2};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 74, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(19, 74, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 74, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/streamserver.pyx":77
 *                 ft_partial(self.__on_ssl_connected, client))
 * 
 *         client._accept(<UVStream>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):
 */
  __pyx_t_6 = __pyx_f_6uvloop_4loop_8UVStream__accept(__pyx_v_client, ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self)); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/handles/streamserver.pyx":54
 *             return
 * 
 *     cdef inline _on_listen(self):             # <<<<<<<<<<<<<<
 *         cdef UVStream client
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer._on_listen", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_client);
  __Pyx_XDECREF(__pyx_v_protocol);
  __Pyx_XDECREF(__pyx_v_waiter);
  __Pyx_XDECREF(__pyx_v_ssl_protocol);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":79
 *         client._accept(<UVStream>self)
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         # Overload UVHandle._fatal_error
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__fatal_error(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_throw, struct __pyx_opt_args_6uvloop_4loop_14UVStreamServer__fatal_error *__pyx_optional_args) {
  PyObject *__pyx_v_reason = ((PyObject *)Py_None);
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("_fatal_error", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_reason = __pyx_optional_args->reason;
    }
  }

  /* "uvloop/handles/streamserver.pyx":82
 *         # Overload UVHandle._fatal_error
 * 
 *         self._close()             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(exc, (BrokenPipeError,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/streamserver.pyx":84
 *         self._close()
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_BrokenPipeError); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/handles/streamserver.pyx":85
 * 
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,             # <<<<<<<<<<<<<<
 *                                 ConnectionAbortedError)):
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionResetError); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/handles/streamserver.pyx":86
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):             # <<<<<<<<<<<<<<
 * 
 *             if throw or self._loop is None:
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionAbortedError); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/handles/streamserver.pyx":84
 *         self._close()
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_1); 
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }

  /* "uvloop/handles/streamserver.pyx":85
 * 
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,             # <<<<<<<<<<<<<<
 *                                 ConnectionAbortedError)):
 * 
 */
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_2); 
  __pyx_t_5 = (__pyx_t_6 != 0);
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }

  /* "uvloop/handles/streamserver.pyx":86
 *         if not isinstance(exc, (BrokenPipeError,
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):             # <<<<<<<<<<<<<<
 * 
 *             if throw or self._loop is None:
 */
  __pyx_t_5 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_3); 
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_4 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/streamserver.pyx":84
 *         self._close()
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  __pyx_t_6 = ((!(__pyx_t_4 != 0)) != 0);
  if (__pyx_t_6) {

    /* "uvloop/handles/streamserver.pyx":88
 *                                 ConnectionAbortedError)):
 * 
 *             if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_throw); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(19, 88, __pyx_L1_error)
    if (!__pyx_t_4) {
    } else {
      __pyx_t_6 = __pyx_t_4;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_4 = (((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop) == Py_None);
    __pyx_t_5 = (__pyx_t_4 != 0);
    __pyx_t_6 = __pyx_t_5;
    __pyx_L8_bool_binop_done:;
    if (unlikely(__pyx_t_6)) {

      /* "uvloop/handles/streamserver.pyx":89
 * 
 *             if throw or self._loop is None:
 *                 raise exc             # <<<<<<<<<<<<<<
 * 
 *             msg = 'Fatal error on server {}'.format(
 */
      __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
      __PYX_ERR(19, 89, __pyx_L1_error)

      /* "uvloop/handles/streamserver.pyx":88
 *                                 ConnectionAbortedError)):
 * 
 *             if throw or self._loop is None:             # <<<<<<<<<<<<<<
 *                 raise exc
 * 
 */
    }

    /* "uvloop/handles/streamserver.pyx":91
 *                 raise exc
 * 
 *             msg = 'Fatal error on server {}'.format(             # <<<<<<<<<<<<<<
 *                     self.__class__.__name__)
 *             if reason is not None:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Fatal_error_on_server, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "uvloop/handles/streamserver.pyx":92
 * 
 *             msg = 'Fatal error on server {}'.format(
 *                     self.__class__.__name__)             # <<<<<<<<<<<<<<
 *             if reason is not None:
 *                 msg = '{} ({})'.format(msg, reason)
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(19, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 91, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 91, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 91, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(19, 91, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 91, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_msg = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/streamserver.pyx":93
 *             msg = 'Fatal error on server {}'.format(
 *                     self.__class__.__name__)
 *             if reason is not None:             # <<<<<<<<<<<<<<
 *                 msg = '{} ({})'.format(msg, reason)
 * 
 */
    __pyx_t_6 = (__pyx_v_reason != Py_None);
    __pyx_t_5 = (__pyx_t_6 != 0);
    if (__pyx_t_5) {

      /* "uvloop/handles/streamserver.pyx":94
 *                     self.__class__.__name__)
 *             if reason is not None:
 *                 msg = '{} ({})'.format(msg, reason)             # <<<<<<<<<<<<<<
 * 
 *             self._loop.call_exception_handler({
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u__159, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 94, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_msg, __pyx_v_reason};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 94, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_msg, __pyx_v_reason};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 94, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(19, 94, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_v_msg);
        __Pyx_GIVEREF(__pyx_v_msg);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_9, __pyx_v_msg);
        __Pyx_INCREF(__pyx_v_reason);
        __Pyx_GIVEREF(__pyx_v_reason);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_9, __pyx_v_reason);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 94, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_msg, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "uvloop/handles/streamserver.pyx":93
 *             msg = 'Fatal error on server {}'.format(
 *                     self.__class__.__name__)
 *             if reason is not None:             # <<<<<<<<<<<<<<
 *                 msg = '{} ({})'.format(msg, reason)
 * 
 */
    }

    /* "uvloop/handles/streamserver.pyx":96
 *                 msg = '{} ({})'.format(msg, reason)
 * 
 *             self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                 'message': msg,
 *                 'exception': exc,
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 96, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "uvloop/handles/streamserver.pyx":97
 * 
 *             self._loop.call_exception_handler({
 *                 'message': msg,             # <<<<<<<<<<<<<<
 *                 'exception': exc,
 *             })
 */
    __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(19, 97, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_message, __pyx_v_msg) < 0) __PYX_ERR(19, 97, __pyx_L1_error)

    /* "uvloop/handles/streamserver.pyx":98
 *             self._loop.call_exception_handler({
 *                 'message': msg,
 *                 'exception': exc,             # <<<<<<<<<<<<<<
 *             })
 * 
 */
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_exception, __pyx_v_exc) < 0) __PYX_ERR(19, 97, __pyx_L1_error)
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 96, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 96, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 96, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_3 = PyTuple_New(1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(19, 96, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_3, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 96, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/streamserver.pyx":84
 *         self._close()
 * 
 *         if not isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                                 ConnectionResetError,
 *                                 ConnectionAbortedError)):
 */
  }

  /* "uvloop/handles/streamserver.pyx":79
 *         client._accept(<UVStream>self)
 * 
 *     cdef _fatal_error(self, exc, throw, reason=None):             # <<<<<<<<<<<<<<
 *         # Overload UVHandle._fatal_error
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":101
 *             })
 * 
 *     cdef inline _mark_as_open(self):             # <<<<<<<<<<<<<<
 *         self.opened = 1
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_6uvloop_4loop_14UVStreamServer__mark_as_open(struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_mark_as_open", 0);

  /* "uvloop/handles/streamserver.pyx":102
 * 
 *     cdef inline _mark_as_open(self):
 *         self.opened = 1             # <<<<<<<<<<<<<<
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):
 */
  __pyx_v_self->opened = 1;

  /* "uvloop/handles/streamserver.pyx":101
 *             })
 * 
 *     cdef inline _mark_as_open(self):             # <<<<<<<<<<<<<<
 *         self.opened = 1
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":104
 *         self.opened = 1
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

static struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_f_6uvloop_4loop_14UVStreamServer__make_new_transport(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_protocol, CYTHON_UNUSED PyObject *__pyx_v_waiter) {
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_make_new_transport", 0);

  /* "uvloop/handles/streamserver.pyx":105
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def __on_ssl_connected(self, transport, fut):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(19, 105, __pyx_L1_error)

  /* "uvloop/handles/streamserver.pyx":104
 *         self.opened = 1
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer._make_new_transport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":107
 *         raise NotImplementedError
 * 
 *     def __on_ssl_connected(self, transport, fut):             # <<<<<<<<<<<<<<
 *         exc = fut.exception()
 *         if exc is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_14UVStreamServer_3__on_ssl_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_14UVStreamServer_2__on_ssl_connected[] = "UVStreamServer.__on_ssl_connected(self, transport, fut)";
static PyObject *__pyx_pw_6uvloop_4loop_14UVStreamServer_3__on_ssl_connected(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_transport = 0;
  PyObject *__pyx_v_fut = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__on_ssl_connected (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_transport,&__pyx_n_s_fut,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_transport)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fut)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__on_ssl_connected", 1, 2, 2, 1); __PYX_ERR(19, 107, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__on_ssl_connected") < 0)) __PYX_ERR(19, 107, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_transport = values[0];
    __pyx_v_fut = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__on_ssl_connected", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(19, 107, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer.__on_ssl_connected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_14UVStreamServer_2__on_ssl_connected(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self), __pyx_v_transport, __pyx_v_fut);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_14UVStreamServer_2__on_ssl_connected(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, PyObject *__pyx_v_transport, PyObject *__pyx_v_fut) {
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__on_ssl_connected", 0);

  /* "uvloop/handles/streamserver.pyx":108
 * 
 *     def __on_ssl_connected(self, transport, fut):
 *         exc = fut.exception()             # <<<<<<<<<<<<<<
 *         if exc is not None:
 *             transport._force_close(exc)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 108, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 108, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_exc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/streamserver.pyx":109
 *     def __on_ssl_connected(self, transport, fut):
 *         exc = fut.exception()
 *         if exc is not None:             # <<<<<<<<<<<<<<
 *             transport._force_close(exc)
 * 
 */
  __pyx_t_4 = (__pyx_v_exc != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "uvloop/handles/streamserver.pyx":110
 *         exc = fut.exception()
 *         if exc is not None:
 *             transport._force_close(exc)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_transport, __pyx_n_s_force_close); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 110, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 110, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 110, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(19, 110, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_exc);
        __Pyx_GIVEREF(__pyx_v_exc);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_exc);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 110, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/streamserver.pyx":109
 *     def __on_ssl_connected(self, transport, fut):
 *         exc = fut.exception()
 *         if exc is not None:             # <<<<<<<<<<<<<<
 *             transport._force_close(exc)
 * 
 */
  }

  /* "uvloop/handles/streamserver.pyx":107
 *         raise NotImplementedError
 * 
 *     def __on_ssl_connected(self, transport, fut):             # <<<<<<<<<<<<<<
 *         exc = fut.exception()
 *         if exc is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer.__on_ssl_connected", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_14UVStreamServer_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_14UVStreamServer_4__reduce_cython__[] = "UVStreamServer.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_14UVStreamServer_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_14UVStreamServer_4__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_14UVStreamServer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__188, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_14UVStreamServer_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_14UVStreamServer_6__setstate_cython__[] = "UVStreamServer.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_14UVStreamServer_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_14UVStreamServer_6__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_14UVStreamServer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__189, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVStreamServer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/streamserver.pyx":113
 * 
 * 
 * cdef void __uv_streamserver_on_listen(uv.uv_stream_t* handle,             # <<<<<<<<<<<<<<
 *                                       int status) with gil:
 * 
 */

static void __pyx_f_6uvloop_4loop___uv_streamserver_on_listen(uv_stream_t *__pyx_v_handle, int __pyx_v_status) {
  struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_stream = 0;
  PyObject *__pyx_v_exc = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_t_3 = NULL;
  struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  char const *__pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uv_streamserver_on_listen", 0);

  /* "uvloop/handles/streamserver.pyx":119
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,
 *                             "UVStream listen callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_handle), ((char const *)"UVStream listen callback")) == 0) != 0);

  /* "uvloop/handles/streamserver.pyx":118
 *     # callback for uv_listen
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,             # <<<<<<<<<<<<<<
 *                             "UVStream listen callback") == 0:
 *         return
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/streamserver.pyx":120
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,
 *                             "UVStream listen callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/handles/streamserver.pyx":118
 *     # callback for uv_listen
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,             # <<<<<<<<<<<<<<
 *                             "UVStream listen callback") == 0:
 *         return
 */
  }

  /* "uvloop/handles/streamserver.pyx":123
 * 
 *     cdef:
 *         UVStreamServer stream = <UVStreamServer> handle.data             # <<<<<<<<<<<<<<
 * 
 *     if status < 0:
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_stream = ((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/streamserver.pyx":125
 *         UVStreamServer stream = <UVStreamServer> handle.data
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_listen_errors_total += 1
 */
  __pyx_t_1 = ((__pyx_v_status < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/streamserver.pyx":126
 * 
 *     if status < 0:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_listen_errors_total += 1
 * 
 */
    __pyx_t_1 = (UVLOOP_DEBUG != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/streamserver.pyx":127
 *     if status < 0:
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_listen_errors_total += 1             # <<<<<<<<<<<<<<
 * 
 *         exc = convert_error(status)
 */
      __Pyx_INCREF(((PyObject *)__pyx_v_stream->__pyx_base.__pyx_base._loop));
      __pyx_t_3 = __pyx_v_stream->__pyx_base.__pyx_base._loop;
      __pyx_t_3->_debug_stream_listen_errors_total = (__pyx_t_3->_debug_stream_listen_errors_total + 1);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;

      /* "uvloop/handles/streamserver.pyx":126
 * 
 *     if status < 0:
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             stream._loop._debug_stream_listen_errors_total += 1
 * 
 */
    }

    /* "uvloop/handles/streamserver.pyx":129
 *             stream._loop._debug_stream_listen_errors_total += 1
 * 
 *         exc = convert_error(status)             # <<<<<<<<<<<<<<
 *         stream._fatal_error(exc, False,
 *             "error status in uv_stream_t.listen callback")
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/streamserver.pyx":130
 * 
 *         exc = convert_error(status)
 *         stream._fatal_error(exc, False,             # <<<<<<<<<<<<<<
 *             "error status in uv_stream_t.listen callback")
 *         return
 */
    __pyx_t_4.__pyx_n = 1;
    __pyx_t_4.reason = __pyx_kp_u_error_status_in_uv_stream_t_list;
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_stream), __pyx_v_exc, Py_False, &__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/streamserver.pyx":132
 *         stream._fatal_error(exc, False,
 *             "error status in uv_stream_t.listen callback")
 *         return             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    goto __pyx_L0;

    /* "uvloop/handles/streamserver.pyx":125
 *         UVStreamServer stream = <UVStreamServer> handle.data
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             stream._loop._debug_stream_listen_errors_total += 1
 */
  }

  /* "uvloop/handles/streamserver.pyx":134
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         stream._on_listen()
 *     except BaseException as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    /*try:*/ {

      /* "uvloop/handles/streamserver.pyx":135
 * 
 *     try:
 *         stream._on_listen()             # <<<<<<<<<<<<<<
 *     except BaseException as exc:
 *         stream._error(exc, False)
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_14UVStreamServer__on_listen(__pyx_v_stream); if (unlikely(!__pyx_t_2)) __PYX_ERR(19, 135, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/streamserver.pyx":134
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         stream._on_listen()
 *     except BaseException as exc:
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/streamserver.pyx":136
 *     try:
 *         stream._on_listen()
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         stream._error(exc, False)
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_8) {
      __Pyx_AddTraceback("uvloop.loop.__uv_streamserver_on_listen", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_9, &__pyx_t_10) < 0) __PYX_ERR(19, 136, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __pyx_v_exc = __pyx_t_9;
      /*try:*/ {

        /* "uvloop/handles/streamserver.pyx":137
 *         stream._on_listen()
 *     except BaseException as exc:
 *         stream._error(exc, False)             # <<<<<<<<<<<<<<
 */
        __pyx_t_11 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)__pyx_v_stream->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_stream), __pyx_v_exc, Py_False); if (unlikely(!__pyx_t_11)) __PYX_ERR(19, 137, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }

      /* "uvloop/handles/streamserver.pyx":136
 *     try:
 *         stream._on_listen()
 *     except BaseException as exc:             # <<<<<<<<<<<<<<
 *         stream._error(exc, False)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L18;
        }
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __Pyx_XDECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __pyx_t_8 = __pyx_lineno; __pyx_t_12 = __pyx_clineno; __pyx_t_13 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          }
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_ErrRestore(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0;
          __pyx_lineno = __pyx_t_8; __pyx_clineno = __pyx_t_12; __pyx_filename = __pyx_t_13;
          goto __pyx_L8_except_error;
        }
        __pyx_L18:;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/handles/streamserver.pyx":134
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         stream._on_listen()
 *     except BaseException as exc:
 */
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    goto __pyx_L1_error;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
    __pyx_L11_try_end:;
  }

  /* "uvloop/handles/streamserver.pyx":113
 * 
 * 
 * cdef void __uv_streamserver_on_listen(uv.uv_stream_t* handle,             # <<<<<<<<<<<<<<
 *                                       int status) with gil:
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(((PyObject *)__pyx_t_3));
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_WriteUnraisable("uvloop.loop.__uv_streamserver_on_listen", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_stream);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/tcp.pyx":1
 * cdef __tcp_init_uv_handle(UVStream handle, Loop loop, unsigned int flags):             # <<<<<<<<<<<<<<
 *     cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop___tcp_init_uv_handle(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_handle, CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, unsigned int __pyx_v_flags) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__tcp_init_uv_handle", 0);

  /* "uvloop/handles/tcp.pyx":4
 *     cdef int err
 * 
 *     handle._handle = <uv.uv_handle_t*> \             # <<<<<<<<<<<<<<
 *                         PyMem_RawMalloc(sizeof(uv.uv_tcp_t))
 *     if handle._handle is NULL:
 */
  __pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_tcp_t))));

  /* "uvloop/handles/tcp.pyx":6
 *     handle._handle = <uv.uv_handle_t*> \
 *                         PyMem_RawMalloc(sizeof(uv.uv_tcp_t))
 *     if handle._handle is NULL:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise MemoryError()
 */
  __pyx_t_1 = ((__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/tcp.pyx":7
 *                         PyMem_RawMalloc(sizeof(uv.uv_tcp_t))
 *     if handle._handle is NULL:
 *         handle._abort_init()             # <<<<<<<<<<<<<<
 *         raise MemoryError()
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_handle)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/tcp.pyx":8
 *     if handle._handle is NULL:
 *         handle._abort_init()
 *         raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *     err = uv.uv_tcp_init_ex(handle._loop.uvloop,
 */
    PyErr_NoMemory(); __PYX_ERR(5, 8, __pyx_L1_error)

    /* "uvloop/handles/tcp.pyx":6
 *     handle._handle = <uv.uv_handle_t*> \
 *                         PyMem_RawMalloc(sizeof(uv.uv_tcp_t))
 *     if handle._handle is NULL:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise MemoryError()
 */
  }

  /* "uvloop/handles/tcp.pyx":10
 *         raise MemoryError()
 * 
 *     err = uv.uv_tcp_init_ex(handle._loop.uvloop,             # <<<<<<<<<<<<<<
 *                             <uv.uv_tcp_t*>handle._handle,
 *                             flags)
 */
  __pyx_v_err = uv_tcp_init_ex(__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._loop->uvloop, ((uv_tcp_t *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_v_flags);

  /* "uvloop/handles/tcp.pyx":13
 *                             <uv.uv_tcp_t*>handle._handle,
 *                             flags)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise convert_error(err)
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/tcp.pyx":14
 *                             flags)
 *     if err < 0:
 *         handle._abort_init()             # <<<<<<<<<<<<<<
 *         raise convert_error(err)
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_handle)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/tcp.pyx":15
 *     if err < 0:
 *         handle._abort_init()
 *         raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *     handle._finish_init()
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 15, __pyx_L1_error)

    /* "uvloop/handles/tcp.pyx":13
 *                             <uv.uv_tcp_t*>handle._handle,
 *                             flags)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise convert_error(err)
 */
  }

  /* "uvloop/handles/tcp.pyx":17
 *         raise convert_error(err)
 * 
 *     handle._finish_init()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_handle)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/tcp.pyx":1
 * cdef __tcp_init_uv_handle(UVStream handle, Loop loop, unsigned int flags):             # <<<<<<<<<<<<<<
 *     cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__tcp_init_uv_handle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":20
 * 
 * 
 * cdef __tcp_bind(UVStream handle, system.sockaddr* addr, unsigned int flags):             # <<<<<<<<<<<<<<
 *     cdef int err
 *     err = uv.uv_tcp_bind(<uv.uv_tcp_t *>handle._handle,
 */

static PyObject *__pyx_f_6uvloop_4loop___tcp_bind(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_handle, struct sockaddr *__pyx_v_addr, unsigned int __pyx_v_flags) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__tcp_bind", 0);

  /* "uvloop/handles/tcp.pyx":22
 * cdef __tcp_bind(UVStream handle, system.sockaddr* addr, unsigned int flags):
 *     cdef int err
 *     err = uv.uv_tcp_bind(<uv.uv_tcp_t *>handle._handle,             # <<<<<<<<<<<<<<
 *                          addr, flags)
 *     if err < 0:
 */
  __pyx_v_err = uv_tcp_bind(((uv_tcp_t *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_v_addr, __pyx_v_flags);

  /* "uvloop/handles/tcp.pyx":24
 *     err = uv.uv_tcp_bind(<uv.uv_tcp_t *>handle._handle,
 *                          addr, flags)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(err)
 *         raise exc
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/tcp.pyx":25
 *                          addr, flags)
 *     if err < 0:
 *         exc = convert_error(err)             # <<<<<<<<<<<<<<
 *         raise exc
 * 
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 25, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/tcp.pyx":26
 *     if err < 0:
 *         exc = convert_error(err)
 *         raise exc             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(5, 26, __pyx_L1_error)

    /* "uvloop/handles/tcp.pyx":24
 *     err = uv.uv_tcp_bind(<uv.uv_tcp_t *>handle._handle,
 *                          addr, flags)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(err)
 *         raise exc
 */
  }

  /* "uvloop/handles/tcp.pyx":20
 * 
 * 
 * cdef __tcp_bind(UVStream handle, system.sockaddr* addr, unsigned int flags):             # <<<<<<<<<<<<<<
 *     cdef int err
 *     err = uv.uv_tcp_bind(<uv.uv_tcp_t *>handle._handle,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__tcp_bind", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":29
 * 
 * 
 * cdef __tcp_open(UVStream handle, int sockfd):             # <<<<<<<<<<<<<<
 *     cdef int err
 *     err = uv.uv_tcp_open(<uv.uv_tcp_t *>handle._handle,
 */

static PyObject *__pyx_f_6uvloop_4loop___tcp_open(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_handle, int __pyx_v_sockfd) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__tcp_open", 0);

  /* "uvloop/handles/tcp.pyx":31
 * cdef __tcp_open(UVStream handle, int sockfd):
 *     cdef int err
 *     err = uv.uv_tcp_open(<uv.uv_tcp_t *>handle._handle,             # <<<<<<<<<<<<<<
 *                          <uv.uv_os_sock_t>sockfd)
 *     if err < 0:
 */
  __pyx_v_err = uv_tcp_open(((uv_tcp_t *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle), ((uv_os_sock_t)__pyx_v_sockfd));

  /* "uvloop/handles/tcp.pyx":33
 *     err = uv.uv_tcp_open(<uv.uv_tcp_t *>handle._handle,
 *                          <uv.uv_os_sock_t>sockfd)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(err)
 *         raise exc
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/tcp.pyx":34
 *                          <uv.uv_os_sock_t>sockfd)
 *     if err < 0:
 *         exc = convert_error(err)             # <<<<<<<<<<<<<<
 *         raise exc
 * 
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 34, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/tcp.pyx":35
 *     if err < 0:
 *         exc = convert_error(err)
 *         raise exc             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(5, 35, __pyx_L1_error)

    /* "uvloop/handles/tcp.pyx":33
 *     err = uv.uv_tcp_open(<uv.uv_tcp_t *>handle._handle,
 *                          <uv.uv_os_sock_t>sockfd)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(err)
 *         raise exc
 */
  }

  /* "uvloop/handles/tcp.pyx":29
 * 
 * 
 * cdef __tcp_open(UVStream handle, int sockfd):             # <<<<<<<<<<<<<<
 *     cdef int err
 *     err = uv.uv_tcp_open(<uv.uv_tcp_t *>handle._handle,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__tcp_open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":38
 * 
 * 
 * cdef __tcp_get_socket(UVSocketHandle handle):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int buf_len = sizeof(system.sockaddr_storage)
 */

static PyObject *__pyx_f_6uvloop_4loop___tcp_get_socket(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_handle) {
  int __pyx_v_buf_len;
  int __pyx_v_fileno;
  int __pyx_v_err;
  struct sockaddr_storage __pyx_v_buf;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__tcp_get_socket", 0);

  /* "uvloop/handles/tcp.pyx":40
 * cdef __tcp_get_socket(UVSocketHandle handle):
 *     cdef:
 *         int buf_len = sizeof(system.sockaddr_storage)             # <<<<<<<<<<<<<<
 *         int fileno
 *         int err
 */
  __pyx_v_buf_len = (sizeof(struct sockaddr_storage));

  /* "uvloop/handles/tcp.pyx":45
 *         system.sockaddr_storage buf
 * 
 *     fileno = handle._fileno()             # <<<<<<<<<<<<<<
 * 
 *     err = uv.uv_tcp_getsockname(<uv.uv_tcp_t*>handle._handle,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle *)__pyx_v_handle->__pyx_base.__pyx_vtab)->_fileno(__pyx_v_handle); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_fileno = __pyx_t_2;

  /* "uvloop/handles/tcp.pyx":47
 *     fileno = handle._fileno()
 * 
 *     err = uv.uv_tcp_getsockname(<uv.uv_tcp_t*>handle._handle,             # <<<<<<<<<<<<<<
 *                                 <system.sockaddr*>&buf,
 *                                 &buf_len)
 */
  __pyx_v_err = uv_tcp_getsockname(((uv_tcp_t *)__pyx_v_handle->__pyx_base._handle), ((struct sockaddr *)(&__pyx_v_buf)), (&__pyx_v_buf_len));

  /* "uvloop/handles/tcp.pyx":50
 *                                 <system.sockaddr*>&buf,
 *                                 &buf_len)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         raise convert_error(err)
 * 
 */
  __pyx_t_3 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_3)) {

    /* "uvloop/handles/tcp.pyx":51
 *                                 &buf_len)
 *     if err < 0:
 *         raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *     return PseudoSocket(buf.ss_family, uv.SOCK_STREAM, 0, fileno)
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 51, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(5, 51, __pyx_L1_error)

    /* "uvloop/handles/tcp.pyx":50
 *                                 <system.sockaddr*>&buf,
 *                                 &buf_len)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         raise convert_error(err)
 * 
 */
  }

  /* "uvloop/handles/tcp.pyx":53
 *         raise convert_error(err)
 * 
 *     return PseudoSocket(buf.ss_family, uv.SOCK_STREAM, 0, fileno)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_unsigned_short(__pyx_v_buf.ss_family); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyInt_From_int(SOCK_STREAM); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_fileno); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5);
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop_PseudoSocket), __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/tcp.pyx":38
 * 
 * 
 * cdef __tcp_get_socket(UVSocketHandle handle):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int buf_len = sizeof(system.sockaddr_storage)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.__tcp_get_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":60
 * 
 *     @staticmethod
 *     cdef TCPServer new(Loop loop, object protocol_factory, Server server,             # <<<<<<<<<<<<<<
 *                        object ssl, unsigned int flags,
 *                        object ssl_handshake_timeout):
 */

static struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_f_6uvloop_4loop_9TCPServer_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, unsigned int __pyx_v_flags, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/tcp.pyx":65
 * 
 *         cdef TCPServer handle
 *         handle = TCPServer.__new__(TCPServer)             # <<<<<<<<<<<<<<
 *         handle._init(loop, protocol_factory, server,
 *                      ssl, ssl_handshake_timeout)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_TCPServer(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_TCPServer), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 65, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_TCPServer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":66
 *         cdef TCPServer handle
 *         handle = TCPServer.__new__(TCPServer)
 *         handle._init(loop, protocol_factory, server,             # <<<<<<<<<<<<<<
 *                      ssl, ssl_handshake_timeout)
 *         __tcp_init_uv_handle(<UVStream>handle, loop, flags)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_handle), __pyx_v_loop, __pyx_v_protocol_factory, __pyx_v_server, __pyx_v_ssl, __pyx_v_ssl_handshake_timeout); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":68
 *         handle._init(loop, protocol_factory, server,
 *                      ssl, ssl_handshake_timeout)
 *         __tcp_init_uv_handle(<UVStream>handle, loop, flags)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_init_uv_handle(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop, __pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":69
 *                      ssl, ssl_handshake_timeout)
 *         __tcp_init_uv_handle(<UVStream>handle, loop, flags)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/tcp.pyx":60
 * 
 *     @staticmethod
 *     cdef TCPServer new(Loop loop, object protocol_factory, Server server,             # <<<<<<<<<<<<<<
 *                        object ssl, unsigned int flags,
 *                        object ssl_handshake_timeout):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPServer.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":71
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_9TCPServer__new_socket(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/tcp.pyx":72
 * 
 *     cdef _new_socket(self):
 *         return __tcp_get_socket(<UVSocketHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _open(self, int sockfd):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/tcp.pyx":71
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPServer._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":74
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         try:
 */

static PyObject *__pyx_f_6uvloop_4loop_9TCPServer__open(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, int __pyx_v_sockfd) {
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  char const *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("_open", 0);

  /* "uvloop/handles/tcp.pyx":75
 * 
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         try:
 *             __tcp_open(<UVStream>self, sockfd)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":76
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()
 *         try:             # <<<<<<<<<<<<<<
 *             __tcp_open(<UVStream>self, sockfd)
 *         except Exception as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/handles/tcp.pyx":77
 *         self._ensure_alive()
 *         try:
 *             __tcp_open(<UVStream>self, sockfd)             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             self._fatal_error(exc, True)
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_open(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_sockfd); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 77, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/tcp.pyx":76
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()
 *         try:             # <<<<<<<<<<<<<<
 *             __tcp_open(<UVStream>self, sockfd)
 *         except Exception as exc:
 */
    }

    /* "uvloop/handles/tcp.pyx":81
 *             self._fatal_error(exc, True)
 *         else:
 *             self._mark_as_open()             # <<<<<<<<<<<<<<
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 */
    /*else:*/ {
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._mark_as_open(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 81, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/tcp.pyx":78
 *         try:
 *             __tcp_open(<UVStream>self, sockfd)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *         else:
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_5) {
      __Pyx_AddTraceback("uvloop.loop.TCPServer._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(5, 78, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_exc = __pyx_t_6;
      /*try:*/ {

        /* "uvloop/handles/tcp.pyx":79
 *             __tcp_open(<UVStream>self, sockfd)
 *         except Exception as exc:
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *         else:
 *             self._mark_as_open()
 */
        __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 79, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }

      /* "uvloop/handles/tcp.pyx":78
 *         try:
 *             __tcp_open(<UVStream>self, sockfd)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *         else:
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L15;
        }
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __pyx_t_5 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_10 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          }
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ErrRestore(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
          __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_10;
          goto __pyx_L5_except_error;
        }
        __pyx_L15:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/handles/tcp.pyx":76
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()
 *         try:             # <<<<<<<<<<<<<<
 *             __tcp_open(<UVStream>self, sockfd)
 *         except Exception as exc:
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L8_try_end:;
  }

  /* "uvloop/handles/tcp.pyx":74
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.TCPServer._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":83
 *             self._mark_as_open()
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         try:
 */

static PyObject *__pyx_f_6uvloop_4loop_9TCPServer_bind(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, struct sockaddr *__pyx_v_addr, struct __pyx_opt_args_6uvloop_4loop_9TCPServer_bind *__pyx_optional_args) {
  unsigned int __pyx_v_flags = ((unsigned int)0);
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  char const *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("bind", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_flags = __pyx_optional_args->flags;
    }
  }

  /* "uvloop/handles/tcp.pyx":84
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         try:
 *             __tcp_bind(<UVStream>self, addr, flags)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":85
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 *         self._ensure_alive()
 *         try:             # <<<<<<<<<<<<<<
 *             __tcp_bind(<UVStream>self, addr, flags)
 *         except Exception as exc:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/handles/tcp.pyx":86
 *         self._ensure_alive()
 *         try:
 *             __tcp_bind(<UVStream>self, addr, flags)             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             self._fatal_error(exc, True)
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_bind(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_addr, __pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 86, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/tcp.pyx":85
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 *         self._ensure_alive()
 *         try:             # <<<<<<<<<<<<<<
 *             __tcp_bind(<UVStream>self, addr, flags)
 *         except Exception as exc:
 */
    }

    /* "uvloop/handles/tcp.pyx":90
 *             self._fatal_error(exc, True)
 *         else:
 *             self._mark_as_open()             # <<<<<<<<<<<<<<
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):
 */
    /*else:*/ {
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._mark_as_open(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 90, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/tcp.pyx":87
 *         try:
 *             __tcp_bind(<UVStream>self, addr, flags)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *         else:
 */
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_5) {
      __Pyx_AddTraceback("uvloop.loop.TCPServer.bind", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(5, 87, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_exc = __pyx_t_6;
      /*try:*/ {

        /* "uvloop/handles/tcp.pyx":88
 *             __tcp_bind(<UVStream>self, addr, flags)
 *         except Exception as exc:
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *         else:
 *             self._mark_as_open()
 */
        __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 88, __pyx_L14_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }

      /* "uvloop/handles/tcp.pyx":87
 *         try:
 *             __tcp_bind(<UVStream>self, addr, flags)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *         else:
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L15;
        }
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __pyx_t_5 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_10 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
          }
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ErrRestore(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
          __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_10;
          goto __pyx_L5_except_error;
        }
        __pyx_L15:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/handles/tcp.pyx":85
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 *         self._ensure_alive()
 *         try:             # <<<<<<<<<<<<<<
 *             __tcp_bind(<UVStream>self, addr, flags)
 *         except Exception as exc:
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L8_try_end:;
  }

  /* "uvloop/handles/tcp.pyx":83
 *             self._mark_as_open()
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.TCPServer.bind", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":92
 *             self._mark_as_open()
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):             # <<<<<<<<<<<<<<
 *         cdef TCPTransport tr
 *         tr = TCPTransport.new(self._loop, protocol, self._server, waiter)
 */

static struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_f_6uvloop_4loop_9TCPServer__make_new_transport(struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, PyObject *__pyx_v_protocol, PyObject *__pyx_v_waiter) {
  struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_tr = 0;
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_make_new_transport", 0);

  /* "uvloop/handles/tcp.pyx":94
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):
 *         cdef TCPTransport tr
 *         tr = TCPTransport.new(self._loop, protocol, self._server, waiter)             # <<<<<<<<<<<<<<
 *         return <UVStream>tr
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject *)__pyx_v_self->__pyx_base._server);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_6uvloop_4loop_12TCPTransport_new(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1), __pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_t_2), __pyx_v_waiter)); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tr = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/handles/tcp.pyx":95
 *         cdef TCPTransport tr
 *         tr = TCPTransport.new(self._loop, protocol, self._server, waiter)
 *         return <UVStream>tr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_tr)));
  __pyx_r = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_tr);
  goto __pyx_L0;

  /* "uvloop/handles/tcp.pyx":92
 *             self._mark_as_open()
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):             # <<<<<<<<<<<<<<
 *         cdef TCPTransport tr
 *         tr = TCPTransport.new(self._loop, protocol, self._server, waiter)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.TCPServer._make_new_transport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tr);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_9TCPServer_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_9TCPServer___reduce_cython__[] = "TCPServer.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_9TCPServer_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_9TCPServer___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_TCPServer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_9TCPServer___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__190, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPServer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_9TCPServer_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_9TCPServer_2__setstate_cython__[] = "TCPServer.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_9TCPServer_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_9TCPServer_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_TCPServer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_9TCPServer_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__191, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPServer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":102
 * 
 *     @staticmethod
 *     cdef TCPTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                             object waiter):
 * 
 */

static struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_f_6uvloop_4loop_12TCPTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter) {
  struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/tcp.pyx":106
 * 
 *         cdef TCPTransport handle
 *         handle = TCPTransport.__new__(TCPTransport)             # <<<<<<<<<<<<<<
 *         handle._init(loop, protocol, server, waiter)
 *         __tcp_init_uv_handle(<UVStream>handle, loop, uv.AF_UNSPEC)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_TCPTransport(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_TCPTransport), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 106, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":107
 *         cdef TCPTransport handle
 *         handle = TCPTransport.__new__(TCPTransport)
 *         handle._init(loop, protocol, server, waiter)             # <<<<<<<<<<<<<<
 *         __tcp_init_uv_handle(<UVStream>handle, loop, uv.AF_UNSPEC)
 *         handle.__peername_set = 0
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop, __pyx_v_protocol, __pyx_v_server, __pyx_v_waiter); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":108
 *         handle = TCPTransport.__new__(TCPTransport)
 *         handle._init(loop, protocol, server, waiter)
 *         __tcp_init_uv_handle(<UVStream>handle, loop, uv.AF_UNSPEC)             # <<<<<<<<<<<<<<
 *         handle.__peername_set = 0
 *         handle.__sockname_set = 0
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_init_uv_handle(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop, AF_UNSPEC); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":109
 *         handle._init(loop, protocol, server, waiter)
 *         __tcp_init_uv_handle(<UVStream>handle, loop, uv.AF_UNSPEC)
 *         handle.__peername_set = 0             # <<<<<<<<<<<<<<
 *         handle.__sockname_set = 0
 *         handle._set_nodelay()
 */
  __pyx_v_handle->__pyx___peername_set = 0;

  /* "uvloop/handles/tcp.pyx":110
 *         __tcp_init_uv_handle(<UVStream>handle, loop, uv.AF_UNSPEC)
 *         handle.__peername_set = 0
 *         handle.__sockname_set = 0             # <<<<<<<<<<<<<<
 *         handle._set_nodelay()
 *         return handle
 */
  __pyx_v_handle->__pyx___sockname_set = 0;

  /* "uvloop/handles/tcp.pyx":111
 *         handle.__peername_set = 0
 *         handle.__sockname_set = 0
 *         handle._set_nodelay()             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_set_nodelay(__pyx_v_handle); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":112
 *         handle.__sockname_set = 0
 *         handle._set_nodelay()
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef _set_nodelay(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/tcp.pyx":102
 * 
 *     @staticmethod
 *     cdef TCPTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                             object waiter):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":114
 *         return handle
 * 
 *     cdef _set_nodelay(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__set_nodelay(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_set_nodelay", 0);

  /* "uvloop/handles/tcp.pyx":116
 *     cdef _set_nodelay(self):
 *         cdef int err
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         err = uv.uv_tcp_nodelay(<uv.uv_tcp_t*>self._handle, 1);
 *         if err < 0:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":117
 *         cdef int err
 *         self._ensure_alive()
 *         err = uv.uv_tcp_nodelay(<uv.uv_tcp_t*>self._handle, 1);             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
  __pyx_v_err = uv_tcp_nodelay(((uv_tcp_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._handle), 1);

  /* "uvloop/handles/tcp.pyx":118
 *         self._ensure_alive()
 *         err = uv.uv_tcp_nodelay(<uv.uv_tcp_t*>self._handle, 1);
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/tcp.pyx":119
 *         err = uv.uv_tcp_nodelay(<uv.uv_tcp_t*>self._handle, 1);
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *     cdef _call_connection_made(self):
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(5, 119, __pyx_L1_error)

    /* "uvloop/handles/tcp.pyx":118
 *         self._ensure_alive()
 *         err = uv.uv_tcp_nodelay(<uv.uv_tcp_t*>self._handle, 1);
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  }

  /* "uvloop/handles/tcp.pyx":114
 *         return handle
 * 
 *     cdef _set_nodelay(self):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport._set_nodelay", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":121
 *             raise convert_error(err)
 * 
 *     cdef _call_connection_made(self):             # <<<<<<<<<<<<<<
 *         # asyncio saves peername & sockname when transports are instantiated,
 *         # so that they're accessible even after the transport is closed.
 */

static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__call_connection_made(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self) {
  int __pyx_v_err;
  int __pyx_v_buf_len;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_call_connection_made", 0);

  /* "uvloop/handles/tcp.pyx":131
 *             int buf_len
 * 
 *         buf_len = sizeof(system.sockaddr_storage)             # <<<<<<<<<<<<<<
 *         err = uv.uv_tcp_getsockname(<uv.uv_tcp_t*>self._handle,
 *                                     <system.sockaddr*>&self.__sockname,
 */
  __pyx_v_buf_len = (sizeof(struct sockaddr_storage));

  /* "uvloop/handles/tcp.pyx":132
 * 
 *         buf_len = sizeof(system.sockaddr_storage)
 *         err = uv.uv_tcp_getsockname(<uv.uv_tcp_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                     <system.sockaddr*>&self.__sockname,
 *                                     &buf_len)
 */
  __pyx_v_err = uv_tcp_getsockname(((uv_tcp_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._handle), ((struct sockaddr *)(&__pyx_v_self->__pyx___sockname)), (&__pyx_v_buf_len));

  /* "uvloop/handles/tcp.pyx":135
 *                                     <system.sockaddr*>&self.__sockname,
 *                                     &buf_len)
 *         if err >= 0:             # <<<<<<<<<<<<<<
 *             # Ignore errors, this is an optional thing.
 *             # If something serious is going on, the transport
 */
  __pyx_t_1 = ((__pyx_v_err >= 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/tcp.pyx":140
 *             # will crash later (in roughly the same way how
 *             # an asyncio transport would.)
 *             self.__sockname_set = 1             # <<<<<<<<<<<<<<
 * 
 *         buf_len = sizeof(system.sockaddr_storage)
 */
    __pyx_v_self->__pyx___sockname_set = 1;

    /* "uvloop/handles/tcp.pyx":135
 *                                     <system.sockaddr*>&self.__sockname,
 *                                     &buf_len)
 *         if err >= 0:             # <<<<<<<<<<<<<<
 *             # Ignore errors, this is an optional thing.
 *             # If something serious is going on, the transport
 */
  }

  /* "uvloop/handles/tcp.pyx":142
 *             self.__sockname_set = 1
 * 
 *         buf_len = sizeof(system.sockaddr_storage)             # <<<<<<<<<<<<<<
 *         err = uv.uv_tcp_getpeername(<uv.uv_tcp_t*>self._handle,
 *                                     <system.sockaddr*>&self.__peername,
 */
  __pyx_v_buf_len = (sizeof(struct sockaddr_storage));

  /* "uvloop/handles/tcp.pyx":143
 * 
 *         buf_len = sizeof(system.sockaddr_storage)
 *         err = uv.uv_tcp_getpeername(<uv.uv_tcp_t*>self._handle,             # <<<<<<<<<<<<<<
 *                                     <system.sockaddr*>&self.__peername,
 *                                     &buf_len)
 */
  __pyx_v_err = uv_tcp_getpeername(((uv_tcp_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._handle), ((struct sockaddr *)(&__pyx_v_self->__pyx___peername)), (&__pyx_v_buf_len));

  /* "uvloop/handles/tcp.pyx":146
 *                                     <system.sockaddr*>&self.__peername,
 *                                     &buf_len)
 *         if err >= 0:             # <<<<<<<<<<<<<<
 *             # Same as few lines above -- we don't really care
 *             # about error case here.
 */
  __pyx_t_1 = ((__pyx_v_err >= 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/tcp.pyx":149
 *             # Same as few lines above -- we don't really care
 *             # about error case here.
 *             self.__peername_set = 1             # <<<<<<<<<<<<<<
 * 
 *         UVBaseTransport._call_connection_made(self)
 */
    __pyx_v_self->__pyx___peername_set = 1;

    /* "uvloop/handles/tcp.pyx":146
 *                                     <system.sockaddr*>&self.__peername,
 *                                     &buf_len)
 *         if err >= 0:             # <<<<<<<<<<<<<<
 *             # Same as few lines above -- we don't really care
 *             # about error case here.
 */
  }

  /* "uvloop/handles/tcp.pyx":151
 *             self.__peername_set = 1
 * 
 *         UVBaseTransport._call_connection_made(self)             # <<<<<<<<<<<<<<
 * 
 *     def get_extra_info(self, name, default=None):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_15UVBaseTransport__call_connection_made(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/tcp.pyx":121
 *             raise convert_error(err)
 * 
 *     cdef _call_connection_made(self):             # <<<<<<<<<<<<<<
 *         # asyncio saves peername & sockname when transports are instantiated,
 *         # so that they're accessible even after the transport is closed.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport._call_connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":153
 *         UVBaseTransport._call_connection_made(self)
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if name == 'sockname':
 *             if self.__sockname_set:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12TCPTransport_1get_extra_info(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12TCPTransport_get_extra_info[] = "TCPTransport.get_extra_info(self, name, default=None)";
static PyObject *__pyx_pw_6uvloop_4loop_12TCPTransport_1get_extra_info(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_extra_info (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name_2,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_extra_info") < 0)) __PYX_ERR(5, 153, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_extra_info", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(5, 153, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.TCPTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_12TCPTransport_get_extra_info(((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_v_self), __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12TCPTransport_get_extra_info(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("get_extra_info", 0);

  /* "uvloop/handles/tcp.pyx":154
 * 
 *     def get_extra_info(self, name, default=None):
 *         if name == 'sockname':             # <<<<<<<<<<<<<<
 *             if self.__sockname_set:
 *                 return __convert_sockaddr_to_pyaddr(
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_sockname, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(5, 154, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/handles/tcp.pyx":155
 *     def get_extra_info(self, name, default=None):
 *         if name == 'sockname':
 *             if self.__sockname_set:             # <<<<<<<<<<<<<<
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__sockname)
 */
    __pyx_t_1 = (__pyx_v_self->__pyx___sockname_set != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/tcp.pyx":156
 *         if name == 'sockname':
 *             if self.__sockname_set:
 *                 return __convert_sockaddr_to_pyaddr(             # <<<<<<<<<<<<<<
 *                     <system.sockaddr*>&self.__sockname)
 *         elif name == 'peername':
 */
      __Pyx_XDECREF(__pyx_r);

      /* "uvloop/handles/tcp.pyx":157
 *             if self.__sockname_set:
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__sockname)             # <<<<<<<<<<<<<<
 *         elif name == 'peername':
 *             if self.__peername_set:
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop___convert_sockaddr_to_pyaddr(((struct sockaddr *)(&__pyx_v_self->__pyx___sockname))); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 156, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "uvloop/handles/tcp.pyx":155
 *     def get_extra_info(self, name, default=None):
 *         if name == 'sockname':
 *             if self.__sockname_set:             # <<<<<<<<<<<<<<
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__sockname)
 */
    }

    /* "uvloop/handles/tcp.pyx":154
 * 
 *     def get_extra_info(self, name, default=None):
 *         if name == 'sockname':             # <<<<<<<<<<<<<<
 *             if self.__sockname_set:
 *                 return __convert_sockaddr_to_pyaddr(
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/tcp.pyx":158
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__sockname)
 *         elif name == 'peername':             # <<<<<<<<<<<<<<
 *             if self.__peername_set:
 *                 return __convert_sockaddr_to_pyaddr(
 */
  __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_n_u_peername, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(5, 158, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "uvloop/handles/tcp.pyx":159
 *                     <system.sockaddr*>&self.__sockname)
 *         elif name == 'peername':
 *             if self.__peername_set:             # <<<<<<<<<<<<<<
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__peername)
 */
    __pyx_t_1 = (__pyx_v_self->__pyx___peername_set != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/tcp.pyx":160
 *         elif name == 'peername':
 *             if self.__peername_set:
 *                 return __convert_sockaddr_to_pyaddr(             # <<<<<<<<<<<<<<
 *                     <system.sockaddr*>&self.__peername)
 *         return super().get_extra_info(name, default)
 */
      __Pyx_XDECREF(__pyx_r);

      /* "uvloop/handles/tcp.pyx":161
 *             if self.__peername_set:
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__peername)             # <<<<<<<<<<<<<<
 *         return super().get_extra_info(name, default)
 * 
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop___convert_sockaddr_to_pyaddr(((struct sockaddr *)(&__pyx_v_self->__pyx___peername))); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 160, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;

      /* "uvloop/handles/tcp.pyx":159
 *                     <system.sockaddr*>&self.__sockname)
 *         elif name == 'peername':
 *             if self.__peername_set:             # <<<<<<<<<<<<<<
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__peername)
 */
    }

    /* "uvloop/handles/tcp.pyx":158
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__sockname)
 *         elif name == 'peername':             # <<<<<<<<<<<<<<
 *             if self.__peername_set:
 *                 return __convert_sockaddr_to_pyaddr(
 */
  }
  __pyx_L3:;

  /* "uvloop/handles/tcp.pyx":162
 *                 return __convert_sockaddr_to_pyaddr(
 *                     <system.sockaddr*>&self.__peername)
 *         return super().get_extra_info(name, default)             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_ptype_6uvloop_4loop_TCPTransport));
  __Pyx_GIVEREF(((PyObject *)__pyx_ptype_6uvloop_4loop_TCPTransport));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_ptype_6uvloop_4loop_TCPTransport));
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_self));
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_super, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get_extra_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_name, __pyx_v_default};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 162, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_name, __pyx_v_default};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 162, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_name);
    __Pyx_GIVEREF(__pyx_v_name);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_name);
    __Pyx_INCREF(__pyx_v_default);
    __Pyx_GIVEREF(__pyx_v_default);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_default);
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 162, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/tcp.pyx":153
 *         UVBaseTransport._call_connection_made(self)
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if name == 'sockname':
 *             if self.__sockname_set:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":164
 *         return super().get_extra_info(name, default)
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__new_socket(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/tcp.pyx":165
 * 
 *     cdef _new_socket(self):
 *         return __tcp_get_socket(<UVSocketHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/tcp.pyx":164
 *         return super().get_extra_info(name, default)
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":167
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         __tcp_bind(<UVStream>self, addr, flags)
 */

static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport_bind(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, struct sockaddr *__pyx_v_addr, struct __pyx_opt_args_6uvloop_4loop_12TCPTransport_bind *__pyx_optional_args) {
  unsigned int __pyx_v_flags = ((unsigned int)0);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("bind", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_flags = __pyx_optional_args->flags;
    }
  }

  /* "uvloop/handles/tcp.pyx":168
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         __tcp_bind(<UVStream>self, addr, flags)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":169
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):
 *         self._ensure_alive()
 *         __tcp_bind(<UVStream>self, addr, flags)             # <<<<<<<<<<<<<<
 * 
 *     cdef _open(self, int sockfd):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_bind(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_addr, __pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":167
 *         return __tcp_get_socket(<UVSocketHandle>self)
 * 
 *     cdef bind(self, system.sockaddr* addr, unsigned int flags=0):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         __tcp_bind(<UVStream>self, addr, flags)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport.bind", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":171
 *         __tcp_bind(<UVStream>self, addr, flags)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         __tcp_open(<UVStream>self, sockfd)
 */

static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport__open(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, int __pyx_v_sockfd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_open", 0);

  /* "uvloop/handles/tcp.pyx":172
 * 
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         __tcp_open(<UVStream>self, sockfd)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":173
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()
 *         __tcp_open(<UVStream>self, sockfd)             # <<<<<<<<<<<<<<
 * 
 *     cdef connect(self, system.sockaddr* addr):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___tcp_open(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_sockfd); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":171
 *         __tcp_bind(<UVStream>self, addr, flags)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         __tcp_open(<UVStream>self, sockfd)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":175
 *         __tcp_open(<UVStream>self, sockfd)
 * 
 *     cdef connect(self, system.sockaddr* addr):             # <<<<<<<<<<<<<<
 *         cdef _TCPConnectRequest req
 *         req = _TCPConnectRequest(self._loop, self)
 */

static PyObject *__pyx_f_6uvloop_4loop_12TCPTransport_connect(struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, struct sockaddr *__pyx_v_addr) {
  struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_req = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("connect", 0);

  /* "uvloop/handles/tcp.pyx":177
 *     cdef connect(self, system.sockaddr* addr):
 *         cdef _TCPConnectRequest req
 *         req = _TCPConnectRequest(self._loop, self)             # <<<<<<<<<<<<<<
 *         req.connect(addr)
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._loop));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._loop));
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self));
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop__TCPConnectRequest), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 177, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_req = ((struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/tcp.pyx":178
 *         cdef _TCPConnectRequest req
 *         req = _TCPConnectRequest(self._loop, self)
 *         req.connect(addr)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__TCPConnectRequest *)__pyx_v_req->__pyx_base.__pyx_vtab)->connect(__pyx_v_req, __pyx_v_addr); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/tcp.pyx":175
 *         __tcp_open(<UVStream>self, sockfd)
 * 
 *     cdef connect(self, system.sockaddr* addr):             # <<<<<<<<<<<<<<
 *         cdef _TCPConnectRequest req
 *         req = _TCPConnectRequest(self._loop, self)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport.connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_req);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12TCPTransport_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12TCPTransport_2__reduce_cython__[] = "TCPTransport.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12TCPTransport_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12TCPTransport_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12TCPTransport_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__192, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12TCPTransport_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_12TCPTransport_4__setstate_cython__[] = "TCPTransport.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_12TCPTransport_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12TCPTransport_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12TCPTransport_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__193, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.TCPTransport.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":186
 *         uv.uv_connect_t _req_data
 * 
 *     def __cinit__(self, loop, transport):             # <<<<<<<<<<<<<<
 *         self.request = <uv.uv_req_t*>&self._req_data
 *         self.request.data = <void*>self
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_18_TCPConnectRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_18_TCPConnectRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_loop = 0;
  PyObject *__pyx_v_transport = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loop,&__pyx_n_s_transport,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_transport)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(5, 186, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(5, 186, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_loop = values[0];
    __pyx_v_transport = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(5, 186, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._TCPConnectRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_18_TCPConnectRequest___cinit__(((struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)__pyx_v_self), __pyx_v_loop, __pyx_v_transport);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_18_TCPConnectRequest___cinit__(struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_loop, PyObject *__pyx_v_transport) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/tcp.pyx":187
 * 
 *     def __cinit__(self, loop, transport):
 *         self.request = <uv.uv_req_t*>&self._req_data             # <<<<<<<<<<<<<<
 *         self.request.data = <void*>self
 *         self.transport = transport
 */
  __pyx_v_self->__pyx_base.request = ((uv_req_t *)(&__pyx_v_self->_req_data));

  /* "uvloop/handles/tcp.pyx":188
 *     def __cinit__(self, loop, transport):
 *         self.request = <uv.uv_req_t*>&self._req_data
 *         self.request.data = <void*>self             # <<<<<<<<<<<<<<
 *         self.transport = transport
 * 
 */
  __pyx_v_self->__pyx_base.request->data = ((void *)__pyx_v_self);

  /* "uvloop/handles/tcp.pyx":189
 *         self.request = <uv.uv_req_t*>&self._req_data
 *         self.request.data = <void*>self
 *         self.transport = transport             # <<<<<<<<<<<<<<
 * 
 *     cdef connect(self, system.sockaddr* addr):
 */
  if (!(likely(((__pyx_v_transport) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_transport, __pyx_ptype_6uvloop_4loop_TCPTransport))))) __PYX_ERR(5, 189, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_transport;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->transport);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->transport));
  __pyx_v_self->transport = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":186
 *         uv.uv_connect_t _req_data
 * 
 *     def __cinit__(self, loop, transport):             # <<<<<<<<<<<<<<
 *         self.request = <uv.uv_req_t*>&self._req_data
 *         self.request.data = <void*>self
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._TCPConnectRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":191
 *         self.transport = transport
 * 
 *     cdef connect(self, system.sockaddr* addr):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         err = uv.uv_tcp_connect(<uv.uv_connect_t*>self.request,
 */

static PyObject *__pyx_f_6uvloop_4loop_18_TCPConnectRequest_connect(struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self, struct sockaddr *__pyx_v_addr) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("connect", 0);

  /* "uvloop/handles/tcp.pyx":193
 *     cdef connect(self, system.sockaddr* addr):
 *         cdef int err
 *         err = uv.uv_tcp_connect(<uv.uv_connect_t*>self.request,             # <<<<<<<<<<<<<<
 *                                 <uv.uv_tcp_t*>self.transport._handle,
 *                                 addr,
 */
  __pyx_v_err = uv_tcp_connect(((uv_connect_t *)__pyx_v_self->__pyx_base.request), ((uv_tcp_t *)__pyx_v_self->transport->__pyx_base.__pyx_base.__pyx_base.__pyx_base._handle), __pyx_v_addr, __pyx_f_6uvloop_4loop___tcp_connect_callback);

  /* "uvloop/handles/tcp.pyx":197
 *                                 addr,
 *                                 __tcp_connect_callback)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self.on_done()
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/tcp.pyx":198
 *                                 __tcp_connect_callback)
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self.on_done()
 *             raise exc
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/tcp.pyx":199
 *         if err < 0:
 *             exc = convert_error(err)
 *             self.on_done()             # <<<<<<<<<<<<<<
 *             raise exc
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__TCPConnectRequest *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/tcp.pyx":200
 *             exc = convert_error(err)
 *             self.on_done()
 *             raise exc             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(5, 200, __pyx_L1_error)

    /* "uvloop/handles/tcp.pyx":197
 *                                 addr,
 *                                 __tcp_connect_callback)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self.on_done()
 */
  }

  /* "uvloop/handles/tcp.pyx":191
 *         self.transport = transport
 * 
 *     cdef connect(self, system.sockaddr* addr):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         err = uv.uv_tcp_connect(<uv.uv_connect_t*>self.request,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop._TCPConnectRequest.connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18_TCPConnectRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18_TCPConnectRequest_2__reduce_cython__[] = "_TCPConnectRequest.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18_TCPConnectRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18_TCPConnectRequest_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18_TCPConnectRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__194, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._TCPConnectRequest.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18_TCPConnectRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_18_TCPConnectRequest_4__setstate_cython__[] = "_TCPConnectRequest.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_18_TCPConnectRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18_TCPConnectRequest_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18_TCPConnectRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__195, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._TCPConnectRequest.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/tcp.pyx":203
 * 
 * 
 * cdef void __tcp_connect_callback(uv.uv_connect_t* req, int status) with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         _TCPConnectRequest wrapper
 */

static void __pyx_f_6uvloop_4loop___tcp_connect_callback(uv_connect_t *__pyx_v_req, int __pyx_v_status) {
  struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *__pyx_v_wrapper = 0;
  struct __pyx_obj_6uvloop_4loop_TCPTransport *__pyx_v_transport = 0;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  char const *__pyx_t_18;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__tcp_connect_callback", 0);

  /* "uvloop/handles/tcp.pyx":208
 *         TCPTransport transport
 * 
 *     wrapper = <_TCPConnectRequest> req.data             # <<<<<<<<<<<<<<
 *     transport = wrapper.transport
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_req->data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_wrapper = ((struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":209
 * 
 *     wrapper = <_TCPConnectRequest> req.data
 *     transport = wrapper.transport             # <<<<<<<<<<<<<<
 * 
 *     if status < 0:
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_wrapper->transport);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_transport = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/tcp.pyx":211
 *     transport = wrapper.transport
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(status)
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_status < 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/tcp.pyx":212
 * 
 *     if status < 0:
 *         exc = convert_error(status)             # <<<<<<<<<<<<<<
 *     else:
 *         exc = None
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/tcp.pyx":211
 *     transport = wrapper.transport
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(status)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/tcp.pyx":214
 *         exc = convert_error(status)
 *     else:
 *         exc = None             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_exc = Py_None;
  }
  __pyx_L3:;

  /* "uvloop/handles/tcp.pyx":216
 *         exc = None
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/handles/tcp.pyx":217
 * 
 *     try:
 *         transport._on_connect(exc)             # <<<<<<<<<<<<<<
 *     except BaseException as ex:
 *         wrapper.transport._fatal_error(ex, False)
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_v_transport->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._on_connect(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_transport), __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 217, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "uvloop/handles/tcp.pyx":216
 *         exc = None
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/tcp.pyx":218
 *     try:
 *         transport._on_connect(exc)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         wrapper.transport._fatal_error(ex, False)
 *     finally:
 */
      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
      if (__pyx_t_6) {
        __Pyx_AddTraceback("uvloop.loop.__tcp_connect_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(5, 218, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_ex = __pyx_t_7;
        /*try:*/ {

          /* "uvloop/handles/tcp.pyx":219
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 *         wrapper.transport._fatal_error(ex, False)             # <<<<<<<<<<<<<<
 *     finally:
 *         wrapper.on_done()
 */
          __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport *)__pyx_v_wrapper->transport->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_wrapper->transport), __pyx_v_ex, Py_False, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 219, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }

        /* "uvloop/handles/tcp.pyx":218
 *     try:
 *         transport._on_connect(exc)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         wrapper.transport._fatal_error(ex, False)
 *     finally:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L19;
          }
          __pyx_L18_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __pyx_t_6 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
            }
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
            __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
            __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
            goto __pyx_L9_except_error;
          }
          __pyx_L19:;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/handles/tcp.pyx":216
 *         exc = None
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L5_error;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_L12_try_end:;
    }
  }

  /* "uvloop/handles/tcp.pyx":221
 *         wrapper.transport._fatal_error(ex, False)
 *     finally:
 *         wrapper.on_done()             # <<<<<<<<<<<<<<
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop__TCPConnectRequest *)__pyx_v_wrapper->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_wrapper)); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 221, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3) < 0)) __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_10 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
      {
        __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop__TCPConnectRequest *)__pyx_v_wrapper->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_wrapper)); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 221, __pyx_L25_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
      }
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ErrRestore(__pyx_t_5, __pyx_t_4, __pyx_t_3);
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_18;
      goto __pyx_L1_error;
      __pyx_L25_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/handles/tcp.pyx":203
 * 
 * 
 * cdef void __tcp_connect_callback(uv.uv_connect_t* req, int status) with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         _TCPConnectRequest wrapper
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__tcp_connect_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_wrapper);
  __Pyx_XDECREF((PyObject *)__pyx_v_transport);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/pipe.pyx":1
 * cdef __pipe_init_uv_handle(UVStream handle, Loop loop):             # <<<<<<<<<<<<<<
 *     cdef int err
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop___pipe_init_uv_handle(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_handle, CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__pipe_init_uv_handle", 0);

  /* "uvloop/handles/pipe.pyx":4
 *     cdef int err
 * 
 *     handle._handle = <uv.uv_handle_t*> \             # <<<<<<<<<<<<<<
 *                         PyMem_RawMalloc(sizeof(uv.uv_pipe_t))
 *     if handle._handle is NULL:
 */
  __pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_pipe_t))));

  /* "uvloop/handles/pipe.pyx":6
 *     handle._handle = <uv.uv_handle_t*> \
 *                         PyMem_RawMalloc(sizeof(uv.uv_pipe_t))
 *     if handle._handle is NULL:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise MemoryError()
 */
  __pyx_t_1 = ((__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/pipe.pyx":7
 *                         PyMem_RawMalloc(sizeof(uv.uv_pipe_t))
 *     if handle._handle is NULL:
 *         handle._abort_init()             # <<<<<<<<<<<<<<
 *         raise MemoryError()
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_handle)); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/pipe.pyx":8
 *     if handle._handle is NULL:
 *         handle._abort_init()
 *         raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *     # Initialize pipe handle with ipc=0.
 */
    PyErr_NoMemory(); __PYX_ERR(20, 8, __pyx_L1_error)

    /* "uvloop/handles/pipe.pyx":6
 *     handle._handle = <uv.uv_handle_t*> \
 *                         PyMem_RawMalloc(sizeof(uv.uv_pipe_t))
 *     if handle._handle is NULL:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise MemoryError()
 */
  }

  /* "uvloop/handles/pipe.pyx":13
 *     # ipc=1 means that libuv will use recvmsg/sendmsg
 *     # instead of recv/send.
 *     err = uv.uv_pipe_init(handle._loop.uvloop,             # <<<<<<<<<<<<<<
 *                           <uv.uv_pipe_t*>handle._handle,
 *                           0)
 */
  __pyx_v_err = uv_pipe_init(__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._loop->uvloop, ((uv_pipe_t *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle), 0);

  /* "uvloop/handles/pipe.pyx":16
 *                           <uv.uv_pipe_t*>handle._handle,
 *                           0)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise convert_error(err)
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/pipe.pyx":17
 *                           0)
 *     if err < 0:
 *         handle._abort_init()             # <<<<<<<<<<<<<<
 *         raise convert_error(err)
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_handle)); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/pipe.pyx":18
 *     if err < 0:
 *         handle._abort_init()
 *         raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *     handle._finish_init()
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 18, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(20, 18, __pyx_L1_error)

    /* "uvloop/handles/pipe.pyx":16
 *                           <uv.uv_pipe_t*>handle._handle,
 *                           0)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         handle._abort_init()
 *         raise convert_error(err)
 */
  }

  /* "uvloop/handles/pipe.pyx":20
 *         raise convert_error(err)
 * 
 *     handle._finish_init()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStream *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_handle)); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/pipe.pyx":1
 * cdef __pipe_init_uv_handle(UVStream handle, Loop loop):             # <<<<<<<<<<<<<<
 *     cdef int err
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__pipe_init_uv_handle", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":23
 * 
 * 
 * cdef __pipe_open(UVStream handle, int fd):             # <<<<<<<<<<<<<<
 *     cdef int err
 *     err = uv.uv_pipe_open(<uv.uv_pipe_t *>handle._handle,
 */

static PyObject *__pyx_f_6uvloop_4loop___pipe_open(struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_v_handle, int __pyx_v_fd) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__pipe_open", 0);

  /* "uvloop/handles/pipe.pyx":25
 * cdef __pipe_open(UVStream handle, int fd):
 *     cdef int err
 *     err = uv.uv_pipe_open(<uv.uv_pipe_t *>handle._handle,             # <<<<<<<<<<<<<<
 *                           <uv.uv_file>fd)
 *     if err < 0:
 */
  __pyx_v_err = uv_pipe_open(((uv_pipe_t *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base._handle), ((uv_file)__pyx_v_fd));

  /* "uvloop/handles/pipe.pyx":27
 *     err = uv.uv_pipe_open(<uv.uv_pipe_t *>handle._handle,
 *                           <uv.uv_file>fd)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(err)
 *         raise exc
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/pipe.pyx":28
 *                           <uv.uv_file>fd)
 *     if err < 0:
 *         exc = convert_error(err)             # <<<<<<<<<<<<<<
 *         raise exc
 * 
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 28, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/pipe.pyx":29
 *     if err < 0:
 *         exc = convert_error(err)
 *         raise exc             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(20, 29, __pyx_L1_error)

    /* "uvloop/handles/pipe.pyx":27
 *     err = uv.uv_pipe_open(<uv.uv_pipe_t *>handle._handle,
 *                           <uv.uv_file>fd)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(err)
 *         raise exc
 */
  }

  /* "uvloop/handles/pipe.pyx":23
 * 
 * 
 * cdef __pipe_open(UVStream handle, int fd):             # <<<<<<<<<<<<<<
 *     cdef int err
 *     err = uv.uv_pipe_open(<uv.uv_pipe_t *>handle._handle,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__pipe_open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":32
 * 
 * 
 * cdef __pipe_get_socket(UVSocketHandle handle):             # <<<<<<<<<<<<<<
 *     fileno = handle._fileno()
 *     return PseudoSocket(uv.AF_UNIX, uv.SOCK_STREAM, 0, fileno)
 */

static PyObject *__pyx_f_6uvloop_4loop___pipe_get_socket(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *__pyx_v_handle) {
  PyObject *__pyx_v_fileno = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__pipe_get_socket", 0);

  /* "uvloop/handles/pipe.pyx":33
 * 
 * cdef __pipe_get_socket(UVSocketHandle handle):
 *     fileno = handle._fileno()             # <<<<<<<<<<<<<<
 *     return PseudoSocket(uv.AF_UNIX, uv.SOCK_STREAM, 0, fileno)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle *)__pyx_v_handle->__pyx_base.__pyx_vtab)->_fileno(__pyx_v_handle); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fileno = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":34
 * cdef __pipe_get_socket(UVSocketHandle handle):
 *     fileno = handle._fileno()
 *     return PseudoSocket(uv.AF_UNIX, uv.SOCK_STREAM, 0, fileno)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(AF_UNIX); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(SOCK_STREAM); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(20, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_int_0);
  __Pyx_INCREF(__pyx_v_fileno);
  __Pyx_GIVEREF(__pyx_v_fileno);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_fileno);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop_PseudoSocket), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":32
 * 
 * 
 * cdef __pipe_get_socket(UVSocketHandle handle):             # <<<<<<<<<<<<<<
 *     fileno = handle._fileno()
 *     return PseudoSocket(uv.AF_UNIX, uv.SOCK_STREAM, 0, fileno)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.__pipe_get_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fileno);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":41
 * 
 *     @staticmethod
 *     cdef UnixServer new(Loop loop, object protocol_factory, Server server,             # <<<<<<<<<<<<<<
 *                         object ssl, object ssl_handshake_timeout):
 * 
 */

static struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_f_6uvloop_4loop_10UnixServer_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol_factory, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_ssl, PyObject *__pyx_v_ssl_handshake_timeout) {
  struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/pipe.pyx":45
 * 
 *         cdef UnixServer handle
 *         handle = UnixServer.__new__(UnixServer)             # <<<<<<<<<<<<<<
 *         handle._init(loop, protocol_factory, server,
 *                      ssl, ssl_handshake_timeout)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UnixServer(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UnixServer), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 45, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UnixServer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":46
 *         cdef UnixServer handle
 *         handle = UnixServer.__new__(UnixServer)
 *         handle._init(loop, protocol_factory, server,             # <<<<<<<<<<<<<<
 *                      ssl, ssl_handshake_timeout)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_handle), __pyx_v_loop, __pyx_v_protocol_factory, __pyx_v_server, __pyx_v_ssl, __pyx_v_ssl_handshake_timeout); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":48
 *         handle._init(loop, protocol_factory, server,
 *                      ssl, ssl_handshake_timeout)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_init_uv_handle(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":49
 *                      ssl, ssl_handshake_timeout)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":41
 * 
 *     @staticmethod
 *     cdef UnixServer new(Loop loop, object protocol_factory, Server server,             # <<<<<<<<<<<<<<
 *                         object ssl, object ssl_handshake_timeout):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixServer.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":51
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_10UnixServer__new_socket(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/pipe.pyx":52
 * 
 *     cdef _new_socket(self):
 *         return __pipe_get_socket(<UVSocketHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _open(self, int sockfd):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":51
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixServer._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":54
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         __pipe_open(<UVStream>self, sockfd)
 */

static PyObject *__pyx_f_6uvloop_4loop_10UnixServer__open(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, int __pyx_v_sockfd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_open", 0);

  /* "uvloop/handles/pipe.pyx":55
 * 
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         __pipe_open(<UVStream>self, sockfd)
 *         self._mark_as_open()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":56
 *     cdef _open(self, int sockfd):
 *         self._ensure_alive()
 *         __pipe_open(<UVStream>self, sockfd)             # <<<<<<<<<<<<<<
 *         self._mark_as_open()
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_open(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_sockfd); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":57
 *         self._ensure_alive()
 *         __pipe_open(<UVStream>self, sockfd)
 *         self._mark_as_open()             # <<<<<<<<<<<<<<
 * 
 *     cdef bind(self, str path):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._mark_as_open(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":54
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         __pipe_open(<UVStream>self, sockfd)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixServer._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":59
 *         self._mark_as_open()
 * 
 *     cdef bind(self, str path):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

static PyObject *__pyx_f_6uvloop_4loop_10UnixServer_bind(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, PyObject *__pyx_v_path) {
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char const *__pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("bind", 0);

  /* "uvloop/handles/pipe.pyx":61
 *     cdef bind(self, str path):
 *         cdef int err
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         err = uv.uv_pipe_bind(<uv.uv_pipe_t *>self._handle,
 *                               path.encode())
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":63
 *         self._ensure_alive()
 *         err = uv.uv_pipe_bind(<uv.uv_pipe_t *>self._handle,
 *                               path.encode())             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             exc = convert_error(err)
 */
  if (unlikely(__pyx_v_path == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "encode");
    __PYX_ERR(20, 63, __pyx_L1_error)
  }
  __pyx_t_1 = PyUnicode_AsEncodedString(__pyx_v_path, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBytes_AsString(__pyx_t_1); if (unlikely((!__pyx_t_2) && PyErr_Occurred())) __PYX_ERR(20, 63, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":62
 *         cdef int err
 *         self._ensure_alive()
 *         err = uv.uv_pipe_bind(<uv.uv_pipe_t *>self._handle,             # <<<<<<<<<<<<<<
 *                               path.encode())
 *         if err < 0:
 */
  __pyx_v_err = uv_pipe_bind(((uv_pipe_t *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._handle), __pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":64
 *         err = uv.uv_pipe_bind(<uv.uv_pipe_t *>self._handle,
 *                               path.encode())
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  __pyx_t_3 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/pipe.pyx":65
 *                               path.encode())
 *         if err < 0:
 *             exc = convert_error(err)             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, True)
 *             return
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/pipe.pyx":66
 *         if err < 0:
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, Py_True, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/pipe.pyx":67
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._mark_as_open()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/pipe.pyx":64
 *         err = uv.uv_pipe_bind(<uv.uv_pipe_t *>self._handle,
 *                               path.encode())
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             exc = convert_error(err)
 *             self._fatal_error(exc, True)
 */
  }

  /* "uvloop/handles/pipe.pyx":69
 *             return
 * 
 *         self._mark_as_open()             # <<<<<<<<<<<<<<
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixServer *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._mark_as_open(((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":59
 *         self._mark_as_open()
 * 
 *     cdef bind(self, str path):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixServer.bind", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":71
 *         self._mark_as_open()
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):             # <<<<<<<<<<<<<<
 *         cdef UnixTransport tr
 *         tr = UnixTransport.new(self._loop, protocol, self._server, waiter)
 */

static struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_f_6uvloop_4loop_10UnixServer__make_new_transport(struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, PyObject *__pyx_v_protocol, PyObject *__pyx_v_waiter) {
  struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_tr = 0;
  struct __pyx_obj_6uvloop_4loop_UVStream *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_make_new_transport", 0);

  /* "uvloop/handles/pipe.pyx":73
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):
 *         cdef UnixTransport tr
 *         tr = UnixTransport.new(self._loop, protocol, self._server, waiter)             # <<<<<<<<<<<<<<
 *         return <UVStream>tr
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = ((PyObject *)__pyx_v_self->__pyx_base._server);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = ((PyObject *)__pyx_f_6uvloop_4loop_13UnixTransport_new(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1), __pyx_v_protocol, ((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_t_2), __pyx_v_waiter)); if (unlikely(!__pyx_t_3)) __PYX_ERR(20, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_tr = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/handles/pipe.pyx":74
 *         cdef UnixTransport tr
 *         tr = UnixTransport.new(self._loop, protocol, self._server, waiter)
 *         return <UVStream>tr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_tr)));
  __pyx_r = ((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_tr);
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":71
 *         self._mark_as_open()
 * 
 *     cdef UVStream _make_new_transport(self, object protocol, object waiter):             # <<<<<<<<<<<<<<
 *         cdef UnixTransport tr
 *         tr = UnixTransport.new(self._loop, protocol, self._server, waiter)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UnixServer._make_new_transport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tr);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_10UnixServer_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_10UnixServer___reduce_cython__[] = "UnixServer.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_10UnixServer_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_10UnixServer___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UnixServer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_10UnixServer___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__196, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixServer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_10UnixServer_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_10UnixServer_2__setstate_cython__[] = "UnixServer.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_10UnixServer_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_10UnixServer_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UnixServer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_10UnixServer_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixServer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__197, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixServer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":81
 * 
 *     @staticmethod
 *     cdef UnixTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                              object waiter):
 * 
 */

static struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_f_6uvloop_4loop_13UnixTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter) {
  struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/pipe.pyx":85
 * 
 *         cdef UnixTransport handle
 *         handle = UnixTransport.__new__(UnixTransport)             # <<<<<<<<<<<<<<
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UnixTransport(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UnixTransport), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 85, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":86
 *         cdef UnixTransport handle
 *         handle = UnixTransport.__new__(UnixTransport)
 *         handle._init(loop, protocol, server, waiter)             # <<<<<<<<<<<<<<
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 *         return handle
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop, __pyx_v_protocol, __pyx_v_server, __pyx_v_waiter); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":87
 *         handle = UnixTransport.__new__(UnixTransport)
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_init_uv_handle(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":88
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":81
 * 
 *     @staticmethod
 *     cdef UnixTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                              object waiter):
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixTransport.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":90
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_13UnixTransport__new_socket(struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/pipe.pyx":91
 * 
 *     cdef _new_socket(self):
 *         return __pipe_get_socket(<UVSocketHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _open(self, int sockfd):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":90
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixTransport._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":93
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_13UnixTransport__open(struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self, int __pyx_v_sockfd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_open", 0);

  /* "uvloop/handles/pipe.pyx":94
 * 
 *     cdef _open(self, int sockfd):
 *         __pipe_open(<UVStream>self, sockfd)             # <<<<<<<<<<<<<<
 * 
 *     cdef connect(self, char* addr):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_open(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_sockfd); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":93
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixTransport._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":96
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 *     cdef connect(self, char* addr):             # <<<<<<<<<<<<<<
 *         cdef _PipeConnectRequest req
 *         req = _PipeConnectRequest(self._loop, self)
 */

static PyObject *__pyx_f_6uvloop_4loop_13UnixTransport_connect(struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self, char *__pyx_v_addr) {
  struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_req = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("connect", 0);

  /* "uvloop/handles/pipe.pyx":98
 *     cdef connect(self, char* addr):
 *         cdef _PipeConnectRequest req
 *         req = _PipeConnectRequest(self._loop, self)             # <<<<<<<<<<<<<<
 *         req.connect(addr)
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._loop));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_base._loop));
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self));
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop__PipeConnectRequest), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_req = ((struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/pipe.pyx":99
 *         cdef _PipeConnectRequest req
 *         req = _PipeConnectRequest(self._loop, self)
 *         req.connect(addr)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__PipeConnectRequest *)__pyx_v_req->__pyx_base.__pyx_vtab)->connect(__pyx_v_req, __pyx_v_addr); if (unlikely(!__pyx_t_2)) __PYX_ERR(20, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/pipe.pyx":96
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 *     cdef connect(self, char* addr):             # <<<<<<<<<<<<<<
 *         cdef _PipeConnectRequest req
 *         req = _PipeConnectRequest(self._loop, self)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UnixTransport.connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_req);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_13UnixTransport_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_13UnixTransport___reduce_cython__[] = "UnixTransport.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_13UnixTransport_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_13UnixTransport___reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_13UnixTransport___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__198, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixTransport.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_13UnixTransport_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_13UnixTransport_2__setstate_cython__[] = "UnixTransport.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_13UnixTransport_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_13UnixTransport_2__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_13UnixTransport_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__199, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UnixTransport.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":106
 * 
 *     @staticmethod
 *     cdef ReadUnixTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                                  object waiter):
 *         cdef ReadUnixTransport handle
 */

static struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_f_6uvloop_4loop_17ReadUnixTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter) {
  struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/pipe.pyx":109
 *                                  object waiter):
 *         cdef ReadUnixTransport handle
 *         handle = ReadUnixTransport.__new__(ReadUnixTransport)             # <<<<<<<<<<<<<<
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_ReadUnixTransport(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_ReadUnixTransport), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 109, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":110
 *         cdef ReadUnixTransport handle
 *         handle = ReadUnixTransport.__new__(ReadUnixTransport)
 *         handle._init(loop, protocol, server, waiter)             # <<<<<<<<<<<<<<
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 *         return handle
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop, __pyx_v_protocol, __pyx_v_server, __pyx_v_waiter); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":111
 *         handle = ReadUnixTransport.__new__(ReadUnixTransport)
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_init_uv_handle(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":112
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":106
 * 
 *     @staticmethod
 *     cdef ReadUnixTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                                  object waiter):
 *         cdef ReadUnixTransport handle
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":114
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_17ReadUnixTransport__new_socket(struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/pipe.pyx":115
 * 
 *     cdef _new_socket(self):
 *         return __pipe_get_socket(<UVSocketHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _open(self, int sockfd):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":114
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":117
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_17ReadUnixTransport__open(struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, int __pyx_v_sockfd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_open", 0);

  /* "uvloop/handles/pipe.pyx":118
 * 
 *     cdef _open(self, int sockfd):
 *         __pipe_open(<UVStream>self, sockfd)             # <<<<<<<<<<<<<<
 * 
 *     def get_write_buffer_limits(self):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_open(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_sockfd); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":117
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":120
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 *     def get_write_buffer_limits(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_1get_write_buffer_limits(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_get_write_buffer_limits[] = "ReadUnixTransport.get_write_buffer_limits(self)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_1get_write_buffer_limits(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_write_buffer_limits (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_get_write_buffer_limits(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_get_write_buffer_limits(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_write_buffer_limits", 0);

  /* "uvloop/handles/pipe.pyx":121
 * 
 *     def get_write_buffer_limits(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 121, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":120
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 *     def get_write_buffer_limits(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.get_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":123
 *         raise NotImplementedError
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_3set_write_buffer_limits(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_2set_write_buffer_limits[] = "ReadUnixTransport.set_write_buffer_limits(self, high=None, low=None)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_3set_write_buffer_limits(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_high = 0;
  CYTHON_UNUSED PyObject *__pyx_v_low = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_write_buffer_limits (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_high_2,&__pyx_n_s_low,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)Py_None);
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_high_2);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_low);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_write_buffer_limits") < 0)) __PYX_ERR(20, 123, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_high = values[0];
    __pyx_v_low = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_write_buffer_limits", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(20, 123, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.set_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_2set_write_buffer_limits(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self), __pyx_v_high, __pyx_v_low);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_2set_write_buffer_limits(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_high, CYTHON_UNUSED PyObject *__pyx_v_low) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_write_buffer_limits", 0);

  /* "uvloop/handles/pipe.pyx":124
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def get_write_buffer_size(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 124, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":123
 *         raise NotImplementedError
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.set_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":126
 *         raise NotImplementedError
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_5get_write_buffer_size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_4get_write_buffer_size[] = "ReadUnixTransport.get_write_buffer_size(self)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_5get_write_buffer_size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_write_buffer_size (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_4get_write_buffer_size(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_4get_write_buffer_size(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_write_buffer_size", 0);

  /* "uvloop/handles/pipe.pyx":127
 * 
 *     def get_write_buffer_size(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def write(self, data):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 127, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":126
 *         raise NotImplementedError
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.get_write_buffer_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":129
 *         raise NotImplementedError
 * 
 *     def write(self, data):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_7write(PyObject *__pyx_v_self, PyObject *__pyx_v_data); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_6write[] = "ReadUnixTransport.write(self, data)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_7write(PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_6write(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self), ((PyObject *)__pyx_v_data));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_6write(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write", 0);

  /* "uvloop/handles/pipe.pyx":130
 * 
 *     def write(self, data):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def writelines(self, list_of_data):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 130, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":129
 *         raise NotImplementedError
 * 
 *     def write(self, data):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":132
 *         raise NotImplementedError
 * 
 *     def writelines(self, list_of_data):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_9writelines(PyObject *__pyx_v_self, PyObject *__pyx_v_list_of_data); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_8writelines[] = "ReadUnixTransport.writelines(self, list_of_data)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_9writelines(PyObject *__pyx_v_self, PyObject *__pyx_v_list_of_data) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("writelines (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_8writelines(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self), ((PyObject *)__pyx_v_list_of_data));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_8writelines(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_list_of_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("writelines", 0);

  /* "uvloop/handles/pipe.pyx":133
 * 
 *     def writelines(self, list_of_data):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def write_eof(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 133, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":132
 *         raise NotImplementedError
 * 
 *     def writelines(self, list_of_data):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.writelines", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":135
 *         raise NotImplementedError
 * 
 *     def write_eof(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_11write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_10write_eof[] = "ReadUnixTransport.write_eof(self)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_11write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write_eof (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_10write_eof(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_10write_eof(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write_eof", 0);

  /* "uvloop/handles/pipe.pyx":136
 * 
 *     def write_eof(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def can_write_eof(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 136, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":135
 *         raise NotImplementedError
 * 
 *     def write_eof(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.write_eof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":138
 *         raise NotImplementedError
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_13can_write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_12can_write_eof[] = "ReadUnixTransport.can_write_eof(self)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_13can_write_eof(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("can_write_eof (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_12can_write_eof(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_12can_write_eof(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("can_write_eof", 0);

  /* "uvloop/handles/pipe.pyx":139
 * 
 *     def can_write_eof(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def abort(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 139, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":138
 *         raise NotImplementedError
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.can_write_eof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":141
 *         raise NotImplementedError
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_15abort(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_14abort[] = "ReadUnixTransport.abort(self)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_15abort(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("abort (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_14abort(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_14abort(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("abort", 0);

  /* "uvloop/handles/pipe.pyx":142
 * 
 *     def abort(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 142, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":141
 *         raise NotImplementedError
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.abort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_17__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_16__reduce_cython__[] = "ReadUnixTransport.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_17__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_16__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_16__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__200, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_19__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_17ReadUnixTransport_18__setstate_cython__[] = "ReadUnixTransport.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_17ReadUnixTransport_19__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_17ReadUnixTransport_18__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_17ReadUnixTransport_18__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__201, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.ReadUnixTransport.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":149
 * 
 *     @staticmethod
 *     cdef WriteUnixTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                                   object waiter):
 *         cdef WriteUnixTransport handle
 */

static struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_f_6uvloop_4loop_18WriteUnixTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_server, PyObject *__pyx_v_waiter) {
  struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_handle = 0;
  struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/pipe.pyx":152
 *                                   object waiter):
 *         cdef WriteUnixTransport handle
 *         handle = WriteUnixTransport.__new__(WriteUnixTransport)             # <<<<<<<<<<<<<<
 * 
 *         # We listen for read events on write-end of the pipe. When
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_WriteUnixTransport(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_WriteUnixTransport), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 152, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":158
 *         # receive an error -- we want to silence that error, and just
 *         # close the transport.
 *         handle._close_on_read_error()             # <<<<<<<<<<<<<<
 * 
 *         handle._init(loop, protocol, server, waiter)
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._close_on_read_error(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":160
 *         handle._close_on_read_error()
 * 
 *         handle._init(loop, protocol, server, waiter)             # <<<<<<<<<<<<<<
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 *         return handle
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop, __pyx_v_protocol, __pyx_v_server, __pyx_v_waiter); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":161
 * 
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)             # <<<<<<<<<<<<<<
 *         return handle
 * 
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_init_uv_handle(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_handle), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":162
 *         handle._init(loop, protocol, server, waiter)
 *         __pipe_init_uv_handle(<UVStream>handle, loop)
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":149
 * 
 *     @staticmethod
 *     cdef WriteUnixTransport new(Loop loop, object protocol, Server server,             # <<<<<<<<<<<<<<
 *                                   object waiter):
 *         cdef WriteUnixTransport handle
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.WriteUnixTransport.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":164
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_18WriteUnixTransport__new_socket(struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/pipe.pyx":165
 * 
 *     cdef _new_socket(self):
 *         return __pipe_get_socket(<UVSocketHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _open(self, int sockfd):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/pipe.pyx":164
 *         return handle
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.WriteUnixTransport._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":167
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_18WriteUnixTransport__open(struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self, int __pyx_v_sockfd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_open", 0);

  /* "uvloop/handles/pipe.pyx":168
 * 
 *     cdef _open(self, int sockfd):
 *         __pipe_open(<UVStream>self, sockfd)             # <<<<<<<<<<<<<<
 * 
 *     def pause_reading(self):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pipe_open(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_self), __pyx_v_sockfd); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":167
 *         return __pipe_get_socket(<UVSocketHandle>self)
 * 
 *     cdef _open(self, int sockfd):             # <<<<<<<<<<<<<<
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.WriteUnixTransport._open", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":170
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_1pause_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18WriteUnixTransport_pause_reading[] = "WriteUnixTransport.pause_reading(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_1pause_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pause_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18WriteUnixTransport_pause_reading(((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_pause_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pause_reading", 0);

  /* "uvloop/handles/pipe.pyx":171
 * 
 *     def pause_reading(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     def resume_reading(self):
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 171, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":170
 *         __pipe_open(<UVStream>self, sockfd)
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.WriteUnixTransport.pause_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":173
 *         raise NotImplementedError
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_3resume_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18WriteUnixTransport_2resume_reading[] = "WriteUnixTransport.resume_reading(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_3resume_reading(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resume_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18WriteUnixTransport_2resume_reading(((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_2resume_reading(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resume_reading", 0);

  /* "uvloop/handles/pipe.pyx":174
 * 
 *     def resume_reading(self):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(20, 174, __pyx_L1_error)

  /* "uvloop/handles/pipe.pyx":173
 *         raise NotImplementedError
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.WriteUnixTransport.resume_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18WriteUnixTransport_4__reduce_cython__[] = "WriteUnixTransport.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18WriteUnixTransport_4__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__202, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.WriteUnixTransport.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_18WriteUnixTransport_6__setstate_cython__[] = "WriteUnixTransport.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_18WriteUnixTransport_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18WriteUnixTransport_6__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18WriteUnixTransport_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__203, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.WriteUnixTransport.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":182
 *         uv.uv_connect_t _req_data
 * 
 *     def __cinit__(self, loop, transport):             # <<<<<<<<<<<<<<
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.request.data = <void*>self
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_19_PipeConnectRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_19_PipeConnectRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_loop = 0;
  PyObject *__pyx_v_transport = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loop,&__pyx_n_s_transport,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_transport)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(20, 182, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(20, 182, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_loop = values[0];
    __pyx_v_transport = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(20, 182, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._PipeConnectRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_19_PipeConnectRequest___cinit__(((struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)__pyx_v_self), __pyx_v_loop, __pyx_v_transport);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_19_PipeConnectRequest___cinit__(struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_loop, PyObject *__pyx_v_transport) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/pipe.pyx":183
 * 
 *     def __cinit__(self, loop, transport):
 *         self.request = <uv.uv_req_t*> &self._req_data             # <<<<<<<<<<<<<<
 *         self.request.data = <void*>self
 *         self.transport = transport
 */
  __pyx_v_self->__pyx_base.request = ((uv_req_t *)(&__pyx_v_self->_req_data));

  /* "uvloop/handles/pipe.pyx":184
 *     def __cinit__(self, loop, transport):
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.request.data = <void*>self             # <<<<<<<<<<<<<<
 *         self.transport = transport
 * 
 */
  __pyx_v_self->__pyx_base.request->data = ((void *)__pyx_v_self);

  /* "uvloop/handles/pipe.pyx":185
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.request.data = <void*>self
 *         self.transport = transport             # <<<<<<<<<<<<<<
 * 
 *     cdef connect(self, char* addr):
 */
  if (!(likely(((__pyx_v_transport) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_transport, __pyx_ptype_6uvloop_4loop_UnixTransport))))) __PYX_ERR(20, 185, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_transport;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->transport);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->transport));
  __pyx_v_self->transport = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":182
 *         uv.uv_connect_t _req_data
 * 
 *     def __cinit__(self, loop, transport):             # <<<<<<<<<<<<<<
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.request.data = <void*>self
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._PipeConnectRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":187
 *         self.transport = transport
 * 
 *     cdef connect(self, char* addr):             # <<<<<<<<<<<<<<
 *         # uv_pipe_connect returns void
 *         uv.uv_pipe_connect(<uv.uv_connect_t*>self.request,
 */

static PyObject *__pyx_f_6uvloop_4loop_19_PipeConnectRequest_connect(struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self, char *__pyx_v_addr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect", 0);

  /* "uvloop/handles/pipe.pyx":189
 *     cdef connect(self, char* addr):
 *         # uv_pipe_connect returns void
 *         uv.uv_pipe_connect(<uv.uv_connect_t*>self.request,             # <<<<<<<<<<<<<<
 *                            <uv.uv_pipe_t*>self.transport._handle,
 *                            addr,
 */
  uv_pipe_connect(((uv_connect_t *)__pyx_v_self->__pyx_base.request), ((uv_pipe_t *)__pyx_v_self->transport->__pyx_base.__pyx_base.__pyx_base.__pyx_base._handle), __pyx_v_addr, __pyx_f_6uvloop_4loop___pipe_connect_callback);

  /* "uvloop/handles/pipe.pyx":187
 *         self.transport = transport
 * 
 *     cdef connect(self, char* addr):             # <<<<<<<<<<<<<<
 *         # uv_pipe_connect returns void
 *         uv.uv_pipe_connect(<uv.uv_connect_t*>self.request,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_19_PipeConnectRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_19_PipeConnectRequest_2__reduce_cython__[] = "_PipeConnectRequest.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_19_PipeConnectRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_19_PipeConnectRequest_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_19_PipeConnectRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__204, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._PipeConnectRequest.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_19_PipeConnectRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_19_PipeConnectRequest_4__setstate_cython__[] = "_PipeConnectRequest.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_19_PipeConnectRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_19_PipeConnectRequest_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_19_PipeConnectRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__205, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._PipeConnectRequest.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/pipe.pyx":194
 *                            __pipe_connect_callback)
 * 
 * cdef void __pipe_connect_callback(uv.uv_connect_t* req, int status) with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         _PipeConnectRequest wrapper
 */

static void __pyx_f_6uvloop_4loop___pipe_connect_callback(uv_connect_t *__pyx_v_req, int __pyx_v_status) {
  struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *__pyx_v_wrapper = 0;
  struct __pyx_obj_6uvloop_4loop_UnixTransport *__pyx_v_transport = 0;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  char const *__pyx_t_18;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__pipe_connect_callback", 0);

  /* "uvloop/handles/pipe.pyx":199
 *         UnixTransport transport
 * 
 *     wrapper = <_PipeConnectRequest> req.data             # <<<<<<<<<<<<<<
 *     transport = wrapper.transport
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_req->data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_wrapper = ((struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":200
 * 
 *     wrapper = <_PipeConnectRequest> req.data
 *     transport = wrapper.transport             # <<<<<<<<<<<<<<
 * 
 *     if status < 0:
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_wrapper->transport);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_transport = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/pipe.pyx":202
 *     transport = wrapper.transport
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(status)
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_status < 0) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/pipe.pyx":203
 * 
 *     if status < 0:
 *         exc = convert_error(status)             # <<<<<<<<<<<<<<
 *     else:
 *         exc = None
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/pipe.pyx":202
 *     transport = wrapper.transport
 * 
 *     if status < 0:             # <<<<<<<<<<<<<<
 *         exc = convert_error(status)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/pipe.pyx":205
 *         exc = convert_error(status)
 *     else:
 *         exc = None             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_exc = Py_None;
  }
  __pyx_L3:;

  /* "uvloop/handles/pipe.pyx":207
 *         exc = None
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "uvloop/handles/pipe.pyx":208
 * 
 *     try:
 *         transport._on_connect(exc)             # <<<<<<<<<<<<<<
 *     except BaseException as ex:
 *         wrapper.transport._fatal_error(ex, False)
 */
        __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_v_transport->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._on_connect(((struct __pyx_obj_6uvloop_4loop_UVStream *)__pyx_v_transport), __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(20, 208, __pyx_L7_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "uvloop/handles/pipe.pyx":207
 *         exc = None
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/pipe.pyx":209
 *     try:
 *         transport._on_connect(exc)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         wrapper.transport._fatal_error(ex, False)
 *     finally:
 */
      __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
      if (__pyx_t_6) {
        __Pyx_AddTraceback("uvloop.loop.__pipe_connect_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(20, 209, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_ex = __pyx_t_7;
        /*try:*/ {

          /* "uvloop/handles/pipe.pyx":210
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 *         wrapper.transport._fatal_error(ex, False)             # <<<<<<<<<<<<<<
 *     finally:
 *         wrapper.on_done()
 */
          __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport *)__pyx_v_wrapper->transport->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_wrapper->transport), __pyx_v_ex, Py_False, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(20, 210, __pyx_L18_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        }

        /* "uvloop/handles/pipe.pyx":209
 *     try:
 *         transport._on_connect(exc)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         wrapper.transport._fatal_error(ex, False)
 *     finally:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L19;
          }
          __pyx_L18_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_13);
            __Pyx_XGOTREF(__pyx_t_14);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __pyx_t_6 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_15);
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
            }
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_XGIVEREF(__pyx_t_13);
            __Pyx_XGIVEREF(__pyx_t_14);
            __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
            __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
            __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
            goto __pyx_L9_except_error;
          }
          __pyx_L19:;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/handles/pipe.pyx":207
 *         exc = None
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         transport._on_connect(exc)
 *     except BaseException as ex:
 */
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L5_error;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_L12_try_end:;
    }
  }

  /* "uvloop/handles/pipe.pyx":212
 *         wrapper.transport._fatal_error(ex, False)
 *     finally:
 *         wrapper.on_done()             # <<<<<<<<<<<<<<
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop__PipeConnectRequest *)__pyx_v_wrapper->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_wrapper)); if (unlikely(!__pyx_t_8)) __PYX_ERR(20, 212, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_17, &__pyx_t_16, &__pyx_t_15);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3) < 0)) __Pyx_ErrFetch(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_17);
      __Pyx_XGOTREF(__pyx_t_16);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_10 = __pyx_lineno; __pyx_t_6 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
      {
        __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop__PipeConnectRequest *)__pyx_v_wrapper->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_wrapper)); if (unlikely(!__pyx_t_8)) __PYX_ERR(20, 212, __pyx_L25_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
      }
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_ErrRestore(__pyx_t_5, __pyx_t_4, __pyx_t_3);
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_6; __pyx_filename = __pyx_t_18;
      goto __pyx_L1_error;
      __pyx_L25_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_16, __pyx_t_15);
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/handles/pipe.pyx":194
 *                            __pipe_connect_callback)
 * 
 * cdef void __pipe_connect_callback(uv.uv_connect_t* req, int status) with gil:             # <<<<<<<<<<<<<<
 *     cdef:
 *         _PipeConnectRequest wrapper
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__pipe_connect_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_wrapper);
  __Pyx_XDECREF((PyObject *)__pyx_v_transport);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/process.pyx":5
 *     """Abstract class; wrapper over uv_process_t handle."""
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.uv_opt_env = NULL
 *         self.uv_opt_args = NULL
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_9UVProcess_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_9UVProcess_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_9UVProcess___cinit__(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_9UVProcess___cinit__(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/process.pyx":6
 * 
 *     def __cinit__(self):
 *         self.uv_opt_env = NULL             # <<<<<<<<<<<<<<
 *         self.uv_opt_args = NULL
 *         self._returncode = None
 */
  __pyx_v_self->uv_opt_env = NULL;

  /* "uvloop/handles/process.pyx":7
 *     def __cinit__(self):
 *         self.uv_opt_env = NULL
 *         self.uv_opt_args = NULL             # <<<<<<<<<<<<<<
 *         self._returncode = None
 *         self._pid = None
 */
  __pyx_v_self->uv_opt_args = NULL;

  /* "uvloop/handles/process.pyx":8
 *         self.uv_opt_env = NULL
 *         self.uv_opt_args = NULL
 *         self._returncode = None             # <<<<<<<<<<<<<<
 *         self._pid = None
 *         self._fds_to_close = set()
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_returncode);
  __Pyx_DECREF(__pyx_v_self->_returncode);
  __pyx_v_self->_returncode = Py_None;

  /* "uvloop/handles/process.pyx":9
 *         self.uv_opt_args = NULL
 *         self._returncode = None
 *         self._pid = None             # <<<<<<<<<<<<<<
 *         self._fds_to_close = set()
 *         self._preexec_fn = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_pid);
  __Pyx_DECREF(__pyx_v_self->_pid);
  __pyx_v_self->_pid = Py_None;

  /* "uvloop/handles/process.pyx":10
 *         self._returncode = None
 *         self._pid = None
 *         self._fds_to_close = set()             # <<<<<<<<<<<<<<
 *         self._preexec_fn = None
 *         self._restore_signals = True
 */
  __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_fds_to_close);
  __Pyx_DECREF(__pyx_v_self->_fds_to_close);
  __pyx_v_self->_fds_to_close = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":11
 *         self._pid = None
 *         self._fds_to_close = set()
 *         self._preexec_fn = None             # <<<<<<<<<<<<<<
 *         self._restore_signals = True
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_preexec_fn);
  __Pyx_DECREF(__pyx_v_self->_preexec_fn);
  __pyx_v_self->_preexec_fn = Py_None;

  /* "uvloop/handles/process.pyx":12
 *         self._fds_to_close = set()
 *         self._preexec_fn = None
 *         self._restore_signals = True             # <<<<<<<<<<<<<<
 * 
 *     cdef _init(self, Loop loop, list args, dict env,
 */
  __pyx_v_self->_restore_signals = 1;

  /* "uvloop/handles/process.pyx":5
 *     """Abstract class; wrapper over uv_process_t handle."""
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.uv_opt_env = NULL
 *         self.uv_opt_args = NULL
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcess.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":14
 *         self._restore_signals = True
 * 
 *     cdef _init(self, Loop loop, list args, dict env,             # <<<<<<<<<<<<<<
 *                cwd, start_new_session,
 *                _stdin, _stdout, _stderr,  # std* can be defined as macros in C
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_args, PyObject *__pyx_v_env, PyObject *__pyx_v_cwd, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr, PyObject *__pyx_v_pass_fds, PyObject *__pyx_v_debug_flags, PyObject *__pyx_v_preexec_fn, PyObject *__pyx_v_restore_signals) {
  int __pyx_v_err;
  PyObject *__pyx_v_restore_inheritable = NULL;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_v_errpipe_data = NULL;
  PyObject *__pyx_v_part = NULL;
  PyObject *__pyx_v_fds_to_close = NULL;
  PyObject *__pyx_v_exc_name = NULL;
  PyObject *__pyx_v_exc_msg = NULL;
  PyObject *__pyx_v_exc_cls = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  PyObject *(*__pyx_t_16)(PyObject *);
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  int __pyx_t_25;
  Py_ssize_t __pyx_t_26;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/process.pyx":24
 *         cdef int err
 * 
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 * 
 *         self._handle = <uv.uv_handle_t*> \
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":26
 *         self._start_init(loop)
 * 
 *         self._handle = <uv.uv_handle_t*> \             # <<<<<<<<<<<<<<
 *                             PyMem_RawMalloc(sizeof(uv.uv_process_t))
 *         if self._handle is NULL:
 */
  __pyx_v_self->__pyx_base._handle = ((uv_handle_t *)PyMem_RawMalloc((sizeof(uv_process_t))));

  /* "uvloop/handles/process.pyx":28
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_process_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  __pyx_t_2 = ((__pyx_v_self->__pyx_base._handle == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/process.pyx":29
 *                             PyMem_RawMalloc(sizeof(uv.uv_process_t))
 *         if self._handle is NULL:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":30
 *         if self._handle is NULL:
 *             self._abort_init()
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         # Too early to call _finish_init, but still a lot of work to do.
 */
    PyErr_NoMemory(); __PYX_ERR(6, 30, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":28
 *         self._handle = <uv.uv_handle_t*> \
 *                             PyMem_RawMalloc(sizeof(uv.uv_process_t))
 *         if self._handle is NULL:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise MemoryError()
 */
  }

  /* "uvloop/handles/process.pyx":35
 *         # Let's set handle.data to NULL, so in case something goes wrong,
 *         # callbacks have a chance to avoid casting *something* into UVHandle.
 *         self._handle.data = NULL             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_v_self->__pyx_base._handle->data = NULL;

  /* "uvloop/handles/process.pyx":37
 *         self._handle.data = NULL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self._init_options(args, env, cwd, start_new_session,
 *                                _stdin, _stdout, _stderr)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "uvloop/handles/process.pyx":38
 * 
 *         try:
 *             self._init_options(args, env, cwd, start_new_session,             # <<<<<<<<<<<<<<
 *                                _stdin, _stdout, _stderr)
 * 
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->_init_options(__pyx_v_self, __pyx_v_args, __pyx_v_env, __pyx_v_cwd, __pyx_v_start_new_session, __pyx_v__stdin, __pyx_v__stdout, __pyx_v__stderr); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 38, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":41
 *                                _stdin, _stdout, _stderr)
 * 
 *             restore_inheritable = set()             # <<<<<<<<<<<<<<
 *             if pass_fds:
 *                 for fd in pass_fds:
 */
      __pyx_t_1 = PySet_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 41, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_v_restore_inheritable = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":42
 * 
 *             restore_inheritable = set()
 *             if pass_fds:             # <<<<<<<<<<<<<<
 *                 for fd in pass_fds:
 *                     if not os_get_inheritable(fd):
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_pass_fds); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 42, __pyx_L4_error)
      if (__pyx_t_2) {

        /* "uvloop/handles/process.pyx":43
 *             restore_inheritable = set()
 *             if pass_fds:
 *                 for fd in pass_fds:             # <<<<<<<<<<<<<<
 *                     if not os_get_inheritable(fd):
 *                         restore_inheritable.add(fd)
 */
        if (likely(PyList_CheckExact(__pyx_v_pass_fds)) || PyTuple_CheckExact(__pyx_v_pass_fds)) {
          __pyx_t_1 = __pyx_v_pass_fds; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
          __pyx_t_7 = NULL;
        } else {
          __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_pass_fds); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 43, __pyx_L4_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 43, __pyx_L4_error)
        }
        for (;;) {
          if (likely(!__pyx_t_7)) {
            if (likely(PyList_CheckExact(__pyx_t_1))) {
              if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(6, 43, __pyx_L4_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 43, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            } else {
              if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(6, 43, __pyx_L4_error)
              #else
              __pyx_t_8 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 43, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_8);
              #endif
            }
          } else {
            __pyx_t_8 = __pyx_t_7(__pyx_t_1);
            if (unlikely(!__pyx_t_8)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(6, 43, __pyx_L4_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_8);
          }
          __Pyx_XDECREF_SET(__pyx_v_fd, __pyx_t_8);
          __pyx_t_8 = 0;

          /* "uvloop/handles/process.pyx":44
 *             if pass_fds:
 *                 for fd in pass_fds:
 *                     if not os_get_inheritable(fd):             # <<<<<<<<<<<<<<
 *                         restore_inheritable.add(fd)
 *                         os_set_inheritable(fd, True)
 */
          __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_get_inheritable);
          __pyx_t_9 = __pyx_v_6uvloop_4loop_os_get_inheritable; __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_10) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_v_fd); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 44, __pyx_L4_error)
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_fd};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 44, __pyx_L4_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_fd};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 44, __pyx_L4_error)
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            {
              __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 44, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
              __Pyx_INCREF(__pyx_v_fd);
              __Pyx_GIVEREF(__pyx_v_fd);
              PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_fd);
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_11, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 44, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 44, __pyx_L4_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_12 = ((!__pyx_t_2) != 0);
          if (__pyx_t_12) {

            /* "uvloop/handles/process.pyx":45
 *                 for fd in pass_fds:
 *                     if not os_get_inheritable(fd):
 *                         restore_inheritable.add(fd)             # <<<<<<<<<<<<<<
 *                         os_set_inheritable(fd, True)
 *         except:
 */
            __pyx_t_13 = PySet_Add(__pyx_v_restore_inheritable, __pyx_v_fd); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(6, 45, __pyx_L4_error)

            /* "uvloop/handles/process.pyx":46
 *                     if not os_get_inheritable(fd):
 *                         restore_inheritable.add(fd)
 *                         os_set_inheritable(fd, True)             # <<<<<<<<<<<<<<
 *         except:
 *             self._abort_init()
 */
            __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
            __pyx_t_9 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_11 = NULL;
            __pyx_t_14 = 0;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
              __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
              if (likely(__pyx_t_11)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
                __Pyx_INCREF(__pyx_t_11);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_9, function);
                __pyx_t_14 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_fd, Py_True};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 46, __pyx_L4_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_fd, Py_True};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 46, __pyx_L4_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 46, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_10);
              if (__pyx_t_11) {
                __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_11); __pyx_t_11 = NULL;
              }
              __Pyx_INCREF(__pyx_v_fd);
              __Pyx_GIVEREF(__pyx_v_fd);
              PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_14, __pyx_v_fd);
              __Pyx_INCREF(Py_True);
              __Pyx_GIVEREF(Py_True);
              PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_14, Py_True);
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 46, __pyx_L4_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

            /* "uvloop/handles/process.pyx":44
 *             if pass_fds:
 *                 for fd in pass_fds:
 *                     if not os_get_inheritable(fd):             # <<<<<<<<<<<<<<
 *                         restore_inheritable.add(fd)
 *                         os_set_inheritable(fd, True)
 */
          }

          /* "uvloop/handles/process.pyx":43
 *             restore_inheritable = set()
 *             if pass_fds:
 *                 for fd in pass_fds:             # <<<<<<<<<<<<<<
 *                     if not os_get_inheritable(fd):
 *                         restore_inheritable.add(fd)
 */
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "uvloop/handles/process.pyx":42
 * 
 *             restore_inheritable = set()
 *             if pass_fds:             # <<<<<<<<<<<<<<
 *                 for fd in pass_fds:
 *                     if not os_get_inheritable(fd):
 */
      }

      /* "uvloop/handles/process.pyx":37
 *         self._handle.data = NULL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self._init_options(args, env, cwd, start_new_session,
 *                                _stdin, _stdout, _stderr)
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":47
 *                         restore_inheritable.add(fd)
 *                         os_set_inheritable(fd, True)
 *         except:             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise
 */
    /*except:*/ {
      __Pyx_AddTraceback("uvloop.loop.UVProcess._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(6, 47, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_9);

      /* "uvloop/handles/process.pyx":48
 *                         os_set_inheritable(fd, True)
 *         except:
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_10 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 48, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "uvloop/handles/process.pyx":49
 *         except:
 *             self._abort_init()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         if __forking or loop.active_process_handler is not None:
 */
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_8, __pyx_t_9);
      __pyx_t_1 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; 
      __PYX_ERR(6, 49, __pyx_L6_except_error)
    }
    __pyx_L6_except_error:;

    /* "uvloop/handles/process.pyx":37
 *         self._handle.data = NULL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             self._init_options(args, env, cwd, start_new_session,
 *                                _stdin, _stdout, _stderr)
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/process.pyx":51
 *             raise
 * 
 *         if __forking or loop.active_process_handler is not None:             # <<<<<<<<<<<<<<
 *             # Our pthread_atfork handlers won't work correctly when
 *             # another loop is forking in another thread (even though
 */
  __pyx_t_2 = (__pyx_v_6uvloop_4loop___forking != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_12 = __pyx_t_2;
    goto __pyx_L17_bool_binop_done;
  }
  __pyx_t_2 = (((PyObject *)__pyx_v_loop->active_process_handler) != Py_None);
  __pyx_t_15 = (__pyx_t_2 != 0);
  __pyx_t_12 = __pyx_t_15;
  __pyx_L17_bool_binop_done:;
  if (unlikely(__pyx_t_12)) {

    /* "uvloop/handles/process.pyx":55
 *             # another loop is forking in another thread (even though
 *             # GIL should help us to avoid that.)
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'Racing with another loop to spawn a process.')
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/handles/process.pyx":56
 *             # GIL should help us to avoid that.)
 *             self._abort_init()
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'Racing with another loop to spawn a process.')
 * 
 */
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__206, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 56, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_Raise(__pyx_t_9, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __PYX_ERR(6, 56, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":51
 *             raise
 * 
 *         if __forking or loop.active_process_handler is not None:             # <<<<<<<<<<<<<<
 *             # Our pthread_atfork handlers won't work correctly when
 *             # another loop is forking in another thread (even though
 */
  }

  /* "uvloop/handles/process.pyx":59
 *                 'Racing with another loop to spawn a process.')
 * 
 *         self._errpipe_read, self._errpipe_write = os_pipe()             # <<<<<<<<<<<<<<
 *         try:
 *             os_set_inheritable(self._errpipe_write, True)
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_pipe);
  __pyx_t_8 = __pyx_v_6uvloop_4loop_os_pipe; __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  if (__pyx_t_1) {
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 59, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 59, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_9))) || (PyList_CheckExact(__pyx_t_9))) {
    PyObject* sequence = __pyx_t_9;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(6, 59, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_1);
    #else
    __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_10 = PyObject_GetIter(__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_16 = Py_TYPE(__pyx_t_10)->tp_iternext;
    index = 0; __pyx_t_8 = __pyx_t_16(__pyx_t_10); if (unlikely(!__pyx_t_8)) goto __pyx_L19_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_8);
    index = 1; __pyx_t_1 = __pyx_t_16(__pyx_t_10); if (unlikely(!__pyx_t_1)) goto __pyx_L19_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_10), 2) < 0) __PYX_ERR(6, 59, __pyx_L1_error)
    __pyx_t_16 = NULL;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L20_unpacking_done;
    __pyx_L19_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_16 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(6, 59, __pyx_L1_error)
    __pyx_L20_unpacking_done:;
  }
  __Pyx_GIVEREF(__pyx_t_8);
  __Pyx_GOTREF(__pyx_v_self->_errpipe_read);
  __Pyx_DECREF(__pyx_v_self->_errpipe_read);
  __pyx_v_self->_errpipe_read = __pyx_t_8;
  __pyx_t_8 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_errpipe_write);
  __Pyx_DECREF(__pyx_v_self->_errpipe_write);
  __pyx_v_self->_errpipe_write = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":60
 * 
 *         self._errpipe_read, self._errpipe_write = os_pipe()
 *         try:             # <<<<<<<<<<<<<<
 *             os_set_inheritable(self._errpipe_write, True)
 * 
 */
  /*try:*/ {

    /* "uvloop/handles/process.pyx":61
 *         self._errpipe_read, self._errpipe_write = os_pipe()
 *         try:
 *             os_set_inheritable(self._errpipe_write, True)             # <<<<<<<<<<<<<<
 * 
 *             self._preexec_fn = preexec_fn
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
    __pyx_t_1 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_8 = NULL;
    __pyx_t_14 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_14 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_self->_errpipe_write, Py_True};
      __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 61, __pyx_L22_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_self->_errpipe_write, Py_True};
      __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 61, __pyx_L22_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_9);
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 61, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_INCREF(__pyx_v_self->_errpipe_write);
      __Pyx_GIVEREF(__pyx_v_self->_errpipe_write);
      PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_14, __pyx_v_self->_errpipe_write);
      __Pyx_INCREF(Py_True);
      __Pyx_GIVEREF(Py_True);
      PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_14, Py_True);
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 61, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/handles/process.pyx":63
 *             os_set_inheritable(self._errpipe_write, True)
 * 
 *             self._preexec_fn = preexec_fn             # <<<<<<<<<<<<<<
 *             self._restore_signals = restore_signals
 * 
 */
    __Pyx_INCREF(__pyx_v_preexec_fn);
    __Pyx_GIVEREF(__pyx_v_preexec_fn);
    __Pyx_GOTREF(__pyx_v_self->_preexec_fn);
    __Pyx_DECREF(__pyx_v_self->_preexec_fn);
    __pyx_v_self->_preexec_fn = __pyx_v_preexec_fn;

    /* "uvloop/handles/process.pyx":64
 * 
 *             self._preexec_fn = preexec_fn
 *             self._restore_signals = restore_signals             # <<<<<<<<<<<<<<
 * 
 *             loop.active_process_handler = self
 */
    __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_restore_signals); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 64, __pyx_L22_error)
    __pyx_v_self->_restore_signals = __pyx_t_12;

    /* "uvloop/handles/process.pyx":66
 *             self._restore_signals = restore_signals
 * 
 *             loop.active_process_handler = self             # <<<<<<<<<<<<<<
 *             __forking = 1
 *             __forking_loop = loop
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_loop->active_process_handler);
    __Pyx_DECREF(((PyObject *)__pyx_v_loop->active_process_handler));
    __pyx_v_loop->active_process_handler = __pyx_v_self;

    /* "uvloop/handles/process.pyx":67
 * 
 *             loop.active_process_handler = self
 *             __forking = 1             # <<<<<<<<<<<<<<
 *             __forking_loop = loop
 * 
 */
    __pyx_v_6uvloop_4loop___forking = 1;

    /* "uvloop/handles/process.pyx":68
 *             loop.active_process_handler = self
 *             __forking = 1
 *             __forking_loop = loop             # <<<<<<<<<<<<<<
 * 
 *             _PyImport_AcquireLock()
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_loop));
    __Pyx_XGOTREF(((PyObject *)__pyx_v_6uvloop_4loop___forking_loop));
    __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop___forking_loop, __pyx_v_loop);
    __Pyx_GIVEREF(((PyObject *)__pyx_v_loop));

    /* "uvloop/handles/process.pyx":70
 *             __forking_loop = loop
 * 
 *             _PyImport_AcquireLock()             # <<<<<<<<<<<<<<
 * 
 *             err = uv.uv_spawn(loop.uvloop,
 */
    _PyImport_AcquireLock();

    /* "uvloop/handles/process.pyx":72
 *             _PyImport_AcquireLock()
 * 
 *             err = uv.uv_spawn(loop.uvloop,             # <<<<<<<<<<<<<<
 *                               <uv.uv_process_t*>self._handle,
 *                               &self.options)
 */
    __pyx_v_err = uv_spawn(__pyx_v_loop->uvloop, ((uv_process_t *)__pyx_v_self->__pyx_base._handle), (&__pyx_v_self->options));

    /* "uvloop/handles/process.pyx":76
 *                               &self.options)
 * 
 *             __forking = 0             # <<<<<<<<<<<<<<
 *             __forking_loop = None
 *             loop.active_process_handler = None
 */
    __pyx_v_6uvloop_4loop___forking = 0;

    /* "uvloop/handles/process.pyx":77
 * 
 *             __forking = 0
 *             __forking_loop = None             # <<<<<<<<<<<<<<
 *             loop.active_process_handler = None
 * 
 */
    __Pyx_INCREF(Py_None);
    __Pyx_XGOTREF(((PyObject *)__pyx_v_6uvloop_4loop___forking_loop));
    __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop___forking_loop, ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None));
    __Pyx_GIVEREF(Py_None);

    /* "uvloop/handles/process.pyx":78
 *             __forking = 0
 *             __forking_loop = None
 *             loop.active_process_handler = None             # <<<<<<<<<<<<<<
 * 
 *             if _PyImport_ReleaseLock() < 0:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_loop->active_process_handler);
    __Pyx_DECREF(((PyObject *)__pyx_v_loop->active_process_handler));
    __pyx_v_loop->active_process_handler = ((struct __pyx_obj_6uvloop_4loop_UVProcess *)Py_None);

    /* "uvloop/handles/process.pyx":80
 *             loop.active_process_handler = None
 * 
 *             if _PyImport_ReleaseLock() < 0:             # <<<<<<<<<<<<<<
 *                 # See CPython/posixmodule.c for details
 *                 self._abort_init()
 */
    __pyx_t_12 = ((_PyImport_ReleaseLock() < 0) != 0);
    if (unlikely(__pyx_t_12)) {

      /* "uvloop/handles/process.pyx":82
 *             if _PyImport_ReleaseLock() < 0:
 *                 # See CPython/posixmodule.c for details
 *                 self._abort_init()             # <<<<<<<<<<<<<<
 *                 raise RuntimeError('not holding the import lock')
 * 
 */
      __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 82, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/handles/process.pyx":83
 *                 # See CPython/posixmodule.c for details
 *                 self._abort_init()
 *                 raise RuntimeError('not holding the import lock')             # <<<<<<<<<<<<<<
 * 
 *             if err < 0:
 */
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__207, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 83, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(6, 83, __pyx_L22_error)

      /* "uvloop/handles/process.pyx":80
 *             loop.active_process_handler = None
 * 
 *             if _PyImport_ReleaseLock() < 0:             # <<<<<<<<<<<<<<
 *                 # See CPython/posixmodule.c for details
 *                 self._abort_init()
 */
    }

    /* "uvloop/handles/process.pyx":85
 *                 raise RuntimeError('not holding the import lock')
 * 
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 self._abort_init()
 *                 raise convert_error(err)
 */
    __pyx_t_12 = ((__pyx_v_err < 0) != 0);
    if (unlikely(__pyx_t_12)) {

      /* "uvloop/handles/process.pyx":86
 * 
 *             if err < 0:
 *                 self._abort_init()             # <<<<<<<<<<<<<<
 *                 raise convert_error(err)
 * 
 */
      __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 86, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/handles/process.pyx":87
 *             if err < 0:
 *                 self._abort_init()
 *                 raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *             self._finish_init()
 */
      __pyx_t_9 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 87, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(6, 87, __pyx_L22_error)

      /* "uvloop/handles/process.pyx":85
 *                 raise RuntimeError('not holding the import lock')
 * 
 *             if err < 0:             # <<<<<<<<<<<<<<
 *                 self._abort_init()
 *                 raise convert_error(err)
 */
    }

    /* "uvloop/handles/process.pyx":89
 *                 raise convert_error(err)
 * 
 *             self._finish_init()             # <<<<<<<<<<<<<<
 * 
 *             os_close(self._errpipe_write)
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 89, __pyx_L22_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/handles/process.pyx":91
 *             self._finish_init()
 * 
 *             os_close(self._errpipe_write)             # <<<<<<<<<<<<<<
 * 
 *             if preexec_fn is not None:
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
    __pyx_t_1 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_10) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_self->_errpipe_write); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 91, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_self->_errpipe_write};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 91, __pyx_L22_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_self->_errpipe_write};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 91, __pyx_L22_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 91, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        __Pyx_INCREF(__pyx_v_self->_errpipe_write);
        __Pyx_GIVEREF(__pyx_v_self->_errpipe_write);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_self->_errpipe_write);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 91, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/handles/process.pyx":93
 *             os_close(self._errpipe_write)
 * 
 *             if preexec_fn is not None:             # <<<<<<<<<<<<<<
 *                 errpipe_data = bytearray()
 *                 while True:
 */
    __pyx_t_12 = (__pyx_v_preexec_fn != Py_None);
    __pyx_t_15 = (__pyx_t_12 != 0);
    if (__pyx_t_15) {

      /* "uvloop/handles/process.pyx":94
 * 
 *             if preexec_fn is not None:
 *                 errpipe_data = bytearray()             # <<<<<<<<<<<<<<
 *                 while True:
 *                     # XXX: This is a blocking code that has to be
 */
      __pyx_t_9 = __Pyx_PyObject_CallNoArg(((PyObject *)(&PyByteArray_Type))); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 94, __pyx_L22_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_v_errpipe_data = __pyx_t_9;
      __pyx_t_9 = 0;

      /* "uvloop/handles/process.pyx":95
 *             if preexec_fn is not None:
 *                 errpipe_data = bytearray()
 *                 while True:             # <<<<<<<<<<<<<<
 *                     # XXX: This is a blocking code that has to be
 *                     # rewritten (using loop.connect_read_pipe() or
 */
      while (1) {

        /* "uvloop/handles/process.pyx":99
 *                     # rewritten (using loop.connect_read_pipe() or
 *                     # otherwise.)
 *                     part = os_read(self._errpipe_read, 50000)             # <<<<<<<<<<<<<<
 *                     errpipe_data += part
 *                     if not part or len(errpipe_data) > 50000:
 */
        __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_read);
        __pyx_t_1 = __pyx_v_6uvloop_4loop_os_read; __pyx_t_8 = NULL;
        __pyx_t_14 = 0;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_14 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_self->_errpipe_read, __pyx_int_50000};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 99, __pyx_L22_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_self->_errpipe_read, __pyx_int_50000};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 99, __pyx_L22_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        {
          __pyx_t_10 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 99, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (__pyx_t_8) {
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
          }
          __Pyx_INCREF(__pyx_v_self->_errpipe_read);
          __Pyx_GIVEREF(__pyx_v_self->_errpipe_read);
          PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_14, __pyx_v_self->_errpipe_read);
          __Pyx_INCREF(__pyx_int_50000);
          __Pyx_GIVEREF(__pyx_int_50000);
          PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_14, __pyx_int_50000);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 99, __pyx_L22_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "uvloop/handles/process.pyx":100
 *                     # otherwise.)
 *                     part = os_read(self._errpipe_read, 50000)
 *                     errpipe_data += part             # <<<<<<<<<<<<<<
 *                     if not part or len(errpipe_data) > 50000:
 *                         break
 */
        __pyx_t_9 = PyNumber_InPlaceAdd(__pyx_v_errpipe_data, __pyx_v_part); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 100, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF_SET(__pyx_v_errpipe_data, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "uvloop/handles/process.pyx":101
 *                     part = os_read(self._errpipe_read, 50000)
 *                     errpipe_data += part
 *                     if not part or len(errpipe_data) > 50000:             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_part); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(6, 101, __pyx_L22_error)
        __pyx_t_2 = ((!__pyx_t_12) != 0);
        if (!__pyx_t_2) {
        } else {
          __pyx_t_15 = __pyx_t_2;
          goto __pyx_L30_bool_binop_done;
        }
        __pyx_t_6 = PyObject_Length(__pyx_v_errpipe_data); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(6, 101, __pyx_L22_error)
        __pyx_t_2 = ((__pyx_t_6 > 0xC350) != 0);
        __pyx_t_15 = __pyx_t_2;
        __pyx_L30_bool_binop_done:;
        if (__pyx_t_15) {

          /* "uvloop/handles/process.pyx":102
 *                     errpipe_data += part
 *                     if not part or len(errpipe_data) > 50000:
 *                         break             # <<<<<<<<<<<<<<
 * 
 *         finally:
 */
          goto __pyx_L28_break;

          /* "uvloop/handles/process.pyx":101
 *                     part = os_read(self._errpipe_read, 50000)
 *                     errpipe_data += part
 *                     if not part or len(errpipe_data) > 50000:             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
        }
      }
      __pyx_L28_break:;

      /* "uvloop/handles/process.pyx":93
 *             os_close(self._errpipe_write)
 * 
 *             if preexec_fn is not None:             # <<<<<<<<<<<<<<
 *                 errpipe_data = bytearray()
 *                 while True:
 */
    }
  }

  /* "uvloop/handles/process.pyx":105
 * 
 *         finally:
 *             os_close(self._errpipe_read)             # <<<<<<<<<<<<<<
 *             try:
 *                 os_close(self._errpipe_write)
 */
  /*finally:*/ {
    /*normal exit:*/{
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
      __pyx_t_1 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (!__pyx_t_10) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_self->_errpipe_read); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_self->_errpipe_read};
          __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
          PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_self->_errpipe_read};
          __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_GOTREF(__pyx_t_9);
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 105, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
          __Pyx_INCREF(__pyx_v_self->_errpipe_read);
          __Pyx_GIVEREF(__pyx_v_self->_errpipe_read);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_self->_errpipe_read);
          __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/handles/process.pyx":106
 *         finally:
 *             os_close(self._errpipe_read)
 *             try:             # <<<<<<<<<<<<<<
 *                 os_close(self._errpipe_write)
 *             except OSError:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_3);
        /*try:*/ {

          /* "uvloop/handles/process.pyx":107
 *             os_close(self._errpipe_read)
 *             try:
 *                 os_close(self._errpipe_write)             # <<<<<<<<<<<<<<
 *             except OSError:
 *                 # Might be already closed
 */
          __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
          __pyx_t_1 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
            }
          }
          if (!__pyx_t_8) {
            __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_self->_errpipe_write); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L32_error)
            __Pyx_GOTREF(__pyx_t_9);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_errpipe_write};
              __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L32_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_9);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_errpipe_write};
              __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L32_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_9);
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 107, __pyx_L32_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
              __Pyx_INCREF(__pyx_v_self->_errpipe_write);
              __Pyx_GIVEREF(__pyx_v_self->_errpipe_write);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_self->_errpipe_write);
              __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L32_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "uvloop/handles/process.pyx":106
 *         finally:
 *             os_close(self._errpipe_read)
 *             try:             # <<<<<<<<<<<<<<
 *                 os_close(self._errpipe_write)
 *             except OSError:
 */
        }
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L37_try_end;
        __pyx_L32_error:;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "uvloop/handles/process.pyx":108
 *             try:
 *                 os_close(self._errpipe_write)
 *             except OSError:             # <<<<<<<<<<<<<<
 *                 # Might be already closed
 *                 pass
 */
        __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
        if (__pyx_t_14) {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L33_exception_handled;
        }
        goto __pyx_L34_except_error;
        __pyx_L34_except_error:;

        /* "uvloop/handles/process.pyx":106
 *         finally:
 *             os_close(self._errpipe_read)
 *             try:             # <<<<<<<<<<<<<<
 *                 os_close(self._errpipe_write)
 *             except OSError:
 */
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
        goto __pyx_L1_error;
        __pyx_L33_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_3);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
        __pyx_L37_try_end:;
      }
      goto __pyx_L23;
    }
    __pyx_L22_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_3 = 0; __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5) < 0)) __Pyx_ErrFetch(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_19);
      __Pyx_XGOTREF(__pyx_t_20);
      __Pyx_XGOTREF(__pyx_t_21);
      __pyx_t_14 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
      {

        /* "uvloop/handles/process.pyx":105
 * 
 *         finally:
 *             os_close(self._errpipe_read)             # <<<<<<<<<<<<<<
 *             try:
 *                 os_close(self._errpipe_write)
 */
        __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
        __pyx_t_1 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        if (!__pyx_t_10) {
          __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_self->_errpipe_read); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L39_error)
          __Pyx_GOTREF(__pyx_t_9);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_1)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_self->_errpipe_read};
            __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L39_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_9);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_self->_errpipe_read};
            __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L39_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_9);
          } else
          #endif
          {
            __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 105, __pyx_L39_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
            __Pyx_INCREF(__pyx_v_self->_errpipe_read);
            __Pyx_GIVEREF(__pyx_v_self->_errpipe_read);
            PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_self->_errpipe_read);
            __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 105, __pyx_L39_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "uvloop/handles/process.pyx":106
 *         finally:
 *             os_close(self._errpipe_read)
 *             try:             # <<<<<<<<<<<<<<
 *                 os_close(self._errpipe_write)
 *             except OSError:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          /*try:*/ {

            /* "uvloop/handles/process.pyx":107
 *             os_close(self._errpipe_read)
 *             try:
 *                 os_close(self._errpipe_write)             # <<<<<<<<<<<<<<
 *             except OSError:
 *                 # Might be already closed
 */
            __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
            __pyx_t_1 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_8 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_8)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_8);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
              }
            }
            if (!__pyx_t_8) {
              __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_self->_errpipe_write); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L40_error)
              __Pyx_GOTREF(__pyx_t_9);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_1)) {
                PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_errpipe_write};
                __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L40_error)
                __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_GOTREF(__pyx_t_9);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
                PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_errpipe_write};
                __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L40_error)
                __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                __Pyx_GOTREF(__pyx_t_9);
              } else
              #endif
              {
                __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 107, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_10);
                __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
                __Pyx_INCREF(__pyx_v_self->_errpipe_write);
                __Pyx_GIVEREF(__pyx_v_self->_errpipe_write);
                PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_v_self->_errpipe_write);
                __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_10, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 107, __pyx_L40_error)
                __Pyx_GOTREF(__pyx_t_9);
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

            /* "uvloop/handles/process.pyx":106
 *         finally:
 *             os_close(self._errpipe_read)
 *             try:             # <<<<<<<<<<<<<<
 *                 os_close(self._errpipe_write)
 *             except OSError:
 */
          }
          __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
          __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
          goto __pyx_L45_try_end;
          __pyx_L40_error:;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

          /* "uvloop/handles/process.pyx":108
 *             try:
 *                 os_close(self._errpipe_write)
 *             except OSError:             # <<<<<<<<<<<<<<
 *                 # Might be already closed
 *                 pass
 */
          __pyx_t_25 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
          if (__pyx_t_25) {
            __Pyx_ErrRestore(0,0,0);
            goto __pyx_L41_exception_handled;
          }
          goto __pyx_L42_except_error;
          __pyx_L42_except_error:;

          /* "uvloop/handles/process.pyx":106
 *         finally:
 *             os_close(self._errpipe_read)
 *             try:             # <<<<<<<<<<<<<<
 *                 os_close(self._errpipe_write)
 *             except OSError:
 */
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_XGIVEREF(__pyx_t_23);
          __Pyx_XGIVEREF(__pyx_t_24);
          __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
          goto __pyx_L39_error;
          __pyx_L41_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_XGIVEREF(__pyx_t_23);
          __Pyx_XGIVEREF(__pyx_t_24);
          __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
          __pyx_L45_try_end:;
        }
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
      }
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ErrRestore(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      __pyx_t_3 = 0; __pyx_t_4 = 0; __pyx_t_5 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
      __pyx_lineno = __pyx_t_14; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
      goto __pyx_L1_error;
      __pyx_L39_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L23:;
  }

  /* "uvloop/handles/process.pyx":115
 *         # so that the transport knows what the PID was even
 *         # after the process is finished.
 *         self._pid = (<uv.uv_process_t*>self._handle).pid             # <<<<<<<<<<<<<<
 * 
 *         # Track the process handle (create a strong ref to it)
 */
  __pyx_t_9 = __Pyx_PyInt_From_int(((uv_process_t *)__pyx_v_self->__pyx_base._handle)->pid); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_9);
  __Pyx_GOTREF(__pyx_v_self->_pid);
  __Pyx_DECREF(__pyx_v_self->_pid);
  __pyx_v_self->_pid = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "uvloop/handles/process.pyx":123
 *         # which will call `UVProcess._close()`, which will, in turn,
 *         # untrack this handle.
 *         self._loop._track_process(self)             # <<<<<<<<<<<<<<
 * 
 *         for fd in restore_inheritable:
 */
  __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_base._loop->__pyx_vtab)->_track_process(__pyx_v_self->__pyx_base._loop, __pyx_v_self); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/handles/process.pyx":125
 *         self._loop._track_process(self)
 * 
 *         for fd in restore_inheritable:             # <<<<<<<<<<<<<<
 *             os_set_inheritable(fd, False)
 * 
 */
  __pyx_t_6 = 0;
  __pyx_t_1 = __Pyx_set_iterator(__pyx_v_restore_inheritable, 1, (&__pyx_t_26), (&__pyx_t_17)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_9);
  __pyx_t_9 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_14 = __Pyx_set_iter_next(__pyx_t_9, __pyx_t_26, &__pyx_t_6, &__pyx_t_1, __pyx_t_17);
    if (unlikely(__pyx_t_14 == 0)) break;
    if (unlikely(__pyx_t_14 == -1)) __PYX_ERR(6, 125, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_fd, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":126
 * 
 *         for fd in restore_inheritable:
 *             os_set_inheritable(fd, False)             # <<<<<<<<<<<<<<
 * 
 *         fds_to_close = self._fds_to_close
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
    __pyx_t_10 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_8 = NULL;
    __pyx_t_14 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_14 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_fd, Py_False};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 126, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_fd, Py_False};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 126, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_INCREF(__pyx_v_fd);
      __Pyx_GIVEREF(__pyx_v_fd);
      PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_14, __pyx_v_fd);
      __Pyx_INCREF(Py_False);
      __Pyx_GIVEREF(Py_False);
      PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_14, Py_False);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 126, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/handles/process.pyx":128
 *             os_set_inheritable(fd, False)
 * 
 *         fds_to_close = self._fds_to_close             # <<<<<<<<<<<<<<
 *         self._fds_to_close = None
 *         for fd in fds_to_close:
 */
  __pyx_t_9 = __pyx_v_self->_fds_to_close;
  __Pyx_INCREF(__pyx_t_9);
  __pyx_v_fds_to_close = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "uvloop/handles/process.pyx":129
 * 
 *         fds_to_close = self._fds_to_close
 *         self._fds_to_close = None             # <<<<<<<<<<<<<<
 *         for fd in fds_to_close:
 *             os_close(fd)
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_fds_to_close);
  __Pyx_DECREF(__pyx_v_self->_fds_to_close);
  __pyx_v_self->_fds_to_close = ((PyObject*)Py_None);

  /* "uvloop/handles/process.pyx":130
 *         fds_to_close = self._fds_to_close
 *         self._fds_to_close = None
 *         for fd in fds_to_close:             # <<<<<<<<<<<<<<
 *             os_close(fd)
 * 
 */
  __pyx_t_26 = 0;
  __pyx_t_1 = __Pyx_set_iterator(__pyx_v_fds_to_close, 1, (&__pyx_t_6), (&__pyx_t_17)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_9);
  __pyx_t_9 = __pyx_t_1;
  __pyx_t_1 = 0;
  while (1) {
    __pyx_t_14 = __Pyx_set_iter_next(__pyx_t_9, __pyx_t_6, &__pyx_t_26, &__pyx_t_1, __pyx_t_17);
    if (unlikely(__pyx_t_14 == 0)) break;
    if (unlikely(__pyx_t_14 == -1)) __PYX_ERR(6, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_fd, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":131
 *         self._fds_to_close = None
 *         for fd in fds_to_close:
 *             os_close(fd)             # <<<<<<<<<<<<<<
 * 
 *         if debug_flags & __PROCESS_DEBUG_SLEEP_AFTER_FORK:
 */
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
    __pyx_t_10 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_11 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_11)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_11) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_fd};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 131, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_v_fd};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 131, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_11); __pyx_t_11 = NULL;
        __Pyx_INCREF(__pyx_v_fd);
        __Pyx_GIVEREF(__pyx_v_fd);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_fd);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "uvloop/handles/process.pyx":133
 *             os_close(fd)
 * 
 *         if debug_flags & __PROCESS_DEBUG_SLEEP_AFTER_FORK:             # <<<<<<<<<<<<<<
 *             time_sleep(1)
 * 
 */
  __pyx_t_9 = __Pyx_PyInt_AndObjC(__pyx_v_debug_flags, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(6, 133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (__pyx_t_15) {

    /* "uvloop/handles/process.pyx":134
 * 
 *         if debug_flags & __PROCESS_DEBUG_SLEEP_AFTER_FORK:
 *             time_sleep(1)             # <<<<<<<<<<<<<<
 * 
 *         if preexec_fn is not None and errpipe_data:
 */
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_time_sleep, __pyx_tuple__208, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "uvloop/handles/process.pyx":133
 *             os_close(fd)
 * 
 *         if debug_flags & __PROCESS_DEBUG_SLEEP_AFTER_FORK:             # <<<<<<<<<<<<<<
 *             time_sleep(1)
 * 
 */
  }

  /* "uvloop/handles/process.pyx":136
 *             time_sleep(1)
 * 
 *         if preexec_fn is not None and errpipe_data:             # <<<<<<<<<<<<<<
 *             # preexec_fn has raised an exception.  The child
 *             # process must be dead now.
 */
  __pyx_t_2 = (__pyx_v_preexec_fn != Py_None);
  __pyx_t_12 = (__pyx_t_2 != 0);
  if (__pyx_t_12) {
  } else {
    __pyx_t_15 = __pyx_t_12;
    goto __pyx_L52_bool_binop_done;
  }
  if (unlikely(!__pyx_v_errpipe_data)) { __Pyx_RaiseUnboundLocalError("errpipe_data"); __PYX_ERR(6, 136, __pyx_L1_error) }
  __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_errpipe_data); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(6, 136, __pyx_L1_error)
  __pyx_t_15 = __pyx_t_12;
  __pyx_L52_bool_binop_done:;
  if (__pyx_t_15) {

    /* "uvloop/handles/process.pyx":139
 *             # preexec_fn has raised an exception.  The child
 *             # process must be dead now.
 *             try:             # <<<<<<<<<<<<<<
 *                 exc_name, exc_msg = errpipe_data.split(b':', 1)
 *                 exc_name = exc_name.decode()
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
      __Pyx_XGOTREF(__pyx_t_21);
      __Pyx_XGOTREF(__pyx_t_20);
      __Pyx_XGOTREF(__pyx_t_19);
      /*try:*/ {

        /* "uvloop/handles/process.pyx":140
 *             # process must be dead now.
 *             try:
 *                 exc_name, exc_msg = errpipe_data.split(b':', 1)             # <<<<<<<<<<<<<<
 *                 exc_name = exc_name.decode()
 *                 exc_msg = exc_msg.decode()
 */
        if (unlikely(!__pyx_v_errpipe_data)) { __Pyx_RaiseUnboundLocalError("errpipe_data"); __PYX_ERR(6, 140, __pyx_L54_error) }
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_errpipe_data, __pyx_n_s_split); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 140, __pyx_L54_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__210, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 140, __pyx_L54_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(6, 140, __pyx_L54_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_10 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          #else
          __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 140, __pyx_L54_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 140, __pyx_L54_error)
          __Pyx_GOTREF(__pyx_t_10);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_8 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 140, __pyx_L54_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_16 = Py_TYPE(__pyx_t_8)->tp_iternext;
          index = 0; __pyx_t_9 = __pyx_t_16(__pyx_t_8); if (unlikely(!__pyx_t_9)) goto __pyx_L60_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_9);
          index = 1; __pyx_t_10 = __pyx_t_16(__pyx_t_8); if (unlikely(!__pyx_t_10)) goto __pyx_L60_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_10);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_16(__pyx_t_8), 2) < 0) __PYX_ERR(6, 140, __pyx_L54_error)
          __pyx_t_16 = NULL;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L61_unpacking_done;
          __pyx_L60_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_16 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(6, 140, __pyx_L54_error)
          __pyx_L61_unpacking_done:;
        }
        __pyx_v_exc_name = __pyx_t_9;
        __pyx_t_9 = 0;
        __pyx_v_exc_msg = __pyx_t_10;
        __pyx_t_10 = 0;

        /* "uvloop/handles/process.pyx":141
 *             try:
 *                 exc_name, exc_msg = errpipe_data.split(b':', 1)
 *                 exc_name = exc_name.decode()             # <<<<<<<<<<<<<<
 *                 exc_msg = exc_msg.decode()
 *             except Exception:
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc_name, __pyx_n_s_decode); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 141, __pyx_L54_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        if (__pyx_t_9) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 141, __pyx_L54_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 141, __pyx_L54_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF_SET(__pyx_v_exc_name, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "uvloop/handles/process.pyx":142
 *                 exc_name, exc_msg = errpipe_data.split(b':', 1)
 *                 exc_name = exc_name.decode()
 *                 exc_msg = exc_msg.decode()             # <<<<<<<<<<<<<<
 *             except Exception:
 *                 self._close()
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc_msg, __pyx_n_s_decode); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 142, __pyx_L54_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        if (__pyx_t_9) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 142, __pyx_L54_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 142, __pyx_L54_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF_SET(__pyx_v_exc_msg, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "uvloop/handles/process.pyx":139
 *             # preexec_fn has raised an exception.  The child
 *             # process must be dead now.
 *             try:             # <<<<<<<<<<<<<<
 *                 exc_name, exc_msg = errpipe_data.split(b':', 1)
 *                 exc_name = exc_name.decode()
 */
      }
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
      __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
      goto __pyx_L59_try_end;
      __pyx_L54_error:;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":143
 *                 exc_name = exc_name.decode()
 *                 exc_msg = exc_msg.decode()
 *             except Exception:             # <<<<<<<<<<<<<<
 *                 self._close()
 *                 raise subprocess_SubprocessError(
 */
      __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_17) {
        __Pyx_AddTraceback("uvloop.loop.UVProcess._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_10, &__pyx_t_9) < 0) __PYX_ERR(6, 143, __pyx_L56_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GOTREF(__pyx_t_9);

        /* "uvloop/handles/process.pyx":144
 *                 exc_msg = exc_msg.decode()
 *             except Exception:
 *                 self._close()             # <<<<<<<<<<<<<<
 *                 raise subprocess_SubprocessError(
 *                     'Bad exception data from child: {!r}'.format(
 */
        __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 144, __pyx_L56_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "uvloop/handles/process.pyx":146
 *                 self._close()
 *                 raise subprocess_SubprocessError(
 *                     'Bad exception data from child: {!r}'.format(             # <<<<<<<<<<<<<<
 *                         errpipe_data))
 *             exc_cls = getattr(__builtins__, exc_name,
 */
        __pyx_t_27 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Bad_exception_data_from_child_r, __pyx_n_s_format); if (unlikely(!__pyx_t_27)) __PYX_ERR(6, 146, __pyx_L56_except_error)
        __Pyx_GOTREF(__pyx_t_27);

        /* "uvloop/handles/process.pyx":147
 *                 raise subprocess_SubprocessError(
 *                     'Bad exception data from child: {!r}'.format(
 *                         errpipe_data))             # <<<<<<<<<<<<<<
 *             exc_cls = getattr(__builtins__, exc_name,
 *                               subprocess_SubprocessError)
 */
        if (unlikely(!__pyx_v_errpipe_data)) { __Pyx_RaiseUnboundLocalError("errpipe_data"); __PYX_ERR(6, 147, __pyx_L56_except_error) }
        __pyx_t_28 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_27))) {
          __pyx_t_28 = PyMethod_GET_SELF(__pyx_t_27);
          if (likely(__pyx_t_28)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_27);
            __Pyx_INCREF(__pyx_t_28);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_27, function);
          }
        }
        if (!__pyx_t_28) {
          __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_27, __pyx_v_errpipe_data); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 146, __pyx_L56_except_error)
          __Pyx_GOTREF(__pyx_t_11);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_27)) {
            PyObject *__pyx_temp[2] = {__pyx_t_28, __pyx_v_errpipe_data};
            __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_27, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 146, __pyx_L56_except_error)
            __Pyx_XDECREF(__pyx_t_28); __pyx_t_28 = 0;
            __Pyx_GOTREF(__pyx_t_11);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_27)) {
            PyObject *__pyx_temp[2] = {__pyx_t_28, __pyx_v_errpipe_data};
            __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_27, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 146, __pyx_L56_except_error)
            __Pyx_XDECREF(__pyx_t_28); __pyx_t_28 = 0;
            __Pyx_GOTREF(__pyx_t_11);
          } else
          #endif
          {
            __pyx_t_29 = PyTuple_New(1+1); if (unlikely(!__pyx_t_29)) __PYX_ERR(6, 146, __pyx_L56_except_error)
            __Pyx_GOTREF(__pyx_t_29);
            __Pyx_GIVEREF(__pyx_t_28); PyTuple_SET_ITEM(__pyx_t_29, 0, __pyx_t_28); __pyx_t_28 = NULL;
            __Pyx_INCREF(__pyx_v_errpipe_data);
            __Pyx_GIVEREF(__pyx_v_errpipe_data);
            PyTuple_SET_ITEM(__pyx_t_29, 0+1, __pyx_v_errpipe_data);
            __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_27, __pyx_t_29, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 146, __pyx_L56_except_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
        __Pyx_INCREF(__pyx_v_6uvloop_4loop_subprocess_SubprocessError);
        __pyx_t_27 = __pyx_v_6uvloop_4loop_subprocess_SubprocessError; __pyx_t_29 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_27))) {
          __pyx_t_29 = PyMethod_GET_SELF(__pyx_t_27);
          if (likely(__pyx_t_29)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_27);
            __Pyx_INCREF(__pyx_t_29);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_27, function);
          }
        }
        if (!__pyx_t_29) {
          __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_27, __pyx_t_11); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 145, __pyx_L56_except_error)
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_27)) {
            PyObject *__pyx_temp[2] = {__pyx_t_29, __pyx_t_11};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_27, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 145, __pyx_L56_except_error)
            __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_27)) {
            PyObject *__pyx_temp[2] = {__pyx_t_29, __pyx_t_11};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_27, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 145, __pyx_L56_except_error)
            __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          } else
          #endif
          {
            __pyx_t_28 = PyTuple_New(1+1); if (unlikely(!__pyx_t_28)) __PYX_ERR(6, 145, __pyx_L56_except_error)
            __Pyx_GOTREF(__pyx_t_28);
            __Pyx_GIVEREF(__pyx_t_29); PyTuple_SET_ITEM(__pyx_t_28, 0, __pyx_t_29); __pyx_t_29 = NULL;
            __Pyx_GIVEREF(__pyx_t_11);
            PyTuple_SET_ITEM(__pyx_t_28, 0+1, __pyx_t_11);
            __pyx_t_11 = 0;
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_27, __pyx_t_28, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 145, __pyx_L56_except_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
        __Pyx_Raise(__pyx_t_8, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __PYX_ERR(6, 145, __pyx_L56_except_error)
      }
      goto __pyx_L56_except_error;
      __pyx_L56_except_error:;

      /* "uvloop/handles/process.pyx":139
 *             # preexec_fn has raised an exception.  The child
 *             # process must be dead now.
 *             try:             # <<<<<<<<<<<<<<
 *                 exc_name, exc_msg = errpipe_data.split(b':', 1)
 *                 exc_name = exc_name.decode()
 */
      __Pyx_XGIVEREF(__pyx_t_21);
      __Pyx_XGIVEREF(__pyx_t_20);
      __Pyx_XGIVEREF(__pyx_t_19);
      __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
      goto __pyx_L1_error;
      __pyx_L59_try_end:;
    }

    /* "uvloop/handles/process.pyx":148
 *                     'Bad exception data from child: {!r}'.format(
 *                         errpipe_data))
 *             exc_cls = getattr(__builtins__, exc_name,             # <<<<<<<<<<<<<<
 *                               subprocess_SubprocessError)
 * 
 */
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_builtins); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);

    /* "uvloop/handles/process.pyx":149
 *                         errpipe_data))
 *             exc_cls = getattr(__builtins__, exc_name,
 *                               subprocess_SubprocessError)             # <<<<<<<<<<<<<<
 * 
 *             exc = subprocess_SubprocessError(
 */
    __pyx_t_10 = __pyx_v_6uvloop_4loop_subprocess_SubprocessError;
    __Pyx_INCREF(__pyx_t_10);

    /* "uvloop/handles/process.pyx":148
 *                     'Bad exception data from child: {!r}'.format(
 *                         errpipe_data))
 *             exc_cls = getattr(__builtins__, exc_name,             # <<<<<<<<<<<<<<
 *                               subprocess_SubprocessError)
 * 
 */
    __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_9, __pyx_v_exc_name, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 148, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_v_exc_cls = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":151
 *                               subprocess_SubprocessError)
 * 
 *             exc = subprocess_SubprocessError(             # <<<<<<<<<<<<<<
 *                 'Exception occurred in preexec_fn.')
 *             exc.__cause__ = exc_cls(exc_msg)
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_subprocess_SubprocessError, __pyx_tuple__211, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_exc = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":153
 *             exc = subprocess_SubprocessError(
 *                 'Exception occurred in preexec_fn.')
 *             exc.__cause__ = exc_cls(exc_msg)             # <<<<<<<<<<<<<<
 *             self._close()
 *             raise exc
 */
    __Pyx_INCREF(__pyx_v_exc_cls);
    __pyx_t_10 = __pyx_v_exc_cls; __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_exc_msg); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_exc_msg};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 153, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_v_exc_msg};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 153, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 153, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_INCREF(__pyx_v_exc_msg);
        __Pyx_GIVEREF(__pyx_v_exc_msg);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_exc_msg);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 153, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_cause, __pyx_t_1) < 0) __PYX_ERR(6, 153, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":154
 *                 'Exception occurred in preexec_fn.')
 *             exc.__cause__ = exc_cls(exc_msg)
 *             self._close()             # <<<<<<<<<<<<<<
 *             raise exc
 * 
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":155
 *             exc.__cause__ = exc_cls(exc_msg)
 *             self._close()
 *             raise exc             # <<<<<<<<<<<<<<
 * 
 *     cdef _after_fork(self):
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(6, 155, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":136
 *             time_sleep(1)
 * 
 *         if preexec_fn is not None and errpipe_data:             # <<<<<<<<<<<<<<
 *             # preexec_fn has raised an exception.  The child
 *             # process must be dead now.
 */
  }

  /* "uvloop/handles/process.pyx":14
 *         self._restore_signals = True
 * 
 *     cdef _init(self, Loop loop, list args, dict env,             # <<<<<<<<<<<<<<
 *                cwd, start_new_session,
 *                _stdin, _stdout, _stderr,  # std* can be defined as macros in C
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_restore_inheritable);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XDECREF(__pyx_v_errpipe_data);
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_XDECREF(__pyx_v_fds_to_close);
  __Pyx_XDECREF(__pyx_v_exc_name);
  __Pyx_XDECREF(__pyx_v_exc_msg);
  __Pyx_XDECREF(__pyx_v_exc_cls);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":157
 *             raise exc
 * 
 *     cdef _after_fork(self):             # <<<<<<<<<<<<<<
 *         # See CPython/_posixsubprocess.c for details
 *         cdef int err
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__after_fork(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_t_20;
  char const *__pyx_t_21;
  PyObject *__pyx_t_22 = NULL;
  char const *__pyx_t_23;
  __Pyx_RefNannySetupContext("_after_fork", 0);

  /* "uvloop/handles/process.pyx":161
 *         cdef int err
 * 
 *         if self._restore_signals:             # <<<<<<<<<<<<<<
 *             _Py_RestoreSignals()
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_restore_signals != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":162
 * 
 *         if self._restore_signals:
 *             _Py_RestoreSignals()             # <<<<<<<<<<<<<<
 * 
 *         PyOS_AfterFork()
 */
    _Py_RestoreSignals();

    /* "uvloop/handles/process.pyx":161
 *         cdef int err
 * 
 *         if self._restore_signals:             # <<<<<<<<<<<<<<
 *             _Py_RestoreSignals()
 * 
 */
  }

  /* "uvloop/handles/process.pyx":164
 *             _Py_RestoreSignals()
 * 
 *         PyOS_AfterFork()             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_loop_fork(self._loop.uvloop)
 */
  PyOS_AfterFork();

  /* "uvloop/handles/process.pyx":166
 *         PyOS_AfterFork()
 * 
 *         err = uv.uv_loop_fork(self._loop.uvloop)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
  __pyx_v_err = uv_loop_fork(__pyx_v_self->__pyx_base._loop->uvloop);

  /* "uvloop/handles/process.pyx":167
 * 
 *         err = uv.uv_loop_fork(self._loop.uvloop)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/process.pyx":168
 *         err = uv.uv_loop_fork(self._loop.uvloop)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         if self._preexec_fn is not None:
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 168, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(6, 168, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":167
 * 
 *         err = uv.uv_loop_fork(self._loop.uvloop)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  }

  /* "uvloop/handles/process.pyx":170
 *             raise convert_error(err)
 * 
 *         if self._preexec_fn is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 gc_disable()
 */
  __pyx_t_1 = (__pyx_v_self->_preexec_fn != Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/process.pyx":171
 * 
 *         if self._preexec_fn is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 gc_disable()
 *                 self._preexec_fn()
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/handles/process.pyx":172
 *         if self._preexec_fn is not None:
 *             try:
 *                 gc_disable()             # <<<<<<<<<<<<<<
 *                 self._preexec_fn()
 *             except BaseException as ex:
 */
        __Pyx_INCREF(__pyx_v_6uvloop_4loop_gc_disable);
        __pyx_t_7 = __pyx_v_6uvloop_4loop_gc_disable; __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (__pyx_t_8) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 172, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else {
          __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 172, __pyx_L6_error)
        }
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/handles/process.pyx":173
 *             try:
 *                 gc_disable()
 *                 self._preexec_fn()             # <<<<<<<<<<<<<<
 *             except BaseException as ex:
 *                 try:
 */
        __Pyx_INCREF(__pyx_v_self->_preexec_fn);
        __pyx_t_7 = __pyx_v_self->_preexec_fn; __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (__pyx_t_8) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 173, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else {
          __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 173, __pyx_L6_error)
        }
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/handles/process.pyx":171
 * 
 *         if self._preexec_fn is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 gc_disable()
 *                 self._preexec_fn()
 */
      }

      /* "uvloop/handles/process.pyx":183
 *                     system._exit(255)
 *             else:
 *                 os_close(self._errpipe_write)             # <<<<<<<<<<<<<<
 *         else:
 *             os_close(self._errpipe_write)
 */
      /*else:*/ {
        __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
        __pyx_t_7 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_8 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        if (!__pyx_t_8) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_self->_errpipe_write); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 183, __pyx_L8_except_error)
          __Pyx_GOTREF(__pyx_t_2);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_errpipe_write};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 183, __pyx_L8_except_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->_errpipe_write};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 183, __pyx_L8_except_error)
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          {
            __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 183, __pyx_L8_except_error)
            __Pyx_GOTREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
            __Pyx_INCREF(__pyx_v_self->_errpipe_write);
            __Pyx_GIVEREF(__pyx_v_self->_errpipe_write);
            PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_self->_errpipe_write);
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 183, __pyx_L8_except_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/process.pyx":174
 *                 gc_disable()
 *                 self._preexec_fn()
 *             except BaseException as ex:             # <<<<<<<<<<<<<<
 *                 try:
 *                     with open(self._errpipe_write, 'wb') as f:
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.UVProcess._after_fork", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_9) < 0) __PYX_ERR(6, 174, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_ex = __pyx_t_7;
        /*try:*/ {

          /* "uvloop/handles/process.pyx":175
 *                 self._preexec_fn()
 *             except BaseException as ex:
 *                 try:             # <<<<<<<<<<<<<<
 *                     with open(self._errpipe_write, 'wb') as f:
 *                         f.write(str(ex.__class__.__name__).encode())
 */
          /*try:*/ {

            /* "uvloop/handles/process.pyx":176
 *             except BaseException as ex:
 *                 try:
 *                     with open(self._errpipe_write, 'wb') as f:             # <<<<<<<<<<<<<<
 *                         f.write(str(ex.__class__.__name__).encode())
 *                         f.write(b':')
 */
            /*with:*/ {
              __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 176, __pyx_L22_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_INCREF(__pyx_v_self->_errpipe_write);
              __Pyx_GIVEREF(__pyx_v_self->_errpipe_write);
              PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_self->_errpipe_write);
              __Pyx_INCREF(__pyx_n_u_wb);
              __Pyx_GIVEREF(__pyx_n_u_wb);
              PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_n_u_wb);
              __pyx_t_11 = __Pyx_PyObject_Call(__pyx_builtin_open, __pyx_t_8, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 176, __pyx_L22_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
              __pyx_t_12 = __Pyx_PyObject_LookupSpecial(__pyx_t_11, __pyx_n_s_exit); if (unlikely(!__pyx_t_12)) __PYX_ERR(6, 176, __pyx_L22_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_13 = __Pyx_PyObject_LookupSpecial(__pyx_t_11, __pyx_n_s_enter); if (unlikely(!__pyx_t_13)) __PYX_ERR(6, 176, __pyx_L24_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_14 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
                __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
                if (likely(__pyx_t_14)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                  __Pyx_INCREF(__pyx_t_14);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_13, function);
                }
              }
              if (__pyx_t_14) {
                __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 176, __pyx_L24_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              } else {
                __pyx_t_8 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 176, __pyx_L24_error)
              }
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __pyx_t_13 = __pyx_t_8;
              __pyx_t_8 = 0;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              /*try:*/ {
                {
                  __Pyx_PyThreadState_declare
                  __Pyx_PyThreadState_assign
                  __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
                  __Pyx_XGOTREF(__pyx_t_15);
                  __Pyx_XGOTREF(__pyx_t_16);
                  __Pyx_XGOTREF(__pyx_t_17);
                  /*try:*/ {
                    __pyx_v_f = __pyx_t_13;
                    __pyx_t_13 = 0;

                    /* "uvloop/handles/process.pyx":177
 *                 try:
 *                     with open(self._errpipe_write, 'wb') as f:
 *                         f.write(str(ex.__class__.__name__).encode())             # <<<<<<<<<<<<<<
 *                         f.write(b':')
 *                         f.write(str(ex.args[0]).encode())
 */
                    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_write); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 177, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_11);
                    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_ex, __pyx_n_s_class); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 177, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_8);
                    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_name); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 177, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_14);
                    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                    __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_14); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 177, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_8);
                    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                    __pyx_t_14 = PyUnicode_AsEncodedString(((PyObject*)__pyx_t_8), NULL, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 177, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_14);
                    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                    __pyx_t_8 = NULL;
                    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
                      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_11);
                      if (likely(__pyx_t_8)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
                        __Pyx_INCREF(__pyx_t_8);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_11, function);
                      }
                    }
                    if (!__pyx_t_8) {
                      __pyx_t_13 = __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(6, 177, __pyx_L30_error)
                      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                      __Pyx_GOTREF(__pyx_t_13);
                    } else {
                      #if CYTHON_FAST_PYCALL
                      if (PyFunction_Check(__pyx_t_11)) {
                        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_14};
                        __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(6, 177, __pyx_L30_error)
                        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                        __Pyx_GOTREF(__pyx_t_13);
                        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                      } else
                      #endif
                      #if CYTHON_FAST_PYCCALL
                      if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
                        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_14};
                        __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(6, 177, __pyx_L30_error)
                        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                        __Pyx_GOTREF(__pyx_t_13);
                        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                      } else
                      #endif
                      {
                        __pyx_t_18 = PyTuple_New(1+1); if (unlikely(!__pyx_t_18)) __PYX_ERR(6, 177, __pyx_L30_error)
                        __Pyx_GOTREF(__pyx_t_18);
                        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_8); __pyx_t_8 = NULL;
                        __Pyx_GIVEREF(__pyx_t_14);
                        PyTuple_SET_ITEM(__pyx_t_18, 0+1, __pyx_t_14);
                        __pyx_t_14 = 0;
                        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_18, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(6, 177, __pyx_L30_error)
                        __Pyx_GOTREF(__pyx_t_13);
                        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                      }
                    }
                    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

                    /* "uvloop/handles/process.pyx":178
 *                     with open(self._errpipe_write, 'wb') as f:
 *                         f.write(str(ex.__class__.__name__).encode())
 *                         f.write(b':')             # <<<<<<<<<<<<<<
 *                         f.write(str(ex.args[0]).encode())
 *                 finally:
 */
                    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_write); if (unlikely(!__pyx_t_13)) __PYX_ERR(6, 178, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_13);
                    __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__212, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 178, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_11);
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

                    /* "uvloop/handles/process.pyx":179
 *                         f.write(str(ex.__class__.__name__).encode())
 *                         f.write(b':')
 *                         f.write(str(ex.args[0]).encode())             # <<<<<<<<<<<<<<
 *                 finally:
 *                     system._exit(255)
 */
                    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_f, __pyx_n_s_write); if (unlikely(!__pyx_t_13)) __PYX_ERR(6, 179, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_13);
                    __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_ex, __pyx_n_s_args); if (unlikely(!__pyx_t_18)) __PYX_ERR(6, 179, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_18);
                    __pyx_t_14 = __Pyx_GetItemInt(__pyx_t_18, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 179, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_14);
                    __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                    __pyx_t_18 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_t_14); if (unlikely(!__pyx_t_18)) __PYX_ERR(6, 179, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_18);
                    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                    __pyx_t_14 = PyUnicode_AsEncodedString(((PyObject*)__pyx_t_18), NULL, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 179, __pyx_L30_error)
                    __Pyx_GOTREF(__pyx_t_14);
                    __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
                    __pyx_t_18 = NULL;
                    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
                      __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_13);
                      if (likely(__pyx_t_18)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                        __Pyx_INCREF(__pyx_t_18);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_13, function);
                      }
                    }
                    if (!__pyx_t_18) {
                      __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_14); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 179, __pyx_L30_error)
                      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                      __Pyx_GOTREF(__pyx_t_11);
                    } else {
                      #if CYTHON_FAST_PYCALL
                      if (PyFunction_Check(__pyx_t_13)) {
                        PyObject *__pyx_temp[2] = {__pyx_t_18, __pyx_t_14};
                        __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 179, __pyx_L30_error)
                        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                        __Pyx_GOTREF(__pyx_t_11);
                        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                      } else
                      #endif
                      #if CYTHON_FAST_PYCCALL
                      if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
                        PyObject *__pyx_temp[2] = {__pyx_t_18, __pyx_t_14};
                        __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 179, __pyx_L30_error)
                        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                        __Pyx_GOTREF(__pyx_t_11);
                        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                      } else
                      #endif
                      {
                        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 179, __pyx_L30_error)
                        __Pyx_GOTREF(__pyx_t_8);
                        __Pyx_GIVEREF(__pyx_t_18); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_18); __pyx_t_18 = NULL;
                        __Pyx_GIVEREF(__pyx_t_14);
                        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_14);
                        __pyx_t_14 = 0;
                        __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_8, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 179, __pyx_L30_error)
                        __Pyx_GOTREF(__pyx_t_11);
                        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                      }
                    }
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

                    /* "uvloop/handles/process.pyx":176
 *             except BaseException as ex:
 *                 try:
 *                     with open(self._errpipe_write, 'wb') as f:             # <<<<<<<<<<<<<<
 *                         f.write(str(ex.__class__.__name__).encode())
 *                         f.write(b':')
 */
                  }
                  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                  goto __pyx_L37_try_end;
                  __pyx_L30_error:;
                  __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
                  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                  /*except:*/ {
                    __Pyx_AddTraceback("uvloop.loop.UVProcess._after_fork", __pyx_clineno, __pyx_lineno, __pyx_filename);
                    if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_13, &__pyx_t_8) < 0) __PYX_ERR(6, 176, __pyx_L32_except_error)
                    __Pyx_GOTREF(__pyx_t_11);
                    __Pyx_GOTREF(__pyx_t_13);
                    __Pyx_GOTREF(__pyx_t_8);
                    __pyx_t_14 = PyTuple_Pack(3, __pyx_t_11, __pyx_t_13, __pyx_t_8); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 176, __pyx_L32_except_error)
                    __Pyx_GOTREF(__pyx_t_14);
                    __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_14, NULL);
                    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
                    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                    if (unlikely(!__pyx_t_19)) __PYX_ERR(6, 176, __pyx_L32_except_error)
                    __Pyx_GOTREF(__pyx_t_19);
                    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_19);
                    __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
                    if (__pyx_t_3 < 0) __PYX_ERR(6, 176, __pyx_L32_except_error)
                    __pyx_t_1 = ((!(__pyx_t_3 != 0)) != 0);
                    if (__pyx_t_1) {
                      __Pyx_GIVEREF(__pyx_t_11);
                      __Pyx_GIVEREF(__pyx_t_13);
                      __Pyx_XGIVEREF(__pyx_t_8);
                      __Pyx_ErrRestoreWithState(__pyx_t_11, __pyx_t_13, __pyx_t_8);
                      __pyx_t_11 = 0; __pyx_t_13 = 0; __pyx_t_8 = 0; 
                      __PYX_ERR(6, 176, __pyx_L32_except_error)
                    }
                    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
                    goto __pyx_L31_exception_handled;
                  }
                  __pyx_L32_except_error:;
                  __Pyx_XGIVEREF(__pyx_t_15);
                  __Pyx_XGIVEREF(__pyx_t_16);
                  __Pyx_XGIVEREF(__pyx_t_17);
                  __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
                  goto __pyx_L22_error;
                  __pyx_L31_exception_handled:;
                  __Pyx_XGIVEREF(__pyx_t_15);
                  __Pyx_XGIVEREF(__pyx_t_16);
                  __Pyx_XGIVEREF(__pyx_t_17);
                  __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
                  __pyx_L37_try_end:;
                }
              }
              /*finally:*/ {
                /*normal exit:*/{
                  if (__pyx_t_12) {
                    __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_tuple__213, NULL);
                    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
                    if (unlikely(!__pyx_t_17)) __PYX_ERR(6, 176, __pyx_L22_error)
                    __Pyx_GOTREF(__pyx_t_17);
                    __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                  }
                  goto __pyx_L29;
                }
                __pyx_L29:;
              }
              goto __pyx_L41;
              __pyx_L24_error:;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              goto __pyx_L22_error;
              __pyx_L41:;
            }
          }

          /* "uvloop/handles/process.pyx":181
 *                         f.write(str(ex.args[0]).encode())
 *                 finally:
 *                     system._exit(255)             # <<<<<<<<<<<<<<
 *             else:
 *                 os_close(self._errpipe_write)
 */
          /*finally:*/ {
            /*normal exit:*/{
              _exit(0xFF);
              goto __pyx_L23;
            }
            __pyx_L22_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_12 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_19 = 0; __pyx_t_22 = 0;
              __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_19, &__pyx_t_22);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_17, &__pyx_t_16) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_17, &__pyx_t_16);
              __Pyx_XGOTREF(__pyx_t_12);
              __Pyx_XGOTREF(__pyx_t_17);
              __Pyx_XGOTREF(__pyx_t_16);
              __Pyx_XGOTREF(__pyx_t_15);
              __Pyx_XGOTREF(__pyx_t_19);
              __Pyx_XGOTREF(__pyx_t_22);
              __pyx_t_10 = __pyx_lineno; __pyx_t_20 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
              {
                _exit(0xFF);
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_15);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_22);
                __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_19, __pyx_t_22);
              }
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_ErrRestore(__pyx_t_12, __pyx_t_17, __pyx_t_16);
              __pyx_t_12 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0; __pyx_t_15 = 0; __pyx_t_19 = 0; __pyx_t_22 = 0;
              __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_20; __pyx_filename = __pyx_t_21;
              goto __pyx_L17_error;
            }
            __pyx_L23:;
          }
        }

        /* "uvloop/handles/process.pyx":174
 *                 gc_disable()
 *                 self._preexec_fn()
 *             except BaseException as ex:             # <<<<<<<<<<<<<<
 *                 try:
 *                     with open(self._errpipe_write, 'wb') as f:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L18;
          }
          __pyx_L17_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_22 = 0; __pyx_t_19 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_16, &__pyx_t_17, &__pyx_t_12);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_19, &__pyx_t_15) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_19, &__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_15);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_12);
            __pyx_t_20 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_23 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_16);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_XGIVEREF(__pyx_t_12);
              __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_12);
            }
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_ErrRestore(__pyx_t_22, __pyx_t_19, __pyx_t_15);
            __pyx_t_22 = 0; __pyx_t_19 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_12 = 0;
            __pyx_lineno = __pyx_t_20; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_23;
            goto __pyx_L8_except_error;
          }
          __pyx_L18:;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L7_exception_handled;
      }
      goto __pyx_L8_except_error;
      __pyx_L8_except_error:;

      /* "uvloop/handles/process.pyx":171
 * 
 *         if self._preexec_fn is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 gc_disable()
 *                 self._preexec_fn()
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_L11_try_end:;
    }

    /* "uvloop/handles/process.pyx":170
 *             raise convert_error(err)
 * 
 *         if self._preexec_fn is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 gc_disable()
 */
    goto __pyx_L5;
  }

  /* "uvloop/handles/process.pyx":185
 *                 os_close(self._errpipe_write)
 *         else:
 *             os_close(self._errpipe_write)             # <<<<<<<<<<<<<<
 * 
 *     cdef _close_after_spawn(self, int fd):
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_close);
    __pyx_t_7 = __pyx_v_6uvloop_4loop_os_close; __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_self->_errpipe_write); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 185, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self->_errpipe_write};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 185, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_self->_errpipe_write};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 185, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 185, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_INCREF(__pyx_v_self->_errpipe_write);
        __Pyx_GIVEREF(__pyx_v_self->_errpipe_write);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_self->_errpipe_write);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 185, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __pyx_L5:;

  /* "uvloop/handles/process.pyx":157
 *             raise exc
 * 
 *     cdef _after_fork(self):             # <<<<<<<<<<<<<<
 *         # See CPython/_posixsubprocess.c for details
 *         cdef int err
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._after_fork", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":187
 *             os_close(self._errpipe_write)
 * 
 *     cdef _close_after_spawn(self, int fd):             # <<<<<<<<<<<<<<
 *         if self._fds_to_close is None:
 *             raise RuntimeError(
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__close_after_spawn(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, int __pyx_v_fd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("_close_after_spawn", 0);

  /* "uvloop/handles/process.pyx":188
 * 
 *     cdef _close_after_spawn(self, int fd):
 *         if self._fds_to_close is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'UVProcess._close_after_spawn called after uv_spawn')
 */
  __pyx_t_1 = (__pyx_v_self->_fds_to_close == ((PyObject*)Py_None));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/process.pyx":189
 *     cdef _close_after_spawn(self, int fd):
 *         if self._fds_to_close is None:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'UVProcess._close_after_spawn called after uv_spawn')
 *         self._fds_to_close.add(fd)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__214, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(6, 189, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":188
 * 
 *     cdef _close_after_spawn(self, int fd):
 *         if self._fds_to_close is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(
 *                 'UVProcess._close_after_spawn called after uv_spawn')
 */
  }

  /* "uvloop/handles/process.pyx":191
 *             raise RuntimeError(
 *                 'UVProcess._close_after_spawn called after uv_spawn')
 *         self._fds_to_close.add(fd)             # <<<<<<<<<<<<<<
 * 
 *     cdef _dealloc_impl(self):
 */
  if (unlikely(__pyx_v_self->_fds_to_close == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(6, 191, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PySet_Add(__pyx_v_self->_fds_to_close, __pyx_t_3); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(6, 191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/process.pyx":187
 *             os_close(self._errpipe_write)
 * 
 *     cdef _close_after_spawn(self, int fd):             # <<<<<<<<<<<<<<
 *         if self._fds_to_close is None:
 *             raise RuntimeError(
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._close_after_spawn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":193
 *         self._fds_to_close.add(fd)
 * 
 *     cdef _dealloc_impl(self):             # <<<<<<<<<<<<<<
 *         if self.uv_opt_env is not NULL:
 *             PyMem_RawFree(self.uv_opt_env)
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__dealloc_impl(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_dealloc_impl", 0);

  /* "uvloop/handles/process.pyx":194
 * 
 *     cdef _dealloc_impl(self):
 *         if self.uv_opt_env is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_RawFree(self.uv_opt_env)
 *             self.uv_opt_env = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->uv_opt_env != NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":195
 *     cdef _dealloc_impl(self):
 *         if self.uv_opt_env is not NULL:
 *             PyMem_RawFree(self.uv_opt_env)             # <<<<<<<<<<<<<<
 *             self.uv_opt_env = NULL
 * 
 */
    PyMem_RawFree(__pyx_v_self->uv_opt_env);

    /* "uvloop/handles/process.pyx":196
 *         if self.uv_opt_env is not NULL:
 *             PyMem_RawFree(self.uv_opt_env)
 *             self.uv_opt_env = NULL             # <<<<<<<<<<<<<<
 * 
 *         if self.uv_opt_args is not NULL:
 */
    __pyx_v_self->uv_opt_env = NULL;

    /* "uvloop/handles/process.pyx":194
 * 
 *     cdef _dealloc_impl(self):
 *         if self.uv_opt_env is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_RawFree(self.uv_opt_env)
 *             self.uv_opt_env = NULL
 */
  }

  /* "uvloop/handles/process.pyx":198
 *             self.uv_opt_env = NULL
 * 
 *         if self.uv_opt_args is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_RawFree(self.uv_opt_args)
 *             self.uv_opt_args = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->uv_opt_args != NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":199
 * 
 *         if self.uv_opt_args is not NULL:
 *             PyMem_RawFree(self.uv_opt_args)             # <<<<<<<<<<<<<<
 *             self.uv_opt_args = NULL
 * 
 */
    PyMem_RawFree(__pyx_v_self->uv_opt_args);

    /* "uvloop/handles/process.pyx":200
 *         if self.uv_opt_args is not NULL:
 *             PyMem_RawFree(self.uv_opt_args)
 *             self.uv_opt_args = NULL             # <<<<<<<<<<<<<<
 * 
 *         UVHandle._dealloc_impl(self)
 */
    __pyx_v_self->uv_opt_args = NULL;

    /* "uvloop/handles/process.pyx":198
 *             self.uv_opt_env = NULL
 * 
 *         if self.uv_opt_args is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_RawFree(self.uv_opt_args)
 *             self.uv_opt_args = NULL
 */
  }

  /* "uvloop/handles/process.pyx":202
 *             self.uv_opt_args = NULL
 * 
 *         UVHandle._dealloc_impl(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef char** __to_cstring_array(self, list arr):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVHandle__dealloc_impl(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/process.pyx":193
 *         self._fds_to_close.add(fd)
 * 
 *     cdef _dealloc_impl(self):             # <<<<<<<<<<<<<<
 *         if self.uv_opt_env is not NULL:
 *             PyMem_RawFree(self.uv_opt_env)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._dealloc_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":204
 *         UVHandle._dealloc_impl(self)
 * 
 *     cdef char** __to_cstring_array(self, list arr):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int i
 */

static char **__pyx_f_6uvloop_4loop_9UVProcess___to_cstring_array(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_arr) {
  int __pyx_v_i;
  Py_ssize_t __pyx_v_arr_len;
  PyObject *__pyx_v_el = 0;
  char **__pyx_v_ret;
  char **__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  __Pyx_RefNannySetupContext("__to_cstring_array", 0);

  /* "uvloop/handles/process.pyx":207
 *         cdef:
 *             int i
 *             ssize_t arr_len = len(arr)             # <<<<<<<<<<<<<<
 *             bytes el
 * 
 */
  if (unlikely(__pyx_v_arr == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(6, 207, __pyx_L1_error)
  }
  __pyx_t_1 = PyList_GET_SIZE(__pyx_v_arr); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(6, 207, __pyx_L1_error)
  __pyx_v_arr_len = __pyx_t_1;

  /* "uvloop/handles/process.pyx":212
 *             char **ret
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             assert arr_len > 0
 * 
 */
  __pyx_t_2 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":213
 * 
 *         if UVLOOP_DEBUG:
 *             assert arr_len > 0             # <<<<<<<<<<<<<<
 * 
 *         ret = <char **>PyMem_RawMalloc((arr_len + 1) * sizeof(char *))
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_arr_len > 0) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(6, 213, __pyx_L1_error)
      }
    }
    #endif

    /* "uvloop/handles/process.pyx":212
 *             char **ret
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             assert arr_len > 0
 * 
 */
  }

  /* "uvloop/handles/process.pyx":215
 *             assert arr_len > 0
 * 
 *         ret = <char **>PyMem_RawMalloc((arr_len + 1) * sizeof(char *))             # <<<<<<<<<<<<<<
 *         if ret is NULL:
 *             raise MemoryError()
 */
  __pyx_v_ret = ((char **)PyMem_RawMalloc(((__pyx_v_arr_len + 1) * (sizeof(char *)))));

  /* "uvloop/handles/process.pyx":216
 * 
 *         ret = <char **>PyMem_RawMalloc((arr_len + 1) * sizeof(char *))
 *         if ret is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
  __pyx_t_2 = ((__pyx_v_ret == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/process.pyx":217
 *         ret = <char **>PyMem_RawMalloc((arr_len + 1) * sizeof(char *))
 *         if ret is NULL:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *         for i in range(arr_len):
 */
    PyErr_NoMemory(); __PYX_ERR(6, 217, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":216
 * 
 *         ret = <char **>PyMem_RawMalloc((arr_len + 1) * sizeof(char *))
 *         if ret is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
  }

  /* "uvloop/handles/process.pyx":219
 *             raise MemoryError()
 * 
 *         for i in range(arr_len):             # <<<<<<<<<<<<<<
 *             el = arr[i]
 *             # NB: PyBytes_AsSptring doesn't copy the data;
 */
  __pyx_t_3 = __pyx_v_arr_len;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "uvloop/handles/process.pyx":220
 * 
 *         for i in range(arr_len):
 *             el = arr[i]             # <<<<<<<<<<<<<<
 *             # NB: PyBytes_AsSptring doesn't copy the data;
 *             # we have to be careful when the "arr" is GCed,
 */
    if (unlikely(__pyx_v_arr == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(6, 220, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_v_arr, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (!(likely(PyBytes_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_6)->tp_name), 0))) __PYX_ERR(6, 220, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_el, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "uvloop/handles/process.pyx":224
 *             # we have to be careful when the "arr" is GCed,
 *             # and it shouldn't be ever mutated.
 *             ret[i] = PyBytes_AsString(el)             # <<<<<<<<<<<<<<
 * 
 *         ret[arr_len] = NULL
 */
    __pyx_t_7 = PyBytes_AsString(__pyx_v_el); if (unlikely(__pyx_t_7 == ((char *)NULL))) __PYX_ERR(6, 224, __pyx_L1_error)
    (__pyx_v_ret[__pyx_v_i]) = __pyx_t_7;
  }

  /* "uvloop/handles/process.pyx":226
 *             ret[i] = PyBytes_AsString(el)
 * 
 *         ret[arr_len] = NULL             # <<<<<<<<<<<<<<
 *         return ret
 * 
 */
  (__pyx_v_ret[__pyx_v_arr_len]) = NULL;

  /* "uvloop/handles/process.pyx":227
 * 
 *         ret[arr_len] = NULL
 *         return ret             # <<<<<<<<<<<<<<
 * 
 *     cdef _init_options(self, list args, dict env, cwd, start_new_session,
 */
  __pyx_r = __pyx_v_ret;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":204
 *         UVHandle._dealloc_impl(self)
 * 
 *     cdef char** __to_cstring_array(self, list arr):             # <<<<<<<<<<<<<<
 *         cdef:
 *             int i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_WriteUnraisable("uvloop.loop.UVProcess.__to_cstring_array", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_el);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":229
 *         return ret
 * 
 *     cdef _init_options(self, list args, dict env, cwd, start_new_session,             # <<<<<<<<<<<<<<
 *                        _stdin, _stdout, _stderr):
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_options(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_args, PyObject *__pyx_v_env, PyObject *__pyx_v_cwd, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr) {
  PyObject *__pyx_v_fspath = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char **__pyx_t_2;
  char *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  __Pyx_RefNannySetupContext("_init_options", 0);
  __Pyx_INCREF(__pyx_v_cwd);

  /* "uvloop/handles/process.pyx":232
 *                        _stdin, _stdout, _stderr):
 * 
 *         memset(&self.options, 0, sizeof(uv.uv_process_options_t))             # <<<<<<<<<<<<<<
 * 
 *         self._init_env(env)
 */
  (void)(memset((&__pyx_v_self->options), 0, (sizeof(uv_process_options_t))));

  /* "uvloop/handles/process.pyx":234
 *         memset(&self.options, 0, sizeof(uv.uv_process_options_t))
 * 
 *         self._init_env(env)             # <<<<<<<<<<<<<<
 *         self.options.env = self.uv_opt_env
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->_init_env(__pyx_v_self, __pyx_v_env); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 234, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":235
 * 
 *         self._init_env(env)
 *         self.options.env = self.uv_opt_env             # <<<<<<<<<<<<<<
 * 
 *         self._init_args(args)
 */
  __pyx_t_2 = __pyx_v_self->uv_opt_env;
  __pyx_v_self->options.env = __pyx_t_2;

  /* "uvloop/handles/process.pyx":237
 *         self.options.env = self.uv_opt_env
 * 
 *         self._init_args(args)             # <<<<<<<<<<<<<<
 *         self.options.file = self.uv_opt_file
 *         self.options.args = self.uv_opt_args
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->_init_args(__pyx_v_self, __pyx_v_args); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":238
 * 
 *         self._init_args(args)
 *         self.options.file = self.uv_opt_file             # <<<<<<<<<<<<<<
 *         self.options.args = self.uv_opt_args
 * 
 */
  __pyx_t_3 = __pyx_v_self->uv_opt_file;
  __pyx_v_self->options.file = __pyx_t_3;

  /* "uvloop/handles/process.pyx":239
 *         self._init_args(args)
 *         self.options.file = self.uv_opt_file
 *         self.options.args = self.uv_opt_args             # <<<<<<<<<<<<<<
 * 
 *         if start_new_session:
 */
  __pyx_t_2 = __pyx_v_self->uv_opt_args;
  __pyx_v_self->options.args = __pyx_t_2;

  /* "uvloop/handles/process.pyx":241
 *         self.options.args = self.uv_opt_args
 * 
 *         if start_new_session:             # <<<<<<<<<<<<<<
 *             self.options.flags |= uv.UV_PROCESS_DETACHED
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_start_new_session); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(6, 241, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "uvloop/handles/process.pyx":242
 * 
 *         if start_new_session:
 *             self.options.flags |= uv.UV_PROCESS_DETACHED             # <<<<<<<<<<<<<<
 * 
 *         if cwd is not None:
 */
    __pyx_v_self->options.flags = (__pyx_v_self->options.flags | UV_PROCESS_DETACHED);

    /* "uvloop/handles/process.pyx":241
 *         self.options.args = self.uv_opt_args
 * 
 *         if start_new_session:             # <<<<<<<<<<<<<<
 *             self.options.flags |= uv.UV_PROCESS_DETACHED
 * 
 */
  }

  /* "uvloop/handles/process.pyx":244
 *             self.options.flags |= uv.UV_PROCESS_DETACHED
 * 
 *         if cwd is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 */
  __pyx_t_4 = (__pyx_v_cwd != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "uvloop/handles/process.pyx":245
 * 
 *         if cwd is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "uvloop/handles/process.pyx":248
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 *                 fspath = type(cwd).__fspath__             # <<<<<<<<<<<<<<
 *             except AttributeError:
 *                 pass
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_cwd)), __pyx_n_s_fspath); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 248, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_fspath = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "uvloop/handles/process.pyx":245
 * 
 *         if cwd is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
      }

      /* "uvloop/handles/process.pyx":252
 *                 pass
 *             else:
 *                 cwd = fspath(cwd)             # <<<<<<<<<<<<<<
 * 
 *             if isinstance(cwd, str):
 */
      /*else:*/ {
        __Pyx_INCREF(__pyx_v_fspath);
        __pyx_t_9 = __pyx_v_fspath; __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
          }
        }
        if (!__pyx_t_10) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_v_cwd); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 252, __pyx_L7_except_error)
          __Pyx_GOTREF(__pyx_t_1);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_9)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_cwd};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 252, __pyx_L7_except_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
            PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_cwd};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 252, __pyx_L7_except_error)
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          {
            __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 252, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
            __Pyx_INCREF(__pyx_v_cwd);
            __Pyx_GIVEREF(__pyx_v_cwd);
            PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_v_cwd);
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 252, __pyx_L7_except_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF_SET(__pyx_v_cwd, __pyx_t_1);
        __pyx_t_1 = 0;
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L10_try_end;
      __pyx_L5_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":249
 *                 # available on Python 3.5.
 *                 fspath = type(cwd).__fspath__
 *             except AttributeError:             # <<<<<<<<<<<<<<
 *                 pass
 *             else:
 */
      __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
      if (__pyx_t_12) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L6_exception_handled;
      }
      goto __pyx_L7_except_error;
      __pyx_L7_except_error:;

      /* "uvloop/handles/process.pyx":245
 * 
 *         if cwd is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 *                 # available on Python 3.5.
 */
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L6_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L10_try_end:;
    }

    /* "uvloop/handles/process.pyx":254
 *                 cwd = fspath(cwd)
 * 
 *             if isinstance(cwd, str):             # <<<<<<<<<<<<<<
 *                 cwd = PyUnicode_EncodeFSDefault(cwd)
 *             if not isinstance(cwd, bytes):
 */
    __pyx_t_5 = PyUnicode_Check(__pyx_v_cwd); 
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (__pyx_t_4) {

      /* "uvloop/handles/process.pyx":255
 * 
 *             if isinstance(cwd, str):
 *                 cwd = PyUnicode_EncodeFSDefault(cwd)             # <<<<<<<<<<<<<<
 *             if not isinstance(cwd, bytes):
 *                 raise ValueError('cwd must be a str or bytes object')
 */
      __pyx_t_1 = PyUnicode_EncodeFSDefault(__pyx_v_cwd); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 255, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF_SET(__pyx_v_cwd, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":254
 *                 cwd = fspath(cwd)
 * 
 *             if isinstance(cwd, str):             # <<<<<<<<<<<<<<
 *                 cwd = PyUnicode_EncodeFSDefault(cwd)
 *             if not isinstance(cwd, bytes):
 */
    }

    /* "uvloop/handles/process.pyx":256
 *             if isinstance(cwd, str):
 *                 cwd = PyUnicode_EncodeFSDefault(cwd)
 *             if not isinstance(cwd, bytes):             # <<<<<<<<<<<<<<
 *                 raise ValueError('cwd must be a str or bytes object')
 * 
 */
    __pyx_t_4 = PyBytes_Check(__pyx_v_cwd); 
    __pyx_t_5 = ((!(__pyx_t_4 != 0)) != 0);
    if (unlikely(__pyx_t_5)) {

      /* "uvloop/handles/process.pyx":257
 *                 cwd = PyUnicode_EncodeFSDefault(cwd)
 *             if not isinstance(cwd, bytes):
 *                 raise ValueError('cwd must be a str or bytes object')             # <<<<<<<<<<<<<<
 * 
 *             self.__cwd = cwd
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__215, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 257, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(6, 257, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":256
 *             if isinstance(cwd, str):
 *                 cwd = PyUnicode_EncodeFSDefault(cwd)
 *             if not isinstance(cwd, bytes):             # <<<<<<<<<<<<<<
 *                 raise ValueError('cwd must be a str or bytes object')
 * 
 */
    }

    /* "uvloop/handles/process.pyx":259
 *                 raise ValueError('cwd must be a str or bytes object')
 * 
 *             self.__cwd = cwd             # <<<<<<<<<<<<<<
 *             self.options.cwd = PyBytes_AsString(self.__cwd)
 * 
 */
    if (!(likely(PyBytes_CheckExact(__pyx_v_cwd))||((__pyx_v_cwd) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_v_cwd)->tp_name), 0))) __PYX_ERR(6, 259, __pyx_L1_error)
    __pyx_t_1 = __pyx_v_cwd;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx___cwd);
    __Pyx_DECREF(__pyx_v_self->__pyx___cwd);
    __pyx_v_self->__pyx___cwd = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":260
 * 
 *             self.__cwd = cwd
 *             self.options.cwd = PyBytes_AsString(self.__cwd)             # <<<<<<<<<<<<<<
 * 
 *         self.options.exit_cb = &__uvprocess_on_exit_callback
 */
    __pyx_t_1 = __pyx_v_self->__pyx___cwd;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = PyBytes_AsString(__pyx_t_1); if (unlikely(__pyx_t_3 == ((char *)NULL))) __PYX_ERR(6, 260, __pyx_L1_error)
    __pyx_v_self->options.cwd = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":244
 *             self.options.flags |= uv.UV_PROCESS_DETACHED
 * 
 *         if cwd is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 # Lookup __fspath__ manually, as os.fspath() isn't
 */
  }

  /* "uvloop/handles/process.pyx":262
 *             self.options.cwd = PyBytes_AsString(self.__cwd)
 * 
 *         self.options.exit_cb = &__uvprocess_on_exit_callback             # <<<<<<<<<<<<<<
 * 
 *         self._init_files(_stdin, _stdout, _stderr)
 */
  __pyx_v_self->options.exit_cb = (&__pyx_f_6uvloop_4loop___uvprocess_on_exit_callback);

  /* "uvloop/handles/process.pyx":264
 *         self.options.exit_cb = &__uvprocess_on_exit_callback
 * 
 *         self._init_files(_stdin, _stdout, _stderr)             # <<<<<<<<<<<<<<
 * 
 *     cdef _init_args(self, list args):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->_init_files(__pyx_v_self, __pyx_v__stdin, __pyx_v__stdout, __pyx_v__stderr); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":229
 *         return ret
 * 
 *     cdef _init_options(self, list args, dict env, cwd, start_new_session,             # <<<<<<<<<<<<<<
 *                        _stdin, _stdout, _stderr):
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._init_options", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fspath);
  __Pyx_XDECREF(__pyx_v_cwd);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":266
 *         self._init_files(_stdin, _stdout, _stderr)
 * 
 *     cdef _init_args(self, list args):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes path
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_args(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_args) {
  PyObject *__pyx_v_path = 0;
  int __pyx_v_an;
  int __pyx_v_i;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  char *__pyx_t_8;
  __Pyx_RefNannySetupContext("_init_args", 0);

  /* "uvloop/handles/process.pyx":269
 *         cdef:
 *             bytes path
 *             int an = len(args)             # <<<<<<<<<<<<<<
 * 
 *         if an < 1:
 */
  if (unlikely(__pyx_v_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(6, 269, __pyx_L1_error)
  }
  __pyx_t_1 = PyList_GET_SIZE(__pyx_v_args); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(6, 269, __pyx_L1_error)
  __pyx_v_an = __pyx_t_1;

  /* "uvloop/handles/process.pyx":271
 *             int an = len(args)
 * 
 *         if an < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError('cannot spawn a process: args are empty')
 * 
 */
  __pyx_t_2 = ((__pyx_v_an < 1) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/process.pyx":272
 * 
 *         if an < 1:
 *             raise ValueError('cannot spawn a process: args are empty')             # <<<<<<<<<<<<<<
 * 
 *         self.__args = args.copy()
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__216, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(6, 272, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":271
 *             int an = len(args)
 * 
 *         if an < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError('cannot spawn a process: args are empty')
 * 
 */
  }

  /* "uvloop/handles/process.pyx":274
 *             raise ValueError('cannot spawn a process: args are empty')
 * 
 *         self.__args = args.copy()             # <<<<<<<<<<<<<<
 *         for i in range(an):
 *             arg = args[i]
 */
  __pyx_t_3 = __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyList_Type_copy, __pyx_v_args); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(PyList_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(6, 274, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->__pyx___args);
  __Pyx_DECREF(__pyx_v_self->__pyx___args);
  __pyx_v_self->__pyx___args = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/handles/process.pyx":275
 * 
 *         self.__args = args.copy()
 *         for i in range(an):             # <<<<<<<<<<<<<<
 *             arg = args[i]
 *             if isinstance(arg, str):
 */
  __pyx_t_4 = __pyx_v_an;
  __pyx_t_5 = __pyx_t_4;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "uvloop/handles/process.pyx":276
 *         self.__args = args.copy()
 *         for i in range(an):
 *             arg = args[i]             # <<<<<<<<<<<<<<
 *             if isinstance(arg, str):
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)
 */
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(6, 276, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_args, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/handles/process.pyx":277
 *         for i in range(an):
 *             arg = args[i]
 *             if isinstance(arg, str):             # <<<<<<<<<<<<<<
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)
 *             elif not isinstance(arg, bytes):
 */
    __pyx_t_2 = PyUnicode_Check(__pyx_v_arg); 
    __pyx_t_7 = (__pyx_t_2 != 0);
    if (__pyx_t_7) {

      /* "uvloop/handles/process.pyx":278
 *             arg = args[i]
 *             if isinstance(arg, str):
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)             # <<<<<<<<<<<<<<
 *             elif not isinstance(arg, bytes):
 *                 raise TypeError('all args must be str or bytes')
 */
      __pyx_t_3 = PyUnicode_EncodeFSDefault(__pyx_v_arg); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(__pyx_v_self->__pyx___args == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(6, 278, __pyx_L1_error)
      }
      if (unlikely(__Pyx_SetItemInt(__pyx_v_self->__pyx___args, __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(6, 278, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/process.pyx":277
 *         for i in range(an):
 *             arg = args[i]
 *             if isinstance(arg, str):             # <<<<<<<<<<<<<<
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)
 *             elif not isinstance(arg, bytes):
 */
      goto __pyx_L6;
    }

    /* "uvloop/handles/process.pyx":279
 *             if isinstance(arg, str):
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)
 *             elif not isinstance(arg, bytes):             # <<<<<<<<<<<<<<
 *                 raise TypeError('all args must be str or bytes')
 * 
 */
    __pyx_t_7 = PyBytes_Check(__pyx_v_arg); 
    __pyx_t_2 = ((!(__pyx_t_7 != 0)) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/handles/process.pyx":280
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)
 *             elif not isinstance(arg, bytes):
 *                 raise TypeError('all args must be str or bytes')             # <<<<<<<<<<<<<<
 * 
 *         path = self.__args[0]
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__217, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 280, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(6, 280, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":279
 *             if isinstance(arg, str):
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)
 *             elif not isinstance(arg, bytes):             # <<<<<<<<<<<<<<
 *                 raise TypeError('all args must be str or bytes')
 * 
 */
    }
    __pyx_L6:;
  }

  /* "uvloop/handles/process.pyx":282
 *                 raise TypeError('all args must be str or bytes')
 * 
 *         path = self.__args[0]             # <<<<<<<<<<<<<<
 *         self.uv_opt_file = PyBytes_AsString(path)
 *         self.uv_opt_args = self.__to_cstring_array(self.__args)
 */
  if (unlikely(__pyx_v_self->__pyx___args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(6, 282, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___args, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "bytes", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(6, 282, __pyx_L1_error)
  __pyx_v_path = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/handles/process.pyx":283
 * 
 *         path = self.__args[0]
 *         self.uv_opt_file = PyBytes_AsString(path)             # <<<<<<<<<<<<<<
 *         self.uv_opt_args = self.__to_cstring_array(self.__args)
 * 
 */
  __pyx_t_8 = PyBytes_AsString(__pyx_v_path); if (unlikely(__pyx_t_8 == ((char *)NULL))) __PYX_ERR(6, 283, __pyx_L1_error)
  __pyx_v_self->uv_opt_file = __pyx_t_8;

  /* "uvloop/handles/process.pyx":284
 *         path = self.__args[0]
 *         self.uv_opt_file = PyBytes_AsString(path)
 *         self.uv_opt_args = self.__to_cstring_array(self.__args)             # <<<<<<<<<<<<<<
 * 
 *     cdef _init_env(self, dict env):
 */
  __pyx_t_3 = __pyx_v_self->__pyx___args;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_self->uv_opt_args = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx___to_cstring_array(__pyx_v_self, ((PyObject*)__pyx_t_3));
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/handles/process.pyx":266
 *         self._init_files(_stdin, _stdout, _stderr)
 * 
 *     cdef _init_args(self, list args):             # <<<<<<<<<<<<<<
 *         cdef:
 *             bytes path
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._init_args", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":286
 *         self.uv_opt_args = self.__to_cstring_array(self.__args)
 * 
 *     cdef _init_env(self, dict env):             # <<<<<<<<<<<<<<
 *         if env is not None and len(env):
 *             self.__env = list()
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_env(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, PyObject *__pyx_v_env) {
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("_init_env", 0);

  /* "uvloop/handles/process.pyx":287
 * 
 *     cdef _init_env(self, dict env):
 *         if env is not None and len(env):             # <<<<<<<<<<<<<<
 *             self.__env = list()
 *             for key in env:
 */
  __pyx_t_2 = (__pyx_v_env != ((PyObject*)Py_None));
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  if (unlikely(__pyx_v_env == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(6, 287, __pyx_L1_error)
  }
  __pyx_t_4 = PyDict_Size(__pyx_v_env); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(6, 287, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":288
 *     cdef _init_env(self, dict env):
 *         if env is not None and len(env):
 *             self.__env = list()             # <<<<<<<<<<<<<<
 *             for key in env:
 *                 val = env[key]
 */
    __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_v_self->__pyx___env);
    __Pyx_DECREF(__pyx_v_self->__pyx___env);
    __pyx_v_self->__pyx___env = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "uvloop/handles/process.pyx":289
 *         if env is not None and len(env):
 *             self.__env = list()
 *             for key in env:             # <<<<<<<<<<<<<<
 *                 val = env[key]
 * 
 */
    __pyx_t_4 = 0;
    if (unlikely(__pyx_v_env == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(6, 289, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_dict_iterator(__pyx_v_env, 1, ((PyObject *)NULL), (&__pyx_t_6), (&__pyx_t_7)); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5);
    __pyx_t_5 = __pyx_t_8;
    __pyx_t_8 = 0;
    while (1) {
      __pyx_t_9 = __Pyx_dict_iter_next(__pyx_t_5, __pyx_t_6, &__pyx_t_4, &__pyx_t_8, NULL, NULL, __pyx_t_7);
      if (unlikely(__pyx_t_9 == 0)) break;
      if (unlikely(__pyx_t_9 == -1)) __PYX_ERR(6, 289, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "uvloop/handles/process.pyx":290
 *             self.__env = list()
 *             for key in env:
 *                 val = env[key]             # <<<<<<<<<<<<<<
 * 
 *                 if isinstance(key, str):
 */
      if (unlikely(__pyx_v_env == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(6, 290, __pyx_L1_error)
      }
      __pyx_t_8 = __Pyx_PyDict_GetItem(__pyx_v_env, __pyx_v_key); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 290, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "uvloop/handles/process.pyx":292
 *                 val = env[key]
 * 
 *                 if isinstance(key, str):             # <<<<<<<<<<<<<<
 *                     key = PyUnicode_EncodeFSDefault(key)
 *                 elif not isinstance(key, bytes):
 */
      __pyx_t_1 = PyUnicode_Check(__pyx_v_key); 
      __pyx_t_3 = (__pyx_t_1 != 0);
      if (__pyx_t_3) {

        /* "uvloop/handles/process.pyx":293
 * 
 *                 if isinstance(key, str):
 *                     key = PyUnicode_EncodeFSDefault(key)             # <<<<<<<<<<<<<<
 *                 elif not isinstance(key, bytes):
 *                     raise TypeError(
 */
        __pyx_t_8 = PyUnicode_EncodeFSDefault(__pyx_v_key); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 293, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF_SET(__pyx_v_key, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "uvloop/handles/process.pyx":292
 *                 val = env[key]
 * 
 *                 if isinstance(key, str):             # <<<<<<<<<<<<<<
 *                     key = PyUnicode_EncodeFSDefault(key)
 *                 elif not isinstance(key, bytes):
 */
        goto __pyx_L8;
      }

      /* "uvloop/handles/process.pyx":294
 *                 if isinstance(key, str):
 *                     key = PyUnicode_EncodeFSDefault(key)
 *                 elif not isinstance(key, bytes):             # <<<<<<<<<<<<<<
 *                     raise TypeError(
 *                         'all environment vars must be bytes or str')
 */
      __pyx_t_3 = PyBytes_Check(__pyx_v_key); 
      __pyx_t_1 = ((!(__pyx_t_3 != 0)) != 0);
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/handles/process.pyx":295
 *                     key = PyUnicode_EncodeFSDefault(key)
 *                 elif not isinstance(key, bytes):
 *                     raise TypeError(             # <<<<<<<<<<<<<<
 *                         'all environment vars must be bytes or str')
 * 
 */
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__218, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 295, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_Raise(__pyx_t_8, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __PYX_ERR(6, 295, __pyx_L1_error)

        /* "uvloop/handles/process.pyx":294
 *                 if isinstance(key, str):
 *                     key = PyUnicode_EncodeFSDefault(key)
 *                 elif not isinstance(key, bytes):             # <<<<<<<<<<<<<<
 *                     raise TypeError(
 *                         'all environment vars must be bytes or str')
 */
      }
      __pyx_L8:;

      /* "uvloop/handles/process.pyx":298
 *                         'all environment vars must be bytes or str')
 * 
 *                 if isinstance(val, str):             # <<<<<<<<<<<<<<
 *                     val = PyUnicode_EncodeFSDefault(val)
 *                 elif not isinstance(val, bytes):
 */
      __pyx_t_1 = PyUnicode_Check(__pyx_v_val); 
      __pyx_t_3 = (__pyx_t_1 != 0);
      if (__pyx_t_3) {

        /* "uvloop/handles/process.pyx":299
 * 
 *                 if isinstance(val, str):
 *                     val = PyUnicode_EncodeFSDefault(val)             # <<<<<<<<<<<<<<
 *                 elif not isinstance(val, bytes):
 *                     raise TypeError(
 */
        __pyx_t_8 = PyUnicode_EncodeFSDefault(__pyx_v_val); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF_SET(__pyx_v_val, __pyx_t_8);
        __pyx_t_8 = 0;

        /* "uvloop/handles/process.pyx":298
 *                         'all environment vars must be bytes or str')
 * 
 *                 if isinstance(val, str):             # <<<<<<<<<<<<<<
 *                     val = PyUnicode_EncodeFSDefault(val)
 *                 elif not isinstance(val, bytes):
 */
        goto __pyx_L9;
      }

      /* "uvloop/handles/process.pyx":300
 *                 if isinstance(val, str):
 *                     val = PyUnicode_EncodeFSDefault(val)
 *                 elif not isinstance(val, bytes):             # <<<<<<<<<<<<<<
 *                     raise TypeError(
 *                         'all environment values must be bytes or str')
 */
      __pyx_t_3 = PyBytes_Check(__pyx_v_val); 
      __pyx_t_1 = ((!(__pyx_t_3 != 0)) != 0);
      if (unlikely(__pyx_t_1)) {

        /* "uvloop/handles/process.pyx":301
 *                     val = PyUnicode_EncodeFSDefault(val)
 *                 elif not isinstance(val, bytes):
 *                     raise TypeError(             # <<<<<<<<<<<<<<
 *                         'all environment values must be bytes or str')
 * 
 */
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__219, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 301, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_Raise(__pyx_t_8, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __PYX_ERR(6, 301, __pyx_L1_error)

        /* "uvloop/handles/process.pyx":300
 *                 if isinstance(val, str):
 *                     val = PyUnicode_EncodeFSDefault(val)
 *                 elif not isinstance(val, bytes):             # <<<<<<<<<<<<<<
 *                     raise TypeError(
 *                         'all environment values must be bytes or str')
 */
      }
      __pyx_L9:;

      /* "uvloop/handles/process.pyx":304
 *                         'all environment values must be bytes or str')
 * 
 *                 self.__env.append(key + b'=' + val)             # <<<<<<<<<<<<<<
 * 
 *             self.uv_opt_env = self.__to_cstring_array(self.__env)
 */
      if (unlikely(__pyx_v_self->__pyx___env == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(6, 304, __pyx_L1_error)
      }
      __pyx_t_8 = PyNumber_Add(__pyx_v_key, __pyx_kp_b__220); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 304, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = PyNumber_Add(__pyx_t_8, __pyx_v_val); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 304, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_self->__pyx___env, __pyx_t_10); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(6, 304, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/process.pyx":306
 *                 self.__env.append(key + b'=' + val)
 * 
 *             self.uv_opt_env = self.__to_cstring_array(self.__env)             # <<<<<<<<<<<<<<
 *         else:
 *             self.__env = None
 */
    __pyx_t_5 = __pyx_v_self->__pyx___env;
    __Pyx_INCREF(__pyx_t_5);
    __pyx_v_self->uv_opt_env = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx___to_cstring_array(__pyx_v_self, ((PyObject*)__pyx_t_5));
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/process.pyx":287
 * 
 *     cdef _init_env(self, dict env):
 *         if env is not None and len(env):             # <<<<<<<<<<<<<<
 *             self.__env = list()
 *             for key in env:
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":308
 *             self.uv_opt_env = self.__to_cstring_array(self.__env)
 *         else:
 *             self.__env = None             # <<<<<<<<<<<<<<
 * 
 *     cdef _init_files(self, _stdin, _stdout, _stderr):
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->__pyx___env);
    __Pyx_DECREF(__pyx_v_self->__pyx___env);
    __pyx_v_self->__pyx___env = ((PyObject*)Py_None);
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":286
 *         self.uv_opt_args = self.__to_cstring_array(self.__args)
 * 
 *     cdef _init_env(self, dict env):             # <<<<<<<<<<<<<<
 *         if env is not None and len(env):
 *             self.__env = list()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._init_env", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":310
 *             self.__env = None
 * 
 *     cdef _init_files(self, _stdin, _stdout, _stderr):             # <<<<<<<<<<<<<<
 *         self.options.stdio_count = 0
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__init_files(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v__stdin, CYTHON_UNUSED PyObject *__pyx_v__stdout, CYTHON_UNUSED PyObject *__pyx_v__stderr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_init_files", 0);

  /* "uvloop/handles/process.pyx":311
 * 
 *     cdef _init_files(self, _stdin, _stdout, _stderr):
 *         self.options.stdio_count = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef _kill(self, int signum):
 */
  __pyx_v_self->options.stdio_count = 0;

  /* "uvloop/handles/process.pyx":310
 *             self.__env = None
 * 
 *     cdef _init_files(self, _stdin, _stdout, _stderr):             # <<<<<<<<<<<<<<
 *         self.options.stdio_count = 0
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":313
 *         self.options.stdio_count = 0
 * 
 *     cdef _kill(self, int signum):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__kill(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, int __pyx_v_signum) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("_kill", 0);

  /* "uvloop/handles/process.pyx":315
 *     cdef _kill(self, int signum):
 *         cdef int err
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         err = uv.uv_process_kill(<uv.uv_process_t*>self._handle, signum)
 *         if err < 0:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":316
 *         cdef int err
 *         self._ensure_alive()
 *         err = uv.uv_process_kill(<uv.uv_process_t*>self._handle, signum)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
  __pyx_v_err = uv_process_kill(((uv_process_t *)__pyx_v_self->__pyx_base._handle), __pyx_v_signum);

  /* "uvloop/handles/process.pyx":317
 *         self._ensure_alive()
 *         err = uv.uv_process_kill(<uv.uv_process_t*>self._handle, signum)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  __pyx_t_2 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/process.pyx":318
 *         err = uv.uv_process_kill(<uv.uv_process_t*>self._handle, signum)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(6, 318, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":317
 *         self._ensure_alive()
 *         err = uv.uv_process_kill(<uv.uv_process_t*>self._handle, signum)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
  }

  /* "uvloop/handles/process.pyx":313
 *         self.options.stdio_count = 0
 * 
 *     cdef _kill(self, int signum):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         self._ensure_alive()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":320
 *             raise convert_error(err)
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):             # <<<<<<<<<<<<<<
 *         if term_signal:
 *             # From Python docs:
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__on_exit(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, int64_t __pyx_v_exit_status, int __pyx_v_term_signal) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_on_exit", 0);

  /* "uvloop/handles/process.pyx":321
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):
 *         if term_signal:             # <<<<<<<<<<<<<<
 *             # From Python docs:
 *             #    A negative value -N indicates that the child was
 */
  __pyx_t_1 = (__pyx_v_term_signal != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":325
 *             #    A negative value -N indicates that the child was
 *             #    terminated by signal N (POSIX only).
 *             self._returncode = -term_signal             # <<<<<<<<<<<<<<
 *         else:
 *             self._returncode = exit_status
 */
    __pyx_t_2 = __Pyx_PyInt_From_int((-__pyx_v_term_signal)); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_returncode);
    __Pyx_DECREF(__pyx_v_self->_returncode);
    __pyx_v_self->_returncode = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":321
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):
 *         if term_signal:             # <<<<<<<<<<<<<<
 *             # From Python docs:
 *             #    A negative value -N indicates that the child was
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":327
 *             self._returncode = -term_signal
 *         else:
 *             self._returncode = exit_status             # <<<<<<<<<<<<<<
 * 
 *         self._close()
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyInt_From_int64_t(__pyx_v_exit_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 327, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->_returncode);
    __Pyx_DECREF(__pyx_v_self->_returncode);
    __pyx_v_self->_returncode = __pyx_t_2;
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":329
 *             self._returncode = exit_status
 * 
 *         self._close()             # <<<<<<<<<<<<<<
 * 
 *     cdef _close(self):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/process.pyx":320
 *             raise convert_error(err)
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):             # <<<<<<<<<<<<<<
 *         if term_signal:
 *             # From Python docs:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._on_exit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":331
 *         self._close()
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._loop is not None:
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVProcess__close(struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  char const *__pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "uvloop/handles/process.pyx":332
 * 
 *     cdef _close(self):
 *         try:             # <<<<<<<<<<<<<<
 *             if self._loop is not None:
 *                 self._loop._untrack_process(self)
 */
  /*try:*/ {

    /* "uvloop/handles/process.pyx":333
 *     cdef _close(self):
 *         try:
 *             if self._loop is not None:             # <<<<<<<<<<<<<<
 *                 self._loop._untrack_process(self)
 *         finally:
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->__pyx_base._loop) != Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/process.pyx":334
 *         try:
 *             if self._loop is not None:
 *                 self._loop._untrack_process(self)             # <<<<<<<<<<<<<<
 *         finally:
 *             UVHandle._close(self)
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->__pyx_base._loop->__pyx_vtab)->_untrack_process(__pyx_v_self->__pyx_base._loop, __pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 334, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/process.pyx":333
 *     cdef _close(self):
 *         try:
 *             if self._loop is not None:             # <<<<<<<<<<<<<<
 *                 self._loop._untrack_process(self)
 *         finally:
 */
    }
  }

  /* "uvloop/handles/process.pyx":336
 *                 self._loop._untrack_process(self)
 *         finally:
 *             UVHandle._close(self)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_3 = __pyx_f_6uvloop_4loop_8UVHandle__close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 336, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __pyx_t_4 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_6 = __pyx_filename;
      {
        __pyx_t_3 = __pyx_f_6uvloop_4loop_8UVHandle__close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 336, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_6;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "uvloop/handles/process.pyx":331
 *         self._close()
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._loop is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UVProcess._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_9UVProcess_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_9UVProcess_2__reduce_cython__[] = "UVProcess.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_9UVProcess_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_9UVProcess_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_9UVProcess_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__221, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcess.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_9UVProcess_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_9UVProcess_4__setstate_cython__[] = "UVProcess.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_9UVProcess_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_9UVProcess_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_9UVProcess_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__222, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcess.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":347
 * @cython.no_gc_clear
 * cdef class UVProcessTransport(UVProcess):
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._exit_waiters = []
 *         self._protocol = None
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_18UVProcessTransport_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_18UVProcessTransport_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport___cinit__(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_18UVProcessTransport___cinit__(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/process.pyx":348
 * cdef class UVProcessTransport(UVProcess):
 *     def __cinit__(self):
 *         self._exit_waiters = []             # <<<<<<<<<<<<<<
 *         self._protocol = None
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_exit_waiters);
  __Pyx_DECREF(__pyx_v_self->_exit_waiters);
  __pyx_v_self->_exit_waiters = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":349
 *     def __cinit__(self):
 *         self._exit_waiters = []
 *         self._protocol = None             # <<<<<<<<<<<<<<
 * 
 *         self._init_futs = []
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_protocol);
  __Pyx_DECREF(__pyx_v_self->_protocol);
  __pyx_v_self->_protocol = Py_None;

  /* "uvloop/handles/process.pyx":351
 *         self._protocol = None
 * 
 *         self._init_futs = []             # <<<<<<<<<<<<<<
 *         self._pending_calls = []
 *         self._stdio_ready = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_init_futs);
  __Pyx_DECREF(__pyx_v_self->_init_futs);
  __pyx_v_self->_init_futs = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":352
 * 
 *         self._init_futs = []
 *         self._pending_calls = []             # <<<<<<<<<<<<<<
 *         self._stdio_ready = 0
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_pending_calls);
  __Pyx_DECREF(__pyx_v_self->_pending_calls);
  __pyx_v_self->_pending_calls = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":353
 *         self._init_futs = []
 *         self._pending_calls = []
 *         self._stdio_ready = 0             # <<<<<<<<<<<<<<
 * 
 *         self._stdin = self._stdout = self._stderr = None
 */
  __pyx_v_self->_stdio_ready = 0;

  /* "uvloop/handles/process.pyx":355
 *         self._stdio_ready = 0
 * 
 *         self._stdin = self._stdout = self._stderr = None             # <<<<<<<<<<<<<<
 *         self.stdin_proto = self.stdout_proto = self.stderr_proto = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_stdin);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_stdin));
  __pyx_v_self->_stdin = ((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)Py_None);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_stdout);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_stdout));
  __pyx_v_self->_stdout = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)Py_None);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_stderr);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_stderr));
  __pyx_v_self->_stderr = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)Py_None);

  /* "uvloop/handles/process.pyx":356
 * 
 *         self._stdin = self._stdout = self._stderr = None
 *         self.stdin_proto = self.stdout_proto = self.stderr_proto = None             # <<<<<<<<<<<<<<
 * 
 *         self._finished = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->stdin_proto);
  __Pyx_DECREF(__pyx_v_self->stdin_proto);
  __pyx_v_self->stdin_proto = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->stdout_proto);
  __Pyx_DECREF(__pyx_v_self->stdout_proto);
  __pyx_v_self->stdout_proto = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->stderr_proto);
  __Pyx_DECREF(__pyx_v_self->stderr_proto);
  __pyx_v_self->stderr_proto = Py_None;

  /* "uvloop/handles/process.pyx":358
 *         self.stdin_proto = self.stdout_proto = self.stderr_proto = None
 * 
 *         self._finished = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):
 */
  __pyx_v_self->_finished = 0;

  /* "uvloop/handles/process.pyx":347
 * @cython.no_gc_clear
 * cdef class UVProcessTransport(UVProcess):
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._exit_waiters = []
 *         self._protocol = None
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":360
 *         self._finished = 0
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):             # <<<<<<<<<<<<<<
 *         UVProcess._on_exit(self, exit_status, term_signal)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__on_exit(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int64_t __pyx_v_exit_status, int __pyx_v_term_signal) {
  PyObject *__pyx_v_waiter = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("_on_exit", 0);

  /* "uvloop/handles/process.pyx":361
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):
 *         UVProcess._on_exit(self, exit_status, term_signal)             # <<<<<<<<<<<<<<
 * 
 *         if self._stdio_ready:
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_9UVProcess__on_exit(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_v_exit_status, __pyx_v_term_signal); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":363
 *         UVProcess._on_exit(self, exit_status, term_signal)
 * 
 *         if self._stdio_ready:             # <<<<<<<<<<<<<<
 *             self._loop.call_soon(self._protocol.process_exited)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_self->_stdio_ready != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":364
 * 
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.process_exited)             # <<<<<<<<<<<<<<
 *         else:
 *             self._pending_calls.append((_CALL_PROCESS_EXITED, None, None))
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_process_exited); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 364, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 364, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 364, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 364, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 364, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 364, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":363
 *         UVProcess._on_exit(self, exit_status, term_signal)
 * 
 *         if self._stdio_ready:             # <<<<<<<<<<<<<<
 *             self._loop.call_soon(self._protocol.process_exited)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":366
 *             self._loop.call_soon(self._protocol.process_exited)
 *         else:
 *             self._pending_calls.append((_CALL_PROCESS_EXITED, None, None))             # <<<<<<<<<<<<<<
 * 
 *         self._try_finish()
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->_pending_calls == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(6, 366, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->_pending_calls, __pyx_tuple__223); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(6, 366, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":368
 *             self._pending_calls.append((_CALL_PROCESS_EXITED, None, None))
 * 
 *         self._try_finish()             # <<<<<<<<<<<<<<
 * 
 *         for waiter in self._exit_waiters:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_try_finish(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":370
 *         self._try_finish()
 * 
 *         for waiter in self._exit_waiters:             # <<<<<<<<<<<<<<
 *             if not waiter.cancelled():
 *                 waiter.set_result(self._returncode)
 */
  if (unlikely(__pyx_v_self->_exit_waiters == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(6, 370, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_self->_exit_waiters; __Pyx_INCREF(__pyx_t_1); __pyx_t_8 = 0;
  for (;;) {
    if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(6, 370, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 370, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_waiter, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/handles/process.pyx":371
 * 
 *         for waiter in self._exit_waiters:
 *             if not waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 waiter.set_result(self._returncode)
 *         self._exit_waiters.clear()
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 371, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 371, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 371, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 371, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_9 = ((!__pyx_t_2) != 0);
    if (__pyx_t_9) {

      /* "uvloop/handles/process.pyx":372
 *         for waiter in self._exit_waiters:
 *             if not waiter.cancelled():
 *                 waiter.set_result(self._returncode)             # <<<<<<<<<<<<<<
 *         self._exit_waiters.clear()
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_set_result); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 372, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_self->__pyx_base._returncode); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 372, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_self->__pyx_base._returncode};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 372, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_v_self->__pyx_base._returncode};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 372, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 372, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_INCREF(__pyx_v_self->__pyx_base._returncode);
          __Pyx_GIVEREF(__pyx_v_self->__pyx_base._returncode);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_self->__pyx_base._returncode);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 372, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/handles/process.pyx":371
 * 
 *         for waiter in self._exit_waiters:
 *             if not waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 waiter.set_result(self._returncode)
 *         self._exit_waiters.clear()
 */
    }

    /* "uvloop/handles/process.pyx":370
 *         self._try_finish()
 * 
 *         for waiter in self._exit_waiters:             # <<<<<<<<<<<<<<
 *             if not waiter.cancelled():
 *                 waiter.set_result(self._returncode)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":373
 *             if not waiter.cancelled():
 *                 waiter.set_result(self._returncode)
 *         self._exit_waiters.clear()             # <<<<<<<<<<<<<<
 * 
 *         self._close()
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_exit_waiters, __pyx_n_s_clear); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 373, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 373, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":375
 *         self._exit_waiters.clear()
 * 
 *         self._close()             # <<<<<<<<<<<<<<
 * 
 *     cdef _check_proc(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":360
 *         self._finished = 0
 * 
 *     cdef _on_exit(self, int64_t exit_status, int term_signal):             # <<<<<<<<<<<<<<
 *         UVProcess._on_exit(self, exit_status, term_signal)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._on_exit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_waiter);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":377
 *         self._close()
 * 
 *     cdef _check_proc(self):             # <<<<<<<<<<<<<<
 *         if not self._is_alive() or self._returncode is not None:
 *             raise ProcessLookupError()
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__check_proc(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_check_proc", 0);

  /* "uvloop/handles/process.pyx":378
 * 
 *     cdef _check_proc(self):
 *         if not self._is_alive() or self._returncode is not None:             # <<<<<<<<<<<<<<
 *             raise ProcessLookupError()
 * 
 */
  __pyx_t_2 = ((!(((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._is_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)) != 0)) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->__pyx_base._returncode != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/process.pyx":379
 *     cdef _check_proc(self):
 *         if not self._is_alive() or self._returncode is not None:
 *             raise ProcessLookupError()             # <<<<<<<<<<<<<<
 * 
 *     cdef _pipe_connection_lost(self, int fd, exc):
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ProcessLookupError); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(6, 379, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":378
 * 
 *     cdef _check_proc(self):
 *         if not self._is_alive() or self._returncode is not None:             # <<<<<<<<<<<<<<
 *             raise ProcessLookupError()
 * 
 */
  }

  /* "uvloop/handles/process.pyx":377
 *         self._close()
 * 
 *     cdef _check_proc(self):             # <<<<<<<<<<<<<<
 *         if not self._is_alive() or self._returncode is not None:
 *             raise ProcessLookupError()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._check_proc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":381
 *             raise ProcessLookupError()
 * 
 *     cdef _pipe_connection_lost(self, int fd, exc):             # <<<<<<<<<<<<<<
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.pipe_connection_lost, fd, exc)
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__pipe_connection_lost(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_fd, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("_pipe_connection_lost", 0);

  /* "uvloop/handles/process.pyx":382
 * 
 *     cdef _pipe_connection_lost(self, int fd, exc):
 *         if self._stdio_ready:             # <<<<<<<<<<<<<<
 *             self._loop.call_soon(self._protocol.pipe_connection_lost, fd, exc)
 *             self._try_finish()
 */
  __pyx_t_1 = (__pyx_v_self->_stdio_ready != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":383
 *     cdef _pipe_connection_lost(self, int fd, exc):
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.pipe_connection_lost, fd, exc)             # <<<<<<<<<<<<<<
 *             self._try_finish()
 *         else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_pipe_connection_lost); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 383, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, __pyx_t_5, __pyx_v_exc};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 383, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, __pyx_t_5, __pyx_v_exc};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 383, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_exc);
      __Pyx_GIVEREF(__pyx_v_exc);
      PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_v_exc);
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 383, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":384
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.pipe_connection_lost, fd, exc)
 *             self._try_finish()             # <<<<<<<<<<<<<<
 *         else:
 *             self._pending_calls.append((_CALL_PIPE_CONNECTION_LOST, fd, exc))
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_try_finish(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":382
 * 
 *     cdef _pipe_connection_lost(self, int fd, exc):
 *         if self._stdio_ready:             # <<<<<<<<<<<<<<
 *             self._loop.call_soon(self._protocol.pipe_connection_lost, fd, exc)
 *             self._try_finish()
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":386
 *             self._try_finish()
 *         else:
 *             self._pending_calls.append((_CALL_PIPE_CONNECTION_LOST, fd, exc))             # <<<<<<<<<<<<<<
 * 
 *     cdef _pipe_data_received(self, int fd, data):
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->_pending_calls == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(6, 386, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_int_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_exc);
    __Pyx_GIVEREF(__pyx_v_exc);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_exc);
    __pyx_t_2 = 0;
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_self->_pending_calls, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(6, 386, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":381
 *             raise ProcessLookupError()
 * 
 *     cdef _pipe_connection_lost(self, int fd, exc):             # <<<<<<<<<<<<<<
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.pipe_connection_lost, fd, exc)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._pipe_connection_lost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":388
 *             self._pending_calls.append((_CALL_PIPE_CONNECTION_LOST, fd, exc))
 * 
 *     cdef _pipe_data_received(self, int fd, data):             # <<<<<<<<<<<<<<
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.pipe_data_received, fd, data)
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__pipe_data_received(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_fd, PyObject *__pyx_v_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("_pipe_data_received", 0);

  /* "uvloop/handles/process.pyx":389
 * 
 *     cdef _pipe_data_received(self, int fd, data):
 *         if self._stdio_ready:             # <<<<<<<<<<<<<<
 *             self._loop.call_soon(self._protocol.pipe_data_received, fd, data)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->_stdio_ready != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":390
 *     cdef _pipe_data_received(self, int fd, data):
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.pipe_data_received, fd, data)             # <<<<<<<<<<<<<<
 *         else:
 *             self._pending_calls.append((_CALL_PIPE_DATA_RECEIVED, fd, data))
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_pipe_data_received); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 390, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, __pyx_t_5, __pyx_v_data};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 390, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_t_4, __pyx_t_5, __pyx_v_data};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 390, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(6, 390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_data);
      __Pyx_GIVEREF(__pyx_v_data);
      PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_7, __pyx_v_data);
      __pyx_t_4 = 0;
      __pyx_t_5 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":389
 * 
 *     cdef _pipe_data_received(self, int fd, data):
 *         if self._stdio_ready:             # <<<<<<<<<<<<<<
 *             self._loop.call_soon(self._protocol.pipe_data_received, fd, data)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":392
 *             self._loop.call_soon(self._protocol.pipe_data_received, fd, data)
 *         else:
 *             self._pending_calls.append((_CALL_PIPE_DATA_RECEIVED, fd, data))             # <<<<<<<<<<<<<<
 * 
 *     cdef _file_redirect_stdio(self, int fd):
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->_pending_calls == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
      __PYX_ERR(6, 392, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 392, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_GIVEREF(__pyx_int_0);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_int_0);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_data);
    __Pyx_GIVEREF(__pyx_v_data);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_data);
    __pyx_t_2 = 0;
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_self->_pending_calls, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(6, 392, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":388
 *             self._pending_calls.append((_CALL_PIPE_CONNECTION_LOST, fd, exc))
 * 
 *     cdef _pipe_data_received(self, int fd, data):             # <<<<<<<<<<<<<<
 *         if self._stdio_ready:
 *             self._loop.call_soon(self._protocol.pipe_data_received, fd, data)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._pipe_data_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":394
 *             self._pending_calls.append((_CALL_PIPE_DATA_RECEIVED, fd, data))
 * 
 *     cdef _file_redirect_stdio(self, int fd):             # <<<<<<<<<<<<<<
 *         fd = os_dup(fd)
 *         os_set_inheritable(fd, True)
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_redirect_stdio(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_fd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("_file_redirect_stdio", 0);

  /* "uvloop/handles/process.pyx":395
 * 
 *     cdef _file_redirect_stdio(self, int fd):
 *         fd = os_dup(fd)             # <<<<<<<<<<<<<<
 *         os_set_inheritable(fd, True)
 *         self._close_after_spawn(fd)
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_dup);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_os_dup; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 395, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 395, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 395, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 395, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 395, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_fd = __pyx_t_6;

  /* "uvloop/handles/process.pyx":396
 *     cdef _file_redirect_stdio(self, int fd):
 *         fd = os_dup(fd)
 *         os_set_inheritable(fd, True)             # <<<<<<<<<<<<<<
 *         self._close_after_spawn(fd)
 *         return fd
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __pyx_t_5 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_3, Py_True};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 396, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_3, Py_True};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 396, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_6, __pyx_t_3);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_6, Py_True);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 396, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":397
 *         fd = os_dup(fd)
 *         os_set_inheritable(fd, True)
 *         self._close_after_spawn(fd)             # <<<<<<<<<<<<<<
 *         return fd
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._close_after_spawn(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 397, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":398
 *         os_set_inheritable(fd, True)
 *         self._close_after_spawn(fd)
 *         return fd             # <<<<<<<<<<<<<<
 * 
 *     cdef _file_devnull(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":394
 *             self._pending_calls.append((_CALL_PIPE_DATA_RECEIVED, fd, data))
 * 
 *     cdef _file_redirect_stdio(self, int fd):             # <<<<<<<<<<<<<<
 *         fd = os_dup(fd)
 *         os_set_inheritable(fd, True)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._file_redirect_stdio", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":400
 *         return fd
 * 
 *     cdef _file_devnull(self):             # <<<<<<<<<<<<<<
 *         dn = os_open(os_devnull, os_O_RDWR)
 *         os_set_inheritable(dn, True)
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_devnull(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_v_dn = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_file_devnull", 0);

  /* "uvloop/handles/process.pyx":401
 * 
 *     cdef _file_devnull(self):
 *         dn = os_open(os_devnull, os_O_RDWR)             # <<<<<<<<<<<<<<
 *         os_set_inheritable(dn, True)
 *         self._close_after_spawn(dn)
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_open);
  __pyx_t_2 = __pyx_v_6uvloop_4loop_os_open; __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_6uvloop_4loop_os_devnull, __pyx_v_6uvloop_4loop_os_O_RDWR};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 401, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_6uvloop_4loop_os_devnull, __pyx_v_6uvloop_4loop_os_O_RDWR};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 401, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_devnull);
    __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_os_devnull);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_6uvloop_4loop_os_devnull);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_O_RDWR);
    __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_os_O_RDWR);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_6uvloop_4loop_os_O_RDWR);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_dn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":402
 *     cdef _file_devnull(self):
 *         dn = os_open(os_devnull, os_O_RDWR)
 *         os_set_inheritable(dn, True)             # <<<<<<<<<<<<<<
 *         self._close_after_spawn(dn)
 *         return dn
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __pyx_t_2 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_5 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_dn, Py_True};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 402, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_dn, Py_True};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 402, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_3 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_dn);
    __Pyx_GIVEREF(__pyx_v_dn);
    PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_4, __pyx_v_dn);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_4, Py_True);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":403
 *         dn = os_open(os_devnull, os_O_RDWR)
 *         os_set_inheritable(dn, True)
 *         self._close_after_spawn(dn)             # <<<<<<<<<<<<<<
 *         return dn
 * 
 */
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_v_dn); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 403, __pyx_L1_error)
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._close_after_spawn(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 403, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":404
 *         os_set_inheritable(dn, True)
 *         self._close_after_spawn(dn)
 *         return dn             # <<<<<<<<<<<<<<
 * 
 *     cdef _file_outpipe(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_dn);
  __pyx_r = __pyx_v_dn;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":400
 *         return fd
 * 
 *     cdef _file_devnull(self):             # <<<<<<<<<<<<<<
 *         dn = os_open(os_devnull, os_O_RDWR)
 *         os_set_inheritable(dn, True)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._file_devnull", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dn);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":406
 *         return dn
 * 
 *     cdef _file_outpipe(self):             # <<<<<<<<<<<<<<
 *         r, w = __socketpair()
 *         os_set_inheritable(w, True)
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_outpipe(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_w = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("_file_outpipe", 0);

  /* "uvloop/handles/process.pyx":407
 * 
 *     cdef _file_outpipe(self):
 *         r, w = __socketpair()             # <<<<<<<<<<<<<<
 *         os_set_inheritable(w, True)
 *         self._close_after_spawn(w)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___socketpair(); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(6, 407, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < 0) __PYX_ERR(6, 407, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(6, 407, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_r = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_w = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/handles/process.pyx":408
 *     cdef _file_outpipe(self):
 *         r, w = __socketpair()
 *         os_set_inheritable(w, True)             # <<<<<<<<<<<<<<
 *         self._close_after_spawn(w)
 *         return r, w
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_w, Py_True};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 408, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_w, Py_True};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 408, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_w);
    __Pyx_GIVEREF(__pyx_v_w);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_6, __pyx_v_w);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_6, Py_True);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":409
 *         r, w = __socketpair()
 *         os_set_inheritable(w, True)
 *         self._close_after_spawn(w)             # <<<<<<<<<<<<<<
 *         return r, w
 * 
 */
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_w); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 409, __pyx_L1_error)
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._close_after_spawn(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":410
 *         os_set_inheritable(w, True)
 *         self._close_after_spawn(w)
 *         return r, w             # <<<<<<<<<<<<<<
 * 
 *     cdef _file_inpipe(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_r);
  __Pyx_GIVEREF(__pyx_v_r);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_r);
  __Pyx_INCREF(__pyx_v_w);
  __Pyx_GIVEREF(__pyx_v_w);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_w);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":406
 *         return dn
 * 
 *     cdef _file_outpipe(self):             # <<<<<<<<<<<<<<
 *         r, w = __socketpair()
 *         os_set_inheritable(w, True)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._file_outpipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_w);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":412
 *         return r, w
 * 
 *     cdef _file_inpipe(self):             # <<<<<<<<<<<<<<
 *         r, w = __socketpair()
 *         os_set_inheritable(r, True)
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__file_inpipe(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_w = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("_file_inpipe", 0);

  /* "uvloop/handles/process.pyx":413
 * 
 *     cdef _file_inpipe(self):
 *         r, w = __socketpair()             # <<<<<<<<<<<<<<
 *         os_set_inheritable(r, True)
 *         self._close_after_spawn(r)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___socketpair(); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(6, 413, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 413, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < 0) __PYX_ERR(6, 413, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(6, 413, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_r = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_w = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/handles/process.pyx":414
 *     cdef _file_inpipe(self):
 *         r, w = __socketpair()
 *         os_set_inheritable(r, True)             # <<<<<<<<<<<<<<
 *         self._close_after_spawn(r)
 *         return r, w
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_2 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_r, Py_True};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 414, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_r, Py_True};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 414, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_r);
    __Pyx_GIVEREF(__pyx_v_r);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_6, __pyx_v_r);
    __Pyx_INCREF(Py_True);
    __Pyx_GIVEREF(Py_True);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_6, Py_True);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":415
 *         r, w = __socketpair()
 *         os_set_inheritable(r, True)
 *         self._close_after_spawn(r)             # <<<<<<<<<<<<<<
 *         return r, w
 * 
 */
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_r); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 415, __pyx_L1_error)
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._close_after_spawn(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":416
 *         os_set_inheritable(r, True)
 *         self._close_after_spawn(r)
 *         return r, w             # <<<<<<<<<<<<<<
 * 
 *     cdef _init_files(self, _stdin, _stdout, _stderr):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_r);
  __Pyx_GIVEREF(__pyx_v_r);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_r);
  __Pyx_INCREF(__pyx_v_w);
  __Pyx_GIVEREF(__pyx_v_w);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_w);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":412
 *         return r, w
 * 
 *     cdef _file_inpipe(self):             # <<<<<<<<<<<<<<
 *         r, w = __socketpair()
 *         os_set_inheritable(r, True)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._file_inpipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_w);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":418
 *         return r, w
 * 
 *     cdef _init_files(self, _stdin, _stdout, _stderr):             # <<<<<<<<<<<<<<
 *         cdef uv.uv_stdio_container_t *iocnt
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__init_files(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr) {
  uv_stdio_container_t *__pyx_v_iocnt;
  PyObject *__pyx_v_io = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_w = NULL;
  PyObject *__pyx_v_waiter = NULL;
  PyObject *__pyx_v_newfd = NULL;
  long __pyx_v_idx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  uv_stdio_container_t *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  long __pyx_t_13;
  __Pyx_RefNannySetupContext("_init_files", 0);

  /* "uvloop/handles/process.pyx":421
 *         cdef uv.uv_stdio_container_t *iocnt
 * 
 *         UVProcess._init_files(self, _stdin, _stdout, _stderr)             # <<<<<<<<<<<<<<
 * 
 *         io = [None, None, None]
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_9UVProcess__init_files(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_v__stdin, __pyx_v__stdout, __pyx_v__stderr); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":423
 *         UVProcess._init_files(self, _stdin, _stdout, _stderr)
 * 
 *         io = [None, None, None]             # <<<<<<<<<<<<<<
 * 
 *         self.options.stdio_count = 3
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyList_SET_ITEM(__pyx_t_1, 0, Py_None);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyList_SET_ITEM(__pyx_t_1, 1, Py_None);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyList_SET_ITEM(__pyx_t_1, 2, Py_None);
  __pyx_v_io = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":425
 *         io = [None, None, None]
 * 
 *         self.options.stdio_count = 3             # <<<<<<<<<<<<<<
 *         self.options.stdio = self.iocnt
 * 
 */
  __pyx_v_self->__pyx_base.options.stdio_count = 3;

  /* "uvloop/handles/process.pyx":426
 * 
 *         self.options.stdio_count = 3
 *         self.options.stdio = self.iocnt             # <<<<<<<<<<<<<<
 * 
 *         if _stdin is not None:
 */
  __pyx_t_2 = __pyx_v_self->__pyx_base.iocnt;
  __pyx_v_self->__pyx_base.options.stdio = __pyx_t_2;

  /* "uvloop/handles/process.pyx":428
 *         self.options.stdio = self.iocnt
 * 
 *         if _stdin is not None:             # <<<<<<<<<<<<<<
 *             if _stdin == subprocess_PIPE:
 *                 r, w  = self._file_inpipe()
 */
  __pyx_t_3 = (__pyx_v__stdin != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "uvloop/handles/process.pyx":429
 * 
 *         if _stdin is not None:
 *             if _stdin == subprocess_PIPE:             # <<<<<<<<<<<<<<
 *                 r, w  = self._file_inpipe()
 *                 io[0] = r
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_PIPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 429, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_RichCompare(__pyx_v__stdin, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 429, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(6, 429, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_4) {

      /* "uvloop/handles/process.pyx":430
 *         if _stdin is not None:
 *             if _stdin == subprocess_PIPE:
 *                 r, w  = self._file_inpipe()             # <<<<<<<<<<<<<<
 *                 io[0] = r
 * 
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_inpipe(__pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 430, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(6, 430, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 430, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
        index = 0; __pyx_t_1 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_1)) goto __pyx_L5_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(6, 430, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L6_unpacking_done;
        __pyx_L5_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(6, 430, __pyx_L1_error)
        __pyx_L6_unpacking_done:;
      }
      __pyx_v_r = __pyx_t_1;
      __pyx_t_1 = 0;
      __pyx_v_w = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":431
 *             if _stdin == subprocess_PIPE:
 *                 r, w  = self._file_inpipe()
 *                 io[0] = r             # <<<<<<<<<<<<<<
 * 
 *                 self.stdin_proto = WriteSubprocessPipeProto(self, 0)
 */
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 0, __pyx_v_r, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 431, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":433
 *                 io[0] = r
 * 
 *                 self.stdin_proto = WriteSubprocessPipeProto(self, 0)             # <<<<<<<<<<<<<<
 *                 waiter = self._loop._new_future()
 *                 self._stdin = WriteUnixTransport.new(
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_WriteSubprocessPipeProto); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_self), __pyx_int_0};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 433, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_self), __pyx_int_0};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 433, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 433, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_9, ((PyObject *)__pyx_v_self));
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_GIVEREF(__pyx_int_0);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_9, __pyx_int_0);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 433, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GIVEREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_v_self->stdin_proto);
      __Pyx_DECREF(__pyx_v_self->stdin_proto);
      __pyx_v_self->stdin_proto = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "uvloop/handles/process.pyx":434
 * 
 *                 self.stdin_proto = WriteSubprocessPipeProto(self, 0)
 *                 waiter = self._loop._new_future()             # <<<<<<<<<<<<<<
 *                 self._stdin = WriteUnixTransport.new(
 *                     self._loop, self.stdin_proto, None, waiter)
 */
      __pyx_t_5 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self->__pyx_base.__pyx_base._loop); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 434, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_v_waiter = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "uvloop/handles/process.pyx":436
 *                 waiter = self._loop._new_future()
 *                 self._stdin = WriteUnixTransport.new(
 *                     self._loop, self.stdin_proto, None, waiter)             # <<<<<<<<<<<<<<
 *                 self._init_futs.append(waiter)
 *                 self._stdin._open(w)
 */
      __pyx_t_5 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = __pyx_v_self->stdin_proto;
      __Pyx_INCREF(__pyx_t_6);

      /* "uvloop/handles/process.pyx":435
 *                 self.stdin_proto = WriteSubprocessPipeProto(self, 0)
 *                 waiter = self._loop._new_future()
 *                 self._stdin = WriteUnixTransport.new(             # <<<<<<<<<<<<<<
 *                     self._loop, self.stdin_proto, None, waiter)
 *                 self._init_futs.append(waiter)
 */
      __pyx_t_7 = ((PyObject *)__pyx_f_6uvloop_4loop_18WriteUnixTransport_new(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_5), __pyx_t_6, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_v_waiter)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 435, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_v_self->_stdin);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->_stdin));
      __pyx_v_self->_stdin = ((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "uvloop/handles/process.pyx":437
 *                 self._stdin = WriteUnixTransport.new(
 *                     self._loop, self.stdin_proto, None, waiter)
 *                 self._init_futs.append(waiter)             # <<<<<<<<<<<<<<
 *                 self._stdin._open(w)
 *                 self._stdin._init_protocol()
 */
      if (unlikely(__pyx_v_self->_init_futs == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(6, 437, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_init_futs, __pyx_v_waiter); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(6, 437, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":438
 *                     self._loop, self.stdin_proto, None, waiter)
 *                 self._init_futs.append(waiter)
 *                 self._stdin._open(w)             # <<<<<<<<<<<<<<
 *                 self._stdin._init_protocol()
 *             elif _stdin == subprocess_DEVNULL:
 */
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_w); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 438, __pyx_L1_error)
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_v_self->_stdin->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self->_stdin), __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 438, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/handles/process.pyx":439
 *                 self._init_futs.append(waiter)
 *                 self._stdin._open(w)
 *                 self._stdin._init_protocol()             # <<<<<<<<<<<<<<
 *             elif _stdin == subprocess_DEVNULL:
 *                 io[0] = self._file_devnull()
 */
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport *)__pyx_v_self->_stdin->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->_stdin)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 439, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/handles/process.pyx":429
 * 
 *         if _stdin is not None:
 *             if _stdin == subprocess_PIPE:             # <<<<<<<<<<<<<<
 *                 r, w  = self._file_inpipe()
 *                 io[0] = r
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/process.pyx":440
 *                 self._stdin._open(w)
 *                 self._stdin._init_protocol()
 *             elif _stdin == subprocess_DEVNULL:             # <<<<<<<<<<<<<<
 *                 io[0] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 */
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_DEVNULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyObject_RichCompare(__pyx_v__stdin, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 440, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(6, 440, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_4) {

      /* "uvloop/handles/process.pyx":441
 *                 self._stdin._init_protocol()
 *             elif _stdin == subprocess_DEVNULL:
 *                 io[0] = self._file_devnull()             # <<<<<<<<<<<<<<
 *             elif _stdout == subprocess_STDOUT:
 *                 raise ValueError(
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_devnull(__pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 441, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 0, __pyx_t_6, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 441, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":440
 *                 self._stdin._open(w)
 *                 self._stdin._init_protocol()
 *             elif _stdin == subprocess_DEVNULL:             # <<<<<<<<<<<<<<
 *                 io[0] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 */
      goto __pyx_L4;
    }

    /* "uvloop/handles/process.pyx":442
 *             elif _stdin == subprocess_DEVNULL:
 *                 io[0] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 */
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_STDOUT); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyObject_RichCompare(__pyx_v__stdout, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 442, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(6, 442, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_t_4)) {

      /* "uvloop/handles/process.pyx":443
 *                 io[0] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 *             else:
 */
      __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__224, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 443, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_Raise(__pyx_t_7, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __PYX_ERR(6, 443, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":442
 *             elif _stdin == subprocess_DEVNULL:
 *                 io[0] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 */
    }

    /* "uvloop/handles/process.pyx":446
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 *             else:
 *                 io[0] = self._file_redirect_stdio(_stdin)             # <<<<<<<<<<<<<<
 *         else:
 *             io[0] = self._file_redirect_stdio(sys.stdin.fileno())
 */
    /*else*/ {
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v__stdin); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 446, __pyx_L1_error)
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_redirect_stdio(__pyx_v_self, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 0, __pyx_t_7, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 446, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __pyx_L4:;

    /* "uvloop/handles/process.pyx":428
 *         self.options.stdio = self.iocnt
 * 
 *         if _stdin is not None:             # <<<<<<<<<<<<<<
 *             if _stdin == subprocess_PIPE:
 *                 r, w  = self._file_inpipe()
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":448
 *                 io[0] = self._file_redirect_stdio(_stdin)
 *         else:
 *             io[0] = self._file_redirect_stdio(sys.stdin.fileno())             # <<<<<<<<<<<<<<
 * 
 *         if _stdout is not None:
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_stdin); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_fileno); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 448, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 448, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 448, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_redirect_stdio(__pyx_v_self, __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 0, __pyx_t_7, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 448, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":450
 *             io[0] = self._file_redirect_stdio(sys.stdin.fileno())
 * 
 *         if _stdout is not None:             # <<<<<<<<<<<<<<
 *             if _stdout == subprocess_PIPE:
 *                 # We can't use UV_CREATE_PIPE here, since 'stderr' might be
 */
  __pyx_t_4 = (__pyx_v__stdout != Py_None);
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/process.pyx":451
 * 
 *         if _stdout is not None:
 *             if _stdout == subprocess_PIPE:             # <<<<<<<<<<<<<<
 *                 # We can't use UV_CREATE_PIPE here, since 'stderr' might be
 *                 # set to 'subprocess.STDOUT', and there is no way to
 */
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_PIPE); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyObject_RichCompare(__pyx_v__stdout, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 451, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(6, 451, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_3) {

      /* "uvloop/handles/process.pyx":458
 *                 # stderr manually.
 * 
 *                 r, w  = self._file_outpipe()             # <<<<<<<<<<<<<<
 *                 io[1] = w
 * 
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_outpipe(__pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 458, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(6, 458, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_1 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 458, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_1)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_7)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_5 = __pyx_t_8(__pyx_t_1); if (unlikely(!__pyx_t_5)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_1), 2) < 0) __PYX_ERR(6, 458, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(6, 458, __pyx_L1_error)
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_r, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_w, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/handles/process.pyx":459
 * 
 *                 r, w  = self._file_outpipe()
 *                 io[1] = w             # <<<<<<<<<<<<<<
 * 
 *                 self.stdout_proto = ReadSubprocessPipeProto(self, 1)
 */
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 1, __pyx_v_w, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 459, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":461
 *                 io[1] = w
 * 
 *                 self.stdout_proto = ReadSubprocessPipeProto(self, 1)             # <<<<<<<<<<<<<<
 *                 waiter = self._loop._new_future()
 *                 self._stdout = ReadUnixTransport.new(
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ReadSubprocessPipeProto); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 461, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, ((PyObject *)__pyx_v_self), __pyx_int_1};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 461, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, ((PyObject *)__pyx_v_self), __pyx_int_1};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 461, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_1 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_9, ((PyObject *)__pyx_v_self));
        __Pyx_INCREF(__pyx_int_1);
        __Pyx_GIVEREF(__pyx_int_1);
        PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_9, __pyx_int_1);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 461, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GIVEREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_v_self->stdout_proto);
      __Pyx_DECREF(__pyx_v_self->stdout_proto);
      __pyx_v_self->stdout_proto = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":462
 * 
 *                 self.stdout_proto = ReadSubprocessPipeProto(self, 1)
 *                 waiter = self._loop._new_future()             # <<<<<<<<<<<<<<
 *                 self._stdout = ReadUnixTransport.new(
 *                     self._loop, self.stdout_proto, None, waiter)
 */
      __pyx_t_6 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self->__pyx_base.__pyx_base._loop); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 462, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_XDECREF_SET(__pyx_v_waiter, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":464
 *                 waiter = self._loop._new_future()
 *                 self._stdout = ReadUnixTransport.new(
 *                     self._loop, self.stdout_proto, None, waiter)             # <<<<<<<<<<<<<<
 *                 self._init_futs.append(waiter)
 *                 self._stdout._open(r)
 */
      __pyx_t_6 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_5 = __pyx_v_self->stdout_proto;
      __Pyx_INCREF(__pyx_t_5);

      /* "uvloop/handles/process.pyx":463
 *                 self.stdout_proto = ReadSubprocessPipeProto(self, 1)
 *                 waiter = self._loop._new_future()
 *                 self._stdout = ReadUnixTransport.new(             # <<<<<<<<<<<<<<
 *                     self._loop, self.stdout_proto, None, waiter)
 *                 self._init_futs.append(waiter)
 */
      __pyx_t_1 = ((PyObject *)__pyx_f_6uvloop_4loop_17ReadUnixTransport_new(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_6), __pyx_t_5, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_v_waiter)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->_stdout);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->_stdout));
      __pyx_v_self->_stdout = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":465
 *                 self._stdout = ReadUnixTransport.new(
 *                     self._loop, self.stdout_proto, None, waiter)
 *                 self._init_futs.append(waiter)             # <<<<<<<<<<<<<<
 *                 self._stdout._open(r)
 *                 self._stdout._init_protocol()
 */
      if (unlikely(__pyx_v_self->_init_futs == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(6, 465, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_init_futs, __pyx_v_waiter); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(6, 465, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":466
 *                     self._loop, self.stdout_proto, None, waiter)
 *                 self._init_futs.append(waiter)
 *                 self._stdout._open(r)             # <<<<<<<<<<<<<<
 *                 self._stdout._init_protocol()
 *             elif _stdout == subprocess_DEVNULL:
 */
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_r); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 466, __pyx_L1_error)
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self->_stdout->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self->_stdout), __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":467
 *                 self._init_futs.append(waiter)
 *                 self._stdout._open(r)
 *                 self._stdout._init_protocol()             # <<<<<<<<<<<<<<
 *             elif _stdout == subprocess_DEVNULL:
 *                 io[1] = self._file_devnull()
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self->_stdout->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->_stdout)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 467, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/process.pyx":451
 * 
 *         if _stdout is not None:
 *             if _stdout == subprocess_PIPE:             # <<<<<<<<<<<<<<
 *                 # We can't use UV_CREATE_PIPE here, since 'stderr' might be
 *                 # set to 'subprocess.STDOUT', and there is no way to
 */
      goto __pyx_L8;
    }

    /* "uvloop/handles/process.pyx":468
 *                 self._stdout._open(r)
 *                 self._stdout._init_protocol()
 *             elif _stdout == subprocess_DEVNULL:             # <<<<<<<<<<<<<<
 *                 io[1] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_DEVNULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 468, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_RichCompare(__pyx_v__stdout, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 468, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(6, 468, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_3) {

      /* "uvloop/handles/process.pyx":469
 *                 self._stdout._init_protocol()
 *             elif _stdout == subprocess_DEVNULL:
 *                 io[1] = self._file_devnull()             # <<<<<<<<<<<<<<
 *             elif _stdout == subprocess_STDOUT:
 *                 raise ValueError(
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_devnull(__pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 469, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 1, __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 469, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/handles/process.pyx":468
 *                 self._stdout._open(r)
 *                 self._stdout._init_protocol()
 *             elif _stdout == subprocess_DEVNULL:             # <<<<<<<<<<<<<<
 *                 io[1] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 */
      goto __pyx_L8;
    }

    /* "uvloop/handles/process.pyx":470
 *             elif _stdout == subprocess_DEVNULL:
 *                 io[1] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 */
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_STDOUT); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 470, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyObject_RichCompare(__pyx_v__stdout, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 470, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(6, 470, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__pyx_t_3)) {

      /* "uvloop/handles/process.pyx":471
 *                 io[1] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 *             else:
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__225, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 471, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(6, 471, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":470
 *             elif _stdout == subprocess_DEVNULL:
 *                 io[1] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 */
    }

    /* "uvloop/handles/process.pyx":474
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 *             else:
 *                 io[1] = self._file_redirect_stdio(_stdout)             # <<<<<<<<<<<<<<
 *         else:
 *             io[1] = self._file_redirect_stdio(sys.stdout.fileno())
 */
    /*else*/ {
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v__stdout); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 474, __pyx_L1_error)
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_redirect_stdio(__pyx_v_self, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 474, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 1, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 474, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L8:;

    /* "uvloop/handles/process.pyx":450
 *             io[0] = self._file_redirect_stdio(sys.stdin.fileno())
 * 
 *         if _stdout is not None:             # <<<<<<<<<<<<<<
 *             if _stdout == subprocess_PIPE:
 *                 # We can't use UV_CREATE_PIPE here, since 'stderr' might be
 */
    goto __pyx_L7;
  }

  /* "uvloop/handles/process.pyx":476
 *                 io[1] = self._file_redirect_stdio(_stdout)
 *         else:
 *             io[1] = self._file_redirect_stdio(sys.stdout.fileno())             # <<<<<<<<<<<<<<
 * 
 *         if _stderr is not None:
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_stdout); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_fileno); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_6) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 476, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 476, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 476, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_redirect_stdio(__pyx_v_self, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 1, __pyx_t_1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 476, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L7:;

  /* "uvloop/handles/process.pyx":478
 *             io[1] = self._file_redirect_stdio(sys.stdout.fileno())
 * 
 *         if _stderr is not None:             # <<<<<<<<<<<<<<
 *             if _stderr == subprocess_PIPE:
 *                 r, w  = self._file_outpipe()
 */
  __pyx_t_3 = (__pyx_v__stderr != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "uvloop/handles/process.pyx":479
 * 
 *         if _stderr is not None:
 *             if _stderr == subprocess_PIPE:             # <<<<<<<<<<<<<<
 *                 r, w  = self._file_outpipe()
 *                 io[2] = w
 */
    __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_PIPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_RichCompare(__pyx_v__stderr, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 479, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(6, 479, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_4) {

      /* "uvloop/handles/process.pyx":480
 *         if _stderr is not None:
 *             if _stderr == subprocess_PIPE:
 *                 r, w  = self._file_outpipe()             # <<<<<<<<<<<<<<
 *                 io[2] = w
 * 
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_outpipe(__pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(6, 480, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 480, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 480, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 480, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
        index = 0; __pyx_t_1 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_1)) goto __pyx_L13_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L13_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(6, 480, __pyx_L1_error)
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L14_unpacking_done;
        __pyx_L13_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(6, 480, __pyx_L1_error)
        __pyx_L14_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_r, __pyx_t_1);
      __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_w, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":481
 *             if _stderr == subprocess_PIPE:
 *                 r, w  = self._file_outpipe()
 *                 io[2] = w             # <<<<<<<<<<<<<<
 * 
 *                 self.stderr_proto = ReadSubprocessPipeProto(self, 2)
 */
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 2, __pyx_v_w, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 481, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":483
 *                 io[2] = w
 * 
 *                 self.stderr_proto = ReadSubprocessPipeProto(self, 2)             # <<<<<<<<<<<<<<
 *                 waiter = self._loop._new_future()
 *                 self._stderr = ReadUnixTransport.new(
 */
      __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ReadSubprocessPipeProto); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 483, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_1 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_self), __pyx_int_2};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 483, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, ((PyObject *)__pyx_v_self), __pyx_int_2};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 483, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 483, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(((PyObject *)__pyx_v_self));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_9, ((PyObject *)__pyx_v_self));
        __Pyx_INCREF(__pyx_int_2);
        __Pyx_GIVEREF(__pyx_int_2);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_9, __pyx_int_2);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 483, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GIVEREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_v_self->stderr_proto);
      __Pyx_DECREF(__pyx_v_self->stderr_proto);
      __pyx_v_self->stderr_proto = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "uvloop/handles/process.pyx":484
 * 
 *                 self.stderr_proto = ReadSubprocessPipeProto(self, 2)
 *                 waiter = self._loop._new_future()             # <<<<<<<<<<<<<<
 *                 self._stderr = ReadUnixTransport.new(
 *                     self._loop, self.stderr_proto, None, waiter)
 */
      __pyx_t_5 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self->__pyx_base.__pyx_base._loop); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_waiter, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/handles/process.pyx":486
 *                 waiter = self._loop._new_future()
 *                 self._stderr = ReadUnixTransport.new(
 *                     self._loop, self.stderr_proto, None, waiter)             # <<<<<<<<<<<<<<
 *                 self._init_futs.append(waiter)
 *                 self._stderr._open(r)
 */
      __pyx_t_5 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop);
      __Pyx_INCREF(__pyx_t_5);
      __pyx_t_6 = __pyx_v_self->stderr_proto;
      __Pyx_INCREF(__pyx_t_6);

      /* "uvloop/handles/process.pyx":485
 *                 self.stderr_proto = ReadSubprocessPipeProto(self, 2)
 *                 waiter = self._loop._new_future()
 *                 self._stderr = ReadUnixTransport.new(             # <<<<<<<<<<<<<<
 *                     self._loop, self.stderr_proto, None, waiter)
 *                 self._init_futs.append(waiter)
 */
      __pyx_t_7 = ((PyObject *)__pyx_f_6uvloop_4loop_17ReadUnixTransport_new(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_5), __pyx_t_6, ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None), __pyx_v_waiter)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 485, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_v_self->_stderr);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->_stderr));
      __pyx_v_self->_stderr = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)__pyx_t_7);
      __pyx_t_7 = 0;

      /* "uvloop/handles/process.pyx":487
 *                 self._stderr = ReadUnixTransport.new(
 *                     self._loop, self.stderr_proto, None, waiter)
 *                 self._init_futs.append(waiter)             # <<<<<<<<<<<<<<
 *                 self._stderr._open(r)
 *                 self._stderr._init_protocol()
 */
      if (unlikely(__pyx_v_self->_init_futs == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(6, 487, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_init_futs, __pyx_v_waiter); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(6, 487, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":488
 *                     self._loop, self.stderr_proto, None, waiter)
 *                 self._init_futs.append(waiter)
 *                 self._stderr._open(r)             # <<<<<<<<<<<<<<
 *                 self._stderr._init_protocol()
 *             elif _stderr == subprocess_STDOUT:
 */
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_r); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 488, __pyx_L1_error)
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self->_stderr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._open(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self->_stderr), __pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 488, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/handles/process.pyx":489
 *                 self._init_futs.append(waiter)
 *                 self._stderr._open(r)
 *                 self._stderr._init_protocol()             # <<<<<<<<<<<<<<
 *             elif _stderr == subprocess_STDOUT:
 *                 if io[1] is None:
 */
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport *)__pyx_v_self->_stderr->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._init_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self->_stderr)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 489, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "uvloop/handles/process.pyx":479
 * 
 *         if _stderr is not None:
 *             if _stderr == subprocess_PIPE:             # <<<<<<<<<<<<<<
 *                 r, w  = self._file_outpipe()
 *                 io[2] = w
 */
      goto __pyx_L12;
    }

    /* "uvloop/handles/process.pyx":490
 *                 self._stderr._open(r)
 *                 self._stderr._init_protocol()
 *             elif _stderr == subprocess_STDOUT:             # <<<<<<<<<<<<<<
 *                 if io[1] is None:
 *                     # shouldn't ever happen
 */
    __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_STDOUT); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 490, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyObject_RichCompare(__pyx_v__stderr, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 490, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(6, 490, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_4) {

      /* "uvloop/handles/process.pyx":491
 *                 self._stderr._init_protocol()
 *             elif _stderr == subprocess_STDOUT:
 *                 if io[1] is None:             # <<<<<<<<<<<<<<
 *                     # shouldn't ever happen
 *                     raise RuntimeError('cannot apply subprocess.STDOUT')
 */
      __pyx_t_6 = __Pyx_GetItemInt_List(__pyx_v_io, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 491, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = (__pyx_t_6 == Py_None);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_3 = (__pyx_t_4 != 0);
      if (unlikely(__pyx_t_3)) {

        /* "uvloop/handles/process.pyx":493
 *                 if io[1] is None:
 *                     # shouldn't ever happen
 *                     raise RuntimeError('cannot apply subprocess.STDOUT')             # <<<<<<<<<<<<<<
 * 
 *                 newfd = os_dup(io[1])
 */
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__226, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 493, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_ERR(6, 493, __pyx_L1_error)

        /* "uvloop/handles/process.pyx":491
 *                 self._stderr._init_protocol()
 *             elif _stderr == subprocess_STDOUT:
 *                 if io[1] is None:             # <<<<<<<<<<<<<<
 *                     # shouldn't ever happen
 *                     raise RuntimeError('cannot apply subprocess.STDOUT')
 */
      }

      /* "uvloop/handles/process.pyx":495
 *                     raise RuntimeError('cannot apply subprocess.STDOUT')
 * 
 *                 newfd = os_dup(io[1])             # <<<<<<<<<<<<<<
 *                 os_set_inheritable(newfd, True)
 *                 self._close_after_spawn(newfd)
 */
      __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_io, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 495, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_dup);
      __pyx_t_5 = __pyx_v_6uvloop_4loop_os_dup; __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_1) {
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 495, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_7};
          __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 495, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_7};
          __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 495, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        {
          __pyx_t_11 = PyTuple_New(1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(6, 495, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_1); __pyx_t_1 = NULL;
          __Pyx_GIVEREF(__pyx_t_7);
          PyTuple_SET_ITEM(__pyx_t_11, 0+1, __pyx_t_7);
          __pyx_t_7 = 0;
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 495, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_newfd = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":496
 * 
 *                 newfd = os_dup(io[1])
 *                 os_set_inheritable(newfd, True)             # <<<<<<<<<<<<<<
 *                 self._close_after_spawn(newfd)
 *                 io[2] = newfd
 */
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
      __pyx_t_5 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_11 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_newfd, Py_True};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 496, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_newfd, Py_True};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 496, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 496, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_v_newfd);
        __Pyx_GIVEREF(__pyx_v_newfd);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_9, __pyx_v_newfd);
        __Pyx_INCREF(Py_True);
        __Pyx_GIVEREF(Py_True);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_9, Py_True);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 496, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":497
 *                 newfd = os_dup(io[1])
 *                 os_set_inheritable(newfd, True)
 *                 self._close_after_spawn(newfd)             # <<<<<<<<<<<<<<
 *                 io[2] = newfd
 *             elif _stderr == subprocess_DEVNULL:
 */
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_newfd); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 497, __pyx_L1_error)
      __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._close_after_spawn(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 497, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/handles/process.pyx":498
 *                 os_set_inheritable(newfd, True)
 *                 self._close_after_spawn(newfd)
 *                 io[2] = newfd             # <<<<<<<<<<<<<<
 *             elif _stderr == subprocess_DEVNULL:
 *                 io[2] = self._file_devnull()
 */
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 2, __pyx_v_newfd, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 498, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":490
 *                 self._stderr._open(r)
 *                 self._stderr._init_protocol()
 *             elif _stderr == subprocess_STDOUT:             # <<<<<<<<<<<<<<
 *                 if io[1] is None:
 *                     # shouldn't ever happen
 */
      goto __pyx_L12;
    }

    /* "uvloop/handles/process.pyx":499
 *                 self._close_after_spawn(newfd)
 *                 io[2] = newfd
 *             elif _stderr == subprocess_DEVNULL:             # <<<<<<<<<<<<<<
 *                 io[2] = self._file_devnull()
 *             else:
 */
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_DEVNULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 499, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 = PyObject_RichCompare(__pyx_v__stderr, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 499, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(6, 499, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_3) {

      /* "uvloop/handles/process.pyx":500
 *                 io[2] = newfd
 *             elif _stderr == subprocess_DEVNULL:
 *                 io[2] = self._file_devnull()             # <<<<<<<<<<<<<<
 *             else:
 *                 io[2] = self._file_redirect_stdio(_stderr)
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_devnull(__pyx_v_self); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 500, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 2, __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 500, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/handles/process.pyx":499
 *                 self._close_after_spawn(newfd)
 *                 io[2] = newfd
 *             elif _stderr == subprocess_DEVNULL:             # <<<<<<<<<<<<<<
 *                 io[2] = self._file_devnull()
 *             else:
 */
      goto __pyx_L12;
    }

    /* "uvloop/handles/process.pyx":502
 *                 io[2] = self._file_devnull()
 *             else:
 *                 io[2] = self._file_redirect_stdio(_stderr)             # <<<<<<<<<<<<<<
 *         else:
 *             io[2] = self._file_redirect_stdio(sys.stderr.fileno())
 */
    /*else*/ {
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v__stderr); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 502, __pyx_L1_error)
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_redirect_stdio(__pyx_v_self, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 2, __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 502, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_L12:;

    /* "uvloop/handles/process.pyx":478
 *             io[1] = self._file_redirect_stdio(sys.stdout.fileno())
 * 
 *         if _stderr is not None:             # <<<<<<<<<<<<<<
 *             if _stderr == subprocess_PIPE:
 *                 r, w  = self._file_outpipe()
 */
    goto __pyx_L11;
  }

  /* "uvloop/handles/process.pyx":504
 *                 io[2] = self._file_redirect_stdio(_stderr)
 *         else:
 *             io[2] = self._file_redirect_stdio(sys.stderr.fileno())             # <<<<<<<<<<<<<<
 * 
 *         assert len(io) == 3
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_stderr); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_fileno); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_7) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 504, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else {
      __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 504, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 504, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_file_redirect_stdio(__pyx_v_self, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 504, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (unlikely(__Pyx_SetItemInt(__pyx_v_io, 2, __pyx_t_5, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0)) __PYX_ERR(6, 504, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L11:;

  /* "uvloop/handles/process.pyx":506
 *             io[2] = self._file_redirect_stdio(sys.stderr.fileno())
 * 
 *         assert len(io) == 3             # <<<<<<<<<<<<<<
 *         for idx in range(3):
 *             if io[idx] is not None:
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_12 = PyList_GET_SIZE(__pyx_v_io); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(6, 506, __pyx_L1_error)
    if (unlikely(!((__pyx_t_12 == 3) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(6, 506, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/handles/process.pyx":507
 * 
 *         assert len(io) == 3
 *         for idx in range(3):             # <<<<<<<<<<<<<<
 *             if io[idx] is not None:
 *                 iocnt = &self.iocnt[idx]
 */
  for (__pyx_t_13 = 0; __pyx_t_13 < 3; __pyx_t_13+=1) {
    __pyx_v_idx = __pyx_t_13;

    /* "uvloop/handles/process.pyx":508
 *         assert len(io) == 3
 *         for idx in range(3):
 *             if io[idx] is not None:             # <<<<<<<<<<<<<<
 *                 iocnt = &self.iocnt[idx]
 *                 iocnt.flags = uv.UV_INHERIT_FD
 */
    __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_io, __pyx_v_idx, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = (__pyx_t_5 != Py_None);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_4 = (__pyx_t_3 != 0);
    if (__pyx_t_4) {

      /* "uvloop/handles/process.pyx":509
 *         for idx in range(3):
 *             if io[idx] is not None:
 *                 iocnt = &self.iocnt[idx]             # <<<<<<<<<<<<<<
 *                 iocnt.flags = uv.UV_INHERIT_FD
 *                 iocnt.data.fd = io[idx]
 */
      __pyx_v_iocnt = (&(__pyx_v_self->__pyx_base.iocnt[__pyx_v_idx]));

      /* "uvloop/handles/process.pyx":510
 *             if io[idx] is not None:
 *                 iocnt = &self.iocnt[idx]
 *                 iocnt.flags = uv.UV_INHERIT_FD             # <<<<<<<<<<<<<<
 *                 iocnt.data.fd = io[idx]
 * 
 */
      __pyx_v_iocnt->flags = UV_INHERIT_FD;

      /* "uvloop/handles/process.pyx":511
 *                 iocnt = &self.iocnt[idx]
 *                 iocnt.flags = uv.UV_INHERIT_FD
 *                 iocnt.data.fd = io[idx]             # <<<<<<<<<<<<<<
 * 
 *     cdef _call_connection_made(self, waiter):
 */
      __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_io, __pyx_v_idx, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 511, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_iocnt->data.fd = __pyx_t_9;

      /* "uvloop/handles/process.pyx":508
 *         assert len(io) == 3
 *         for idx in range(3):
 *             if io[idx] is not None:             # <<<<<<<<<<<<<<
 *                 iocnt = &self.iocnt[idx]
 *                 iocnt.flags = uv.UV_INHERIT_FD
 */
    }
  }

  /* "uvloop/handles/process.pyx":418
 *         return r, w
 * 
 *     cdef _init_files(self, _stdin, _stdout, _stderr):             # <<<<<<<<<<<<<<
 *         cdef uv.uv_stdio_container_t *iocnt
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._init_files", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_io);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_w);
  __Pyx_XDECREF(__pyx_v_waiter);
  __Pyx_XDECREF(__pyx_v_newfd);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":513
 *                 iocnt.data.fd = io[idx]
 * 
 *     cdef _call_connection_made(self, waiter):             # <<<<<<<<<<<<<<
 *         try:
 *             self._protocol.connection_made(self)
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__call_connection_made(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_waiter) {
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_pending_calls = NULL;
  PyObject *__pyx_v_type = NULL;
  PyObject *__pyx_v_fd = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  Py_ssize_t __pyx_t_23;
  PyObject *(*__pyx_t_24)(PyObject *);
  PyObject *(*__pyx_t_25)(PyObject *);
  __Pyx_RefNannySetupContext("_call_connection_made", 0);

  /* "uvloop/handles/process.pyx":514
 * 
 *     cdef _call_connection_made(self, waiter):
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol.connection_made(self)
 *         except Exception as ex:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "uvloop/handles/process.pyx":515
 *     cdef _call_connection_made(self, waiter):
 *         try:
 *             self._protocol.connection_made(self)             # <<<<<<<<<<<<<<
 *         except Exception as ex:
 *             if waiter is not None and not waiter.cancelled():
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_connection_made); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 515, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 515, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, ((PyObject *)__pyx_v_self)};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 515, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, ((PyObject *)__pyx_v_self)};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 515, __pyx_L3_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        {
          __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 515, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_INCREF(((PyObject *)__pyx_v_self));
          __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
          PyTuple_SET_ITEM(__pyx_t_7, 0+1, ((PyObject *)__pyx_v_self));
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 515, __pyx_L3_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/handles/process.pyx":514
 * 
 *     cdef _call_connection_made(self, waiter):
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol.connection_made(self)
 *         except Exception as ex:
 */
    }

    /* "uvloop/handles/process.pyx":522
 *                 raise
 *         else:
 *             if waiter is not None and not waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 waiter.set_result(True)
 * 
 */
    /*else:*/ {
      __pyx_t_9 = (__pyx_v_waiter != Py_None);
      __pyx_t_10 = (__pyx_t_9 != 0);
      if (__pyx_t_10) {
      } else {
        __pyx_t_8 = __pyx_t_10;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 522, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_7) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 522, __pyx_L5_except_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 522, __pyx_L5_except_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(6, 522, __pyx_L5_except_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = ((!__pyx_t_10) != 0);
      __pyx_t_8 = __pyx_t_9;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_8) {

        /* "uvloop/handles/process.pyx":523
 *         else:
 *             if waiter is not None and not waiter.cancelled():
 *                 waiter.set_result(True)             # <<<<<<<<<<<<<<
 * 
 *         self._stdio_ready = 1
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_set_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 523, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__227, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 523, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "uvloop/handles/process.pyx":522
 *                 raise
 *         else:
 *             if waiter is not None and not waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 waiter.set_result(True)
 * 
 */
      }
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/process.pyx":516
 *         try:
 *             self._protocol.connection_made(self)
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             if waiter is not None and not waiter.cancelled():
 *                 waiter.set_exception(ex)
 */
    __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_11) {
      __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._call_connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(6, 516, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v_ex = __pyx_t_4;
      /*try:*/ {

        /* "uvloop/handles/process.pyx":517
 *             self._protocol.connection_made(self)
 *         except Exception as ex:
 *             if waiter is not None and not waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 waiter.set_exception(ex)
 *             else:
 */
        __pyx_t_9 = (__pyx_v_waiter != Py_None);
        __pyx_t_10 = (__pyx_t_9 != 0);
        if (__pyx_t_10) {
        } else {
          __pyx_t_8 = __pyx_t_10;
          goto __pyx_L20_bool_binop_done;
        }
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_12)) __PYX_ERR(6, 517, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_12, function);
          }
        }
        if (__pyx_t_13) {
          __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 517, __pyx_L17_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        } else {
          __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_12); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 517, __pyx_L17_error)
        }
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(6, 517, __pyx_L17_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_9 = ((!__pyx_t_10) != 0);
        __pyx_t_8 = __pyx_t_9;
        __pyx_L20_bool_binop_done:;
        if (likely(__pyx_t_8)) {

          /* "uvloop/handles/process.pyx":518
 *         except Exception as ex:
 *             if waiter is not None and not waiter.cancelled():
 *                 waiter.set_exception(ex)             # <<<<<<<<<<<<<<
 *             else:
 *                 raise
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_12)) __PYX_ERR(6, 518, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_12, function);
            }
          }
          if (!__pyx_t_13) {
            __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_ex); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 518, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_6);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_ex};
              __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 518, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_6);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
              PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_v_ex};
              __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 518, __pyx_L17_error)
              __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_GOTREF(__pyx_t_6);
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 518, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
              __Pyx_INCREF(__pyx_v_ex);
              __Pyx_GIVEREF(__pyx_v_ex);
              PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_v_ex);
              __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_14, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 518, __pyx_L17_error)
              __Pyx_GOTREF(__pyx_t_6);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

          /* "uvloop/handles/process.pyx":517
 *             self._protocol.connection_made(self)
 *         except Exception as ex:
 *             if waiter is not None and not waiter.cancelled():             # <<<<<<<<<<<<<<
 *                 waiter.set_exception(ex)
 *             else:
 */
          goto __pyx_L19;
        }

        /* "uvloop/handles/process.pyx":520
 *                 waiter.set_exception(ex)
 *             else:
 *                 raise             # <<<<<<<<<<<<<<
 *         else:
 *             if waiter is not None and not waiter.cancelled():
 */
        /*else*/ {
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_XGIVEREF(__pyx_t_7);
          __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_4, __pyx_t_7);
          __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_7 = 0; 
          __PYX_ERR(6, 520, __pyx_L17_error)
        }
        __pyx_L19:;
      }

      /* "uvloop/handles/process.pyx":516
 *         try:
 *             self._protocol.connection_made(self)
 *         except Exception as ex:             # <<<<<<<<<<<<<<
 *             if waiter is not None and not waiter.cancelled():
 *                 waiter.set_exception(ex)
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex);
          __pyx_v_ex = NULL;
          goto __pyx_L18;
        }
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __pyx_t_11 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          }
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
          __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
          goto __pyx_L5_except_error;
        }
        __pyx_L18:;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/handles/process.pyx":514
 * 
 *     cdef _call_connection_made(self, waiter):
 *         try:             # <<<<<<<<<<<<<<
 *             self._protocol.connection_made(self)
 *         except Exception as ex:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "uvloop/handles/process.pyx":525
 *                 waiter.set_result(True)
 * 
 *         self._stdio_ready = 1             # <<<<<<<<<<<<<<
 *         if self._pending_calls:
 *             pending_calls = self._pending_calls.copy()
 */
  __pyx_v_self->_stdio_ready = 1;

  /* "uvloop/handles/process.pyx":526
 * 
 *         self._stdio_ready = 1
 *         if self._pending_calls:             # <<<<<<<<<<<<<<
 *             pending_calls = self._pending_calls.copy()
 *             self._pending_calls.clear()
 */
  __pyx_t_8 = (__pyx_v_self->_pending_calls != Py_None)&&(PyList_GET_SIZE(__pyx_v_self->_pending_calls) != 0);
  if (__pyx_t_8) {

    /* "uvloop/handles/process.pyx":527
 *         self._stdio_ready = 1
 *         if self._pending_calls:
 *             pending_calls = self._pending_calls.copy()             # <<<<<<<<<<<<<<
 *             self._pending_calls.clear()
 *             for (type, fd, arg) in pending_calls:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_pending_calls, __pyx_n_s_copy); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 527, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 527, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_pending_calls = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "uvloop/handles/process.pyx":528
 *         if self._pending_calls:
 *             pending_calls = self._pending_calls.copy()
 *             self._pending_calls.clear()             # <<<<<<<<<<<<<<
 *             for (type, fd, arg) in pending_calls:
 *                 if type == _CALL_PIPE_CONNECTION_LOST:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_pending_calls, __pyx_n_s_clear); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 528, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 528, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/handles/process.pyx":529
 *             pending_calls = self._pending_calls.copy()
 *             self._pending_calls.clear()
 *             for (type, fd, arg) in pending_calls:             # <<<<<<<<<<<<<<
 *                 if type == _CALL_PIPE_CONNECTION_LOST:
 *                     self._pipe_connection_lost(fd, arg)
 */
    if (likely(PyList_CheckExact(__pyx_v_pending_calls)) || PyTuple_CheckExact(__pyx_v_pending_calls)) {
      __pyx_t_7 = __pyx_v_pending_calls; __Pyx_INCREF(__pyx_t_7); __pyx_t_23 = 0;
      __pyx_t_24 = NULL;
    } else {
      __pyx_t_23 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_pending_calls); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 529, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_24 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_24)) __PYX_ERR(6, 529, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_24)) {
        if (likely(PyList_CheckExact(__pyx_t_7))) {
          if (__pyx_t_23 >= PyList_GET_SIZE(__pyx_t_7)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_23); __Pyx_INCREF(__pyx_t_4); __pyx_t_23++; if (unlikely(0 < 0)) __PYX_ERR(6, 529, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_7, __pyx_t_23); __pyx_t_23++; if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 529, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_23 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_23); __Pyx_INCREF(__pyx_t_4); __pyx_t_23++; if (unlikely(0 < 0)) __PYX_ERR(6, 529, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_7, __pyx_t_23); __pyx_t_23++; if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 529, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_24(__pyx_t_7);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(6, 529, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
        PyObject* sequence = __pyx_t_4;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(6, 529, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_12 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_12 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_12);
        #else
        __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_12 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_12)) __PYX_ERR(6, 529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        #endif
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_14 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 529, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_25 = Py_TYPE(__pyx_t_14)->tp_iternext;
        index = 0; __pyx_t_5 = __pyx_t_25(__pyx_t_14); if (unlikely(!__pyx_t_5)) goto __pyx_L29_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 1; __pyx_t_6 = __pyx_t_25(__pyx_t_14); if (unlikely(!__pyx_t_6)) goto __pyx_L29_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 2; __pyx_t_12 = __pyx_t_25(__pyx_t_14); if (unlikely(!__pyx_t_12)) goto __pyx_L29_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_25(__pyx_t_14), 3) < 0) __PYX_ERR(6, 529, __pyx_L1_error)
        __pyx_t_25 = NULL;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        goto __pyx_L30_unpacking_done;
        __pyx_L29_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_25 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(6, 529, __pyx_L1_error)
        __pyx_L30_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_type, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_XDECREF_SET(__pyx_v_fd, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_12);
      __pyx_t_12 = 0;

      /* "uvloop/handles/process.pyx":530
 *             self._pending_calls.clear()
 *             for (type, fd, arg) in pending_calls:
 *                 if type == _CALL_PIPE_CONNECTION_LOST:             # <<<<<<<<<<<<<<
 *                     self._pipe_connection_lost(fd, arg)
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:
 */
      __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_type, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 530, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(6, 530, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "uvloop/handles/process.pyx":531
 *             for (type, fd, arg) in pending_calls:
 *                 if type == _CALL_PIPE_CONNECTION_LOST:
 *                     self._pipe_connection_lost(fd, arg)             # <<<<<<<<<<<<<<
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:
 *                     self._pipe_data_received(fd, arg)
 */
        __pyx_t_15 = __Pyx_PyInt_As_int(__pyx_v_fd); if (unlikely((__pyx_t_15 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 531, __pyx_L1_error)
        __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_pipe_connection_lost(__pyx_v_self, __pyx_t_15, __pyx_v_arg); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 531, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/handles/process.pyx":530
 *             self._pending_calls.clear()
 *             for (type, fd, arg) in pending_calls:
 *                 if type == _CALL_PIPE_CONNECTION_LOST:             # <<<<<<<<<<<<<<
 *                     self._pipe_connection_lost(fd, arg)
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:
 */
        goto __pyx_L31;
      }

      /* "uvloop/handles/process.pyx":532
 *                 if type == _CALL_PIPE_CONNECTION_LOST:
 *                     self._pipe_connection_lost(fd, arg)
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:             # <<<<<<<<<<<<<<
 *                     self._pipe_data_received(fd, arg)
 *                 elif type == _CALL_PROCESS_EXITED:
 */
      __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_type, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(6, 532, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "uvloop/handles/process.pyx":533
 *                     self._pipe_connection_lost(fd, arg)
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:
 *                     self._pipe_data_received(fd, arg)             # <<<<<<<<<<<<<<
 *                 elif type == _CALL_PROCESS_EXITED:
 *                     self._loop.call_soon(self._protocol.process_exited)
 */
        __pyx_t_15 = __Pyx_PyInt_As_int(__pyx_v_fd); if (unlikely((__pyx_t_15 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 533, __pyx_L1_error)
        __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_pipe_data_received(__pyx_v_self, __pyx_t_15, __pyx_v_arg); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 533, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/handles/process.pyx":532
 *                 if type == _CALL_PIPE_CONNECTION_LOST:
 *                     self._pipe_connection_lost(fd, arg)
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:             # <<<<<<<<<<<<<<
 *                     self._pipe_data_received(fd, arg)
 *                 elif type == _CALL_PROCESS_EXITED:
 */
        goto __pyx_L31;
      }

      /* "uvloop/handles/process.pyx":534
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:
 *                     self._pipe_data_received(fd, arg)
 *                 elif type == _CALL_PROCESS_EXITED:             # <<<<<<<<<<<<<<
 *                     self._loop.call_soon(self._protocol.process_exited)
 *                 elif type == _CALL_CONNECTION_LOST:
 */
      __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_type, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 534, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(6, 534, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "uvloop/handles/process.pyx":535
 *                     self._pipe_data_received(fd, arg)
 *                 elif type == _CALL_PROCESS_EXITED:
 *                     self._loop.call_soon(self._protocol.process_exited)             # <<<<<<<<<<<<<<
 *                 elif type == _CALL_CONNECTION_LOST:
 *                     self._loop.call_soon(self._protocol.connection_lost, None)
 */
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_12)) __PYX_ERR(6, 535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_process_exited); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 535, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_12);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_12, function);
          }
        }
        if (!__pyx_t_5) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 535, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_12)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
            __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 535, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
            __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 535, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          } else
          #endif
          {
            __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 535, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_5); __pyx_t_5 = NULL;
            __Pyx_GIVEREF(__pyx_t_6);
            PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_t_6);
            __pyx_t_6 = 0;
            __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_14, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 535, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/handles/process.pyx":534
 *                 elif type == _CALL_PIPE_DATA_RECEIVED:
 *                     self._pipe_data_received(fd, arg)
 *                 elif type == _CALL_PROCESS_EXITED:             # <<<<<<<<<<<<<<
 *                     self._loop.call_soon(self._protocol.process_exited)
 *                 elif type == _CALL_CONNECTION_LOST:
 */
        goto __pyx_L31;
      }

      /* "uvloop/handles/process.pyx":536
 *                 elif type == _CALL_PROCESS_EXITED:
 *                     self._loop.call_soon(self._protocol.process_exited)
 *                 elif type == _CALL_CONNECTION_LOST:             # <<<<<<<<<<<<<<
 *                     self._loop.call_soon(self._protocol.connection_lost, None)
 * 
 */
      __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_type, __pyx_int_3, 3, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 536, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(6, 536, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "uvloop/handles/process.pyx":537
 *                     self._loop.call_soon(self._protocol.process_exited)
 *                 elif type == _CALL_CONNECTION_LOST:
 *                     self._loop.call_soon(self._protocol.connection_lost, None)             # <<<<<<<<<<<<<<
 * 
 *     cdef _try_finish(self):
 */
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_12)) __PYX_ERR(6, 537, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_connection_lost); if (unlikely(!__pyx_t_14)) __PYX_ERR(6, 537, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_6 = NULL;
        __pyx_t_15 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_12);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_12, function);
            __pyx_t_15 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_12)) {
          PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_14, Py_None};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 537, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
          PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_t_14, Py_None};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 537, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(2+__pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 537, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          if (__pyx_t_6) {
            __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_6); __pyx_t_6 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_14);
          PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_15, __pyx_t_14);
          __Pyx_INCREF(Py_None);
          __Pyx_GIVEREF(Py_None);
          PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_15, Py_None);
          __pyx_t_14 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 537, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/handles/process.pyx":536
 *                 elif type == _CALL_PROCESS_EXITED:
 *                     self._loop.call_soon(self._protocol.process_exited)
 *                 elif type == _CALL_CONNECTION_LOST:             # <<<<<<<<<<<<<<
 *                     self._loop.call_soon(self._protocol.connection_lost, None)
 * 
 */
      }
      __pyx_L31:;

      /* "uvloop/handles/process.pyx":529
 *             pending_calls = self._pending_calls.copy()
 *             self._pending_calls.clear()
 *             for (type, fd, arg) in pending_calls:             # <<<<<<<<<<<<<<
 *                 if type == _CALL_PIPE_CONNECTION_LOST:
 *                     self._pipe_connection_lost(fd, arg)
 */
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/handles/process.pyx":526
 * 
 *         self._stdio_ready = 1
 *         if self._pending_calls:             # <<<<<<<<<<<<<<
 *             pending_calls = self._pending_calls.copy()
 *             self._pending_calls.clear()
 */
  }

  /* "uvloop/handles/process.pyx":513
 *                 iocnt.data.fd = io[idx]
 * 
 *     cdef _call_connection_made(self, waiter):             # <<<<<<<<<<<<<<
 *         try:
 *             self._protocol.connection_made(self)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._call_connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_pending_calls);
  __Pyx_XDECREF(__pyx_v_type);
  __Pyx_XDECREF(__pyx_v_fd);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":539
 *                     self._loop.call_soon(self._protocol.connection_lost, None)
 * 
 *     cdef _try_finish(self):             # <<<<<<<<<<<<<<
 *         if self._returncode is None or self._finished:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_18UVProcessTransport__try_finish(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("_try_finish", 0);

  /* "uvloop/handles/process.pyx":540
 * 
 *     cdef _try_finish(self):
 *         if self._returncode is None or self._finished:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = (__pyx_v_self->__pyx_base._returncode == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_self->_finished != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":541
 *     cdef _try_finish(self):
 *         if self._returncode is None or self._finished:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if ((self.stdin_proto is None or self.stdin_proto.disconnected) and
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/process.pyx":540
 * 
 *     cdef _try_finish(self):
 *         if self._returncode is None or self._finished:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/process.pyx":543
 *             return
 * 
 *         if ((self.stdin_proto is None or self.stdin_proto.disconnected) and             # <<<<<<<<<<<<<<
 *             (self.stdout_proto is None or self.stdout_proto.disconnected) and
 *             (self.stderr_proto is None or self.stderr_proto.disconnected)):
 */
  __pyx_t_3 = (__pyx_v_self->stdin_proto == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (!__pyx_t_2) {
  } else {
    goto __pyx_L8_next_and;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->stdin_proto, __pyx_n_s_disconnected); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 543, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_L8_next_and:;

  /* "uvloop/handles/process.pyx":544
 * 
 *         if ((self.stdin_proto is None or self.stdin_proto.disconnected) and
 *             (self.stdout_proto is None or self.stdout_proto.disconnected) and             # <<<<<<<<<<<<<<
 *             (self.stderr_proto is None or self.stderr_proto.disconnected)):
 * 
 */
  __pyx_t_2 = (__pyx_v_self->stdout_proto == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    goto __pyx_L10_next_and;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->stdout_proto, __pyx_n_s_disconnected); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(6, 544, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_L10_next_and:;

  /* "uvloop/handles/process.pyx":545
 *         if ((self.stdin_proto is None or self.stdin_proto.disconnected) and
 *             (self.stdout_proto is None or self.stdout_proto.disconnected) and
 *             (self.stderr_proto is None or self.stderr_proto.disconnected)):             # <<<<<<<<<<<<<<
 * 
 *             self._finished = 1
 */
  __pyx_t_3 = (__pyx_v_self->stderr_proto == Py_None);
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->stderr_proto, __pyx_n_s_disconnected); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 545, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L7_bool_binop_done:;

  /* "uvloop/handles/process.pyx":543
 *             return
 * 
 *         if ((self.stdin_proto is None or self.stdin_proto.disconnected) and             # <<<<<<<<<<<<<<
 *             (self.stdout_proto is None or self.stdout_proto.disconnected) and
 *             (self.stderr_proto is None or self.stderr_proto.disconnected)):
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":547
 *             (self.stderr_proto is None or self.stderr_proto.disconnected)):
 * 
 *             self._finished = 1             # <<<<<<<<<<<<<<
 * 
 *             if self._stdio_ready:
 */
    __pyx_v_self->_finished = 1;

    /* "uvloop/handles/process.pyx":549
 *             self._finished = 1
 * 
 *             if self._stdio_ready:             # <<<<<<<<<<<<<<
 *                 self._loop.call_soon(self._protocol.connection_lost, None)
 *             else:
 */
    __pyx_t_1 = (__pyx_v_self->_stdio_ready != 0);
    if (__pyx_t_1) {

      /* "uvloop/handles/process.pyx":550
 * 
 *             if self._stdio_ready:
 *                 self._loop.call_soon(self._protocol.connection_lost, None)             # <<<<<<<<<<<<<<
 *             else:
 *                 self._pending_calls.append((_CALL_CONNECTION_LOST, None, None))
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop), __pyx_n_s_call_soon); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 550, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_protocol, __pyx_n_s_connection_lost); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 550, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_6, Py_None};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 550, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_6, Py_None};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 550, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 550, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_6);
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, Py_None);
        __pyx_t_6 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 550, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/handles/process.pyx":549
 *             self._finished = 1
 * 
 *             if self._stdio_ready:             # <<<<<<<<<<<<<<
 *                 self._loop.call_soon(self._protocol.connection_lost, None)
 *             else:
 */
      goto __pyx_L13;
    }

    /* "uvloop/handles/process.pyx":552
 *                 self._loop.call_soon(self._protocol.connection_lost, None)
 *             else:
 *                 self._pending_calls.append((_CALL_CONNECTION_LOST, None, None))             # <<<<<<<<<<<<<<
 * 
 *     def __stdio_inited(self, waiter, stdio_fut):
 */
    /*else*/ {
      if (unlikely(__pyx_v_self->_pending_calls == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
        __PYX_ERR(6, 552, __pyx_L1_error)
      }
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_self->_pending_calls, __pyx_tuple__228); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(6, 552, __pyx_L1_error)
    }
    __pyx_L13:;

    /* "uvloop/handles/process.pyx":543
 *             return
 * 
 *         if ((self.stdin_proto is None or self.stdin_proto.disconnected) and             # <<<<<<<<<<<<<<
 *             (self.stdout_proto is None or self.stdout_proto.disconnected) and
 *             (self.stderr_proto is None or self.stderr_proto.disconnected)):
 */
  }

  /* "uvloop/handles/process.pyx":539
 *                     self._loop.call_soon(self._protocol.connection_lost, None)
 * 
 *     cdef _try_finish(self):             # <<<<<<<<<<<<<<
 *         if self._returncode is None or self._finished:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._try_finish", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":554
 *                 self._pending_calls.append((_CALL_CONNECTION_LOST, None, None))
 * 
 *     def __stdio_inited(self, waiter, stdio_fut):             # <<<<<<<<<<<<<<
 *         exc = stdio_fut.exception()
 *         if exc is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_3__stdio_inited(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_2__stdio_inited[] = "UVProcessTransport.__stdio_inited(self, waiter, stdio_fut)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_3__stdio_inited(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_waiter = 0;
  PyObject *__pyx_v_stdio_fut = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__stdio_inited (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_waiter,&__pyx_n_s_stdio_fut,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_waiter)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_stdio_fut)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__stdio_inited", 1, 2, 2, 1); __PYX_ERR(6, 554, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__stdio_inited") < 0)) __PYX_ERR(6, 554, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_waiter = values[0];
    __pyx_v_stdio_fut = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__stdio_inited", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(6, 554, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.__stdio_inited", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_2__stdio_inited(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self), __pyx_v_waiter, __pyx_v_stdio_fut);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_2__stdio_inited(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_waiter, PyObject *__pyx_v_stdio_fut) {
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__stdio_inited", 0);

  /* "uvloop/handles/process.pyx":555
 * 
 *     def __stdio_inited(self, waiter, stdio_fut):
 *         exc = stdio_fut.exception()             # <<<<<<<<<<<<<<
 *         if exc is not None:
 *             if waiter is None:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_stdio_fut, __pyx_n_s_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 555, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 555, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_exc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":556
 *     def __stdio_inited(self, waiter, stdio_fut):
 *         exc = stdio_fut.exception()
 *         if exc is not None:             # <<<<<<<<<<<<<<
 *             if waiter is None:
 *                 raise exc
 */
  __pyx_t_4 = (__pyx_v_exc != Py_None);
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "uvloop/handles/process.pyx":557
 *         exc = stdio_fut.exception()
 *         if exc is not None:
 *             if waiter is None:             # <<<<<<<<<<<<<<
 *                 raise exc
 *             else:
 */
    __pyx_t_5 = (__pyx_v_waiter == Py_None);
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (unlikely(__pyx_t_4)) {

      /* "uvloop/handles/process.pyx":558
 *         if exc is not None:
 *             if waiter is None:
 *                 raise exc             # <<<<<<<<<<<<<<
 *             else:
 *                 waiter.set_exception(exc)
 */
      __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
      __PYX_ERR(6, 558, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":557
 *         exc = stdio_fut.exception()
 *         if exc is not None:
 *             if waiter is None:             # <<<<<<<<<<<<<<
 *                 raise exc
 *             else:
 */
    }

    /* "uvloop/handles/process.pyx":560
 *                 raise exc
 *             else:
 *                 waiter.set_exception(exc)             # <<<<<<<<<<<<<<
 *         else:
 *             self._loop._call_soon_handle(
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 560, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (!__pyx_t_3) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 560, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 560, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 560, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 560, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_GIVEREF(__pyx_v_exc);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_exc);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 560, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "uvloop/handles/process.pyx":556
 *     def __stdio_inited(self, waiter, stdio_fut):
 *         exc = stdio_fut.exception()
 *         if exc is not None:             # <<<<<<<<<<<<<<
 *             if waiter is None:
 *                 raise exc
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":562
 *                 waiter.set_exception(exc)
 *         else:
 *             self._loop._call_soon_handle(             # <<<<<<<<<<<<<<
 *                 new_MethodHandle1(self._loop,
 *                                   "UVProcessTransport._call_connection_made",
 */
  /*else*/ {

    /* "uvloop/handles/process.pyx":563
 *         else:
 *             self._loop._call_soon_handle(
 *                 new_MethodHandle1(self._loop,             # <<<<<<<<<<<<<<
 *                                   "UVProcessTransport._call_connection_made",
 *                                   <method1_t>self._call_connection_made,
 */
    __pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._loop);
    __Pyx_INCREF(__pyx_t_1);

    /* "uvloop/handles/process.pyx":566
 *                                   "UVProcessTransport._call_connection_made",
 *                                   <method1_t>self._call_connection_made,
 *                                   self, waiter))             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_new_MethodHandle1(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1), __pyx_kp_u_UVProcessTransport__call_connect, ((__pyx_t_6uvloop_4loop_method1_t)((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_call_connection_made), ((PyObject *)__pyx_v_self), __pyx_v_waiter); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 563, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":563
 *         else:
 *             self._loop._call_soon_handle(
 *                 new_MethodHandle1(self._loop,             # <<<<<<<<<<<<<<
 *                                   "UVProcessTransport._call_connection_made",
 *                                   <method1_t>self._call_connection_made,
 */
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(6, 563, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":562
 *                 waiter.set_exception(exc)
 *         else:
 *             self._loop._call_soon_handle(             # <<<<<<<<<<<<<<
 *                 new_MethodHandle1(self._loop,
 *                                   "UVProcessTransport._call_connection_made",
 */
    __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__call_soon_handle(__pyx_v_self->__pyx_base.__pyx_base._loop, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 562, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":554
 *                 self._pending_calls.append((_CALL_CONNECTION_LOST, None, None))
 * 
 *     def __stdio_inited(self, waiter, stdio_fut):             # <<<<<<<<<<<<<<
 *         exc = stdio_fut.exception()
 *         if exc is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.__stdio_inited", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":569
 * 
 *     @staticmethod
 *     cdef UVProcessTransport new(Loop loop, protocol, args, env,             # <<<<<<<<<<<<<<
 *                                 cwd, start_new_session,
 *                                 _stdin, _stdout, _stderr, pass_fds,
 */

static struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_f_6uvloop_4loop_18UVProcessTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_protocol, PyObject *__pyx_v_args, PyObject *__pyx_v_env, PyObject *__pyx_v_cwd, PyObject *__pyx_v_start_new_session, PyObject *__pyx_v__stdin, PyObject *__pyx_v__stdout, PyObject *__pyx_v__stderr, PyObject *__pyx_v_pass_fds, PyObject *__pyx_v_waiter, PyObject *__pyx_v_debug_flags, PyObject *__pyx_v_preexec_fn, PyObject *__pyx_v_restore_signals) {
  struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_handle = 0;
  PyObject *__pyx_v_init_fut = NULL;
  struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/process.pyx":578
 * 
 *         cdef UVProcessTransport handle
 *         handle = UVProcessTransport.__new__(UVProcessTransport)             # <<<<<<<<<<<<<<
 *         handle._protocol = protocol
 *         handle._init(loop, args, env, cwd, start_new_session,
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UVProcessTransport(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UVProcessTransport), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 578, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_handle = ((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":579
 *         cdef UVProcessTransport handle
 *         handle = UVProcessTransport.__new__(UVProcessTransport)
 *         handle._protocol = protocol             # <<<<<<<<<<<<<<
 *         handle._init(loop, args, env, cwd, start_new_session,
 *                      __process_convert_fileno(_stdin),
 */
  __Pyx_INCREF(__pyx_v_protocol);
  __Pyx_GIVEREF(__pyx_v_protocol);
  __Pyx_GOTREF(__pyx_v_handle->_protocol);
  __Pyx_DECREF(__pyx_v_handle->_protocol);
  __pyx_v_handle->_protocol = __pyx_v_protocol;

  /* "uvloop/handles/process.pyx":580
 *         handle = UVProcessTransport.__new__(UVProcessTransport)
 *         handle._protocol = protocol
 *         handle._init(loop, args, env, cwd, start_new_session,             # <<<<<<<<<<<<<<
 *                      __process_convert_fileno(_stdin),
 *                      __process_convert_fileno(_stdout),
 */
  if (!(likely(PyList_CheckExact(__pyx_v_args))||((__pyx_v_args) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_v_args)->tp_name), 0))) __PYX_ERR(6, 580, __pyx_L1_error)
  if (!(likely(PyDict_CheckExact(__pyx_v_env))||((__pyx_v_env) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "dict", Py_TYPE(__pyx_v_env)->tp_name), 0))) __PYX_ERR(6, 580, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":581
 *         handle._protocol = protocol
 *         handle._init(loop, args, env, cwd, start_new_session,
 *                      __process_convert_fileno(_stdin),             # <<<<<<<<<<<<<<
 *                      __process_convert_fileno(_stdout),
 *                      __process_convert_fileno(_stderr),
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___process_convert_fileno(__pyx_v__stdin); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/handles/process.pyx":582
 *         handle._init(loop, args, env, cwd, start_new_session,
 *                      __process_convert_fileno(_stdin),
 *                      __process_convert_fileno(_stdout),             # <<<<<<<<<<<<<<
 *                      __process_convert_fileno(_stderr),
 *                      pass_fds,
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop___process_convert_fileno(__pyx_v__stdout); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/handles/process.pyx":583
 *                      __process_convert_fileno(_stdin),
 *                      __process_convert_fileno(_stdout),
 *                      __process_convert_fileno(_stderr),             # <<<<<<<<<<<<<<
 *                      pass_fds,
 *                      debug_flags,
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop___process_convert_fileno(__pyx_v__stderr); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/handles/process.pyx":580
 *         handle = UVProcessTransport.__new__(UVProcessTransport)
 *         handle._protocol = protocol
 *         handle._init(loop, args, env, cwd, start_new_session,             # <<<<<<<<<<<<<<
 *                      __process_convert_fileno(_stdin),
 *                      __process_convert_fileno(_stdout),
 */
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._init(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_handle), __pyx_v_loop, ((PyObject*)__pyx_v_args), ((PyObject*)__pyx_v_env), __pyx_v_cwd, __pyx_v_start_new_session, __pyx_t_1, __pyx_t_2, __pyx_t_3, __pyx_v_pass_fds, __pyx_v_debug_flags, __pyx_v_preexec_fn, __pyx_v_restore_signals); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/handles/process.pyx":589
 *                      restore_signals)
 * 
 *         if handle._init_futs:             # <<<<<<<<<<<<<<
 *             handle._stdio_ready = 0
 *             init_fut = aio_gather(*handle._init_futs, loop=loop)
 */
  __pyx_t_5 = (__pyx_v_handle->_init_futs != Py_None)&&(PyList_GET_SIZE(__pyx_v_handle->_init_futs) != 0);
  if (__pyx_t_5) {

    /* "uvloop/handles/process.pyx":590
 * 
 *         if handle._init_futs:
 *             handle._stdio_ready = 0             # <<<<<<<<<<<<<<
 *             init_fut = aio_gather(*handle._init_futs, loop=loop)
 *             init_fut.add_done_callback(
 */
    __pyx_v_handle->_stdio_ready = 0;

    /* "uvloop/handles/process.pyx":591
 *         if handle._init_futs:
 *             handle._stdio_ready = 0
 *             init_fut = aio_gather(*handle._init_futs, loop=loop)             # <<<<<<<<<<<<<<
 *             init_fut.add_done_callback(
 *                 ft_partial(handle.__stdio_inited, waiter))
 */
    __pyx_t_4 = PySequence_Tuple(__pyx_v_handle->_init_futs); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_loop, ((PyObject *)__pyx_v_loop)) < 0) __PYX_ERR(6, 591, __pyx_L1_error)
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_aio_gather, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_init_fut = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":592
 *             handle._stdio_ready = 0
 *             init_fut = aio_gather(*handle._init_futs, loop=loop)
 *             init_fut.add_done_callback(             # <<<<<<<<<<<<<<
 *                 ft_partial(handle.__stdio_inited, waiter))
 *         else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_init_fut, __pyx_n_s_add_done_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 592, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/handles/process.pyx":593
 *             init_fut = aio_gather(*handle._init_futs, loop=loop)
 *             init_fut.add_done_callback(
 *                 ft_partial(handle.__stdio_inited, waiter))             # <<<<<<<<<<<<<<
 *         else:
 *             handle._stdio_ready = 1
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_handle), __pyx_n_s_stdio_inited); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 593, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_ft_partial);
    __pyx_t_6 = __pyx_v_6uvloop_4loop_ft_partial; __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_1, __pyx_v_waiter};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 593, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_t_1, __pyx_v_waiter};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 593, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_7) {
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_8, __pyx_t_1);
      __Pyx_INCREF(__pyx_v_waiter);
      __Pyx_GIVEREF(__pyx_v_waiter);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_8, __pyx_v_waiter);
      __pyx_t_1 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_9, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 593, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 592, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 592, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_4};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 592, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 592, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 592, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":589
 *                      restore_signals)
 * 
 *         if handle._init_futs:             # <<<<<<<<<<<<<<
 *             handle._stdio_ready = 0
 *             init_fut = aio_gather(*handle._init_futs, loop=loop)
 */
    goto __pyx_L3;
  }

  /* "uvloop/handles/process.pyx":595
 *                 ft_partial(handle.__stdio_inited, waiter))
 *         else:
 *             handle._stdio_ready = 1             # <<<<<<<<<<<<<<
 *             loop._call_soon_handle(
 *                 new_MethodHandle1(loop,
 */
  /*else*/ {
    __pyx_v_handle->_stdio_ready = 1;

    /* "uvloop/handles/process.pyx":597
 *             handle._stdio_ready = 1
 *             loop._call_soon_handle(
 *                 new_MethodHandle1(loop,             # <<<<<<<<<<<<<<
 *                                   "UVProcessTransport._call_connection_made",
 *                                   <method1_t>handle._call_connection_made,
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_new_MethodHandle1(__pyx_v_loop, __pyx_kp_u_UVProcessTransport__call_connect, ((__pyx_t_6uvloop_4loop_method1_t)((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_handle->__pyx_base.__pyx_base.__pyx_vtab)->_call_connection_made), ((PyObject *)__pyx_v_handle), __pyx_v_waiter); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(6, 597, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":596
 *         else:
 *             handle._stdio_ready = 1
 *             loop._call_soon_handle(             # <<<<<<<<<<<<<<
 *                 new_MethodHandle1(loop,
 *                                   "UVProcessTransport._call_connection_made",
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_4Loop__call_soon_handle(__pyx_v_loop, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "uvloop/handles/process.pyx":602
 *                                   handle, waiter))
 * 
 *         return handle             # <<<<<<<<<<<<<<
 * 
 *     def get_protocol(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_handle));
  __pyx_r = __pyx_v_handle;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":569
 * 
 *     @staticmethod
 *     cdef UVProcessTransport new(Loop loop, protocol, args, env,             # <<<<<<<<<<<<<<
 *                                 cwd, start_new_session,
 *                                 _stdin, _stdout, _stderr, pass_fds,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_handle);
  __Pyx_XDECREF(__pyx_v_init_fut);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":604
 *         return handle
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._protocol
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_5get_protocol(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_4get_protocol[] = "UVProcessTransport.get_protocol(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_5get_protocol(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_protocol (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_4get_protocol(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_4get_protocol(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_protocol", 0);

  /* "uvloop/handles/process.pyx":605
 * 
 *     def get_protocol(self):
 *         return self._protocol             # <<<<<<<<<<<<<<
 * 
 *     def set_protocol(self, protocol):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_protocol);
  __pyx_r = __pyx_v_self->_protocol;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":604
 *         return handle
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._protocol
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":607
 *         return self._protocol
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._protocol = protocol
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_7set_protocol(PyObject *__pyx_v_self, PyObject *__pyx_v_protocol); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_6set_protocol[] = "UVProcessTransport.set_protocol(self, protocol)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_7set_protocol(PyObject *__pyx_v_self, PyObject *__pyx_v_protocol) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_protocol (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_6set_protocol(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self), ((PyObject *)__pyx_v_protocol));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_6set_protocol(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_protocol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_protocol", 0);

  /* "uvloop/handles/process.pyx":608
 * 
 *     def set_protocol(self, protocol):
 *         self._protocol = protocol             # <<<<<<<<<<<<<<
 * 
 *     def get_pid(self):
 */
  __Pyx_INCREF(__pyx_v_protocol);
  __Pyx_GIVEREF(__pyx_v_protocol);
  __Pyx_GOTREF(__pyx_v_self->_protocol);
  __Pyx_DECREF(__pyx_v_self->_protocol);
  __pyx_v_self->_protocol = __pyx_v_protocol;

  /* "uvloop/handles/process.pyx":607
 *         return self._protocol
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._protocol = protocol
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":610
 *         self._protocol = protocol
 * 
 *     def get_pid(self):             # <<<<<<<<<<<<<<
 *         return self._pid
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_9get_pid(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_8get_pid[] = "UVProcessTransport.get_pid(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_9get_pid(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pid (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_8get_pid(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_8get_pid(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pid", 0);

  /* "uvloop/handles/process.pyx":611
 * 
 *     def get_pid(self):
 *         return self._pid             # <<<<<<<<<<<<<<
 * 
 *     def get_returncode(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx_base._pid);
  __pyx_r = __pyx_v_self->__pyx_base._pid;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":610
 *         self._protocol = protocol
 * 
 *     def get_pid(self):             # <<<<<<<<<<<<<<
 *         return self._pid
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":613
 *         return self._pid
 * 
 *     def get_returncode(self):             # <<<<<<<<<<<<<<
 *         return self._returncode
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_11get_returncode(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_10get_returncode[] = "UVProcessTransport.get_returncode(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_11get_returncode(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_returncode (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_10get_returncode(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_10get_returncode(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_returncode", 0);

  /* "uvloop/handles/process.pyx":614
 * 
 *     def get_returncode(self):
 *         return self._returncode             # <<<<<<<<<<<<<<
 * 
 *     def get_pipe_transport(self, fd):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx_base._returncode);
  __pyx_r = __pyx_v_self->__pyx_base._returncode;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":613
 *         return self._pid
 * 
 *     def get_returncode(self):             # <<<<<<<<<<<<<<
 *         return self._returncode
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":616
 *         return self._returncode
 * 
 *     def get_pipe_transport(self, fd):             # <<<<<<<<<<<<<<
 *         if fd == 0:
 *             return self._stdin
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_13get_pipe_transport(PyObject *__pyx_v_self, PyObject *__pyx_v_fd); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_12get_pipe_transport[] = "UVProcessTransport.get_pipe_transport(self, fd)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_13get_pipe_transport(PyObject *__pyx_v_self, PyObject *__pyx_v_fd) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_pipe_transport (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_12get_pipe_transport(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self), ((PyObject *)__pyx_v_fd));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_12get_pipe_transport(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, PyObject *__pyx_v_fd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("get_pipe_transport", 0);

  /* "uvloop/handles/process.pyx":617
 * 
 *     def get_pipe_transport(self, fd):
 *         if fd == 0:             # <<<<<<<<<<<<<<
 *             return self._stdin
 *         elif fd == 1:
 */
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_fd, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":618
 *     def get_pipe_transport(self, fd):
 *         if fd == 0:
 *             return self._stdin             # <<<<<<<<<<<<<<
 *         elif fd == 1:
 *             return self._stdout
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_self->_stdin));
    __pyx_r = ((PyObject *)__pyx_v_self->_stdin);
    goto __pyx_L0;

    /* "uvloop/handles/process.pyx":617
 * 
 *     def get_pipe_transport(self, fd):
 *         if fd == 0:             # <<<<<<<<<<<<<<
 *             return self._stdin
 *         elif fd == 1:
 */
  }

  /* "uvloop/handles/process.pyx":619
 *         if fd == 0:
 *             return self._stdin
 *         elif fd == 1:             # <<<<<<<<<<<<<<
 *             return self._stdout
 *         elif fd == 2:
 */
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_fd, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 619, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":620
 *             return self._stdin
 *         elif fd == 1:
 *             return self._stdout             # <<<<<<<<<<<<<<
 *         elif fd == 2:
 *             return self._stderr
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_self->_stdout));
    __pyx_r = ((PyObject *)__pyx_v_self->_stdout);
    goto __pyx_L0;

    /* "uvloop/handles/process.pyx":619
 *         if fd == 0:
 *             return self._stdin
 *         elif fd == 1:             # <<<<<<<<<<<<<<
 *             return self._stdout
 *         elif fd == 2:
 */
  }

  /* "uvloop/handles/process.pyx":621
 *         elif fd == 1:
 *             return self._stdout
 *         elif fd == 2:             # <<<<<<<<<<<<<<
 *             return self._stderr
 * 
 */
  __pyx_t_1 = __Pyx_PyInt_EqObjC(__pyx_v_fd, __pyx_int_2, 2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(6, 621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":622
 *             return self._stdout
 *         elif fd == 2:
 *             return self._stderr             # <<<<<<<<<<<<<<
 * 
 *     def terminate(self):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_self->_stderr));
    __pyx_r = ((PyObject *)__pyx_v_self->_stderr);
    goto __pyx_L0;

    /* "uvloop/handles/process.pyx":621
 *         elif fd == 1:
 *             return self._stdout
 *         elif fd == 2:             # <<<<<<<<<<<<<<
 *             return self._stderr
 * 
 */
  }

  /* "uvloop/handles/process.pyx":616
 *         return self._returncode
 * 
 *     def get_pipe_transport(self, fd):             # <<<<<<<<<<<<<<
 *         if fd == 0:
 *             return self._stdin
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.get_pipe_transport", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":624
 *             return self._stderr
 * 
 *     def terminate(self):             # <<<<<<<<<<<<<<
 *         self._check_proc()
 *         self._kill(uv.SIGTERM)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_15terminate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_14terminate[] = "UVProcessTransport.terminate(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_15terminate(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("terminate (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_14terminate(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_14terminate(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("terminate", 0);

  /* "uvloop/handles/process.pyx":625
 * 
 *     def terminate(self):
 *         self._check_proc()             # <<<<<<<<<<<<<<
 *         self._kill(uv.SIGTERM)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_check_proc(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":626
 *     def terminate(self):
 *         self._check_proc()
 *         self._kill(uv.SIGTERM)             # <<<<<<<<<<<<<<
 * 
 *     def kill(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._kill(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), SIGTERM); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":624
 *             return self._stderr
 * 
 *     def terminate(self):             # <<<<<<<<<<<<<<
 *         self._check_proc()
 *         self._kill(uv.SIGTERM)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.terminate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":628
 *         self._kill(uv.SIGTERM)
 * 
 *     def kill(self):             # <<<<<<<<<<<<<<
 *         self._check_proc()
 *         self._kill(uv.SIGKILL)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_17kill(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_16kill[] = "UVProcessTransport.kill(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_17kill(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("kill (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_16kill(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_16kill(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("kill", 0);

  /* "uvloop/handles/process.pyx":629
 * 
 *     def kill(self):
 *         self._check_proc()             # <<<<<<<<<<<<<<
 *         self._kill(uv.SIGKILL)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_check_proc(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":630
 *     def kill(self):
 *         self._check_proc()
 *         self._kill(uv.SIGKILL)             # <<<<<<<<<<<<<<
 * 
 *     def send_signal(self, int signal):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._kill(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), SIGKILL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":628
 *         self._kill(uv.SIGTERM)
 * 
 *     def kill(self):             # <<<<<<<<<<<<<<
 *         self._check_proc()
 *         self._kill(uv.SIGKILL)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.kill", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":632
 *         self._kill(uv.SIGKILL)
 * 
 *     def send_signal(self, int signal):             # <<<<<<<<<<<<<<
 *         self._check_proc()
 *         self._kill(signal)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_19send_signal(PyObject *__pyx_v_self, PyObject *__pyx_arg_signal); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_18send_signal[] = "UVProcessTransport.send_signal(self, int signal)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_19send_signal(PyObject *__pyx_v_self, PyObject *__pyx_arg_signal) {
  int __pyx_v_signal;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("send_signal (wrapper)", 0);
  assert(__pyx_arg_signal); {
    __pyx_v_signal = __Pyx_PyInt_As_int(__pyx_arg_signal); if (unlikely((__pyx_v_signal == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 632, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.send_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_18send_signal(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self), ((int)__pyx_v_signal));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_18send_signal(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, int __pyx_v_signal) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("send_signal", 0);

  /* "uvloop/handles/process.pyx":633
 * 
 *     def send_signal(self, int signal):
 *         self._check_proc()             # <<<<<<<<<<<<<<
 *         self._kill(signal)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->_check_proc(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":634
 *     def send_signal(self, int signal):
 *         self._check_proc()
 *         self._kill(signal)             # <<<<<<<<<<<<<<
 * 
 *     def is_closing(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._kill(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), __pyx_v_signal); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":632
 *         self._kill(uv.SIGKILL)
 * 
 *     def send_signal(self, int signal):             # <<<<<<<<<<<<<<
 *         self._check_proc()
 *         self._kill(signal)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.send_signal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":636
 *         self._kill(signal)
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closed
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_21is_closing(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_20is_closing[] = "UVProcessTransport.is_closing(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_21is_closing(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_closing (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_20is_closing(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_20is_closing(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("is_closing", 0);

  /* "uvloop/handles/process.pyx":637
 * 
 *     def is_closing(self):
 *         return self._closed             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->__pyx_base.__pyx_base._closed); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":636
 *         self._kill(signal)
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closed
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.is_closing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":639
 *         return self._closed
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         if self._returncode is None:
 *             self._kill(uv.SIGKILL)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_23close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_22close[] = "UVProcessTransport.close(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_23close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_22close(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_22close(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("close", 0);

  /* "uvloop/handles/process.pyx":640
 * 
 *     def close(self):
 *         if self._returncode is None:             # <<<<<<<<<<<<<<
 *             self._kill(uv.SIGKILL)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base._returncode == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":641
 *     def close(self):
 *         if self._returncode is None:
 *             self._kill(uv.SIGKILL)             # <<<<<<<<<<<<<<
 * 
 *         if self._stdin is not None:
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._kill(((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_v_self), SIGKILL); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/process.pyx":640
 * 
 *     def close(self):
 *         if self._returncode is None:             # <<<<<<<<<<<<<<
 *             self._kill(uv.SIGKILL)
 * 
 */
  }

  /* "uvloop/handles/process.pyx":643
 *             self._kill(uv.SIGKILL)
 * 
 *         if self._stdin is not None:             # <<<<<<<<<<<<<<
 *             self._stdin.close()
 *         if self._stdout is not None:
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->_stdin) != Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":644
 * 
 *         if self._stdin is not None:
 *             self._stdin.close()             # <<<<<<<<<<<<<<
 *         if self._stdout is not None:
 *             self._stdout.close()
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->_stdin), __pyx_n_s_close); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 644, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 644, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/process.pyx":643
 *             self._kill(uv.SIGKILL)
 * 
 *         if self._stdin is not None:             # <<<<<<<<<<<<<<
 *             self._stdin.close()
 *         if self._stdout is not None:
 */
  }

  /* "uvloop/handles/process.pyx":645
 *         if self._stdin is not None:
 *             self._stdin.close()
 *         if self._stdout is not None:             # <<<<<<<<<<<<<<
 *             self._stdout.close()
 *         if self._stderr is not None:
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_stdout) != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":646
 *             self._stdin.close()
 *         if self._stdout is not None:
 *             self._stdout.close()             # <<<<<<<<<<<<<<
 *         if self._stderr is not None:
 *             self._stderr.close()
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->_stdout), __pyx_n_s_close); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 646, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 646, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/process.pyx":645
 *         if self._stdin is not None:
 *             self._stdin.close()
 *         if self._stdout is not None:             # <<<<<<<<<<<<<<
 *             self._stdout.close()
 *         if self._stderr is not None:
 */
  }

  /* "uvloop/handles/process.pyx":647
 *         if self._stdout is not None:
 *             self._stdout.close()
 *         if self._stderr is not None:             # <<<<<<<<<<<<<<
 *             self._stderr.close()
 * 
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->_stderr) != Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":648
 *             self._stdout.close()
 *         if self._stderr is not None:
 *             self._stderr.close()             # <<<<<<<<<<<<<<
 * 
 *         if self._returncode is not None:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->_stderr), __pyx_n_s_close); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 648, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 648, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/process.pyx":647
 *         if self._stdout is not None:
 *             self._stdout.close()
 *         if self._stderr is not None:             # <<<<<<<<<<<<<<
 *             self._stderr.close()
 * 
 */
  }

  /* "uvloop/handles/process.pyx":650
 *             self._stderr.close()
 * 
 *         if self._returncode is not None:             # <<<<<<<<<<<<<<
 *             # The process is dead, just close the UV handle.
 *             #
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base._returncode != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/process.pyx":657
 *             # which the transport will be GC'ed and the uvhandle will be
 *             # closed in UVHandle.__dealloc__.)
 *             self._close()             # <<<<<<<<<<<<<<
 * 
 *     def get_extra_info(self, name, default=None):
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/process.pyx":650
 *             self._stderr.close()
 * 
 *         if self._returncode is not None:             # <<<<<<<<<<<<<<
 *             # The process is dead, just close the UV handle.
 *             #
 */
  }

  /* "uvloop/handles/process.pyx":639
 *         return self._closed
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         if self._returncode is None:
 *             self._kill(uv.SIGKILL)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":659
 *             self._close()
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return default
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_25get_extra_info(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_24get_extra_info[] = "UVProcessTransport.get_extra_info(self, name, default=None)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_25get_extra_info(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_extra_info (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name_2,&__pyx_n_s_default,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_extra_info") < 0)) __PYX_ERR(6, 659, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_name = values[0];
    __pyx_v_default = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_extra_info", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(6, 659, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_24get_extra_info(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self), __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_24get_extra_info(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_extra_info", 0);

  /* "uvloop/handles/process.pyx":660
 * 
 *     def get_extra_info(self, name, default=None):
 *         return default             # <<<<<<<<<<<<<<
 * 
 *     def _wait(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_default);
  __pyx_r = __pyx_v_default;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":659
 *             self._close()
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         return default
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":662
 *         return default
 * 
 *     def _wait(self):             # <<<<<<<<<<<<<<
 *         fut = self._loop._new_future()
 *         if self._returncode is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_27_wait(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_26_wait[] = "UVProcessTransport._wait(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_27_wait(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_wait (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_26_wait(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_26_wait(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_v_fut = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("_wait", 0);

  /* "uvloop/handles/process.pyx":663
 * 
 *     def _wait(self):
 *         fut = self._loop._new_future()             # <<<<<<<<<<<<<<
 *         if self._returncode is not None:
 *             fut.set_result(self._returncode)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_v_self->__pyx_base.__pyx_base._loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fut = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":664
 *     def _wait(self):
 *         fut = self._loop._new_future()
 *         if self._returncode is not None:             # <<<<<<<<<<<<<<
 *             fut.set_result(self._returncode)
 *             return fut
 */
  __pyx_t_2 = (__pyx_v_self->__pyx_base._returncode != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/process.pyx":665
 *         fut = self._loop._new_future()
 *         if self._returncode is not None:
 *             fut.set_result(self._returncode)             # <<<<<<<<<<<<<<
 *             return fut
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fut, __pyx_n_s_set_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 665, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_self->__pyx_base._returncode); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 665, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_self->__pyx_base._returncode};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 665, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_self->__pyx_base._returncode};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 665, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 665, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_self->__pyx_base._returncode);
        __Pyx_GIVEREF(__pyx_v_self->__pyx_base._returncode);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_self->__pyx_base._returncode);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 665, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/process.pyx":666
 *         if self._returncode is not None:
 *             fut.set_result(self._returncode)
 *             return fut             # <<<<<<<<<<<<<<
 * 
 *         self._exit_waiters.append(fut)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_fut);
    __pyx_r = __pyx_v_fut;
    goto __pyx_L0;

    /* "uvloop/handles/process.pyx":664
 *     def _wait(self):
 *         fut = self._loop._new_future()
 *         if self._returncode is not None:             # <<<<<<<<<<<<<<
 *             fut.set_result(self._returncode)
 *             return fut
 */
  }

  /* "uvloop/handles/process.pyx":668
 *             return fut
 * 
 *         self._exit_waiters.append(fut)             # <<<<<<<<<<<<<<
 *         return fut
 * 
 */
  if (unlikely(__pyx_v_self->_exit_waiters == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(6, 668, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_self->_exit_waiters, __pyx_v_fut); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(6, 668, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":669
 * 
 *         self._exit_waiters.append(fut)
 *         return fut             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_fut);
  __pyx_r = __pyx_v_fut;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":662
 *         return default
 * 
 *     def _wait(self):             # <<<<<<<<<<<<<<
 *         fut = self._loop._new_future()
 *         if self._returncode is not None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport._wait", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fut);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_29__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_28__reduce_cython__[] = "UVProcessTransport.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_29__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_28__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__229, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_31__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_18UVProcessTransport_30__setstate_cython__[] = "UVProcessTransport.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_18UVProcessTransport_31__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_18UVProcessTransport_30__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_18UVProcessTransport_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVProcessTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__230, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVProcessTransport.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":674
 * class WriteSubprocessPipeProto(aio_BaseProtocol):
 * 
 *     def __init__(self, proc, fd):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if type(proc) is not UVProcessTransport:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto___init__[] = "WriteSubprocessPipeProto.__init__(self, proc, fd)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_1__init__ = {"__init__", (PyCFunction)__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_1__init__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto___init__};
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_proc = 0;
  PyObject *__pyx_v_fd = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_proc,&__pyx_n_s_fd,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_proc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(6, 674, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fd)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(6, 674, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(6, 674, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_proc = values[1];
    __pyx_v_fd = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(6, 674, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto___init__(__pyx_self, __pyx_v_self, __pyx_v_proc, __pyx_v_fd);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_proc, PyObject *__pyx_v_fd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/handles/process.pyx":675
 * 
 *     def __init__(self, proc, fd):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if type(proc) is not UVProcessTransport:
 *                 raise TypeError
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":676
 *     def __init__(self, proc, fd):
 *         if UVLOOP_DEBUG:
 *             if type(proc) is not UVProcessTransport:             # <<<<<<<<<<<<<<
 *                 raise TypeError
 *             if not isinstance(fd, int):
 */
    __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_proc)) != ((PyObject *)__pyx_ptype_6uvloop_4loop_UVProcessTransport));
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/handles/process.pyx":677
 *         if UVLOOP_DEBUG:
 *             if type(proc) is not UVProcessTransport:
 *                 raise TypeError             # <<<<<<<<<<<<<<
 *             if not isinstance(fd, int):
 *                 raise TypeError
 */
      __Pyx_Raise(__pyx_builtin_TypeError, 0, 0, 0);
      __PYX_ERR(6, 677, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":676
 *     def __init__(self, proc, fd):
 *         if UVLOOP_DEBUG:
 *             if type(proc) is not UVProcessTransport:             # <<<<<<<<<<<<<<
 *                 raise TypeError
 *             if not isinstance(fd, int):
 */
    }

    /* "uvloop/handles/process.pyx":678
 *             if type(proc) is not UVProcessTransport:
 *                 raise TypeError
 *             if not isinstance(fd, int):             # <<<<<<<<<<<<<<
 *                 raise TypeError
 *         self.proc = proc
 */
    __pyx_t_2 = PyInt_Check(__pyx_v_fd); 
    __pyx_t_1 = ((!(__pyx_t_2 != 0)) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/handles/process.pyx":679
 *                 raise TypeError
 *             if not isinstance(fd, int):
 *                 raise TypeError             # <<<<<<<<<<<<<<
 *         self.proc = proc
 *         self.fd = fd
 */
      __Pyx_Raise(__pyx_builtin_TypeError, 0, 0, 0);
      __PYX_ERR(6, 679, __pyx_L1_error)

      /* "uvloop/handles/process.pyx":678
 *             if type(proc) is not UVProcessTransport:
 *                 raise TypeError
 *             if not isinstance(fd, int):             # <<<<<<<<<<<<<<
 *                 raise TypeError
 *         self.proc = proc
 */
    }

    /* "uvloop/handles/process.pyx":675
 * 
 *     def __init__(self, proc, fd):
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if type(proc) is not UVProcessTransport:
 *                 raise TypeError
 */
  }

  /* "uvloop/handles/process.pyx":680
 *             if not isinstance(fd, int):
 *                 raise TypeError
 *         self.proc = proc             # <<<<<<<<<<<<<<
 *         self.fd = fd
 *         self.pipe = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_proc, __pyx_v_proc) < 0) __PYX_ERR(6, 680, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":681
 *                 raise TypeError
 *         self.proc = proc
 *         self.fd = fd             # <<<<<<<<<<<<<<
 *         self.pipe = None
 *         self.disconnected = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_fd, __pyx_v_fd) < 0) __PYX_ERR(6, 681, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":682
 *         self.proc = proc
 *         self.fd = fd
 *         self.pipe = None             # <<<<<<<<<<<<<<
 *         self.disconnected = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pipe, Py_None) < 0) __PYX_ERR(6, 682, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":683
 *         self.fd = fd
 *         self.pipe = None
 *         self.disconnected = False             # <<<<<<<<<<<<<<
 * 
 *     def connection_made(self, transport):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_disconnected, Py_False) < 0) __PYX_ERR(6, 683, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":674
 * class WriteSubprocessPipeProto(aio_BaseProtocol):
 * 
 *     def __init__(self, proc, fd):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if type(proc) is not UVProcessTransport:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":685
 *         self.disconnected = False
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         self.pipe = transport
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_3connection_made(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_2connection_made[] = "WriteSubprocessPipeProto.connection_made(self, transport)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_3connection_made = {"connection_made", (PyCFunction)__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_3connection_made, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_2connection_made};
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_3connection_made(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_transport = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connection_made (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_transport,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_transport)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("connection_made", 1, 2, 2, 1); __PYX_ERR(6, 685, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "connection_made") < 0)) __PYX_ERR(6, 685, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_transport = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connection_made", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(6, 685, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_2connection_made(__pyx_self, __pyx_v_self, __pyx_v_transport);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_2connection_made(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_transport) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connection_made", 0);

  /* "uvloop/handles/process.pyx":686
 * 
 *     def connection_made(self, transport):
 *         self.pipe = transport             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_pipe, __pyx_v_transport) < 0) __PYX_ERR(6, 686, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":685
 *         self.disconnected = False
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         self.pipe = transport
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":688
 *         self.pipe = transport
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return ('<%s fd=%s pipe=%r>'
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_4__repr__[] = "WriteSubprocessPipeProto.__repr__(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_5__repr__ = {"__repr__", (PyCFunction)__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_5__repr__, METH_O, __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_4__repr__};
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_5__repr__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_4__repr__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_4__repr__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/handles/process.pyx":689
 * 
 *     def __repr__(self):
 *         return ('<%s fd=%s pipe=%r>'             # <<<<<<<<<<<<<<
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u__128);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__128);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__128);

  /* "uvloop/handles/process.pyx":690
 *     def __repr__(self):
 *         return ('<%s fd=%s pipe=%r>'
 *                 % (self.__class__.__name__, self.fd, self.pipe))             # <<<<<<<<<<<<<<
 * 
 *     def connection_lost(self, exc):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_fd_2);
  __pyx_t_2 += 4;
  __Pyx_GIVEREF(__pyx_kp_u_fd_2);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_fd_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fd); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_pipe_2);
  __pyx_t_2 += 6;
  __Pyx_GIVEREF(__pyx_kp_u_pipe_2);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u_pipe_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_pipe); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__130);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__130);
  PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_kp_u__130);

  /* "uvloop/handles/process.pyx":689
 * 
 *     def __repr__(self):
 *         return ('<%s fd=%s pipe=%r>'             # <<<<<<<<<<<<<<
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 * 
 */
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 7, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":688
 *         self.pipe = transport
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return ('<%s fd=%s pipe=%r>'
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":692
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         self.disconnected = True
 *         (<UVProcessTransport>self.proc)._pipe_connection_lost(self.fd, exc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_7connection_lost(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_6connection_lost[] = "WriteSubprocessPipeProto.connection_lost(self, exc)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_7connection_lost = {"connection_lost", (PyCFunction)__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_7connection_lost, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_6connection_lost};
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_7connection_lost(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exc = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connection_lost (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_exc,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_exc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("connection_lost", 1, 2, 2, 1); __PYX_ERR(6, 692, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "connection_lost") < 0)) __PYX_ERR(6, 692, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_exc = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connection_lost", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(6, 692, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.connection_lost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_6connection_lost(__pyx_self, __pyx_v_self, __pyx_v_exc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_6connection_lost(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("connection_lost", 0);

  /* "uvloop/handles/process.pyx":693
 * 
 *     def connection_lost(self, exc):
 *         self.disconnected = True             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._pipe_connection_lost(self.fd, exc)
 *         self.proc = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_disconnected, Py_True) < 0) __PYX_ERR(6, 693, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":694
 *     def connection_lost(self, exc):
 *         self.disconnected = True
 *         (<UVProcessTransport>self.proc)._pipe_connection_lost(self.fd, exc)             # <<<<<<<<<<<<<<
 *         self.proc = None
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_proc); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_1)->__pyx_base.__pyx_base.__pyx_vtab)->_pipe_connection_lost(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_1), __pyx_t_3, __pyx_v_exc); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/process.pyx":695
 *         self.disconnected = True
 *         (<UVProcessTransport>self.proc)._pipe_connection_lost(self.fd, exc)
 *         self.proc = None             # <<<<<<<<<<<<<<
 * 
 *     def pause_writing(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_proc, Py_None) < 0) __PYX_ERR(6, 695, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":692
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         self.disconnected = True
 *         (<UVProcessTransport>self.proc)._pipe_connection_lost(self.fd, exc)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.connection_lost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":697
 *         self.proc = None
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_9pause_writing(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_8pause_writing[] = "WriteSubprocessPipeProto.pause_writing(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_9pause_writing = {"pause_writing", (PyCFunction)__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_9pause_writing, METH_O, __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_8pause_writing};
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_9pause_writing(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pause_writing (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_8pause_writing(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_8pause_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("pause_writing", 0);

  /* "uvloop/handles/process.pyx":698
 * 
 *     def pause_writing(self):
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()             # <<<<<<<<<<<<<<
 * 
 *     def resume_writing(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_proc); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_2)->_protocol, __pyx_n_s_pause_writing); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 698, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 698, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":697
 *         self.proc = None
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.pause_writing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":700
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.resume_writing()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_11resume_writing(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_10resume_writing[] = "WriteSubprocessPipeProto.resume_writing(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_11resume_writing = {"resume_writing", (PyCFunction)__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_11resume_writing, METH_O, __pyx_doc_6uvloop_4loop_24WriteSubprocessPipeProto_10resume_writing};
static PyObject *__pyx_pw_6uvloop_4loop_24WriteSubprocessPipeProto_11resume_writing(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resume_writing (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_10resume_writing(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_24WriteSubprocessPipeProto_10resume_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("resume_writing", 0);

  /* "uvloop/handles/process.pyx":701
 * 
 *     def resume_writing(self):
 *         (<UVProcessTransport>self.proc)._protocol.resume_writing()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_proc); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_2)->_protocol, __pyx_n_s_resume_writing); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 701, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 701, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":700
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.resume_writing()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.WriteSubprocessPipeProto.resume_writing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":707
 *                               aio_Protocol):
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._pipe_data_received(self.fd, data)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_23ReadSubprocessPipeProto_1data_received(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_23ReadSubprocessPipeProto_data_received[] = "ReadSubprocessPipeProto.data_received(self, data)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_23ReadSubprocessPipeProto_1data_received = {"data_received", (PyCFunction)__pyx_pw_6uvloop_4loop_23ReadSubprocessPipeProto_1data_received, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_23ReadSubprocessPipeProto_data_received};
static PyObject *__pyx_pw_6uvloop_4loop_23ReadSubprocessPipeProto_1data_received(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("data_received (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_data,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("data_received", 1, 2, 2, 1); __PYX_ERR(6, 707, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "data_received") < 0)) __PYX_ERR(6, 707, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("data_received", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(6, 707, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.ReadSubprocessPipeProto.data_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_23ReadSubprocessPipeProto_data_received(__pyx_self, __pyx_v_self, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_23ReadSubprocessPipeProto_data_received(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("data_received", 0);

  /* "uvloop/handles/process.pyx":708
 * 
 *     def data_received(self, data):
 *         (<UVProcessTransport>self.proc)._pipe_data_received(self.fd, data)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_proc); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fd); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(6, 708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport *)((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_1)->__pyx_base.__pyx_base.__pyx_vtab)->_pipe_data_received(((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)__pyx_t_1), __pyx_t_3, __pyx_v_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/process.pyx":707
 *                               aio_Protocol):
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._pipe_data_received(self.fd, data)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.ReadSubprocessPipeProto.data_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":711
 * 
 * 
 * cdef __process_convert_fileno(object obj):             # <<<<<<<<<<<<<<
 *     if obj is None or isinstance(obj, int):
 *         return obj
 */

static PyObject *__pyx_f_6uvloop_4loop___process_convert_fileno(PyObject *__pyx_v_obj) {
  PyObject *__pyx_v_fileno = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__process_convert_fileno", 0);

  /* "uvloop/handles/process.pyx":712
 * 
 * cdef __process_convert_fileno(object obj):
 *     if obj is None or isinstance(obj, int):             # <<<<<<<<<<<<<<
 *         return obj
 * 
 */
  __pyx_t_2 = (__pyx_v_obj == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = PyInt_Check(__pyx_v_obj); 
  __pyx_t_2 = (__pyx_t_3 != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":713
 * cdef __process_convert_fileno(object obj):
 *     if obj is None or isinstance(obj, int):
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     fileno = obj.fileno()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_obj);
    __pyx_r = __pyx_v_obj;
    goto __pyx_L0;

    /* "uvloop/handles/process.pyx":712
 * 
 * cdef __process_convert_fileno(object obj):
 *     if obj is None or isinstance(obj, int):             # <<<<<<<<<<<<<<
 *         return obj
 * 
 */
  }

  /* "uvloop/handles/process.pyx":715
 *         return obj
 * 
 *     fileno = obj.fileno()             # <<<<<<<<<<<<<<
 *     if not isinstance(fileno, int):
 *         raise TypeError(
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_n_s_fileno); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 715, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 715, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 715, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_fileno = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "uvloop/handles/process.pyx":716
 * 
 *     fileno = obj.fileno()
 *     if not isinstance(fileno, int):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             '{!r}.fileno() returned non-integer'.format(obj))
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_fileno); 
  __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/process.pyx":718
 *     if not isinstance(fileno, int):
 *         raise TypeError(
 *             '{!r}.fileno() returned non-integer'.format(obj))             # <<<<<<<<<<<<<<
 *     return fileno
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_r_fileno_returned_non_integer, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_obj); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 718, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_obj};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 718, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_obj};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 718, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 718, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_obj);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 718, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/process.pyx":717
 *     fileno = obj.fileno()
 *     if not isinstance(fileno, int):
 *         raise TypeError(             # <<<<<<<<<<<<<<
 *             '{!r}.fileno() returned non-integer'.format(obj))
 *     return fileno
 */
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 717, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(6, 717, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":716
 * 
 *     fileno = obj.fileno()
 *     if not isinstance(fileno, int):             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             '{!r}.fileno() returned non-integer'.format(obj))
 */
  }

  /* "uvloop/handles/process.pyx":719
 *         raise TypeError(
 *             '{!r}.fileno() returned non-integer'.format(obj))
 *     return fileno             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_fileno);
  __pyx_r = __pyx_v_fileno;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":711
 * 
 * 
 * cdef __process_convert_fileno(object obj):             # <<<<<<<<<<<<<<
 *     if obj is None or isinstance(obj, int):
 *         return obj
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.__process_convert_fileno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fileno);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/process.pyx":722
 * 
 * 
 * cdef void __uvprocess_on_exit_callback(uv.uv_process_t *handle,             # <<<<<<<<<<<<<<
 *                                        int64_t exit_status,
 *                                        int term_signal) with gil:
 */

static void __pyx_f_6uvloop_4loop___uvprocess_on_exit_callback(uv_process_t *__pyx_v_handle, int64_t __pyx_v_exit_status, int __pyx_v_term_signal) {
  struct __pyx_obj_6uvloop_4loop_UVProcess *__pyx_v_proc = 0;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  char const *__pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__uvprocess_on_exit_callback", 0);

  /* "uvloop/handles/process.pyx":727
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,
 *                             "UVProcess exit callback") == 0:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = ((__pyx_f_6uvloop_4loop___ensure_handle_data(((uv_handle_t *)__pyx_v_handle), ((char const *)"UVProcess exit callback")) == 0) != 0);

  /* "uvloop/handles/process.pyx":726
 *                                        int term_signal) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,             # <<<<<<<<<<<<<<
 *                             "UVProcess exit callback") == 0:
 *         return
 */
  if (__pyx_t_1) {

    /* "uvloop/handles/process.pyx":728
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,
 *                             "UVProcess exit callback") == 0:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef UVProcess proc = <UVProcess> handle.data
 */
    goto __pyx_L0;

    /* "uvloop/handles/process.pyx":726
 *                                        int term_signal) with gil:
 * 
 *     if __ensure_handle_data(<uv.uv_handle_t*>handle,             # <<<<<<<<<<<<<<
 *                             "UVProcess exit callback") == 0:
 *         return
 */
  }

  /* "uvloop/handles/process.pyx":730
 *         return
 * 
 *     cdef UVProcess proc = <UVProcess> handle.data             # <<<<<<<<<<<<<<
 *     try:
 *         proc._on_exit(exit_status, term_signal)
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_handle->data);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_proc = ((struct __pyx_obj_6uvloop_4loop_UVProcess *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/handles/process.pyx":731
 * 
 *     cdef UVProcess proc = <UVProcess> handle.data
 *     try:             # <<<<<<<<<<<<<<
 *         proc._on_exit(exit_status, term_signal)
 *     except BaseException as ex:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "uvloop/handles/process.pyx":732
 *     cdef UVProcess proc = <UVProcess> handle.data
 *     try:
 *         proc._on_exit(exit_status, term_signal)             # <<<<<<<<<<<<<<
 *     except BaseException as ex:
 *         proc._error(ex, False)
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_proc->__pyx_base.__pyx_vtab)->_on_exit(__pyx_v_proc, __pyx_v_exit_status, __pyx_v_term_signal); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 732, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/process.pyx":731
 * 
 *     cdef UVProcess proc = <UVProcess> handle.data
 *     try:             # <<<<<<<<<<<<<<
 *         proc._on_exit(exit_status, term_signal)
 *     except BaseException as ex:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":733
 *     try:
 *         proc._on_exit(exit_status, term_signal)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         proc._error(ex, False)
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("uvloop.loop.__uvprocess_on_exit_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(6, 733, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_ex = __pyx_t_7;
      /*try:*/ {

        /* "uvloop/handles/process.pyx":734
 *         proc._on_exit(exit_status, term_signal)
 *     except BaseException as ex:
 *         proc._error(ex, False)             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_t_9 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_proc->__pyx_base.__pyx_vtab)->__pyx_base._error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_proc), __pyx_v_ex, Py_False); if (unlikely(!__pyx_t_9)) __PYX_ERR(6, 734, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }

      /* "uvloop/handles/process.pyx":733
 *     try:
 *         proc._on_exit(exit_status, term_signal)
 *     except BaseException as ex:             # <<<<<<<<<<<<<<
 *         proc._error(ex, False)
 * 
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_ex);
          __pyx_v_ex = NULL;
          goto __pyx_L16;
        }
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __pyx_t_6 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_11 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_15);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
          }
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
          __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0;
          __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_11;
          goto __pyx_L6_except_error;
        }
        __pyx_L16:;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/handles/process.pyx":731
 * 
 *     cdef UVProcess proc = <UVProcess> handle.data
 *     try:             # <<<<<<<<<<<<<<
 *         proc._on_exit(exit_status, term_signal)
 *     except BaseException as ex:
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/process.pyx":722
 * 
 * 
 * cdef void __uvprocess_on_exit_callback(uv.uv_process_t *handle,             # <<<<<<<<<<<<<<
 *                                        int64_t exit_status,
 *                                        int term_signal) with gil:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__uvprocess_on_exit_callback", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_proc);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/handles/process.pyx":737
 * 
 * 
 * cdef __socketpair():             # <<<<<<<<<<<<<<
 *     cdef:
 *         int fds[2]
 */

static PyObject *__pyx_f_6uvloop_4loop___socketpair(void) {
  int __pyx_v_fds[2];
  int __pyx_v_err;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__socketpair", 0);

  /* "uvloop/handles/process.pyx":742
 *         int err
 * 
 *     err = system.socketpair(uv.AF_UNIX, uv.SOCK_STREAM, 0, fds)             # <<<<<<<<<<<<<<
 *     if err:
 *         exc = convert_error(-err)
 */
  __pyx_v_err = socketpair(AF_UNIX, SOCK_STREAM, 0, __pyx_v_fds);

  /* "uvloop/handles/process.pyx":743
 * 
 *     err = system.socketpair(uv.AF_UNIX, uv.SOCK_STREAM, 0, fds)
 *     if err:             # <<<<<<<<<<<<<<
 *         exc = convert_error(-err)
 *         raise exc
 */
  __pyx_t_1 = (__pyx_v_err != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/handles/process.pyx":744
 *     err = system.socketpair(uv.AF_UNIX, uv.SOCK_STREAM, 0, fds)
 *     if err:
 *         exc = convert_error(-err)             # <<<<<<<<<<<<<<
 *         raise exc
 * 
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error((-__pyx_v_err)); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_exc = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "uvloop/handles/process.pyx":745
 *     if err:
 *         exc = convert_error(-err)
 *         raise exc             # <<<<<<<<<<<<<<
 * 
 *     os_set_inheritable(fds[0], False)
 */
    __Pyx_Raise(__pyx_v_exc, 0, 0, 0);
    __PYX_ERR(6, 745, __pyx_L1_error)

    /* "uvloop/handles/process.pyx":743
 * 
 *     err = system.socketpair(uv.AF_UNIX, uv.SOCK_STREAM, 0, fds)
 *     if err:             # <<<<<<<<<<<<<<
 *         exc = convert_error(-err)
 *         raise exc
 */
  }

  /* "uvloop/handles/process.pyx":747
 *         raise exc
 * 
 *     os_set_inheritable(fds[0], False)             # <<<<<<<<<<<<<<
 *     os_set_inheritable(fds[1], False)
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_int((__pyx_v_fds[0])); if (unlikely(!__pyx_t_3)) __PYX_ERR(6, 747, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __pyx_t_4 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_3, Py_False};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 747, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_t_3, Py_False};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 747, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_t_3);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, Py_False);
    __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/process.pyx":748
 * 
 *     os_set_inheritable(fds[0], False)
 *     os_set_inheritable(fds[1], False)             # <<<<<<<<<<<<<<
 * 
 *     return fds[0], fds[1]
 */
  __pyx_t_4 = __Pyx_PyInt_From_int((__pyx_v_fds[1])); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __pyx_t_7 = __pyx_v_6uvloop_4loop_os_set_inheritable; __pyx_t_3 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_4, Py_False};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 748, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_4, Py_False};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 748, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_6, __pyx_t_4);
    __Pyx_INCREF(Py_False);
    __Pyx_GIVEREF(Py_False);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_6, Py_False);
    __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/process.pyx":750
 *     os_set_inheritable(fds[1], False)
 * 
 *     return fds[0], fds[1]             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int((__pyx_v_fds[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyInt_From_int((__pyx_v_fds[1])); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_7);
  __pyx_t_2 = 0;
  __pyx_t_7 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/process.pyx":737
 * 
 * 
 * cdef __socketpair():             # <<<<<<<<<<<<<<
 *     cdef:
 *         int fds[2]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.__socketpair", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/request.pyx":10
 *     """
 * 
 *     def __cinit__(self, Loop loop, *_):             # <<<<<<<<<<<<<<
 *         self.request = NULL
 *         self.loop = loop
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_9UVRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_9UVRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  CYTHON_UNUSED PyObject *__pyx_v__ = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (PyTuple_GET_SIZE(__pyx_args) > 1) {
    __pyx_v__ = PyTuple_GetSlice(__pyx_args, 1, PyTuple_GET_SIZE(__pyx_args));
    if (unlikely(!__pyx_v__)) {
      __Pyx_RefNannyFinishContext();
      return -1;
    }
    __Pyx_GOTREF(__pyx_v__);
  } else {
    __pyx_v__ = __pyx_empty_tuple; __Pyx_INCREF(__pyx_empty_tuple);
  }
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loop,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        default:
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t used_pos_args = (pos_args < 1) ? pos_args : 1;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, used_pos_args, "__cinit__") < 0)) __PYX_ERR(21, 10, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) < 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(21, 10, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_DECREF(__pyx_v__); __pyx_v__ = 0;
  __Pyx_AddTraceback("uvloop.loop.UVRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_loop), __pyx_ptype_6uvloop_4loop_Loop, 1, "loop", 0))) __PYX_ERR(21, 10, __pyx_L1_error)
  __pyx_r = __pyx_pf_6uvloop_4loop_9UVRequest___cinit__(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self), __pyx_v_loop, __pyx_v__);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_9UVRequest___cinit__(struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, CYTHON_UNUSED PyObject *__pyx_v__) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/request.pyx":11
 * 
 *     def __cinit__(self, Loop loop, *_):
 *         self.request = NULL             # <<<<<<<<<<<<<<
 *         self.loop = loop
 *         self.done = 0
 */
  __pyx_v_self->request = NULL;

  /* "uvloop/request.pyx":12
 *     def __cinit__(self, Loop loop, *_):
 *         self.request = NULL
 *         self.loop = loop             # <<<<<<<<<<<<<<
 *         self.done = 0
 *         Py_INCREF(self)
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_loop));
  __Pyx_GOTREF(__pyx_v_self->loop);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->loop));
  __pyx_v_self->loop = __pyx_v_loop;

  /* "uvloop/request.pyx":13
 *         self.request = NULL
 *         self.loop = loop
 *         self.done = 0             # <<<<<<<<<<<<<<
 *         Py_INCREF(self)
 * 
 */
  __pyx_v_self->done = 0;

  /* "uvloop/request.pyx":14
 *         self.loop = loop
 *         self.done = 0
 *         Py_INCREF(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef on_done(self):
 */
  Py_INCREF(((PyObject *)__pyx_v_self));

  /* "uvloop/request.pyx":10
 *     """
 * 
 *     def __cinit__(self, Loop loop, *_):             # <<<<<<<<<<<<<<
 *         self.request = NULL
 *         self.loop = loop
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/request.pyx":16
 *         Py_INCREF(self)
 * 
 *     cdef on_done(self):             # <<<<<<<<<<<<<<
 *         self.done = 1
 *         Py_DECREF(self)
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVRequest_on_done(struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("on_done", 0);

  /* "uvloop/request.pyx":17
 * 
 *     cdef on_done(self):
 *         self.done = 1             # <<<<<<<<<<<<<<
 *         Py_DECREF(self)
 * 
 */
  __pyx_v_self->done = 1;

  /* "uvloop/request.pyx":18
 *     cdef on_done(self):
 *         self.done = 1
 *         Py_DECREF(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef cancel(self):
 */
  Py_DECREF(((PyObject *)__pyx_v_self));

  /* "uvloop/request.pyx":16
 *         Py_INCREF(self)
 * 
 *     cdef on_done(self):             # <<<<<<<<<<<<<<
 *         self.done = 1
 *         Py_DECREF(self)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/request.pyx":20
 *         Py_DECREF(self)
 * 
 *     cdef cancel(self):             # <<<<<<<<<<<<<<
 *         # Most requests are implemented using a threadpool.  It's only
 *         # possible to cancel a request when it's still in a threadpool's
 */

static PyObject *__pyx_f_6uvloop_4loop_9UVRequest_cancel(struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self) {
  int __pyx_v_err;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("cancel", 0);

  /* "uvloop/request.pyx":29
 *         cdef int err
 * 
 *         if self.done == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->done == 1) != 0);
  if (__pyx_t_1) {

    /* "uvloop/request.pyx":30
 * 
 *         if self.done == 1:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/request.pyx":29
 *         cdef int err
 * 
 *         if self.done == 1:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/request.pyx":32
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self.request is NULL:
 *                 raise RuntimeError(
 */
  __pyx_t_1 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_1) {

    /* "uvloop/request.pyx":33
 * 
 *         if UVLOOP_DEBUG:
 *             if self.request is NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}.cancel: .request is NULL'.format(
 */
    __pyx_t_1 = ((__pyx_v_self->request == NULL) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/request.pyx":35
 *             if self.request is NULL:
 *                 raise RuntimeError(
 *                     '{}.cancel: .request is NULL'.format(             # <<<<<<<<<<<<<<
 *                         self.__class__.__name__))
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_cancel_request_is_NULL, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/request.pyx":36
 *                 raise RuntimeError(
 *                     '{}.cancel: .request is NULL'.format(
 *                         self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *             if self.request.data is NULL:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(21, 36, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(21, 36, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 35, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 35, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 35, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(21, 35, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 35, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/request.pyx":34
 *         if UVLOOP_DEBUG:
 *             if self.request is NULL:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{}.cancel: .request is NULL'.format(
 *                         self.__class__.__name__))
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 34, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(21, 34, __pyx_L1_error)

      /* "uvloop/request.pyx":33
 * 
 *         if UVLOOP_DEBUG:
 *             if self.request is NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}.cancel: .request is NULL'.format(
 */
    }

    /* "uvloop/request.pyx":38
 *                         self.__class__.__name__))
 * 
 *             if self.request.data is NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is NULL'.format(
 */
    __pyx_t_1 = ((__pyx_v_self->request->data == NULL) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/request.pyx":40
 *             if self.request.data is NULL:
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is NULL'.format(             # <<<<<<<<<<<<<<
 *                         self.__class__.__name__))
 * 
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_cancel_request_data_is_NULL, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "uvloop/request.pyx":41
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is NULL'.format(
 *                         self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *             if <UVRequest>self.request.data is not self:
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_6)) __PYX_ERR(21, 41, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(21, 41, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      if (!__pyx_t_6) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 40, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 40, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 40, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(21, 40, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 40, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/request.pyx":39
 * 
 *             if self.request.data is NULL:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{}.cancel: .request.data is NULL'.format(
 *                         self.__class__.__name__))
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 39, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(21, 39, __pyx_L1_error)

      /* "uvloop/request.pyx":38
 *                         self.__class__.__name__))
 * 
 *             if self.request.data is NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is NULL'.format(
 */
    }

    /* "uvloop/request.pyx":43
 *                         self.__class__.__name__))
 * 
 *             if <UVRequest>self.request.data is not self:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is not UVRequest'.format(
 */
    __pyx_t_1 = (((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self->request->data) != __pyx_v_self);
    __pyx_t_7 = (__pyx_t_1 != 0);
    if (unlikely(__pyx_t_7)) {

      /* "uvloop/request.pyx":45
 *             if <UVRequest>self.request.data is not self:
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is not UVRequest'.format(             # <<<<<<<<<<<<<<
 *                         self.__class__.__name__))
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_cancel_request_data_is_not_UVRe, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 45, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);

      /* "uvloop/request.pyx":46
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is not UVRequest'.format(
 *                         self.__class__.__name__))             # <<<<<<<<<<<<<<
 * 
 *         # We only can cancel pending requests.  Let's try.
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(21, 46, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(21, 46, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (!__pyx_t_4) {
        __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 45, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 45, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 45, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(21, 45, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
          __Pyx_GIVEREF(__pyx_t_5);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(21, 45, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/request.pyx":44
 * 
 *             if <UVRequest>self.request.data is not self:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '{}.cancel: .request.data is not UVRequest'.format(
 *                         self.__class__.__name__))
 */
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_RuntimeError, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 44, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(21, 44, __pyx_L1_error)

      /* "uvloop/request.pyx":43
 *                         self.__class__.__name__))
 * 
 *             if <UVRequest>self.request.data is not self:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(
 *                     '{}.cancel: .request.data is not UVRequest'.format(
 */
    }

    /* "uvloop/request.pyx":32
 *             return
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             if self.request is NULL:
 *                 raise RuntimeError(
 */
  }

  /* "uvloop/request.pyx":49
 * 
 *         # We only can cancel pending requests.  Let's try.
 *         err = uv.uv_cancel(self.request)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             if err == uv.UV_EBUSY:
 */
  __pyx_v_err = uv_cancel(__pyx_v_self->request);

  /* "uvloop/request.pyx":50
 *         # We only can cancel pending requests.  Let's try.
 *         err = uv.uv_cancel(self.request)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             if err == uv.UV_EBUSY:
 *                 # Can't close the request -- it's executing (see the first
 */
  __pyx_t_7 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_7) {

    /* "uvloop/request.pyx":51
 *         err = uv.uv_cancel(self.request)
 *         if err < 0:
 *             if err == uv.UV_EBUSY:             # <<<<<<<<<<<<<<
 *                 # Can't close the request -- it's executing (see the first
 *                 # comment).  Loop will have to wait until the callback
 */
    __pyx_t_7 = ((__pyx_v_err == UV_EBUSY) != 0);
    if (__pyx_t_7) {
      goto __pyx_L9;
    }

    /* "uvloop/request.pyx":56
 *                 # fires.
 *                 pass
 *             elif err == uv.UV_EINVAL:             # <<<<<<<<<<<<<<
 *                 # From libuv docs:
 *                 #
 */
    __pyx_t_7 = ((__pyx_v_err == UV_EINVAL) != 0);
    if (__pyx_t_7) {

      /* "uvloop/request.pyx":62
 *                 #     uv_getnameinfo_t and uv_work_t requests is currently
 *                 #     supported.
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 ex = convert_error(err)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/request.pyx":56
 *                 # fires.
 *                 pass
 *             elif err == uv.UV_EINVAL:             # <<<<<<<<<<<<<<
 *                 # From libuv docs:
 *                 #
 */
    }

    /* "uvloop/request.pyx":64
 *                 return
 *             else:
 *                 ex = convert_error(err)             # <<<<<<<<<<<<<<
 *                 self.loop._handle_exception(ex)
 */
    /*else*/ {
      __pyx_t_3 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_3)) __PYX_ERR(21, 64, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_ex = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "uvloop/request.pyx":65
 *             else:
 *                 ex = convert_error(err)
 *                 self.loop._handle_exception(ex)             # <<<<<<<<<<<<<<
 */
      ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_self->loop->__pyx_vtab)->_handle_exception(__pyx_v_self->loop, __pyx_v_ex);
    }
    __pyx_L9:;

    /* "uvloop/request.pyx":50
 *         # We only can cancel pending requests.  Let's try.
 *         err = uv.uv_cancel(self.request)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             if err == uv.UV_EBUSY:
 *                 # Can't close the request -- it's executing (see the first
 */
  }

  /* "uvloop/request.pyx":20
 *         Py_DECREF(self)
 * 
 *     cdef cancel(self):             # <<<<<<<<<<<<<<
 *         # Most requests are implemented using a threadpool.  It's only
 *         # possible to cancel a request when it's still in a threadpool's
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UVRequest.cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_9UVRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_9UVRequest_2__reduce_cython__[] = "UVRequest.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_9UVRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_9UVRequest_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_9UVRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__231, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVRequest.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_9UVRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_9UVRequest_4__setstate_cython__[] = "UVRequest.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_9UVRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_9UVRequest_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_9UVRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UVRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__232, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UVRequest.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":1
 * cdef __port_to_int(port, proto):             # <<<<<<<<<<<<<<
 *     if type(port) is int:
 *         return port
 */

static PyObject *__pyx_f_6uvloop_4loop___port_to_int(PyObject *__pyx_v_port, PyObject *__pyx_v_proto) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  __Pyx_RefNannySetupContext("__port_to_int", 0);
  __Pyx_INCREF(__pyx_v_port);

  /* "uvloop/dns.pyx":2
 * cdef __port_to_int(port, proto):
 *     if type(port) is int:             # <<<<<<<<<<<<<<
 *         return port
 * 
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_port)) == ((PyObject *)(&PyInt_Type)));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/dns.pyx":3
 * cdef __port_to_int(port, proto):
 *     if type(port) is int:
 *         return port             # <<<<<<<<<<<<<<
 * 
 *     if port is None or port == '' or port == b'':
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_port);
    __pyx_r = __pyx_v_port;
    goto __pyx_L0;

    /* "uvloop/dns.pyx":2
 * cdef __port_to_int(port, proto):
 *     if type(port) is int:             # <<<<<<<<<<<<<<
 *         return port
 * 
 */
  }

  /* "uvloop/dns.pyx":5
 *         return port
 * 
 *     if port is None or port == '' or port == b'':             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  __pyx_t_1 = (__pyx_v_port == Py_None);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_port, __pyx_kp_u__7, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(7, 5, __pyx_L1_error)
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyBytes_Equals(__pyx_v_port, __pyx_kp_b__7, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(7, 5, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_2) {

    /* "uvloop/dns.pyx":6
 * 
 *     if port is None or port == '' or port == b'':
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_0);
    __pyx_r = __pyx_int_0;
    goto __pyx_L0;

    /* "uvloop/dns.pyx":5
 *         return port
 * 
 *     if port is None or port == '' or port == b'':             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  }

  /* "uvloop/dns.pyx":8
 *         return 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         return int(port)
 *     except (ValueError, TypeError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/dns.pyx":9
 * 
 *     try:
 *         return int(port)             # <<<<<<<<<<<<<<
 *     except (ValueError, TypeError):
 *         pass
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_7 = __Pyx_PyNumber_Int(__pyx_v_port); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 9, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L12_try_return;

      /* "uvloop/dns.pyx":8
 *         return 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         return int(port)
 *     except (ValueError, TypeError):
 */
    }
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/dns.pyx":10
 *     try:
 *         return int(port)
 *     except (ValueError, TypeError):             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError) || __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
    if (__pyx_t_8) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L9_exception_handled;
    }
    goto __pyx_L10_except_error;
    __pyx_L10_except_error:;

    /* "uvloop/dns.pyx":8
 *         return 0
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         return int(port)
 *     except (ValueError, TypeError):
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L12_try_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
    __pyx_L9_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
  }

  /* "uvloop/dns.pyx":13
 *         pass
 * 
 *     if isinstance(port, bytes):             # <<<<<<<<<<<<<<
 *         port = port.decode()
 * 
 */
  __pyx_t_2 = PyBytes_Check(__pyx_v_port); 
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/dns.pyx":14
 * 
 *     if isinstance(port, bytes):
 *         port = port.decode()             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(port, str) and proto is not None:
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_port, __pyx_n_s_decode); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_9, function);
      }
    }
    if (__pyx_t_10) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 14, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else {
      __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 14, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF_SET(__pyx_v_port, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/dns.pyx":13
 *         pass
 * 
 *     if isinstance(port, bytes):             # <<<<<<<<<<<<<<
 *         port = port.decode()
 * 
 */
  }

  /* "uvloop/dns.pyx":16
 *         port = port.decode()
 * 
 *     if isinstance(port, str) and proto is not None:             # <<<<<<<<<<<<<<
 *         if proto == uv.IPPROTO_TCP:
 *             return socket_getservbyname(port, 'tcp')
 */
  __pyx_t_2 = PyUnicode_Check(__pyx_v_port); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {
  } else {
    __pyx_t_3 = __pyx_t_1;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_1 = (__pyx_v_proto != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  __pyx_t_3 = __pyx_t_2;
  __pyx_L16_bool_binop_done:;
  if (__pyx_t_3) {

    /* "uvloop/dns.pyx":17
 * 
 *     if isinstance(port, str) and proto is not None:
 *         if proto == uv.IPPROTO_TCP:             # <<<<<<<<<<<<<<
 *             return socket_getservbyname(port, 'tcp')
 *         elif proto == uv.IPPROTO_UDP:
 */
    __pyx_t_7 = __Pyx_PyInt_From_int(IPPROTO_TCP); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = PyObject_RichCompare(__pyx_v_proto, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 17, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(7, 17, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_3) {

      /* "uvloop/dns.pyx":18
 *     if isinstance(port, str) and proto is not None:
 *         if proto == uv.IPPROTO_TCP:
 *             return socket_getservbyname(port, 'tcp')             # <<<<<<<<<<<<<<
 *         elif proto == uv.IPPROTO_UDP:
 *             return socket_getservbyname(port, 'udp')
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_getservbyname);
      __pyx_t_7 = __pyx_v_6uvloop_4loop_socket_getservbyname; __pyx_t_10 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_port, __pyx_n_u_tcp};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 18, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_v_port, __pyx_n_u_tcp};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 18, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_9);
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(7, 18, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_v_port);
        __Pyx_GIVEREF(__pyx_v_port);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_8, __pyx_v_port);
        __Pyx_INCREF(__pyx_n_u_tcp);
        __Pyx_GIVEREF(__pyx_n_u_tcp);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_8, __pyx_n_u_tcp);
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_11, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 18, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_9;
      __pyx_t_9 = 0;
      goto __pyx_L0;

      /* "uvloop/dns.pyx":17
 * 
 *     if isinstance(port, str) and proto is not None:
 *         if proto == uv.IPPROTO_TCP:             # <<<<<<<<<<<<<<
 *             return socket_getservbyname(port, 'tcp')
 *         elif proto == uv.IPPROTO_UDP:
 */
    }

    /* "uvloop/dns.pyx":19
 *         if proto == uv.IPPROTO_TCP:
 *             return socket_getservbyname(port, 'tcp')
 *         elif proto == uv.IPPROTO_UDP:             # <<<<<<<<<<<<<<
 *             return socket_getservbyname(port, 'udp')
 * 
 */
    __pyx_t_9 = __Pyx_PyInt_From_int(IPPROTO_UDP); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 19, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = PyObject_RichCompare(__pyx_v_proto, __pyx_t_9, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 19, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(7, 19, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_3) {

      /* "uvloop/dns.pyx":20
 *             return socket_getservbyname(port, 'tcp')
 *         elif proto == uv.IPPROTO_UDP:
 *             return socket_getservbyname(port, 'udp')             # <<<<<<<<<<<<<<
 * 
 *     raise OSError('service/proto not found')
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_getservbyname);
      __pyx_t_9 = __pyx_v_6uvloop_4loop_socket_getservbyname; __pyx_t_11 = NULL;
      __pyx_t_8 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_8 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_port, __pyx_n_u_udp};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 20, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_v_port, __pyx_n_u_udp};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_8, 2+__pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 20, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_7);
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_8); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 20, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_v_port);
        __Pyx_GIVEREF(__pyx_v_port);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_8, __pyx_v_port);
        __Pyx_INCREF(__pyx_n_u_udp);
        __Pyx_GIVEREF(__pyx_n_u_udp);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_8, __pyx_n_u_udp);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 20, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L0;

      /* "uvloop/dns.pyx":19
 *         if proto == uv.IPPROTO_TCP:
 *             return socket_getservbyname(port, 'tcp')
 *         elif proto == uv.IPPROTO_UDP:             # <<<<<<<<<<<<<<
 *             return socket_getservbyname(port, 'udp')
 * 
 */
    }

    /* "uvloop/dns.pyx":16
 *         port = port.decode()
 * 
 *     if isinstance(port, str) and proto is not None:             # <<<<<<<<<<<<<<
 *         if proto == uv.IPPROTO_TCP:
 *             return socket_getservbyname(port, 'tcp')
 */
  }

  /* "uvloop/dns.pyx":22
 *             return socket_getservbyname(port, 'udp')
 * 
 *     raise OSError('service/proto not found')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_OSError, __pyx_tuple__233, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_Raise(__pyx_t_7, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __PYX_ERR(7, 22, __pyx_L1_error)

  /* "uvloop/dns.pyx":1
 * cdef __port_to_int(port, proto):             # <<<<<<<<<<<<<<
 *     if type(port) is int:
 *         return port
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("uvloop.loop.__port_to_int", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_port);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":25
 * 
 * 
 * cdef __convert_sockaddr_to_pyaddr(const system.sockaddr* addr):             # <<<<<<<<<<<<<<
 *     # Converts sockaddr structs into what Python socket
 *     # module can understand:
 */

static PyObject *__pyx_f_6uvloop_4loop___convert_sockaddr_to_pyaddr(struct sockaddr const *__pyx_v_addr) {
  char __pyx_v_buf[0x80];
  int __pyx_v_err;
  struct sockaddr_in *__pyx_v_addr4;
  struct sockaddr_in6 *__pyx_v_addr6;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__convert_sockaddr_to_pyaddr", 0);

  /* "uvloop/dns.pyx":37
 *         system.sockaddr_in6 *addr6
 * 
 *     if addr.sa_family == uv.AF_INET:             # <<<<<<<<<<<<<<
 *         addr4 = <system.sockaddr_in*>addr
 * 
 */
  __pyx_t_1 = ((__pyx_v_addr->sa_family == AF_INET) != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":38
 * 
 *     if addr.sa_family == uv.AF_INET:
 *         addr4 = <system.sockaddr_in*>addr             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_ip4_name(addr4, buf, sizeof(buf))
 */
    __pyx_v_addr4 = ((struct sockaddr_in *)__pyx_v_addr);

    /* "uvloop/dns.pyx":40
 *         addr4 = <system.sockaddr_in*>addr
 * 
 *         err = uv.uv_ip4_name(addr4, buf, sizeof(buf))             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
    __pyx_v_err = uv_ip4_name(__pyx_v_addr4, __pyx_v_buf, (sizeof(__pyx_v_buf)));

    /* "uvloop/dns.pyx":41
 * 
 *         err = uv.uv_ip4_name(addr4, buf, sizeof(buf))
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((__pyx_v_err < 0) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/dns.pyx":42
 *         err = uv.uv_ip4_name(addr4, buf, sizeof(buf))
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         return (
 */
      __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(7, 42, __pyx_L1_error)

      /* "uvloop/dns.pyx":41
 * 
 *         err = uv.uv_ip4_name(addr4, buf, sizeof(buf))
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    }

    /* "uvloop/dns.pyx":44
 *             raise convert_error(err)
 * 
 *         return (             # <<<<<<<<<<<<<<
 *             (<bytes>buf).decode(),
 *             system.ntohs(addr4.sin_port)
 */
    __Pyx_XDECREF(__pyx_r);

    /* "uvloop/dns.pyx":45
 * 
 *         return (
 *             (<bytes>buf).decode(),             # <<<<<<<<<<<<<<
 *             system.ntohs(addr4.sin_port)
 *         )
 */
    __pyx_t_2 = __Pyx_PyObject_FromString(__pyx_v_buf); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "decode");
      __PYX_ERR(7, 45, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_decode_bytes(((PyObject*)__pyx_t_2), 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/dns.pyx":46
 *         return (
 *             (<bytes>buf).decode(),
 *             system.ntohs(addr4.sin_port)             # <<<<<<<<<<<<<<
 *         )
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_From_int(ntohs(__pyx_v_addr4->sin_port)); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "uvloop/dns.pyx":45
 * 
 *         return (
 *             (<bytes>buf).decode(),             # <<<<<<<<<<<<<<
 *             system.ntohs(addr4.sin_port)
 *         )
 */
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 45, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/dns.pyx":37
 *         system.sockaddr_in6 *addr6
 * 
 *     if addr.sa_family == uv.AF_INET:             # <<<<<<<<<<<<<<
 *         addr4 = <system.sockaddr_in*>addr
 * 
 */
  }

  /* "uvloop/dns.pyx":49
 *         )
 * 
 *     elif addr.sa_family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *         addr6 = <system.sockaddr_in6*>addr
 * 
 */
  __pyx_t_1 = ((__pyx_v_addr->sa_family == AF_INET6) != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":50
 * 
 *     elif addr.sa_family == uv.AF_INET6:
 *         addr6 = <system.sockaddr_in6*>addr             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_ip6_name(addr6, buf, sizeof(buf))
 */
    __pyx_v_addr6 = ((struct sockaddr_in6 *)__pyx_v_addr);

    /* "uvloop/dns.pyx":52
 *         addr6 = <system.sockaddr_in6*>addr
 * 
 *         err = uv.uv_ip6_name(addr6, buf, sizeof(buf))             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
    __pyx_v_err = uv_ip6_name(__pyx_v_addr6, __pyx_v_buf, (sizeof(__pyx_v_buf)));

    /* "uvloop/dns.pyx":53
 * 
 *         err = uv.uv_ip6_name(addr6, buf, sizeof(buf))
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((__pyx_v_err < 0) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/dns.pyx":54
 *         err = uv.uv_ip6_name(addr6, buf, sizeof(buf))
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         return (
 */
      __pyx_t_4 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 54, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(7, 54, __pyx_L1_error)

      /* "uvloop/dns.pyx":53
 * 
 *         err = uv.uv_ip6_name(addr6, buf, sizeof(buf))
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    }

    /* "uvloop/dns.pyx":56
 *             raise convert_error(err)
 * 
 *         return (             # <<<<<<<<<<<<<<
 *             (<bytes>buf).decode(),
 *             system.ntohs(addr6.sin6_port),
 */
    __Pyx_XDECREF(__pyx_r);

    /* "uvloop/dns.pyx":57
 * 
 *         return (
 *             (<bytes>buf).decode(),             # <<<<<<<<<<<<<<
 *             system.ntohs(addr6.sin6_port),
 *             system.ntohl(addr6.sin6_flowinfo),
 */
    __pyx_t_4 = __Pyx_PyObject_FromString(__pyx_v_buf); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(__pyx_t_4 == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "decode");
      __PYX_ERR(7, 57, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_decode_bytes(((PyObject*)__pyx_t_4), 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/dns.pyx":58
 *         return (
 *             (<bytes>buf).decode(),
 *             system.ntohs(addr6.sin6_port),             # <<<<<<<<<<<<<<
 *             system.ntohl(addr6.sin6_flowinfo),
 *             addr6.sin6_scope_id
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(ntohs(__pyx_v_addr6->sin6_port)); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "uvloop/dns.pyx":59
 *             (<bytes>buf).decode(),
 *             system.ntohs(addr6.sin6_port),
 *             system.ntohl(addr6.sin6_flowinfo),             # <<<<<<<<<<<<<<
 *             addr6.sin6_scope_id
 *         )
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(ntohl(__pyx_v_addr6->sin6_flowinfo)); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/dns.pyx":60
 *             system.ntohs(addr6.sin6_port),
 *             system.ntohl(addr6.sin6_flowinfo),
 *             addr6.sin6_scope_id             # <<<<<<<<<<<<<<
 *         )
 * 
 */
    __pyx_t_5 = __Pyx_PyInt_From_unsigned_long(__pyx_v_addr6->sin6_scope_id); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 60, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "uvloop/dns.pyx":57
 * 
 *         return (
 *             (<bytes>buf).decode(),             # <<<<<<<<<<<<<<
 *             system.ntohs(addr6.sin6_port),
 *             system.ntohl(addr6.sin6_flowinfo),
 */
    __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "uvloop/dns.pyx":49
 *         )
 * 
 *     elif addr.sa_family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *         addr6 = <system.sockaddr_in6*>addr
 * 
 */
  }

  /* "uvloop/dns.pyx":63
 *         )
 * 
 *     raise RuntimeError("cannot convert sockaddr into Python object")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__234, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_Raise(__pyx_t_6, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __PYX_ERR(7, 63, __pyx_L1_error)

  /* "uvloop/dns.pyx":25
 * 
 * 
 * cdef __convert_sockaddr_to_pyaddr(const system.sockaddr* addr):             # <<<<<<<<<<<<<<
 *     # Converts sockaddr structs into what Python socket
 *     # module can understand:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.__convert_sockaddr_to_pyaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":66
 * 
 * 
 * cdef __convert_pyaddr_to_sockaddr(int family, object addr,             # <<<<<<<<<<<<<<
 *                                   system.sockaddr* res):
 *     cdef:
 */

static PyObject *__pyx_f_6uvloop_4loop___convert_pyaddr_to_sockaddr(int __pyx_v_family, PyObject *__pyx_v_addr, struct sockaddr *__pyx_v_res) {
  int __pyx_v_err;
  int __pyx_v_addr_len;
  int __pyx_v_scope_id;
  int __pyx_v_flowinfo;
  PyObject *__pyx_v_host = NULL;
  PyObject *__pyx_v_port = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  char const *__pyx_t_16;
  __Pyx_RefNannySetupContext("__convert_pyaddr_to_sockaddr", 0);

  /* "uvloop/dns.pyx":71
 *         int err
 *         int addr_len
 *         int scope_id = 0             # <<<<<<<<<<<<<<
 *         int flowinfo = 0
 * 
 */
  __pyx_v_scope_id = 0;

  /* "uvloop/dns.pyx":72
 *         int addr_len
 *         int scope_id = 0
 *         int flowinfo = 0             # <<<<<<<<<<<<<<
 * 
 *     if family == uv.AF_INET:
 */
  __pyx_v_flowinfo = 0;

  /* "uvloop/dns.pyx":74
 *         int flowinfo = 0
 * 
 *     if family == uv.AF_INET:             # <<<<<<<<<<<<<<
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET address must be tuple')
 */
  __pyx_t_1 = ((__pyx_v_family == AF_INET) != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":75
 * 
 *     if family == uv.AF_INET:
 *         if not isinstance(addr, tuple):             # <<<<<<<<<<<<<<
 *             raise TypeError('AF_INET address must be tuple')
 *         if len(addr) != 2:
 */
    __pyx_t_1 = PyTuple_Check(__pyx_v_addr); 
    __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/dns.pyx":76
 *     if family == uv.AF_INET:
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET address must be tuple')             # <<<<<<<<<<<<<<
 *         if len(addr) != 2:
 *             raise ValueError('AF_INET address must be tuple of (host, port)')
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__235, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(7, 76, __pyx_L1_error)

      /* "uvloop/dns.pyx":75
 * 
 *     if family == uv.AF_INET:
 *         if not isinstance(addr, tuple):             # <<<<<<<<<<<<<<
 *             raise TypeError('AF_INET address must be tuple')
 *         if len(addr) != 2:
 */
    }

    /* "uvloop/dns.pyx":77
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET address must be tuple')
 *         if len(addr) != 2:             # <<<<<<<<<<<<<<
 *             raise ValueError('AF_INET address must be tuple of (host, port)')
 *         host, port = addr
 */
    __pyx_t_4 = PyObject_Length(__pyx_v_addr); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(7, 77, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_4 != 2) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/dns.pyx":78
 *             raise TypeError('AF_INET address must be tuple')
 *         if len(addr) != 2:
 *             raise ValueError('AF_INET address must be tuple of (host, port)')             # <<<<<<<<<<<<<<
 *         host, port = addr
 *         if isinstance(host, str):
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__236, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 78, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(7, 78, __pyx_L1_error)

      /* "uvloop/dns.pyx":77
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET address must be tuple')
 *         if len(addr) != 2:             # <<<<<<<<<<<<<<
 *             raise ValueError('AF_INET address must be tuple of (host, port)')
 *         host, port = addr
 */
    }

    /* "uvloop/dns.pyx":79
 *         if len(addr) != 2:
 *             raise ValueError('AF_INET address must be tuple of (host, port)')
 *         host, port = addr             # <<<<<<<<<<<<<<
 *         if isinstance(host, str):
 *             try:
 */
    if ((likely(PyTuple_CheckExact(__pyx_v_addr))) || (PyList_CheckExact(__pyx_v_addr))) {
      PyObject* sequence = __pyx_v_addr;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(7, 79, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_v_addr); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L6_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(7, 79, __pyx_L1_error)
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L7_unpacking_done;
      __pyx_L6_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(7, 79, __pyx_L1_error)
      __pyx_L7_unpacking_done:;
    }
    __pyx_v_host = __pyx_t_3;
    __pyx_t_3 = 0;
    __pyx_v_port = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "uvloop/dns.pyx":80
 *             raise ValueError('AF_INET address must be tuple of (host, port)')
 *         host, port = addr
 *         if isinstance(host, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 */
    __pyx_t_2 = PyUnicode_Check(__pyx_v_host); 
    __pyx_t_1 = (__pyx_t_2 != 0);
    if (__pyx_t_1) {

      /* "uvloop/dns.pyx":81
 *         host, port = addr
 *         if isinstance(host, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        /*try:*/ {

          /* "uvloop/dns.pyx":83
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')             # <<<<<<<<<<<<<<
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_host, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 83, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__237, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 83, __pyx_L9_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF_SET(__pyx_v_host, __pyx_t_3);
          __pyx_t_3 = 0;

          /* "uvloop/dns.pyx":81
 *         host, port = addr
 *         if isinstance(host, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 */
        }
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L14_try_end;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "uvloop/dns.pyx":84
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 *             except UnicodeEncodeError:             # <<<<<<<<<<<<<<
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):
 */
        __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_UnicodeEncodeError);
        if (__pyx_t_11) {
          __Pyx_AddTraceback("uvloop.loop.__convert_pyaddr_to_sockaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(7, 84, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GOTREF(__pyx_t_6);

          /* "uvloop/dns.pyx":85
 *                 host = host.encode('ascii')
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')             # <<<<<<<<<<<<<<
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_host, __pyx_n_s_encode); if (unlikely(!__pyx_t_12)) __PYX_ERR(7, 85, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_tuple__238, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(7, 85, __pyx_L11_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_host, __pyx_t_13);
          __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L10_exception_handled;
        }
        goto __pyx_L11_except_error;
        __pyx_L11_except_error:;

        /* "uvloop/dns.pyx":81
 *         host, port = addr
 *         if isinstance(host, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 */
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        goto __pyx_L1_error;
        __pyx_L10_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
        __pyx_L14_try_end:;
      }

      /* "uvloop/dns.pyx":80
 *             raise ValueError('AF_INET address must be tuple of (host, port)')
 *         host, port = addr
 *         if isinstance(host, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 */
    }

    /* "uvloop/dns.pyx":86
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):             # <<<<<<<<<<<<<<
 *             raise TypeError('host must be a string or bytes object')
 * 
 */
    __pyx_t_2 = PyBytes_Check(__pyx_v_host); 
    __pyx_t_14 = (__pyx_t_2 != 0);
    if (!__pyx_t_14) {
    } else {
      __pyx_t_1 = __pyx_t_14;
      goto __pyx_L18_bool_binop_done;
    }
    __pyx_t_14 = PyByteArray_Check(__pyx_v_host); 
    __pyx_t_2 = (__pyx_t_14 != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L18_bool_binop_done:;
    __pyx_t_2 = ((!(__pyx_t_1 != 0)) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/dns.pyx":87
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')             # <<<<<<<<<<<<<<
 * 
 *         port = __port_to_int(port, None)
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__239, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 87, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(7, 87, __pyx_L1_error)

      /* "uvloop/dns.pyx":86
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):             # <<<<<<<<<<<<<<
 *             raise TypeError('host must be a string or bytes object')
 * 
 */
    }

    /* "uvloop/dns.pyx":89
 *             raise TypeError('host must be a string or bytes object')
 * 
 *         port = __port_to_int(port, None)             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_ip4_addr(host, <int>port, <system.sockaddr_in*>res)
 */
    __pyx_t_6 = __pyx_f_6uvloop_4loop___port_to_int(__pyx_v_port, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF_SET(__pyx_v_port, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/dns.pyx":91
 *         port = __port_to_int(port, None)
 * 
 *         err = uv.uv_ip4_addr(host, <int>port, <system.sockaddr_in*>res)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
    __pyx_t_15 = __Pyx_PyObject_AsString(__pyx_v_host); if (unlikely((!__pyx_t_15) && PyErr_Occurred())) __PYX_ERR(7, 91, __pyx_L1_error)
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_port); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 91, __pyx_L1_error)
    __pyx_v_err = uv_ip4_addr(__pyx_t_15, ((int)__pyx_t_11), ((struct sockaddr_in *)__pyx_v_res));

    /* "uvloop/dns.pyx":92
 * 
 *         err = uv.uv_ip4_addr(host, <int>port, <system.sockaddr_in*>res)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_2 = ((__pyx_v_err < 0) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/dns.pyx":93
 *         err = uv.uv_ip4_addr(host, <int>port, <system.sockaddr_in*>res)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *     elif family == uv.AF_INET6:
 */
      __pyx_t_6 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 93, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(7, 93, __pyx_L1_error)

      /* "uvloop/dns.pyx":92
 * 
 *         err = uv.uv_ip4_addr(host, <int>port, <system.sockaddr_in*>res)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    }

    /* "uvloop/dns.pyx":74
 *         int flowinfo = 0
 * 
 *     if family == uv.AF_INET:             # <<<<<<<<<<<<<<
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET address must be tuple')
 */
    goto __pyx_L3;
  }

  /* "uvloop/dns.pyx":95
 *             raise convert_error(err)
 * 
 *     elif family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET6 address must be tuple')
 */
  __pyx_t_2 = ((__pyx_v_family == AF_INET6) != 0);
  if (likely(__pyx_t_2)) {

    /* "uvloop/dns.pyx":96
 * 
 *     elif family == uv.AF_INET6:
 *         if not isinstance(addr, tuple):             # <<<<<<<<<<<<<<
 *             raise TypeError('AF_INET6 address must be tuple')
 * 
 */
    __pyx_t_2 = PyTuple_Check(__pyx_v_addr); 
    __pyx_t_1 = ((!(__pyx_t_2 != 0)) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/dns.pyx":97
 *     elif family == uv.AF_INET6:
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET6 address must be tuple')             # <<<<<<<<<<<<<<
 * 
 *         addr_len = len(addr)
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__240, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(7, 97, __pyx_L1_error)

      /* "uvloop/dns.pyx":96
 * 
 *     elif family == uv.AF_INET6:
 *         if not isinstance(addr, tuple):             # <<<<<<<<<<<<<<
 *             raise TypeError('AF_INET6 address must be tuple')
 * 
 */
    }

    /* "uvloop/dns.pyx":99
 *             raise TypeError('AF_INET6 address must be tuple')
 * 
 *         addr_len = len(addr)             # <<<<<<<<<<<<<<
 *         if addr_len < 2 or addr_len > 4:
 *             raise ValueError(
 */
    __pyx_t_4 = PyObject_Length(__pyx_v_addr); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(7, 99, __pyx_L1_error)
    __pyx_v_addr_len = __pyx_t_4;

    /* "uvloop/dns.pyx":100
 * 
 *         addr_len = len(addr)
 *         if addr_len < 2 or addr_len > 4:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'AF_INET6 must be a tuple of 2-4 parameters: '
 */
    __pyx_t_2 = ((__pyx_v_addr_len < 2) != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L23_bool_binop_done;
    }
    __pyx_t_2 = ((__pyx_v_addr_len > 4) != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L23_bool_binop_done:;
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/dns.pyx":101
 *         addr_len = len(addr)
 *         if addr_len < 2 or addr_len > 4:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'AF_INET6 must be a tuple of 2-4 parameters: '
 *                 '(host, port, flowinfo?, scope_id?)')
 */
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__241, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(7, 101, __pyx_L1_error)

      /* "uvloop/dns.pyx":100
 * 
 *         addr_len = len(addr)
 *         if addr_len < 2 or addr_len > 4:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'AF_INET6 must be a tuple of 2-4 parameters: '
 */
    }

    /* "uvloop/dns.pyx":105
 *                 '(host, port, flowinfo?, scope_id?)')
 * 
 *         host = addr[0]             # <<<<<<<<<<<<<<
 *         if isinstance(host, str):
 *             try:
 */
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_addr, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_host = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "uvloop/dns.pyx":106
 * 
 *         host = addr[0]
 *         if isinstance(host, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 */
    __pyx_t_1 = PyUnicode_Check(__pyx_v_host); 
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "uvloop/dns.pyx":107
 *         host = addr[0]
 *         if isinstance(host, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_9, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "uvloop/dns.pyx":109
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')             # <<<<<<<<<<<<<<
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_host, __pyx_n_s_encode); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 109, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__242, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 109, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_host, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "uvloop/dns.pyx":107
 *         host = addr[0]
 *         if isinstance(host, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 */
        }
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L31_try_end;
        __pyx_L26_error:;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "uvloop/dns.pyx":110
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 *             except UnicodeEncodeError:             # <<<<<<<<<<<<<<
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):
 */
        __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_UnicodeEncodeError);
        if (__pyx_t_11) {
          __Pyx_AddTraceback("uvloop.loop.__convert_pyaddr_to_sockaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_3) < 0) __PYX_ERR(7, 110, __pyx_L28_except_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GOTREF(__pyx_t_3);

          /* "uvloop/dns.pyx":111
 *                 host = host.encode('ascii')
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')             # <<<<<<<<<<<<<<
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')
 */
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_host, __pyx_n_s_encode); if (unlikely(!__pyx_t_13)) __PYX_ERR(7, 111, __pyx_L28_except_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__243, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(7, 111, __pyx_L28_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF_SET(__pyx_v_host, __pyx_t_12);
          __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L27_exception_handled;
        }
        goto __pyx_L28_except_error;
        __pyx_L28_except_error:;

        /* "uvloop/dns.pyx":107
 *         host = addr[0]
 *         if isinstance(host, str):
 *             try:             # <<<<<<<<<<<<<<
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')
 */
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
        goto __pyx_L1_error;
        __pyx_L27_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_9, __pyx_t_8);
        __pyx_L31_try_end:;
      }

      /* "uvloop/dns.pyx":106
 * 
 *         host = addr[0]
 *         if isinstance(host, str):             # <<<<<<<<<<<<<<
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 */
    }

    /* "uvloop/dns.pyx":112
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):             # <<<<<<<<<<<<<<
 *             raise TypeError('host must be a string or bytes object')
 * 
 */
    __pyx_t_1 = PyBytes_Check(__pyx_v_host); 
    __pyx_t_14 = (__pyx_t_1 != 0);
    if (!__pyx_t_14) {
    } else {
      __pyx_t_2 = __pyx_t_14;
      goto __pyx_L35_bool_binop_done;
    }
    __pyx_t_14 = PyByteArray_Check(__pyx_v_host); 
    __pyx_t_1 = (__pyx_t_14 != 0);
    __pyx_t_2 = __pyx_t_1;
    __pyx_L35_bool_binop_done:;
    __pyx_t_1 = ((!(__pyx_t_2 != 0)) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/dns.pyx":113
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')             # <<<<<<<<<<<<<<
 * 
 *         port = __port_to_int(addr[1], None)
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__244, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(7, 113, __pyx_L1_error)

      /* "uvloop/dns.pyx":112
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):             # <<<<<<<<<<<<<<
 *             raise TypeError('host must be a string or bytes object')
 * 
 */
    }

    /* "uvloop/dns.pyx":115
 *             raise TypeError('host must be a string or bytes object')
 * 
 *         port = __port_to_int(addr[1], None)             # <<<<<<<<<<<<<<
 * 
 *         if addr_len > 2:
 */
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_addr, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __pyx_f_6uvloop_4loop___port_to_int(__pyx_t_3, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_port = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "uvloop/dns.pyx":117
 *         port = __port_to_int(addr[1], None)
 * 
 *         if addr_len > 2:             # <<<<<<<<<<<<<<
 *             flowinfo = addr[2]
 *         if addr_len > 3:
 */
    __pyx_t_1 = ((__pyx_v_addr_len > 2) != 0);
    if (__pyx_t_1) {

      /* "uvloop/dns.pyx":118
 * 
 *         if addr_len > 2:
 *             flowinfo = addr[2]             # <<<<<<<<<<<<<<
 *         if addr_len > 3:
 *             scope_id = addr[3]
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_addr, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 118, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 118, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_flowinfo = __pyx_t_11;

      /* "uvloop/dns.pyx":117
 *         port = __port_to_int(addr[1], None)
 * 
 *         if addr_len > 2:             # <<<<<<<<<<<<<<
 *             flowinfo = addr[2]
 *         if addr_len > 3:
 */
    }

    /* "uvloop/dns.pyx":119
 *         if addr_len > 2:
 *             flowinfo = addr[2]
 *         if addr_len > 3:             # <<<<<<<<<<<<<<
 *             scope_id = addr[3]
 * 
 */
    __pyx_t_1 = ((__pyx_v_addr_len > 3) != 0);
    if (__pyx_t_1) {

      /* "uvloop/dns.pyx":120
 *             flowinfo = addr[2]
 *         if addr_len > 3:
 *             scope_id = addr[3]             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_ip6_addr(host, port, <system.sockaddr_in6*>res)
 */
      __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_addr, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 120, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_scope_id = __pyx_t_11;

      /* "uvloop/dns.pyx":119
 *         if addr_len > 2:
 *             flowinfo = addr[2]
 *         if addr_len > 3:             # <<<<<<<<<<<<<<
 *             scope_id = addr[3]
 * 
 */
    }

    /* "uvloop/dns.pyx":122
 *             scope_id = addr[3]
 * 
 *         err = uv.uv_ip6_addr(host, port, <system.sockaddr_in6*>res)             # <<<<<<<<<<<<<<
 *         if err < 0:
 *             raise convert_error(err)
 */
    __pyx_t_16 = __Pyx_PyObject_AsString(__pyx_v_host); if (unlikely((!__pyx_t_16) && PyErr_Occurred())) __PYX_ERR(7, 122, __pyx_L1_error)
    __pyx_t_11 = __Pyx_PyInt_As_int(__pyx_v_port); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 122, __pyx_L1_error)
    __pyx_v_err = uv_ip6_addr(__pyx_t_16, __pyx_t_11, ((struct sockaddr_in6 *)__pyx_v_res));

    /* "uvloop/dns.pyx":123
 * 
 *         err = uv.uv_ip6_addr(host, port, <system.sockaddr_in6*>res)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    __pyx_t_1 = ((__pyx_v_err < 0) != 0);
    if (unlikely(__pyx_t_1)) {

      /* "uvloop/dns.pyx":124
 *         err = uv.uv_ip6_addr(host, port, <system.sockaddr_in6*>res)
 *         if err < 0:
 *             raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 *         (<system.sockaddr_in6*>res).sin6_flowinfo = flowinfo
 */
      __pyx_t_6 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(7, 124, __pyx_L1_error)

      /* "uvloop/dns.pyx":123
 * 
 *         err = uv.uv_ip6_addr(host, port, <system.sockaddr_in6*>res)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             raise convert_error(err)
 * 
 */
    }

    /* "uvloop/dns.pyx":126
 *             raise convert_error(err)
 * 
 *         (<system.sockaddr_in6*>res).sin6_flowinfo = flowinfo             # <<<<<<<<<<<<<<
 *         (<system.sockaddr_in6*>res).sin6_scope_id = scope_id
 * 
 */
    ((struct sockaddr_in6 *)__pyx_v_res)->sin6_flowinfo = __pyx_v_flowinfo;

    /* "uvloop/dns.pyx":127
 * 
 *         (<system.sockaddr_in6*>res).sin6_flowinfo = flowinfo
 *         (<system.sockaddr_in6*>res).sin6_scope_id = scope_id             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
    ((struct sockaddr_in6 *)__pyx_v_res)->sin6_scope_id = __pyx_v_scope_id;

    /* "uvloop/dns.pyx":95
 *             raise convert_error(err)
 * 
 *     elif family == uv.AF_INET6:             # <<<<<<<<<<<<<<
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET6 address must be tuple')
 */
    goto __pyx_L3;
  }

  /* "uvloop/dns.pyx":130
 * 
 *     else:
 *         raise ValueError(             # <<<<<<<<<<<<<<
 *             'epected AF_INET or AF_INET6 family, got {}'.format(family))
 * 
 */
  /*else*/ {

    /* "uvloop/dns.pyx":131
 *     else:
 *         raise ValueError(
 *             'epected AF_INET or AF_INET6 family, got {}'.format(family))             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_epected_AF_INET_or_AF_INET6_fami, __pyx_n_s_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_family); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_12) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 131, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_6);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 131, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 131, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(7, 131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_13, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 131, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/dns.pyx":130
 * 
 *     else:
 *         raise ValueError(             # <<<<<<<<<<<<<<
 *             'epected AF_INET or AF_INET6 family, got {}'.format(family))
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(7, 130, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "uvloop/dns.pyx":66
 * 
 * 
 * cdef __convert_pyaddr_to_sockaddr(int family, object addr,             # <<<<<<<<<<<<<<
 *                                   system.sockaddr* res):
 *     cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.__convert_pyaddr_to_sockaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_host);
  __Pyx_XDECREF(__pyx_v_port);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":134
 * 
 * 
 * cdef __static_getaddrinfo(object host, object port,             # <<<<<<<<<<<<<<
 *                           int family, int type,
 *                           int proto,
 */

static PyObject *__pyx_f_6uvloop_4loop___static_getaddrinfo(PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, struct sockaddr *__pyx_v_addr) {
  PyObject *__pyx_v_hp = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("__static_getaddrinfo", 0);
  __Pyx_INCREF(__pyx_v_port);

  /* "uvloop/dns.pyx":139
 *                           system.sockaddr *addr):
 * 
 *     if proto not in {0, uv.IPPROTO_TCP, uv.IPPROTO_UDP}:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = __pyx_v_proto;
  __pyx_t_3 = ((__pyx_t_1 != 0) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_t_1 != IPPROTO_TCP) != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_t_1 != IPPROTO_UDP) != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/dns.pyx":140
 * 
 *     if proto not in {0, uv.IPPROTO_TCP, uv.IPPROTO_UDP}:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     if _is_sock_stream(type):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/dns.pyx":139
 *                           system.sockaddr *addr):
 * 
 *     if proto not in {0, uv.IPPROTO_TCP, uv.IPPROTO_UDP}:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/dns.pyx":142
 *         return
 * 
 *     if _is_sock_stream(type):             # <<<<<<<<<<<<<<
 *         proto = uv.IPPROTO_TCP
 *     elif _is_sock_dgram(type):
 */
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __pyx_f_6uvloop_4loop__is_sock_stream(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(7, 142, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_3) {

    /* "uvloop/dns.pyx":143
 * 
 *     if _is_sock_stream(type):
 *         proto = uv.IPPROTO_TCP             # <<<<<<<<<<<<<<
 *     elif _is_sock_dgram(type):
 *         proto = uv.IPPROTO_UDP
 */
    __pyx_v_proto = IPPROTO_TCP;

    /* "uvloop/dns.pyx":142
 *         return
 * 
 *     if _is_sock_stream(type):             # <<<<<<<<<<<<<<
 *         proto = uv.IPPROTO_TCP
 *     elif _is_sock_dgram(type):
 */
    goto __pyx_L7;
  }

  /* "uvloop/dns.pyx":144
 *     if _is_sock_stream(type):
 *         proto = uv.IPPROTO_TCP
 *     elif _is_sock_dgram(type):             # <<<<<<<<<<<<<<
 *         proto = uv.IPPROTO_UDP
 *     else:
 */
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __pyx_f_6uvloop_4loop__is_sock_dgram(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(7, 144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_3) {

    /* "uvloop/dns.pyx":145
 *         proto = uv.IPPROTO_TCP
 *     elif _is_sock_dgram(type):
 *         proto = uv.IPPROTO_UDP             # <<<<<<<<<<<<<<
 *     else:
 *         return
 */
    __pyx_v_proto = IPPROTO_UDP;

    /* "uvloop/dns.pyx":144
 *     if _is_sock_stream(type):
 *         proto = uv.IPPROTO_TCP
 *     elif _is_sock_dgram(type):             # <<<<<<<<<<<<<<
 *         proto = uv.IPPROTO_UDP
 *     else:
 */
    goto __pyx_L7;
  }

  /* "uvloop/dns.pyx":147
 *         proto = uv.IPPROTO_UDP
 *     else:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }
  __pyx_L7:;

  /* "uvloop/dns.pyx":149
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         port = __port_to_int(port, proto)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "uvloop/dns.pyx":150
 * 
 *     try:
 *         port = __port_to_int(port, proto)             # <<<<<<<<<<<<<<
 *     except:
 *         return
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_proto); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 150, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __pyx_f_6uvloop_4loop___port_to_int(__pyx_v_port, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 150, __pyx_L8_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF_SET(__pyx_v_port, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/dns.pyx":149
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         port = __port_to_int(port, proto)
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L13_try_end;
    __pyx_L8_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/dns.pyx":151
 *     try:
 *         port = __port_to_int(port, proto)
 *     except:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("uvloop.loop.__static_getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_9) < 0) __PYX_ERR(7, 151, __pyx_L10_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);

      /* "uvloop/dns.pyx":152
 *         port = __port_to_int(port, proto)
 *     except:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     hp = (host, port)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L11_except_return;
    }
    __pyx_L10_except_error:;

    /* "uvloop/dns.pyx":149
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         port = __port_to_int(port, proto)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L11_except_return:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L0;
    __pyx_L13_try_end:;
  }

  /* "uvloop/dns.pyx":154
 *         return
 * 
 *     hp = (host, port)             # <<<<<<<<<<<<<<
 *     if family == uv.AF_UNSPEC:
 *         try:
 */
  __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_v_host);
  __Pyx_GIVEREF(__pyx_v_host);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_host);
  __Pyx_INCREF(__pyx_v_port);
  __Pyx_GIVEREF(__pyx_v_port);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_port);
  __pyx_v_hp = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "uvloop/dns.pyx":155
 * 
 *     hp = (host, port)
 *     if family == uv.AF_UNSPEC:             # <<<<<<<<<<<<<<
 *         try:
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET, hp, addr)
 */
  __pyx_t_3 = ((__pyx_v_family == AF_UNSPEC) != 0);
  if (__pyx_t_3) {

    /* "uvloop/dns.pyx":156
 *     hp = (host, port)
 *     if family == uv.AF_UNSPEC:
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET, hp, addr)
 *         except Exception:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/dns.pyx":157
 *     if family == uv.AF_UNSPEC:
 *         try:
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET, hp, addr)             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
        __pyx_t_9 = __pyx_f_6uvloop_4loop___convert_pyaddr_to_sockaddr(AF_INET, __pyx_v_hp, __pyx_v_addr); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 157, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "uvloop/dns.pyx":156
 *     hp = (host, port)
 *     if family == uv.AF_UNSPEC:
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET, hp, addr)
 *         except Exception:
 */
      }

      /* "uvloop/dns.pyx":161
 *             pass
 *         else:
 *             return (uv.AF_INET, type, proto)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
      /*else:*/ {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_9 = __Pyx_PyInt_From_int(AF_INET); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 161, __pyx_L19_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 161, __pyx_L19_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_proto); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 161, __pyx_L19_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 161, __pyx_L19_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_5);
        __pyx_t_9 = 0;
        __pyx_t_4 = 0;
        __pyx_t_5 = 0;
        __pyx_r = __pyx_t_10;
        __pyx_t_10 = 0;
        goto __pyx_L20_except_return;
      }
      __pyx_L17_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/dns.pyx":158
 *         try:
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET, hp, addr)
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 *         else:
 */
      __pyx_t_1 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_1) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L18_exception_handled;
      }
      goto __pyx_L19_except_error;
      __pyx_L19_except_error:;

      /* "uvloop/dns.pyx":156
 *     hp = (host, port)
 *     if family == uv.AF_UNSPEC:
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET, hp, addr)
 *         except Exception:
 */
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L20_except_return:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      goto __pyx_L0;
      __pyx_L18_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
    }

    /* "uvloop/dns.pyx":163
 *             return (uv.AF_INET, type, proto)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET6, hp, addr)
 *         except Exception:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "uvloop/dns.pyx":164
 * 
 *         try:
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET6, hp, addr)             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
        __pyx_t_10 = __pyx_f_6uvloop_4loop___convert_pyaddr_to_sockaddr(AF_INET6, __pyx_v_hp, __pyx_v_addr); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 164, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "uvloop/dns.pyx":163
 *             return (uv.AF_INET, type, proto)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET6, hp, addr)
 *         except Exception:
 */
      }

      /* "uvloop/dns.pyx":168
 *             pass
 *         else:
 *             return (uv.AF_INET6, type, proto)             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
      /*else:*/ {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_10 = __Pyx_PyInt_From_int(AF_INET6); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 168, __pyx_L25_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_type); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 168, __pyx_L25_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_proto); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 168, __pyx_L25_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 168, __pyx_L25_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_4);
        __pyx_t_10 = 0;
        __pyx_t_5 = 0;
        __pyx_t_4 = 0;
        __pyx_r = __pyx_t_9;
        __pyx_t_9 = 0;
        goto __pyx_L26_except_return;
      }
      __pyx_L23_error:;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "uvloop/dns.pyx":165
 *         try:
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET6, hp, addr)
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 *         else:
 */
      __pyx_t_1 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_1) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L24_exception_handled;
      }
      goto __pyx_L25_except_error;
      __pyx_L25_except_error:;

      /* "uvloop/dns.pyx":163
 *             return (uv.AF_INET, type, proto)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET6, hp, addr)
 *         except Exception:
 */
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L26_except_return:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L0;
      __pyx_L24_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    }

    /* "uvloop/dns.pyx":155
 * 
 *     hp = (host, port)
 *     if family == uv.AF_UNSPEC:             # <<<<<<<<<<<<<<
 *         try:
 *             __convert_pyaddr_to_sockaddr(uv.AF_INET, hp, addr)
 */
    goto __pyx_L16;
  }

  /* "uvloop/dns.pyx":171
 * 
 *     else:
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(family, hp, addr)
 *         except Exception:
 */
  /*else*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/dns.pyx":172
 *     else:
 *         try:
 *             __convert_pyaddr_to_sockaddr(family, hp, addr)             # <<<<<<<<<<<<<<
 *         except Exception:
 *             pass
 */
        __pyx_t_9 = __pyx_f_6uvloop_4loop___convert_pyaddr_to_sockaddr(__pyx_v_family, __pyx_v_hp, __pyx_v_addr); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 172, __pyx_L29_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "uvloop/dns.pyx":171
 * 
 *     else:
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(family, hp, addr)
 *         except Exception:
 */
      }

      /* "uvloop/dns.pyx":176
 *             pass
 *         else:
 *             return (family, type, proto)             # <<<<<<<<<<<<<<
 * 
 * 
 */
      /*else:*/ {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_family); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 176, __pyx_L31_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 176, __pyx_L31_except_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_proto); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 176, __pyx_L31_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 176, __pyx_L31_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_5);
        __pyx_t_9 = 0;
        __pyx_t_4 = 0;
        __pyx_t_5 = 0;
        __pyx_r = __pyx_t_10;
        __pyx_t_10 = 0;
        goto __pyx_L32_except_return;
      }
      __pyx_L29_error:;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/dns.pyx":173
 *         try:
 *             __convert_pyaddr_to_sockaddr(family, hp, addr)
 *         except Exception:             # <<<<<<<<<<<<<<
 *             pass
 *         else:
 */
      __pyx_t_1 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_1) {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L30_exception_handled;
      }
      goto __pyx_L31_except_error;
      __pyx_L31_except_error:;

      /* "uvloop/dns.pyx":171
 * 
 *     else:
 *         try:             # <<<<<<<<<<<<<<
 *             __convert_pyaddr_to_sockaddr(family, hp, addr)
 *         except Exception:
 */
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L32_except_return:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      goto __pyx_L0;
      __pyx_L30_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
    }
  }
  __pyx_L16:;

  /* "uvloop/dns.pyx":134
 * 
 * 
 * cdef __static_getaddrinfo(object host, object port,             # <<<<<<<<<<<<<<
 *                           int family, int type,
 *                           int proto,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.__static_getaddrinfo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_hp);
  __Pyx_XDECREF(__pyx_v_port);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":179
 * 
 * 
 * cdef __static_getaddrinfo_pyaddr(object host, object port,             # <<<<<<<<<<<<<<
 *                                  int family, int type,
 *                                  int proto, int flags):
 */

static PyObject *__pyx_f_6uvloop_4loop___static_getaddrinfo_pyaddr(PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, CYTHON_UNUSED int __pyx_v_flags) {
  struct sockaddr_storage __pyx_v_addr;
  PyObject *__pyx_v_triplet = 0;
  PyObject *__pyx_v_af = NULL;
  PyObject *__pyx_v_pyaddr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("__static_getaddrinfo_pyaddr", 0);

  /* "uvloop/dns.pyx":187
 *         object triplet
 * 
 *     triplet = __static_getaddrinfo(             # <<<<<<<<<<<<<<
 *         host, port, family, type,
 *         proto, <system.sockaddr*>&addr)
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop___static_getaddrinfo(__pyx_v_host, __pyx_v_port, __pyx_v_family, __pyx_v_type, __pyx_v_proto, ((struct sockaddr *)(&__pyx_v_addr))); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_triplet = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/dns.pyx":190
 *         host, port, family, type,
 *         proto, <system.sockaddr*>&addr)
 *     if triplet is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_2 = (__pyx_v_triplet == Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/dns.pyx":191
 *         proto, <system.sockaddr*>&addr)
 *     if triplet is None:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     af, type, proto = triplet
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/dns.pyx":190
 *         host, port, family, type,
 *         proto, <system.sockaddr*>&addr)
 *     if triplet is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "uvloop/dns.pyx":193
 *         return
 * 
 *     af, type, proto = triplet             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  if ((likely(PyTuple_CheckExact(__pyx_v_triplet))) || (PyList_CheckExact(__pyx_v_triplet))) {
    PyObject* sequence = __pyx_v_triplet;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(7, 193, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_v_triplet); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    index = 2; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) __PYX_ERR(7, 193, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(7, 193, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_af = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_type = __pyx_t_8;
  __pyx_v_proto = __pyx_t_9;

  /* "uvloop/dns.pyx":195
 *     af, type, proto = triplet
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         pyaddr = __convert_sockaddr_to_pyaddr(<system.sockaddr*>&addr)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
    __Pyx_XGOTREF(__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_12);
    /*try:*/ {

      /* "uvloop/dns.pyx":196
 * 
 *     try:
 *         pyaddr = __convert_sockaddr_to_pyaddr(<system.sockaddr*>&addr)             # <<<<<<<<<<<<<<
 *     except:
 *         return
 */
      __pyx_t_5 = __pyx_f_6uvloop_4loop___convert_sockaddr_to_pyaddr(((struct sockaddr *)(&__pyx_v_addr))); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 196, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_v_pyaddr = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "uvloop/dns.pyx":195
 *     af, type, proto = triplet
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         pyaddr = __convert_sockaddr_to_pyaddr(<system.sockaddr*>&addr)
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/dns.pyx":197
 *     try:
 *         pyaddr = __convert_sockaddr_to_pyaddr(<system.sockaddr*>&addr)
 *     except:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("uvloop.loop.__static_getaddrinfo_pyaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_1) < 0) __PYX_ERR(7, 197, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_1);

      /* "uvloop/dns.pyx":198
 *         pyaddr = __convert_sockaddr_to_pyaddr(<system.sockaddr*>&addr)
 *     except:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     return af, type, proto, '', pyaddr
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L9_except_return;
    }
    __pyx_L8_except_error:;

    /* "uvloop/dns.pyx":195
 *     af, type, proto = triplet
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         pyaddr = __convert_sockaddr_to_pyaddr(<system.sockaddr*>&addr)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
    goto __pyx_L1_error;
    __pyx_L9_except_return:;
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_XGIVEREF(__pyx_t_11);
    __Pyx_XGIVEREF(__pyx_t_12);
    __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
    goto __pyx_L0;
    __pyx_L11_try_end:;
  }

  /* "uvloop/dns.pyx":200
 *         return
 * 
 *     return af, type, proto, '', pyaddr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_proto); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(7, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_af);
  __Pyx_GIVEREF(__pyx_v_af);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_af);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4);
  __Pyx_INCREF(__pyx_kp_u__7);
  __Pyx_GIVEREF(__pyx_kp_u__7);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_kp_u__7);
  __Pyx_INCREF(__pyx_v_pyaddr);
  __Pyx_GIVEREF(__pyx_v_pyaddr);
  PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_v_pyaddr);
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "uvloop/dns.pyx":179
 * 
 * 
 * cdef __static_getaddrinfo_pyaddr(object host, object port,             # <<<<<<<<<<<<<<
 *                                  int family, int type,
 *                                  int proto, int flags):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.__static_getaddrinfo_pyaddr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_triplet);
  __Pyx_XDECREF(__pyx_v_af);
  __Pyx_XDECREF(__pyx_v_pyaddr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":208
 *         system.addrinfo *data
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = NULL
 * 
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_8AddrInfo_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_8AddrInfo_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_8AddrInfo___cinit__(((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_8AddrInfo___cinit__(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/dns.pyx":209
 * 
 *     def __cinit__(self):
 *         self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_v_self->data = NULL;

  /* "uvloop/dns.pyx":208
 *         system.addrinfo *data
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = NULL
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":211
 *         self.data = NULL
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             uv.uv_freeaddrinfo(self.data) # returns void
 */

/* Python wrapper */
static void __pyx_pw_6uvloop_4loop_8AddrInfo_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6uvloop_4loop_8AddrInfo_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_6uvloop_4loop_8AddrInfo_2__dealloc__(((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6uvloop_4loop_8AddrInfo_2__dealloc__(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "uvloop/dns.pyx":212
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             uv.uv_freeaddrinfo(self.data) # returns void
 *             self.data = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->data != NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":213
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             uv.uv_freeaddrinfo(self.data) # returns void             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    uv_freeaddrinfo(__pyx_v_self->data);

    /* "uvloop/dns.pyx":214
 *         if self.data is not NULL:
 *             uv.uv_freeaddrinfo(self.data) # returns void
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     cdef void set_data(self, system.addrinfo *data):
 */
    __pyx_v_self->data = NULL;

    /* "uvloop/dns.pyx":212
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             uv.uv_freeaddrinfo(self.data) # returns void
 *             self.data = NULL
 */
  }

  /* "uvloop/dns.pyx":211
 *         self.data = NULL
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             uv.uv_freeaddrinfo(self.data) # returns void
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/dns.pyx":216
 *             self.data = NULL
 * 
 *     cdef void set_data(self, system.addrinfo *data):             # <<<<<<<<<<<<<<
 *         self.data = data
 * 
 */

static void __pyx_f_6uvloop_4loop_8AddrInfo_set_data(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self, struct addrinfo *__pyx_v_data) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_data", 0);

  /* "uvloop/dns.pyx":217
 * 
 *     cdef void set_data(self, system.addrinfo *data):
 *         self.data = data             # <<<<<<<<<<<<<<
 * 
 *     cdef unpack(self):
 */
  __pyx_v_self->data = __pyx_v_data;

  /* "uvloop/dns.pyx":216
 *             self.data = NULL
 * 
 *     cdef void set_data(self, system.addrinfo *data):             # <<<<<<<<<<<<<<
 *         self.data = data
 * 
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "uvloop/dns.pyx":219
 *         self.data = data
 * 
 *     cdef unpack(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list result = []
 */

static PyObject *__pyx_f_6uvloop_4loop_8AddrInfo_unpack(struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self) {
  PyObject *__pyx_v_result = 0;
  struct addrinfo *__pyx_v_ptr;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  struct addrinfo *__pyx_t_3;
  unsigned short __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("unpack", 0);

  /* "uvloop/dns.pyx":221
 *     cdef unpack(self):
 *         cdef:
 *             list result = []             # <<<<<<<<<<<<<<
 *             system.addrinfo *ptr
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/dns.pyx":224
 *             system.addrinfo *ptr
 * 
 *         if self.data is NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('AddrInfo.data is NULL')
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->data == NULL) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/dns.pyx":225
 * 
 *         if self.data is NULL:
 *             raise RuntimeError('AddrInfo.data is NULL')             # <<<<<<<<<<<<<<
 * 
 *         ptr = self.data
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__245, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(7, 225, __pyx_L1_error)

    /* "uvloop/dns.pyx":224
 *             system.addrinfo *ptr
 * 
 *         if self.data is NULL:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('AddrInfo.data is NULL')
 * 
 */
  }

  /* "uvloop/dns.pyx":227
 *             raise RuntimeError('AddrInfo.data is NULL')
 * 
 *         ptr = self.data             # <<<<<<<<<<<<<<
 *         while ptr != NULL:
 *             if ptr.ai_addr.sa_family in (uv.AF_INET, uv.AF_INET6):
 */
  __pyx_t_3 = __pyx_v_self->data;
  __pyx_v_ptr = __pyx_t_3;

  /* "uvloop/dns.pyx":228
 * 
 *         ptr = self.data
 *         while ptr != NULL:             # <<<<<<<<<<<<<<
 *             if ptr.ai_addr.sa_family in (uv.AF_INET, uv.AF_INET6):
 *                 result.append((
 */
  while (1) {
    __pyx_t_2 = ((__pyx_v_ptr != NULL) != 0);
    if (!__pyx_t_2) break;

    /* "uvloop/dns.pyx":229
 *         ptr = self.data
 *         while ptr != NULL:
 *             if ptr.ai_addr.sa_family in (uv.AF_INET, uv.AF_INET6):             # <<<<<<<<<<<<<<
 *                 result.append((
 *                     ptr.ai_family,
 */
    __pyx_t_4 = __pyx_v_ptr->ai_addr->sa_family;
    __pyx_t_5 = ((__pyx_t_4 == AF_INET) != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_5 = ((__pyx_t_4 == AF_INET6) != 0);
    __pyx_t_2 = __pyx_t_5;
    __pyx_L7_bool_binop_done:;
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (__pyx_t_5) {

      /* "uvloop/dns.pyx":231
 *             if ptr.ai_addr.sa_family in (uv.AF_INET, uv.AF_INET6):
 *                 result.append((
 *                     ptr.ai_family,             # <<<<<<<<<<<<<<
 *                     ptr.ai_socktype,
 *                     ptr.ai_protocol,
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_ptr->ai_family); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);

      /* "uvloop/dns.pyx":232
 *                 result.append((
 *                     ptr.ai_family,
 *                     ptr.ai_socktype,             # <<<<<<<<<<<<<<
 *                     ptr.ai_protocol,
 *                     '' if ptr.ai_canonname is NULL else
 */
      __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_ptr->ai_socktype); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "uvloop/dns.pyx":233
 *                     ptr.ai_family,
 *                     ptr.ai_socktype,
 *                     ptr.ai_protocol,             # <<<<<<<<<<<<<<
 *                     '' if ptr.ai_canonname is NULL else
 *                         (<bytes>ptr.ai_canonname).decode(),
 */
      __pyx_t_7 = __Pyx_PyInt_From_int(__pyx_v_ptr->ai_protocol); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);

      /* "uvloop/dns.pyx":234
 *                     ptr.ai_socktype,
 *                     ptr.ai_protocol,
 *                     '' if ptr.ai_canonname is NULL else             # <<<<<<<<<<<<<<
 *                         (<bytes>ptr.ai_canonname).decode(),
 *                     __convert_sockaddr_to_pyaddr(ptr.ai_addr)
 */
      if (((__pyx_v_ptr->ai_canonname == NULL) != 0)) {
        __Pyx_INCREF(__pyx_kp_u__7);
        __pyx_t_8 = __pyx_kp_u__7;
      } else {

        /* "uvloop/dns.pyx":235
 *                     ptr.ai_protocol,
 *                     '' if ptr.ai_canonname is NULL else
 *                         (<bytes>ptr.ai_canonname).decode(),             # <<<<<<<<<<<<<<
 *                     __convert_sockaddr_to_pyaddr(ptr.ai_addr)
 *                 ))
 */
        __pyx_t_9 = __Pyx_PyBytes_FromString(__pyx_v_ptr->ai_canonname); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 235, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (unlikely(__pyx_t_9 == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "decode");
          __PYX_ERR(7, 235, __pyx_L1_error)
        }
        __pyx_t_10 = __Pyx_decode_bytes(((PyObject*)__pyx_t_9), 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 235, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_8 = __pyx_t_10;
        __pyx_t_10 = 0;
      }

      /* "uvloop/dns.pyx":236
 *                     '' if ptr.ai_canonname is NULL else
 *                         (<bytes>ptr.ai_canonname).decode(),
 *                     __convert_sockaddr_to_pyaddr(ptr.ai_addr)             # <<<<<<<<<<<<<<
 *                 ))
 * 
 */
      __pyx_t_10 = __pyx_f_6uvloop_4loop___convert_sockaddr_to_pyaddr(__pyx_v_ptr->ai_addr); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 236, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);

      /* "uvloop/dns.pyx":231
 *             if ptr.ai_addr.sa_family in (uv.AF_INET, uv.AF_INET6):
 *                 result.append((
 *                     ptr.ai_family,             # <<<<<<<<<<<<<<
 *                     ptr.ai_socktype,
 *                     ptr.ai_protocol,
 */
      __pyx_t_9 = PyTuple_New(5); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_8);
      PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_8);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_9, 4, __pyx_t_10);
      __pyx_t_1 = 0;
      __pyx_t_6 = 0;
      __pyx_t_7 = 0;
      __pyx_t_8 = 0;
      __pyx_t_10 = 0;

      /* "uvloop/dns.pyx":230
 *         while ptr != NULL:
 *             if ptr.ai_addr.sa_family in (uv.AF_INET, uv.AF_INET6):
 *                 result.append((             # <<<<<<<<<<<<<<
 *                     ptr.ai_family,
 *                     ptr.ai_socktype,
 */
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_9); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(7, 230, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/dns.pyx":229
 *         ptr = self.data
 *         while ptr != NULL:
 *             if ptr.ai_addr.sa_family in (uv.AF_INET, uv.AF_INET6):             # <<<<<<<<<<<<<<
 *                 result.append((
 *                     ptr.ai_family,
 */
    }

    /* "uvloop/dns.pyx":239
 *                 ))
 * 
 *             ptr = ptr.ai_next             # <<<<<<<<<<<<<<
 * 
 *         return result
 */
    __pyx_t_3 = __pyx_v_ptr->ai_next;
    __pyx_v_ptr = __pyx_t_3;
  }

  /* "uvloop/dns.pyx":241
 *             ptr = ptr.ai_next
 * 
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "uvloop/dns.pyx":219
 *         self.data = data
 * 
 *     cdef unpack(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             list result = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.AddrInfo.unpack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":244
 * 
 *     @staticmethod
 *     cdef int isinstance(object other):             # <<<<<<<<<<<<<<
 *         return type(other) is AddrInfo
 * 
 */

static int __pyx_f_6uvloop_4loop_8AddrInfo_isinstance(PyObject *__pyx_v_other) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("isinstance", 0);

  /* "uvloop/dns.pyx":245
 *     @staticmethod
 *     cdef int isinstance(object other):
 *         return type(other) is AddrInfo             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_other)) == ((PyObject *)__pyx_ptype_6uvloop_4loop_AddrInfo));
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "uvloop/dns.pyx":244
 * 
 *     @staticmethod
 *     cdef int isinstance(object other):             # <<<<<<<<<<<<<<
 *         return type(other) is AddrInfo
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8AddrInfo_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8AddrInfo_4__reduce_cython__[] = "AddrInfo.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8AddrInfo_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8AddrInfo_4__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8AddrInfo_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__246, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.AddrInfo.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8AddrInfo_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_8AddrInfo_6__setstate_cython__[] = "AddrInfo.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_8AddrInfo_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8AddrInfo_6__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8AddrInfo_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__247, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.AddrInfo.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":254
 *         uv.uv_getaddrinfo_t _req_data
 * 
 *     def __cinit__(self, Loop loop,             # <<<<<<<<<<<<<<
 *                   bytes host, bytes port,
 *                   int family, int type, int proto, int flags,
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_15AddrInfoRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_15AddrInfoRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  PyObject *__pyx_v_host = 0;
  PyObject *__pyx_v_port = 0;
  int __pyx_v_family;
  int __pyx_v_type;
  int __pyx_v_proto;
  int __pyx_v_flags;
  PyObject *__pyx_v_callback = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loop,&__pyx_n_s_host,&__pyx_n_s_port,&__pyx_n_s_family,&__pyx_n_s_type,&__pyx_n_s_proto,&__pyx_n_s_flags,&__pyx_n_s_callback,0};
    PyObject* values[8] = {0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_host)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, 1); __PYX_ERR(7, 254, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_port)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, 2); __PYX_ERR(7, 254, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_family)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, 3); __PYX_ERR(7, 254, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_type)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, 4); __PYX_ERR(7, 254, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_proto)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, 5); __PYX_ERR(7, 254, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_flags)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, 6); __PYX_ERR(7, 254, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, 7); __PYX_ERR(7, 254, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(7, 254, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 8) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
    }
    __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)values[0]);
    __pyx_v_host = ((PyObject*)values[1]);
    __pyx_v_port = ((PyObject*)values[2]);
    __pyx_v_family = __Pyx_PyInt_As_int(values[3]); if (unlikely((__pyx_v_family == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 256, __pyx_L3_error)
    __pyx_v_type = __Pyx_PyInt_As_int(values[4]); if (unlikely((__pyx_v_type == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 256, __pyx_L3_error)
    __pyx_v_proto = __Pyx_PyInt_As_int(values[5]); if (unlikely((__pyx_v_proto == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 256, __pyx_L3_error)
    __pyx_v_flags = __Pyx_PyInt_As_int(values[6]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(7, 256, __pyx_L3_error)
    __pyx_v_callback = values[7];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 8, 8, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(7, 254, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.AddrInfoRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_loop), __pyx_ptype_6uvloop_4loop_Loop, 1, "loop", 0))) __PYX_ERR(7, 254, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_host), (&PyBytes_Type), 1, "host", 1))) __PYX_ERR(7, 255, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_port), (&PyBytes_Type), 1, "port", 1))) __PYX_ERR(7, 255, __pyx_L1_error)
  __pyx_r = __pyx_pf_6uvloop_4loop_15AddrInfoRequest___cinit__(((struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)__pyx_v_self), __pyx_v_loop, __pyx_v_host, __pyx_v_port, __pyx_v_family, __pyx_v_type, __pyx_v_proto, __pyx_v_flags, __pyx_v_callback);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_15AddrInfoRequest___cinit__(struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_host, PyObject *__pyx_v_port, int __pyx_v_family, int __pyx_v_type, int __pyx_v_proto, int __pyx_v_flags, PyObject *__pyx_v_callback) {
  int __pyx_v_err;
  char *__pyx_v_chost;
  char *__pyx_v_cport;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_v_ex = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  char *__pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  char const *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/dns.pyx":264
 *             char *cport
 * 
 *         if host is None:             # <<<<<<<<<<<<<<
 *             chost = NULL
 *         else:
 */
  __pyx_t_1 = (__pyx_v_host == ((PyObject*)Py_None));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/dns.pyx":265
 * 
 *         if host is None:
 *             chost = NULL             # <<<<<<<<<<<<<<
 *         else:
 *             chost = <char*>host
 */
    __pyx_v_chost = NULL;

    /* "uvloop/dns.pyx":264
 *             char *cport
 * 
 *         if host is None:             # <<<<<<<<<<<<<<
 *             chost = NULL
 *         else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/dns.pyx":267
 *             chost = NULL
 *         else:
 *             chost = <char*>host             # <<<<<<<<<<<<<<
 * 
 *         if port is None:
 */
  /*else*/ {
    if (unlikely(__pyx_v_host == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(7, 267, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyBytes_AsWritableString(__pyx_v_host); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(7, 267, __pyx_L1_error)
    __pyx_v_chost = ((char *)__pyx_t_3);
  }
  __pyx_L3:;

  /* "uvloop/dns.pyx":269
 *             chost = <char*>host
 * 
 *         if port is None:             # <<<<<<<<<<<<<<
 *             cport = NULL
 *         else:
 */
  __pyx_t_2 = (__pyx_v_port == ((PyObject*)Py_None));
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":270
 * 
 *         if port is None:
 *             cport = NULL             # <<<<<<<<<<<<<<
 *         else:
 *             cport = <char*>port
 */
    __pyx_v_cport = NULL;

    /* "uvloop/dns.pyx":269
 *             chost = <char*>host
 * 
 *         if port is None:             # <<<<<<<<<<<<<<
 *             cport = NULL
 *         else:
 */
    goto __pyx_L4;
  }

  /* "uvloop/dns.pyx":272
 *             cport = NULL
 *         else:
 *             cport = <char*>port             # <<<<<<<<<<<<<<
 * 
 *         if cport is NULL and chost is NULL:
 */
  /*else*/ {
    if (unlikely(__pyx_v_port == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
      __PYX_ERR(7, 272, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyBytes_AsWritableString(__pyx_v_port); if (unlikely((!__pyx_t_3) && PyErr_Occurred())) __PYX_ERR(7, 272, __pyx_L1_error)
    __pyx_v_cport = ((char *)__pyx_t_3);
  }
  __pyx_L4:;

  /* "uvloop/dns.pyx":274
 *             cport = <char*>port
 * 
 *         if cport is NULL and chost is NULL:             # <<<<<<<<<<<<<<
 *             self.on_done()
 *             msg = system.gai_strerror(socket_EAI_NONAME).decode('utf-8')
 */
  __pyx_t_2 = ((__pyx_v_cport == NULL) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_chost == NULL) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":275
 * 
 *         if cport is NULL and chost is NULL:
 *             self.on_done()             # <<<<<<<<<<<<<<
 *             msg = system.gai_strerror(socket_EAI_NONAME).decode('utf-8')
 *             ex = socket_gaierror(socket_EAI_NONAME, msg)
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_AddrInfoRequest *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self)); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/dns.pyx":276
 *         if cport is NULL and chost is NULL:
 *             self.on_done()
 *             msg = system.gai_strerror(socket_EAI_NONAME).decode('utf-8')             # <<<<<<<<<<<<<<
 *             ex = socket_gaierror(socket_EAI_NONAME, msg)
 *             callback(ex)
 */
    __pyx_t_5 = gai_strerror(__pyx_v_6uvloop_4loop_socket_EAI_NONAME);
    __pyx_t_4 = __Pyx_decode_c_string(__pyx_t_5, 0, strlen(__pyx_t_5), NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_msg = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/dns.pyx":277
 *             self.on_done()
 *             msg = system.gai_strerror(socket_EAI_NONAME).decode('utf-8')
 *             ex = socket_gaierror(socket_EAI_NONAME, msg)             # <<<<<<<<<<<<<<
 *             callback(ex)
 *             return
 */
    __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_socket_EAI_NONAME); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_socket_gaierror);
    __pyx_t_7 = __pyx_v_6uvloop_4loop_socket_gaierror; __pyx_t_8 = NULL;
    __pyx_t_9 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
        __pyx_t_9 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_v_msg};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 277, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_v_msg};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 277, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(7, 277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_t_6);
      __Pyx_INCREF(__pyx_v_msg);
      __Pyx_GIVEREF(__pyx_v_msg);
      PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_v_msg);
      __pyx_t_6 = 0;
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_ex = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "uvloop/dns.pyx":278
 *             msg = system.gai_strerror(socket_EAI_NONAME).decode('utf-8')
 *             ex = socket_gaierror(socket_EAI_NONAME, msg)
 *             callback(ex)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __Pyx_INCREF(__pyx_v_callback);
    __pyx_t_7 = __pyx_v_callback; __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_10) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_ex); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_ex};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 278, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_v_ex};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 278, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 278, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_10); __pyx_t_10 = NULL;
        __Pyx_INCREF(__pyx_v_ex);
        __Pyx_GIVEREF(__pyx_v_ex);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_ex);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 278, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/dns.pyx":279
 *             ex = socket_gaierror(socket_EAI_NONAME, msg)
 *             callback(ex)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         memset(&self.hints, 0, sizeof(system.addrinfo))
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "uvloop/dns.pyx":274
 *             cport = <char*>port
 * 
 *         if cport is NULL and chost is NULL:             # <<<<<<<<<<<<<<
 *             self.on_done()
 *             msg = system.gai_strerror(socket_EAI_NONAME).decode('utf-8')
 */
  }

  /* "uvloop/dns.pyx":281
 *             return
 * 
 *         memset(&self.hints, 0, sizeof(system.addrinfo))             # <<<<<<<<<<<<<<
 *         self.hints.ai_flags = flags
 *         self.hints.ai_family = family
 */
  (void)(memset((&__pyx_v_self->hints), 0, (sizeof(struct addrinfo))));

  /* "uvloop/dns.pyx":282
 * 
 *         memset(&self.hints, 0, sizeof(system.addrinfo))
 *         self.hints.ai_flags = flags             # <<<<<<<<<<<<<<
 *         self.hints.ai_family = family
 *         self.hints.ai_socktype = type
 */
  __pyx_v_self->hints.ai_flags = __pyx_v_flags;

  /* "uvloop/dns.pyx":283
 *         memset(&self.hints, 0, sizeof(system.addrinfo))
 *         self.hints.ai_flags = flags
 *         self.hints.ai_family = family             # <<<<<<<<<<<<<<
 *         self.hints.ai_socktype = type
 *         self.hints.ai_protocol = proto
 */
  __pyx_v_self->hints.ai_family = __pyx_v_family;

  /* "uvloop/dns.pyx":284
 *         self.hints.ai_flags = flags
 *         self.hints.ai_family = family
 *         self.hints.ai_socktype = type             # <<<<<<<<<<<<<<
 *         self.hints.ai_protocol = proto
 * 
 */
  __pyx_v_self->hints.ai_socktype = __pyx_v_type;

  /* "uvloop/dns.pyx":285
 *         self.hints.ai_family = family
 *         self.hints.ai_socktype = type
 *         self.hints.ai_protocol = proto             # <<<<<<<<<<<<<<
 * 
 *         self.request = <uv.uv_req_t*> &self._req_data
 */
  __pyx_v_self->hints.ai_protocol = __pyx_v_proto;

  /* "uvloop/dns.pyx":287
 *         self.hints.ai_protocol = proto
 * 
 *         self.request = <uv.uv_req_t*> &self._req_data             # <<<<<<<<<<<<<<
 *         self.callback = callback
 *         self.request.data = <void*>self
 */
  __pyx_v_self->__pyx_base.request = ((uv_req_t *)(&__pyx_v_self->_req_data));

  /* "uvloop/dns.pyx":288
 * 
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.callback = callback             # <<<<<<<<<<<<<<
 *         self.request.data = <void*>self
 * 
 */
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  __Pyx_GOTREF(__pyx_v_self->callback);
  __Pyx_DECREF(__pyx_v_self->callback);
  __pyx_v_self->callback = __pyx_v_callback;

  /* "uvloop/dns.pyx":289
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.callback = callback
 *         self.request.data = <void*>self             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_getaddrinfo(loop.uvloop,
 */
  __pyx_v_self->__pyx_base.request->data = ((void *)__pyx_v_self);

  /* "uvloop/dns.pyx":291
 *         self.request.data = <void*>self
 * 
 *         err = uv.uv_getaddrinfo(loop.uvloop,             # <<<<<<<<<<<<<<
 *                                 <uv.uv_getaddrinfo_t*>self.request,
 *                                 __on_addrinfo_resolved,
 */
  __pyx_v_err = uv_getaddrinfo(__pyx_v_loop->uvloop, ((uv_getaddrinfo_t *)__pyx_v_self->__pyx_base.request), __pyx_f_6uvloop_4loop___on_addrinfo_resolved, __pyx_v_chost, __pyx_v_cport, (&__pyx_v_self->hints));

  /* "uvloop/dns.pyx":298
 *                                 &self.hints)
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self.on_done()
 *             callback(convert_error(err))
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":299
 * 
 *         if err < 0:
 *             self.on_done()             # <<<<<<<<<<<<<<
 *             callback(convert_error(err))
 * 
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_AddrInfoRequest *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self)); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/dns.pyx":300
 *         if err < 0:
 *             self.on_done()
 *             callback(convert_error(err))             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_7 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_callback);
    __pyx_t_6 = __pyx_v_callback; __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (!__pyx_t_10) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 300, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 300, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[2] = {__pyx_t_10, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 300, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/dns.pyx":298
 *                                 &self.hints)
 * 
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self.on_done()
 *             callback(convert_error(err))
 */
  }

  /* "uvloop/dns.pyx":254
 *         uv.uv_getaddrinfo_t _req_data
 * 
 *     def __cinit__(self, Loop loop,             # <<<<<<<<<<<<<<
 *                   bytes host, bytes port,
 *                   int family, int type, int proto, int flags,
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.AddrInfoRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15AddrInfoRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15AddrInfoRequest_2__reduce_cython__[] = "AddrInfoRequest.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15AddrInfoRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15AddrInfoRequest_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15AddrInfoRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__248, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.AddrInfoRequest.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15AddrInfoRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_15AddrInfoRequest_4__setstate_cython__[] = "AddrInfoRequest.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_15AddrInfoRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15AddrInfoRequest_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15AddrInfoRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__249, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.AddrInfoRequest.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":308
 *         uv.uv_getnameinfo_t _req_data
 * 
 *     def __cinit__(self, Loop loop, callback):             # <<<<<<<<<<<<<<
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.callback = callback
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_15NameInfoRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_15NameInfoRequest_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  PyObject *__pyx_v_callback = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loop,&__pyx_n_s_callback,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_callback)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, 1); __PYX_ERR(7, 308, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(7, 308, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)values[0]);
    __pyx_v_callback = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(7, 308, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.NameInfoRequest.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_loop), __pyx_ptype_6uvloop_4loop_Loop, 1, "loop", 0))) __PYX_ERR(7, 308, __pyx_L1_error)
  __pyx_r = __pyx_pf_6uvloop_4loop_15NameInfoRequest___cinit__(((struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)__pyx_v_self), __pyx_v_loop, __pyx_v_callback);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_15NameInfoRequest___cinit__(struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self, CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_callback) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/dns.pyx":309
 * 
 *     def __cinit__(self, Loop loop, callback):
 *         self.request = <uv.uv_req_t*> &self._req_data             # <<<<<<<<<<<<<<
 *         self.callback = callback
 *         self.request.data = <void*>self
 */
  __pyx_v_self->__pyx_base.request = ((uv_req_t *)(&__pyx_v_self->_req_data));

  /* "uvloop/dns.pyx":310
 *     def __cinit__(self, Loop loop, callback):
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.callback = callback             # <<<<<<<<<<<<<<
 *         self.request.data = <void*>self
 * 
 */
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  __Pyx_GOTREF(__pyx_v_self->callback);
  __Pyx_DECREF(__pyx_v_self->callback);
  __pyx_v_self->callback = __pyx_v_callback;

  /* "uvloop/dns.pyx":311
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.callback = callback
 *         self.request.data = <void*>self             # <<<<<<<<<<<<<<
 * 
 *     cdef query(self, system.sockaddr *addr, int flags):
 */
  __pyx_v_self->__pyx_base.request->data = ((void *)__pyx_v_self);

  /* "uvloop/dns.pyx":308
 *         uv.uv_getnameinfo_t _req_data
 * 
 *     def __cinit__(self, Loop loop, callback):             # <<<<<<<<<<<<<<
 *         self.request = <uv.uv_req_t*> &self._req_data
 *         self.callback = callback
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":313
 *         self.request.data = <void*>self
 * 
 *     cdef query(self, system.sockaddr *addr, int flags):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         err = uv.uv_getnameinfo(self.loop.uvloop,
 */

static PyObject *__pyx_f_6uvloop_4loop_15NameInfoRequest_query(struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self, struct sockaddr *__pyx_v_addr, int __pyx_v_flags) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("query", 0);

  /* "uvloop/dns.pyx":315
 *     cdef query(self, system.sockaddr *addr, int flags):
 *         cdef int err
 *         err = uv.uv_getnameinfo(self.loop.uvloop,             # <<<<<<<<<<<<<<
 *                                 <uv.uv_getnameinfo_t*>self.request,
 *                                 __on_nameinfo_resolved,
 */
  __pyx_v_err = uv_getnameinfo(__pyx_v_self->__pyx_base.loop->uvloop, ((uv_getnameinfo_t *)__pyx_v_self->__pyx_base.request), __pyx_f_6uvloop_4loop___on_nameinfo_resolved, __pyx_v_addr, __pyx_v_flags);

  /* "uvloop/dns.pyx":320
 *                                 addr,
 *                                 flags)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self.on_done()
 *             self.callback(convert_error(err))
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":321
 *                                 flags)
 *         if err < 0:
 *             self.on_done()             # <<<<<<<<<<<<<<
 *             self.callback(convert_error(err))
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_NameInfoRequest *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/dns.pyx":322
 *         if err < 0:
 *             self.on_done()
 *             self.callback(convert_error(err))             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_self->callback);
    __pyx_t_4 = __pyx_v_self->callback; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 322, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 322, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_3};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 322, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 322, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 322, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/dns.pyx":320
 *                                 addr,
 *                                 flags)
 *         if err < 0:             # <<<<<<<<<<<<<<
 *             self.on_done()
 *             self.callback(convert_error(err))
 */
  }

  /* "uvloop/dns.pyx":313
 *         self.request.data = <void*>self
 * 
 *     cdef query(self, system.sockaddr *addr, int flags):             # <<<<<<<<<<<<<<
 *         cdef int err
 *         err = uv.uv_getnameinfo(self.loop.uvloop,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.NameInfoRequest.query", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15NameInfoRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_15NameInfoRequest_2__reduce_cython__[] = "NameInfoRequest.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_15NameInfoRequest_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15NameInfoRequest_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15NameInfoRequest_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__250, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.NameInfoRequest.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_15NameInfoRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_15NameInfoRequest_4__setstate_cython__[] = "NameInfoRequest.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_15NameInfoRequest_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_15NameInfoRequest_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_15NameInfoRequest_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__251, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.NameInfoRequest.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/dns.pyx":325
 * 
 * 
 * cdef void __on_addrinfo_resolved(uv.uv_getaddrinfo_t *resolver,             # <<<<<<<<<<<<<<
 *                                  int status, system.addrinfo *res) with gil:
 * 
 */

static void __pyx_f_6uvloop_4loop___on_addrinfo_resolved(uv_getaddrinfo_t *__pyx_v_resolver, int __pyx_v_status, struct addrinfo *__pyx_v_res) {
  struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *__pyx_v_request = 0;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  PyObject *__pyx_v_callback = 0;
  struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_v_ai = 0;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  char const *__pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__on_addrinfo_resolved", 0);

  /* "uvloop/dns.pyx":328
 *                                  int status, system.addrinfo *res) with gil:
 * 
 *     if resolver.data is NULL:             # <<<<<<<<<<<<<<
 *         aio_logger.error(
 *             'AddrInfoRequest callback called with NULL resolver.data')
 */
  __pyx_t_1 = ((__pyx_v_resolver->data == NULL) != 0);
  if (__pyx_t_1) {

    /* "uvloop/dns.pyx":329
 * 
 *     if resolver.data is NULL:
 *         aio_logger.error(             # <<<<<<<<<<<<<<
 *             'AddrInfoRequest callback called with NULL resolver.data')
 *         return
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_error); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__252, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/dns.pyx":331
 *         aio_logger.error(
 *             'AddrInfoRequest callback called with NULL resolver.data')
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
    goto __pyx_L0;

    /* "uvloop/dns.pyx":328
 *                                  int status, system.addrinfo *res) with gil:
 * 
 *     if resolver.data is NULL:             # <<<<<<<<<<<<<<
 *         aio_logger.error(
 *             'AddrInfoRequest callback called with NULL resolver.data')
 */
  }

  /* "uvloop/dns.pyx":334
 * 
 *     cdef:
 *         AddrInfoRequest request = <AddrInfoRequest> resolver.data             # <<<<<<<<<<<<<<
 *         Loop loop = request.loop
 *         object callback = request.callback
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_resolver->data);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_request = ((struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/dns.pyx":335
 *     cdef:
 *         AddrInfoRequest request = <AddrInfoRequest> resolver.data
 *         Loop loop = request.loop             # <<<<<<<<<<<<<<
 *         object callback = request.callback
 *         AddrInfo ai
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_request->__pyx_base.loop);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "uvloop/dns.pyx":336
 *         AddrInfoRequest request = <AddrInfoRequest> resolver.data
 *         Loop loop = request.loop
 *         object callback = request.callback             # <<<<<<<<<<<<<<
 *         AddrInfo ai
 * 
 */
  __pyx_t_3 = __pyx_v_request->callback;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_callback = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/dns.pyx":339
 *         AddrInfo ai
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if status < 0:
 *             callback(convert_error(status))
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "uvloop/dns.pyx":340
 * 
 *     try:
 *         if status < 0:             # <<<<<<<<<<<<<<
 *             callback(convert_error(status))
 *         else:
 */
        __pyx_t_1 = ((__pyx_v_status < 0) != 0);
        if (__pyx_t_1) {

          /* "uvloop/dns.pyx":341
 *     try:
 *         if status < 0:
 *             callback(convert_error(status))             # <<<<<<<<<<<<<<
 *         else:
 *             ai = AddrInfo()
 */
          __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 341, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_INCREF(__pyx_v_callback);
          __pyx_t_7 = __pyx_v_callback; __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          if (!__pyx_t_8) {
            __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 341, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_GOTREF(__pyx_t_3);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
              __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 341, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_2};
              __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 341, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 341, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
              __Pyx_GIVEREF(__pyx_t_2);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_2);
              __pyx_t_2 = 0;
              __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 341, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "uvloop/dns.pyx":340
 * 
 *     try:
 *         if status < 0:             # <<<<<<<<<<<<<<
 *             callback(convert_error(status))
 *         else:
 */
          goto __pyx_L13;
        }

        /* "uvloop/dns.pyx":343
 *             callback(convert_error(status))
 *         else:
 *             ai = AddrInfo()             # <<<<<<<<<<<<<<
 *             ai.set_data(res)
 *             callback(ai)
 */
        /*else*/ {
          __pyx_t_3 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6uvloop_4loop_AddrInfo)); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 343, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_v_ai = ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)__pyx_t_3);
          __pyx_t_3 = 0;

          /* "uvloop/dns.pyx":344
 *         else:
 *             ai = AddrInfo()
 *             ai.set_data(res)             # <<<<<<<<<<<<<<
 *             callback(ai)
 *     except Exception as ex:
 */
          ((struct __pyx_vtabstruct_6uvloop_4loop_AddrInfo *)__pyx_v_ai->__pyx_vtab)->set_data(__pyx_v_ai, __pyx_v_res);

          /* "uvloop/dns.pyx":345
 *             ai = AddrInfo()
 *             ai.set_data(res)
 *             callback(ai)             # <<<<<<<<<<<<<<
 *     except Exception as ex:
 *         loop._handle_exception(ex)
 */
          __Pyx_INCREF(__pyx_v_callback);
          __pyx_t_7 = __pyx_v_callback; __pyx_t_9 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          if (!__pyx_t_9) {
            __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)__pyx_v_ai)); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 345, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, ((PyObject *)__pyx_v_ai)};
              __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 345, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_3);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, ((PyObject *)__pyx_v_ai)};
              __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 345, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_3);
            } else
            #endif
            {
              __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 345, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_9); __pyx_t_9 = NULL;
              __Pyx_INCREF(((PyObject *)__pyx_v_ai));
              __Pyx_GIVEREF(((PyObject *)__pyx_v_ai));
              PyTuple_SET_ITEM(__pyx_t_2, 0+1, ((PyObject *)__pyx_v_ai));
              __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(7, 345, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_L13:;

        /* "uvloop/dns.pyx":339
 *         AddrInfo ai
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if status < 0:
 *             callback(convert_error(status))
 */
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L12_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/dns.pyx":346
 *             ai.set_data(res)
 *             callback(ai)
 *     except Exception as ex:             # <<<<<<<<<<<<<<
 *         loop._handle_exception(ex)
 *     finally:
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.__on_addrinfo_resolved", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_7, &__pyx_t_2) < 0) __PYX_ERR(7, 346, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_v_ex = __pyx_t_7;
        /*try:*/ {

          /* "uvloop/dns.pyx":347
 *             callback(ai)
 *     except Exception as ex:
 *         loop._handle_exception(ex)             # <<<<<<<<<<<<<<
 *     finally:
 *         request.on_done()
 */
          ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_loop->__pyx_vtab)->_handle_exception(__pyx_v_loop, __pyx_v_ex);
        }

        /* "uvloop/dns.pyx":346
 *             ai.set_data(res)
 *             callback(ai)
 *     except Exception as ex:             # <<<<<<<<<<<<<<
 *         loop._handle_exception(ex)
 *     finally:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L20;
          }
          __pyx_L20:;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/dns.pyx":339
 *         AddrInfo ai
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if status < 0:
 *             callback(convert_error(status))
 */
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      goto __pyx_L5_error;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
      __pyx_L12_try_end:;
    }
  }

  /* "uvloop/dns.pyx":349
 *         loop._handle_exception(ex)
 *     finally:
 *         request.on_done()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_AddrInfoRequest *)__pyx_v_request->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_request)); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4) < 0)) __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_10 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_12 = __pyx_filename;
      {
        __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_AddrInfoRequest *)__pyx_v_request->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_request)); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 349, __pyx_L22_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ErrRestore(__pyx_t_6, __pyx_t_5, __pyx_t_4);
      __pyx_t_6 = 0; __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_12;
      goto __pyx_L1_error;
      __pyx_L22_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/dns.pyx":325
 * 
 * 
 * cdef void __on_addrinfo_resolved(uv.uv_getaddrinfo_t *resolver,             # <<<<<<<<<<<<<<
 *                                  int status, system.addrinfo *res) with gil:
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__on_addrinfo_resolved", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_request);
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF((PyObject *)__pyx_v_ai);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/dns.pyx":352
 * 
 * 
 * cdef void __on_nameinfo_resolved(uv.uv_getnameinfo_t* req,             # <<<<<<<<<<<<<<
 *                                  int status,
 *                                  const char* hostname,
 */

static void __pyx_f_6uvloop_4loop___on_nameinfo_resolved(uv_getnameinfo_t *__pyx_v_req, int __pyx_v_status, char const *__pyx_v_hostname, char const *__pyx_v_service) {
  struct __pyx_obj_6uvloop_4loop_NameInfoRequest *__pyx_v_request = 0;
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  PyObject *__pyx_v_callback = 0;
  PyObject *__pyx_v_ex = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_t_11;
  char const *__pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("__on_nameinfo_resolved", 0);

  /* "uvloop/dns.pyx":357
 *                                  const char* service) with gil:
 *     cdef:
 *         NameInfoRequest request = <NameInfoRequest> req.data             # <<<<<<<<<<<<<<
 *         Loop loop = request.loop
 *         object callback = request.callback
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_req->data);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_request = ((struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/dns.pyx":358
 *     cdef:
 *         NameInfoRequest request = <NameInfoRequest> req.data
 *         Loop loop = request.loop             # <<<<<<<<<<<<<<
 *         object callback = request.callback
 * 
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_request->__pyx_base.loop);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/dns.pyx":359
 *         NameInfoRequest request = <NameInfoRequest> req.data
 *         Loop loop = request.loop
 *         object callback = request.callback             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __pyx_t_1 = __pyx_v_request->callback;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_callback = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/dns.pyx":361
 *         object callback = request.callback
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if status < 0:
 *             callback(convert_error(status))
 */
  /*try:*/ {
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "uvloop/dns.pyx":362
 * 
 *     try:
 *         if status < 0:             # <<<<<<<<<<<<<<
 *             callback(convert_error(status))
 *         else:
 */
        __pyx_t_5 = ((__pyx_v_status < 0) != 0);
        if (__pyx_t_5) {

          /* "uvloop/dns.pyx":363
 *     try:
 *         if status < 0:
 *             callback(convert_error(status))             # <<<<<<<<<<<<<<
 *         else:
 *             callback(((<bytes>hostname).decode(),
 */
          __pyx_t_6 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_status); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 363, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_INCREF(__pyx_v_callback);
          __pyx_t_7 = __pyx_v_callback; __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          if (!__pyx_t_8) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 363, __pyx_L6_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 363, __pyx_L6_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
              PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 363, __pyx_L6_error)
              __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            {
              __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 363, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_9);
              __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
              __Pyx_GIVEREF(__pyx_t_6);
              PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_6);
              __pyx_t_6 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 363, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "uvloop/dns.pyx":362
 * 
 *     try:
 *         if status < 0:             # <<<<<<<<<<<<<<
 *             callback(convert_error(status))
 *         else:
 */
          goto __pyx_L12;
        }

        /* "uvloop/dns.pyx":365
 *             callback(convert_error(status))
 *         else:
 *             callback(((<bytes>hostname).decode(),             # <<<<<<<<<<<<<<
 *                       (<bytes>service).decode()))
 *     except Exception as ex:
 */
        /*else*/ {
          __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_hostname); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 365, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (unlikely(__pyx_t_7 == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "decode");
            __PYX_ERR(7, 365, __pyx_L6_error)
          }
          __pyx_t_9 = __Pyx_decode_bytes(((PyObject*)__pyx_t_7), 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 365, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "uvloop/dns.pyx":366
 *         else:
 *             callback(((<bytes>hostname).decode(),
 *                       (<bytes>service).decode()))             # <<<<<<<<<<<<<<
 *     except Exception as ex:
 *         loop._handle_exception(ex)
 */
          __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_service); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 366, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          if (unlikely(__pyx_t_7 == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "decode");
            __PYX_ERR(7, 366, __pyx_L6_error)
          }
          __pyx_t_6 = __Pyx_decode_bytes(((PyObject*)__pyx_t_7), 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 366, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "uvloop/dns.pyx":365
 *             callback(convert_error(status))
 *         else:
 *             callback(((<bytes>hostname).decode(),             # <<<<<<<<<<<<<<
 *                       (<bytes>service).decode()))
 *     except Exception as ex:
 */
          __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 365, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_9);
          PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9);
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_6);
          __pyx_t_9 = 0;
          __pyx_t_6 = 0;
          __Pyx_INCREF(__pyx_v_callback);
          __pyx_t_6 = __pyx_v_callback; __pyx_t_9 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_9)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_9);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          if (!__pyx_t_9) {
            __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 365, __pyx_L6_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_7};
              __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 365, __pyx_L6_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_7};
              __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 365, __pyx_L6_error)
              __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            } else
            #endif
            {
              __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 365, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_9); __pyx_t_9 = NULL;
              __Pyx_GIVEREF(__pyx_t_7);
              PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_7);
              __pyx_t_7 = 0;
              __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 365, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L12:;

        /* "uvloop/dns.pyx":361
 *         object callback = request.callback
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if status < 0:
 *             callback(convert_error(status))
 */
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L11_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/dns.pyx":367
 *             callback(((<bytes>hostname).decode(),
 *                       (<bytes>service).decode()))
 *     except Exception as ex:             # <<<<<<<<<<<<<<
 *         loop._handle_exception(ex)
 *     finally:
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.__on_nameinfo_resolved", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(7, 367, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_ex = __pyx_t_6;
        /*try:*/ {

          /* "uvloop/dns.pyx":368
 *                       (<bytes>service).decode()))
 *     except Exception as ex:
 *         loop._handle_exception(ex)             # <<<<<<<<<<<<<<
 *     finally:
 *         request.on_done()
 */
          ((struct __pyx_vtabstruct_6uvloop_4loop_Loop *)__pyx_v_loop->__pyx_vtab)->_handle_exception(__pyx_v_loop, __pyx_v_ex);
        }

        /* "uvloop/dns.pyx":367
 *             callback(((<bytes>hostname).decode(),
 *                       (<bytes>service).decode()))
 *     except Exception as ex:             # <<<<<<<<<<<<<<
 *         loop._handle_exception(ex)
 *     finally:
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_ex);
            __pyx_v_ex = NULL;
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_exception_handled;
      }
      goto __pyx_L8_except_error;
      __pyx_L8_except_error:;

      /* "uvloop/dns.pyx":361
 *         object callback = request.callback
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if status < 0:
 *             callback(convert_error(status))
 */
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L4_error;
      __pyx_L7_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      __pyx_L11_try_end:;
    }
  }

  /* "uvloop/dns.pyx":370
 *         loop._handle_exception(ex)
 *     finally:
 *         request.on_done()             # <<<<<<<<<<<<<<
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_NameInfoRequest *)__pyx_v_request->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_request)); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 370, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2) < 0)) __Pyx_ErrFetch(&__pyx_t_4, &__pyx_t_3, &__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __pyx_t_10 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_12 = __pyx_filename;
      {
        __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_NameInfoRequest *)__pyx_v_request->__pyx_base.__pyx_vtab)->__pyx_base.on_done(((struct __pyx_obj_6uvloop_4loop_UVRequest *)__pyx_v_request)); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 370, __pyx_L21_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_ErrRestore(__pyx_t_4, __pyx_t_3, __pyx_t_2);
      __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_2 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_12;
      goto __pyx_L1_error;
      __pyx_L21_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "uvloop/dns.pyx":352
 * 
 * 
 * cdef void __on_nameinfo_resolved(uv.uv_getnameinfo_t* req,             # <<<<<<<<<<<<<<
 *                                  int status,
 *                                  const char* hostname,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_WriteUnraisable("uvloop.loop.__on_nameinfo_resolved", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_request);
  __Pyx_XDECREF((PyObject *)__pyx_v_loop);
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/sslproto.pyx":4
 * # License: PSFL.
 * 
 * cdef _create_transport_context(server_side, server_hostname):             # <<<<<<<<<<<<<<
 *     if server_side:
 *         raise ValueError('Server side SSL needs a valid SSLContext')
 */

static PyObject *__pyx_f_6uvloop_4loop__create_transport_context(PyObject *__pyx_v_server_side, PyObject *__pyx_v_server_hostname) {
  PyObject *__pyx_v_sslcontext = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("_create_transport_context", 0);

  /* "uvloop/sslproto.pyx":5
 * 
 * cdef _create_transport_context(server_side, server_hostname):
 *     if server_side:             # <<<<<<<<<<<<<<
 *         raise ValueError('Server side SSL needs a valid SSLContext')
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_server_side); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 5, __pyx_L1_error)
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/sslproto.pyx":6
 * cdef _create_transport_context(server_side, server_hostname):
 *     if server_side:
 *         raise ValueError('Server side SSL needs a valid SSLContext')             # <<<<<<<<<<<<<<
 * 
 *     # Client side may pass ssl=True to use a default
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__253, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 6, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":5
 * 
 * cdef _create_transport_context(server_side, server_hostname):
 *     if server_side:             # <<<<<<<<<<<<<<
 *         raise ValueError('Server side SSL needs a valid SSLContext')
 * 
 */
  }

  /* "uvloop/sslproto.pyx":12
 *     # The default is secure for client connections.
 *     # Python 3.4+: use up-to-date strong settings.
 *     sslcontext = ssl_create_default_context()             # <<<<<<<<<<<<<<
 *     if not server_hostname:
 *         sslcontext.check_hostname = False
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_ssl_create_default_context);
  __pyx_t_3 = __pyx_v_6uvloop_4loop_ssl_create_default_context; __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_sslcontext = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/sslproto.pyx":13
 *     # Python 3.4+: use up-to-date strong settings.
 *     sslcontext = ssl_create_default_context()
 *     if not server_hostname:             # <<<<<<<<<<<<<<
 *         sslcontext.check_hostname = False
 *     return sslcontext
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_server_hostname); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 13, __pyx_L1_error)
  __pyx_t_5 = ((!__pyx_t_1) != 0);
  if (__pyx_t_5) {

    /* "uvloop/sslproto.pyx":14
 *     sslcontext = ssl_create_default_context()
 *     if not server_hostname:
 *         sslcontext.check_hostname = False             # <<<<<<<<<<<<<<
 *     return sslcontext
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_sslcontext, __pyx_n_s_check_hostname, Py_False) < 0) __PYX_ERR(0, 14, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":13
 *     # Python 3.4+: use up-to-date strong settings.
 *     sslcontext = ssl_create_default_context()
 *     if not server_hostname:             # <<<<<<<<<<<<<<
 *         sslcontext.check_hostname = False
 *     return sslcontext
 */
  }

  /* "uvloop/sslproto.pyx":15
 *     if not server_hostname:
 *         sslcontext.check_hostname = False
 *     return sslcontext             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_sslcontext);
  __pyx_r = __pyx_v_sslcontext;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":4
 * # License: PSFL.
 * 
 * cdef _create_transport_context(server_side, server_hostname):             # <<<<<<<<<<<<<<
 *     if server_side:
 *         raise ValueError('Server side SSL needs a valid SSLContext')
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop._create_transport_context", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sslcontext);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":61
 * 
 * 
 *     def __init__(self, context, server_side, server_hostname=None):             # <<<<<<<<<<<<<<
 *         """
 *         The *context* argument specifies the ssl.SSLContext to use.
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_8_SSLPipe_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_8_SSLPipe___init__[] = "\n        The *context* argument specifies the ssl.SSLContext to use.\n\n        The *server_side* argument indicates whether this is a server side or\n        client side transport.\n\n        The optional *server_hostname* argument can be used to specify the\n        hostname you are connecting to. You may only specify this parameter if\n        the _ssl module supports Server Name Indication (SNI).\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_6uvloop_4loop_8_SSLPipe___init__;
#endif
static int __pyx_pw_6uvloop_4loop_8_SSLPipe_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_context = 0;
  PyObject *__pyx_v_server_side = 0;
  PyObject *__pyx_v_server_hostname = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_context,&__pyx_n_s_server_side,&__pyx_n_s_server_hostname,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_context)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_server_side)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 61, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_server_hostname);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 61, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_context = values[0];
    __pyx_v_server_side = values[1];
    __pyx_v_server_hostname = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 61, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_8_SSLPipe___init__(((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_v_self), __pyx_v_context, __pyx_v_server_side, __pyx_v_server_hostname);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_8_SSLPipe___init__(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v_context, PyObject *__pyx_v_server_side, PyObject *__pyx_v_server_hostname) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/sslproto.pyx":72
 *         the _ssl module supports Server Name Indication (SNI).
 *         """
 *         self._context = context             # <<<<<<<<<<<<<<
 *         self._server_side = server_side
 *         self._server_hostname = server_hostname
 */
  __Pyx_INCREF(__pyx_v_context);
  __Pyx_GIVEREF(__pyx_v_context);
  __Pyx_GOTREF(__pyx_v_self->_context);
  __Pyx_DECREF(__pyx_v_self->_context);
  __pyx_v_self->_context = __pyx_v_context;

  /* "uvloop/sslproto.pyx":73
 *         """
 *         self._context = context
 *         self._server_side = server_side             # <<<<<<<<<<<<<<
 *         self._server_hostname = server_hostname
 *         self._state = _UNWRAPPED
 */
  __Pyx_INCREF(__pyx_v_server_side);
  __Pyx_GIVEREF(__pyx_v_server_side);
  __Pyx_GOTREF(__pyx_v_self->_server_side);
  __Pyx_DECREF(__pyx_v_self->_server_side);
  __pyx_v_self->_server_side = __pyx_v_server_side;

  /* "uvloop/sslproto.pyx":74
 *         self._context = context
 *         self._server_side = server_side
 *         self._server_hostname = server_hostname             # <<<<<<<<<<<<<<
 *         self._state = _UNWRAPPED
 *         self._incoming = ssl_MemoryBIO()
 */
  __Pyx_INCREF(__pyx_v_server_hostname);
  __Pyx_GIVEREF(__pyx_v_server_hostname);
  __Pyx_GOTREF(__pyx_v_self->_server_hostname);
  __Pyx_DECREF(__pyx_v_self->_server_hostname);
  __pyx_v_self->_server_hostname = __pyx_v_server_hostname;

  /* "uvloop/sslproto.pyx":75
 *         self._server_side = server_side
 *         self._server_hostname = server_hostname
 *         self._state = _UNWRAPPED             # <<<<<<<<<<<<<<
 *         self._incoming = ssl_MemoryBIO()
 *         self._outgoing = ssl_MemoryBIO()
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop__UNWRAPPED);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop__UNWRAPPED);
  __Pyx_GOTREF(__pyx_v_self->_state);
  __Pyx_DECREF(__pyx_v_self->_state);
  __pyx_v_self->_state = __pyx_v_6uvloop_4loop__UNWRAPPED;

  /* "uvloop/sslproto.pyx":76
 *         self._server_hostname = server_hostname
 *         self._state = _UNWRAPPED
 *         self._incoming = ssl_MemoryBIO()             # <<<<<<<<<<<<<<
 *         self._outgoing = ssl_MemoryBIO()
 *         self._sslobj = None
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_ssl_MemoryBIO);
  __pyx_t_2 = __pyx_v_6uvloop_4loop_ssl_MemoryBIO; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_incoming);
  __Pyx_DECREF(__pyx_v_self->_incoming);
  __pyx_v_self->_incoming = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":77
 *         self._state = _UNWRAPPED
 *         self._incoming = ssl_MemoryBIO()
 *         self._outgoing = ssl_MemoryBIO()             # <<<<<<<<<<<<<<
 *         self._sslobj = None
 *         self._need_ssldata = False
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_ssl_MemoryBIO);
  __pyx_t_2 = __pyx_v_6uvloop_4loop_ssl_MemoryBIO; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 77, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_outgoing);
  __Pyx_DECREF(__pyx_v_self->_outgoing);
  __pyx_v_self->_outgoing = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":78
 *         self._incoming = ssl_MemoryBIO()
 *         self._outgoing = ssl_MemoryBIO()
 *         self._sslobj = None             # <<<<<<<<<<<<<<
 *         self._need_ssldata = False
 *         self._handshake_cb = None
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_sslobj);
  __Pyx_DECREF(__pyx_v_self->_sslobj);
  __pyx_v_self->_sslobj = Py_None;

  /* "uvloop/sslproto.pyx":79
 *         self._outgoing = ssl_MemoryBIO()
 *         self._sslobj = None
 *         self._need_ssldata = False             # <<<<<<<<<<<<<<
 *         self._handshake_cb = None
 *         self._shutdown_cb = None
 */
  __pyx_v_self->_need_ssldata = 0;

  /* "uvloop/sslproto.pyx":80
 *         self._sslobj = None
 *         self._need_ssldata = False
 *         self._handshake_cb = None             # <<<<<<<<<<<<<<
 *         self._shutdown_cb = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_handshake_cb);
  __Pyx_DECREF(__pyx_v_self->_handshake_cb);
  __pyx_v_self->_handshake_cb = Py_None;

  /* "uvloop/sslproto.pyx":81
 *         self._need_ssldata = False
 *         self._handshake_cb = None
 *         self._shutdown_cb = None             # <<<<<<<<<<<<<<
 * 
 *     cdef do_handshake(self, callback=None):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_shutdown_cb);
  __Pyx_DECREF(__pyx_v_self->_shutdown_cb);
  __pyx_v_self->_shutdown_cb = Py_None;

  /* "uvloop/sslproto.pyx":61
 * 
 * 
 *     def __init__(self, context, server_side, server_hostname=None):             # <<<<<<<<<<<<<<
 *         """
 *         The *context* argument specifies the ssl.SSLContext to use.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":83
 *         self._shutdown_cb = None
 * 
 *     cdef do_handshake(self, callback=None):             # <<<<<<<<<<<<<<
 *         """Start the SSL handshake.
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_do_handshake(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_do_handshake *__pyx_optional_args) {
  PyObject *__pyx_v_callback = ((PyObject *)Py_None);
  PyObject *__pyx_v_ssldata = NULL;
  PyObject *__pyx_v_appdata = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_ssldata __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_ssize_t __pyx_t_9;
  __Pyx_RefNannySetupContext("do_handshake", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_callback = __pyx_optional_args->callback;
    }
  }

  /* "uvloop/sslproto.pyx":92
 *         called with None if successful, else an exception instance.
 *         """
 *         if self._state is not _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('handshake in progress or completed')
 *         self._sslobj = self._context.wrap_bio(
 */
  __pyx_t_1 = (__pyx_v_self->_state != __pyx_v_6uvloop_4loop__UNWRAPPED);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/sslproto.pyx":93
 *         """
 *         if self._state is not _UNWRAPPED:
 *             raise RuntimeError('handshake in progress or completed')             # <<<<<<<<<<<<<<
 *         self._sslobj = self._context.wrap_bio(
 *             self._incoming, self._outgoing,
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__254, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 93, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 93, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":92
 *         called with None if successful, else an exception instance.
 *         """
 *         if self._state is not _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('handshake in progress or completed')
 *         self._sslobj = self._context.wrap_bio(
 */
  }

  /* "uvloop/sslproto.pyx":94
 *         if self._state is not _UNWRAPPED:
 *             raise RuntimeError('handshake in progress or completed')
 *         self._sslobj = self._context.wrap_bio(             # <<<<<<<<<<<<<<
 *             self._incoming, self._outgoing,
 *             server_side=self._server_side,
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_context, __pyx_n_s_wrap_bio); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/sslproto.pyx":95
 *             raise RuntimeError('handshake in progress or completed')
 *         self._sslobj = self._context.wrap_bio(
 *             self._incoming, self._outgoing,             # <<<<<<<<<<<<<<
 *             server_side=self._server_side,
 *             server_hostname=self._server_hostname)
 */
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_self->_incoming);
  __Pyx_GIVEREF(__pyx_v_self->_incoming);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->_incoming);
  __Pyx_INCREF(__pyx_v_self->_outgoing);
  __Pyx_GIVEREF(__pyx_v_self->_outgoing);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self->_outgoing);

  /* "uvloop/sslproto.pyx":96
 *         self._sslobj = self._context.wrap_bio(
 *             self._incoming, self._outgoing,
 *             server_side=self._server_side,             # <<<<<<<<<<<<<<
 *             server_hostname=self._server_hostname)
 *         self._state = _DO_HANDSHAKE
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_server_side, __pyx_v_self->_server_side) < 0) __PYX_ERR(0, 96, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":97
 *             self._incoming, self._outgoing,
 *             server_side=self._server_side,
 *             server_hostname=self._server_hostname)             # <<<<<<<<<<<<<<
 *         self._state = _DO_HANDSHAKE
 *         self._handshake_cb = callback
 */
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_server_hostname, __pyx_v_self->_server_hostname) < 0) __PYX_ERR(0, 96, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":94
 *         if self._state is not _UNWRAPPED:
 *             raise RuntimeError('handshake in progress or completed')
 *         self._sslobj = self._context.wrap_bio(             # <<<<<<<<<<<<<<
 *             self._incoming, self._outgoing,
 *             server_side=self._server_side,
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF(__pyx_v_self->_sslobj);
  __Pyx_DECREF(__pyx_v_self->_sslobj);
  __pyx_v_self->_sslobj = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":98
 *             server_side=self._server_side,
 *             server_hostname=self._server_hostname)
 *         self._state = _DO_HANDSHAKE             # <<<<<<<<<<<<<<
 *         self._handshake_cb = callback
 *         ssldata, appdata = self.feed_ssldata(b'', only_handshake=True)
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop__DO_HANDSHAKE);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop__DO_HANDSHAKE);
  __Pyx_GOTREF(__pyx_v_self->_state);
  __Pyx_DECREF(__pyx_v_self->_state);
  __pyx_v_self->_state = __pyx_v_6uvloop_4loop__DO_HANDSHAKE;

  /* "uvloop/sslproto.pyx":99
 *             server_hostname=self._server_hostname)
 *         self._state = _DO_HANDSHAKE
 *         self._handshake_cb = callback             # <<<<<<<<<<<<<<
 *         ssldata, appdata = self.feed_ssldata(b'', only_handshake=True)
 *         assert len(appdata) == 0
 */
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  __Pyx_GOTREF(__pyx_v_self->_handshake_cb);
  __Pyx_DECREF(__pyx_v_self->_handshake_cb);
  __pyx_v_self->_handshake_cb = __pyx_v_callback;

  /* "uvloop/sslproto.pyx":100
 *         self._state = _DO_HANDSHAKE
 *         self._handshake_cb = callback
 *         ssldata, appdata = self.feed_ssldata(b'', only_handshake=True)             # <<<<<<<<<<<<<<
 *         assert len(appdata) == 0
 *         return ssldata
 */
  __pyx_t_7.__pyx_n = 1;
  __pyx_t_7.only_handshake = 1;
  __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *)__pyx_v_self->__pyx_vtab)->feed_ssldata(__pyx_v_self, __pyx_kp_b__7, &__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
    PyObject* sequence = __pyx_t_6;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 100, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_3 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = Py_TYPE(__pyx_t_3)->tp_iternext;
    index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_3); if (unlikely(!__pyx_t_5)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_3); if (unlikely(!__pyx_t_4)) goto __pyx_L4_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_3), 2) < 0) __PYX_ERR(0, 100, __pyx_L1_error)
    __pyx_t_8 = NULL;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L5_unpacking_done;
    __pyx_L4_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 100, __pyx_L1_error)
    __pyx_L5_unpacking_done:;
  }
  __pyx_v_ssldata = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_appdata = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "uvloop/sslproto.pyx":101
 *         self._handshake_cb = callback
 *         ssldata, appdata = self.feed_ssldata(b'', only_handshake=True)
 *         assert len(appdata) == 0             # <<<<<<<<<<<<<<
 *         return ssldata
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_9 = PyObject_Length(__pyx_v_appdata); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 101, __pyx_L1_error)
    if (unlikely(!((__pyx_t_9 == 0) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 101, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/sslproto.pyx":102
 *         ssldata, appdata = self.feed_ssldata(b'', only_handshake=True)
 *         assert len(appdata) == 0
 *         return ssldata             # <<<<<<<<<<<<<<
 * 
 *     cdef shutdown(self, callback=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ssldata);
  __pyx_r = __pyx_v_ssldata;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":83
 *         self._shutdown_cb = None
 * 
 *     cdef do_handshake(self, callback=None):             # <<<<<<<<<<<<<<
 *         """Start the SSL handshake.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.do_handshake", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ssldata);
  __Pyx_XDECREF(__pyx_v_appdata);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":104
 *         return ssldata
 * 
 *     cdef shutdown(self, callback=None):             # <<<<<<<<<<<<<<
 *         """Start the SSL shutdown sequence.
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_shutdown(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_shutdown *__pyx_optional_args) {
  PyObject *__pyx_v_callback = ((PyObject *)Py_None);
  PyObject *__pyx_v_ssldata = NULL;
  PyObject *__pyx_v_appdata = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  __Pyx_RefNannySetupContext("shutdown", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_callback = __pyx_optional_args->callback;
    }
  }

  /* "uvloop/sslproto.pyx":113
 *         called without arguments.
 *         """
 *         if self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('no security layer present')
 *         if self._state is _SHUTDOWN:
 */
  __pyx_t_1 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__UNWRAPPED);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/sslproto.pyx":114
 *         """
 *         if self._state is _UNWRAPPED:
 *             raise RuntimeError('no security layer present')             # <<<<<<<<<<<<<<
 *         if self._state is _SHUTDOWN:
 *             raise RuntimeError('shutdown in progress')
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__255, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 114, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":113
 *         called without arguments.
 *         """
 *         if self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('no security layer present')
 *         if self._state is _SHUTDOWN:
 */
  }

  /* "uvloop/sslproto.pyx":115
 *         if self._state is _UNWRAPPED:
 *             raise RuntimeError('no security layer present')
 *         if self._state is _SHUTDOWN:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('shutdown in progress')
 *         assert self._state in (_WRAPPED, _DO_HANDSHAKE)
 */
  __pyx_t_2 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__SHUTDOWN);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/sslproto.pyx":116
 *             raise RuntimeError('no security layer present')
 *         if self._state is _SHUTDOWN:
 *             raise RuntimeError('shutdown in progress')             # <<<<<<<<<<<<<<
 *         assert self._state in (_WRAPPED, _DO_HANDSHAKE)
 *         self._state = _SHUTDOWN
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__256, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 116, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":115
 *         if self._state is _UNWRAPPED:
 *             raise RuntimeError('no security layer present')
 *         if self._state is _SHUTDOWN:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('shutdown in progress')
 *         assert self._state in (_WRAPPED, _DO_HANDSHAKE)
 */
  }

  /* "uvloop/sslproto.pyx":117
 *         if self._state is _SHUTDOWN:
 *             raise RuntimeError('shutdown in progress')
 *         assert self._state in (_WRAPPED, _DO_HANDSHAKE)             # <<<<<<<<<<<<<<
 *         self._state = _SHUTDOWN
 *         self._shutdown_cb = callback
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __Pyx_INCREF(__pyx_v_self->_state);
    __pyx_t_3 = __pyx_v_self->_state;
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_v_6uvloop_4loop__WRAPPED, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 117, __pyx_L1_error)
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_v_6uvloop_4loop__DO_HANDSHAKE, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 117, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!(__pyx_t_1 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 117, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/sslproto.pyx":118
 *             raise RuntimeError('shutdown in progress')
 *         assert self._state in (_WRAPPED, _DO_HANDSHAKE)
 *         self._state = _SHUTDOWN             # <<<<<<<<<<<<<<
 *         self._shutdown_cb = callback
 *         ssldata, appdata = self.feed_ssldata(b'')
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop__SHUTDOWN);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop__SHUTDOWN);
  __Pyx_GOTREF(__pyx_v_self->_state);
  __Pyx_DECREF(__pyx_v_self->_state);
  __pyx_v_self->_state = __pyx_v_6uvloop_4loop__SHUTDOWN;

  /* "uvloop/sslproto.pyx":119
 *         assert self._state in (_WRAPPED, _DO_HANDSHAKE)
 *         self._state = _SHUTDOWN
 *         self._shutdown_cb = callback             # <<<<<<<<<<<<<<
 *         ssldata, appdata = self.feed_ssldata(b'')
 *         assert appdata == [] or appdata == [b'']
 */
  __Pyx_INCREF(__pyx_v_callback);
  __Pyx_GIVEREF(__pyx_v_callback);
  __Pyx_GOTREF(__pyx_v_self->_shutdown_cb);
  __Pyx_DECREF(__pyx_v_self->_shutdown_cb);
  __pyx_v_self->_shutdown_cb = __pyx_v_callback;

  /* "uvloop/sslproto.pyx":120
 *         self._state = _SHUTDOWN
 *         self._shutdown_cb = callback
 *         ssldata, appdata = self.feed_ssldata(b'')             # <<<<<<<<<<<<<<
 *         assert appdata == [] or appdata == [b'']
 *         return ssldata
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *)__pyx_v_self->__pyx_vtab)->feed_ssldata(__pyx_v_self, __pyx_kp_b__7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 120, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_5);
    #else
    __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L7_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 2) < 0) __PYX_ERR(0, 120, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_unpacking_done;
    __pyx_L7_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 120, __pyx_L1_error)
    __pyx_L8_unpacking_done:;
  }
  __pyx_v_ssldata = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_v_appdata = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "uvloop/sslproto.pyx":121
 *         self._shutdown_cb = callback
 *         ssldata, appdata = self.feed_ssldata(b'')
 *         assert appdata == [] or appdata == [b'']             # <<<<<<<<<<<<<<
 *         return ssldata
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_appdata, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L9_bool_binop_done;
    }
    __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_b__7);
    __Pyx_GIVEREF(__pyx_kp_b__7);
    PyList_SET_ITEM(__pyx_t_5, 0, __pyx_kp_b__7);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_appdata, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_2;
    __pyx_L9_bool_binop_done:;
    if (unlikely(!__pyx_t_1)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 121, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/sslproto.pyx":122
 *         ssldata, appdata = self.feed_ssldata(b'')
 *         assert appdata == [] or appdata == [b'']
 *         return ssldata             # <<<<<<<<<<<<<<
 * 
 *     cdef feed_eof(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ssldata);
  __pyx_r = __pyx_v_ssldata;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":104
 *         return ssldata
 * 
 *     cdef shutdown(self, callback=None):             # <<<<<<<<<<<<<<
 *         """Start the SSL shutdown sequence.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.shutdown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ssldata);
  __Pyx_XDECREF(__pyx_v_appdata);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":124
 *         return ssldata
 * 
 *     cdef feed_eof(self):             # <<<<<<<<<<<<<<
 *         """Send a potentially "ragged" EOF.
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_feed_eof(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self) {
  CYTHON_UNUSED PyObject *__pyx_v_ssldata = NULL;
  PyObject *__pyx_v_appdata = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("feed_eof", 0);

  /* "uvloop/sslproto.pyx":130
 *         unexpected.
 *         """
 *         self._incoming.write_eof()             # <<<<<<<<<<<<<<
 *         ssldata, appdata = self.feed_ssldata(b'')
 *         assert appdata == [] or appdata == [b'']
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_incoming, __pyx_n_s_write_eof); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":131
 *         """
 *         self._incoming.write_eof()
 *         ssldata, appdata = self.feed_ssldata(b'')             # <<<<<<<<<<<<<<
 *         assert appdata == [] or appdata == [b'']
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *)__pyx_v_self->__pyx_vtab)->feed_ssldata(__pyx_v_self, __pyx_kp_b__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 131, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < 0) __PYX_ERR(0, 131, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 131, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_ssldata = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_appdata = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":132
 *         self._incoming.write_eof()
 *         ssldata, appdata = self.feed_ssldata(b'')
 *         assert appdata == [] or appdata == [b'']             # <<<<<<<<<<<<<<
 * 
 *     cdef feed_ssldata(self, data, bint only_handshake=False):
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_RichCompare(__pyx_v_appdata, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_kp_b__7);
    __Pyx_GIVEREF(__pyx_kp_b__7);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_kp_b__7);
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_appdata, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __pyx_t_7;
    __pyx_L5_bool_binop_done:;
    if (unlikely(!__pyx_t_6)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 132, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/sslproto.pyx":124
 *         return ssldata
 * 
 *     cdef feed_eof(self):             # <<<<<<<<<<<<<<
 *         """Send a potentially "ragged" EOF.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.feed_eof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ssldata);
  __Pyx_XDECREF(__pyx_v_appdata);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":134
 *         assert appdata == [] or appdata == [b'']
 * 
 *     cdef feed_ssldata(self, data, bint only_handshake=False):             # <<<<<<<<<<<<<<
 *         """Feed SSL record level data into the pipe.
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_feed_ssldata(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v_data, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_ssldata *__pyx_optional_args) {
  int __pyx_v_only_handshake = ((int)0);
  PyObject *__pyx_v_appdata = 0;
  PyObject *__pyx_v_ssldata = 0;
  int __pyx_v_errno;
  PyObject *__pyx_v_chunk = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_t_16;
  char const *__pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  __Pyx_RefNannySetupContext("feed_ssldata", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_only_handshake = __pyx_optional_args->only_handshake;
    }
  }

  /* "uvloop/sslproto.pyx":154
 *             int errno
 * 
 *         if self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             # If unwrapped, pass plaintext data straight through.
 *             if data:
 */
  __pyx_t_1 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__UNWRAPPED);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":156
 *         if self._state is _UNWRAPPED:
 *             # If unwrapped, pass plaintext data straight through.
 *             if data:             # <<<<<<<<<<<<<<
 *                 appdata = [data]
 *             else:
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 156, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "uvloop/sslproto.pyx":157
 *             # If unwrapped, pass plaintext data straight through.
 *             if data:
 *                 appdata = [data]             # <<<<<<<<<<<<<<
 *             else:
 *                 appdata = []
 */
      __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 157, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_data);
      __Pyx_GIVEREF(__pyx_v_data);
      PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_data);
      __pyx_v_appdata = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "uvloop/sslproto.pyx":156
 *         if self._state is _UNWRAPPED:
 *             # If unwrapped, pass plaintext data straight through.
 *             if data:             # <<<<<<<<<<<<<<
 *                 appdata = [data]
 *             else:
 */
      goto __pyx_L4;
    }

    /* "uvloop/sslproto.pyx":159
 *                 appdata = [data]
 *             else:
 *                 appdata = []             # <<<<<<<<<<<<<<
 *             return ([], appdata)
 * 
 */
    /*else*/ {
      __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_appdata = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;
    }
    __pyx_L4:;

    /* "uvloop/sslproto.pyx":160
 *             else:
 *                 appdata = []
 *             return ([], appdata)             # <<<<<<<<<<<<<<
 * 
 *         self._need_ssldata = False
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_INCREF(__pyx_v_appdata);
    __Pyx_GIVEREF(__pyx_v_appdata);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_appdata);
    __pyx_t_3 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":154
 *             int errno
 * 
 *         if self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             # If unwrapped, pass plaintext data straight through.
 *             if data:
 */
  }

  /* "uvloop/sslproto.pyx":162
 *             return ([], appdata)
 * 
 *         self._need_ssldata = False             # <<<<<<<<<<<<<<
 *         if data:
 *             self._incoming.write(data)
 */
  __pyx_v_self->_need_ssldata = 0;

  /* "uvloop/sslproto.pyx":163
 * 
 *         self._need_ssldata = False
 *         if data:             # <<<<<<<<<<<<<<
 *             self._incoming.write(data)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 163, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":164
 *         self._need_ssldata = False
 *         if data:
 *             self._incoming.write(data)             # <<<<<<<<<<<<<<
 * 
 *         ssldata = []
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_incoming, __pyx_n_s_write); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_data); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_data};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 164, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_data};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 164, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 164, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_data);
        __Pyx_GIVEREF(__pyx_v_data);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_data);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 164, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/sslproto.pyx":163
 * 
 *         self._need_ssldata = False
 *         if data:             # <<<<<<<<<<<<<<
 *             self._incoming.write(data)
 * 
 */
  }

  /* "uvloop/sslproto.pyx":166
 *             self._incoming.write(data)
 * 
 *         ssldata = []             # <<<<<<<<<<<<<<
 *         appdata = []
 *         try:
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_ssldata = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/sslproto.pyx":167
 * 
 *         ssldata = []
 *         appdata = []             # <<<<<<<<<<<<<<
 *         try:
 *             if self._state is _DO_HANDSHAKE:
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_appdata = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/sslproto.pyx":168
 *         ssldata = []
 *         appdata = []
 *         try:             # <<<<<<<<<<<<<<
 *             if self._state is _DO_HANDSHAKE:
 *                 # Call do_handshake() until it doesn't raise anymore.
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    /*try:*/ {

      /* "uvloop/sslproto.pyx":169
 *         appdata = []
 *         try:
 *             if self._state is _DO_HANDSHAKE:             # <<<<<<<<<<<<<<
 *                 # Call do_handshake() until it doesn't raise anymore.
 *                 self._sslobj.do_handshake()
 */
      __pyx_t_2 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__DO_HANDSHAKE);
      __pyx_t_1 = (__pyx_t_2 != 0);
      if (__pyx_t_1) {

        /* "uvloop/sslproto.pyx":171
 *             if self._state is _DO_HANDSHAKE:
 *                 # Call do_handshake() until it doesn't raise anymore.
 *                 self._sslobj.do_handshake()             # <<<<<<<<<<<<<<
 *                 self._state = _WRAPPED
 *                 if self._handshake_cb:
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_sslobj, __pyx_n_s_do_handshake); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 171, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (__pyx_t_6) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 171, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else {
          __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 171, __pyx_L6_error)
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/sslproto.pyx":172
 *                 # Call do_handshake() until it doesn't raise anymore.
 *                 self._sslobj.do_handshake()
 *                 self._state = _WRAPPED             # <<<<<<<<<<<<<<
 *                 if self._handshake_cb:
 *                     self._handshake_cb(None)
 */
        __Pyx_INCREF(__pyx_v_6uvloop_4loop__WRAPPED);
        __Pyx_GIVEREF(__pyx_v_6uvloop_4loop__WRAPPED);
        __Pyx_GOTREF(__pyx_v_self->_state);
        __Pyx_DECREF(__pyx_v_self->_state);
        __pyx_v_self->_state = __pyx_v_6uvloop_4loop__WRAPPED;

        /* "uvloop/sslproto.pyx":173
 *                 self._sslobj.do_handshake()
 *                 self._state = _WRAPPED
 *                 if self._handshake_cb:             # <<<<<<<<<<<<<<
 *                     self._handshake_cb(None)
 *                 if only_handshake:
 */
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_handshake_cb); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 173, __pyx_L6_error)
        if (__pyx_t_1) {

          /* "uvloop/sslproto.pyx":174
 *                 self._state = _WRAPPED
 *                 if self._handshake_cb:
 *                     self._handshake_cb(None)             # <<<<<<<<<<<<<<
 *                 if only_handshake:
 *                     return (ssldata, appdata)
 */
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_self->_handshake_cb, __pyx_tuple__257, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 174, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "uvloop/sslproto.pyx":173
 *                 self._sslobj.do_handshake()
 *                 self._state = _WRAPPED
 *                 if self._handshake_cb:             # <<<<<<<<<<<<<<
 *                     self._handshake_cb(None)
 *                 if only_handshake:
 */
        }

        /* "uvloop/sslproto.pyx":175
 *                 if self._handshake_cb:
 *                     self._handshake_cb(None)
 *                 if only_handshake:             # <<<<<<<<<<<<<<
 *                     return (ssldata, appdata)
 *                 # Handshake done: execute the wrapped block
 */
        __pyx_t_1 = (__pyx_v_only_handshake != 0);
        if (__pyx_t_1) {

          /* "uvloop/sslproto.pyx":176
 *                     self._handshake_cb(None)
 *                 if only_handshake:
 *                     return (ssldata, appdata)             # <<<<<<<<<<<<<<
 *                 # Handshake done: execute the wrapped block
 * 
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 176, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_v_ssldata);
          __Pyx_GIVEREF(__pyx_v_ssldata);
          PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_ssldata);
          __Pyx_INCREF(__pyx_v_appdata);
          __Pyx_GIVEREF(__pyx_v_appdata);
          PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_appdata);
          __pyx_r = __pyx_t_4;
          __pyx_t_4 = 0;
          goto __pyx_L10_try_return;

          /* "uvloop/sslproto.pyx":175
 *                 if self._handshake_cb:
 *                     self._handshake_cb(None)
 *                 if only_handshake:             # <<<<<<<<<<<<<<
 *                     return (ssldata, appdata)
 *                 # Handshake done: execute the wrapped block
 */
        }

        /* "uvloop/sslproto.pyx":169
 *         appdata = []
 *         try:
 *             if self._state is _DO_HANDSHAKE:             # <<<<<<<<<<<<<<
 *                 # Call do_handshake() until it doesn't raise anymore.
 *                 self._sslobj.do_handshake()
 */
      }

      /* "uvloop/sslproto.pyx":179
 *                 # Handshake done: execute the wrapped block
 * 
 *             if self._state is _WRAPPED:             # <<<<<<<<<<<<<<
 *                 # Main state: read data from SSL until close_notify
 *                 while True:
 */
      __pyx_t_1 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__WRAPPED);
      __pyx_t_2 = (__pyx_t_1 != 0);
      if (__pyx_t_2) {

        /* "uvloop/sslproto.pyx":181
 *             if self._state is _WRAPPED:
 *                 # Main state: read data from SSL until close_notify
 *                 while True:             # <<<<<<<<<<<<<<
 *                     chunk = self._sslobj.read(READ_MAX_SIZE)
 *                     appdata.append(chunk)
 */
        while (1) {

          /* "uvloop/sslproto.pyx":182
 *                 # Main state: read data from SSL until close_notify
 *                 while True:
 *                     chunk = self._sslobj.read(READ_MAX_SIZE)             # <<<<<<<<<<<<<<
 *                     appdata.append(chunk)
 *                     if not chunk:  # close_notify
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_sslobj, __pyx_n_s_read); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 182, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_6uvloop_4loop_READ_MAX_SIZE); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 182, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          if (!__pyx_t_5) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 182, __pyx_L6_error)
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 182, __pyx_L6_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
              PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_6};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 182, __pyx_L6_error)
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 182, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_5); __pyx_t_5 = NULL;
              __Pyx_GIVEREF(__pyx_t_6);
              PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_6);
              __pyx_t_6 = 0;
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 182, __pyx_L6_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF_SET(__pyx_v_chunk, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "uvloop/sslproto.pyx":183
 *                 while True:
 *                     chunk = self._sslobj.read(READ_MAX_SIZE)
 *                     appdata.append(chunk)             # <<<<<<<<<<<<<<
 *                     if not chunk:  # close_notify
 *                         break
 */
          __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_appdata, __pyx_v_chunk); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 183, __pyx_L6_error)

          /* "uvloop/sslproto.pyx":184
 *                     chunk = self._sslobj.read(READ_MAX_SIZE)
 *                     appdata.append(chunk)
 *                     if not chunk:  # close_notify             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
          __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_chunk); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 184, __pyx_L6_error)
          __pyx_t_1 = ((!__pyx_t_2) != 0);
          if (__pyx_t_1) {

            /* "uvloop/sslproto.pyx":185
 *                     appdata.append(chunk)
 *                     if not chunk:  # close_notify
 *                         break             # <<<<<<<<<<<<<<
 * 
 *             elif self._state is _SHUTDOWN:
 */
            goto __pyx_L17_break;

            /* "uvloop/sslproto.pyx":184
 *                     chunk = self._sslobj.read(READ_MAX_SIZE)
 *                     appdata.append(chunk)
 *                     if not chunk:  # close_notify             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
          }
        }
        __pyx_L17_break:;

        /* "uvloop/sslproto.pyx":179
 *                 # Handshake done: execute the wrapped block
 * 
 *             if self._state is _WRAPPED:             # <<<<<<<<<<<<<<
 *                 # Main state: read data from SSL until close_notify
 *                 while True:
 */
        goto __pyx_L15;
      }

      /* "uvloop/sslproto.pyx":187
 *                         break
 * 
 *             elif self._state is _SHUTDOWN:             # <<<<<<<<<<<<<<
 *                 # Call shutdown() until it doesn't raise anymore.
 *                 self._sslobj.unwrap()
 */
      __pyx_t_1 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__SHUTDOWN);
      __pyx_t_2 = (__pyx_t_1 != 0);
      if (__pyx_t_2) {

        /* "uvloop/sslproto.pyx":189
 *             elif self._state is _SHUTDOWN:
 *                 # Call shutdown() until it doesn't raise anymore.
 *                 self._sslobj.unwrap()             # <<<<<<<<<<<<<<
 *                 self._sslobj = None
 *                 self._state = _UNWRAPPED
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_sslobj, __pyx_n_s_unwrap); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 189, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (__pyx_t_10) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 189, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else {
          __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 189, __pyx_L6_error)
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/sslproto.pyx":190
 *                 # Call shutdown() until it doesn't raise anymore.
 *                 self._sslobj.unwrap()
 *                 self._sslobj = None             # <<<<<<<<<<<<<<
 *                 self._state = _UNWRAPPED
 *                 if self._shutdown_cb:
 */
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->_sslobj);
        __Pyx_DECREF(__pyx_v_self->_sslobj);
        __pyx_v_self->_sslobj = Py_None;

        /* "uvloop/sslproto.pyx":191
 *                 self._sslobj.unwrap()
 *                 self._sslobj = None
 *                 self._state = _UNWRAPPED             # <<<<<<<<<<<<<<
 *                 if self._shutdown_cb:
 *                     self._shutdown_cb()
 */
        __Pyx_INCREF(__pyx_v_6uvloop_4loop__UNWRAPPED);
        __Pyx_GIVEREF(__pyx_v_6uvloop_4loop__UNWRAPPED);
        __Pyx_GOTREF(__pyx_v_self->_state);
        __Pyx_DECREF(__pyx_v_self->_state);
        __pyx_v_self->_state = __pyx_v_6uvloop_4loop__UNWRAPPED;

        /* "uvloop/sslproto.pyx":192
 *                 self._sslobj = None
 *                 self._state = _UNWRAPPED
 *                 if self._shutdown_cb:             # <<<<<<<<<<<<<<
 *                     self._shutdown_cb()
 * 
 */
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->_shutdown_cb); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 192, __pyx_L6_error)
        if (__pyx_t_2) {

          /* "uvloop/sslproto.pyx":193
 *                 self._state = _UNWRAPPED
 *                 if self._shutdown_cb:
 *                     self._shutdown_cb()             # <<<<<<<<<<<<<<
 * 
 *             elif self._state is _UNWRAPPED:
 */
          __Pyx_INCREF(__pyx_v_self->_shutdown_cb);
          __pyx_t_3 = __pyx_v_self->_shutdown_cb; __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          if (__pyx_t_10) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 193, __pyx_L6_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          } else {
            __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 193, __pyx_L6_error)
          }
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "uvloop/sslproto.pyx":192
 *                 self._sslobj = None
 *                 self._state = _UNWRAPPED
 *                 if self._shutdown_cb:             # <<<<<<<<<<<<<<
 *                     self._shutdown_cb()
 * 
 */
        }

        /* "uvloop/sslproto.pyx":187
 *                         break
 * 
 *             elif self._state is _SHUTDOWN:             # <<<<<<<<<<<<<<
 *                 # Call shutdown() until it doesn't raise anymore.
 *                 self._sslobj.unwrap()
 */
        goto __pyx_L15;
      }

      /* "uvloop/sslproto.pyx":195
 *                     self._shutdown_cb()
 * 
 *             elif self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *                 # Drain possible plaintext data after close_notify.
 *                 appdata.append(self._incoming.read())
 */
      __pyx_t_2 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__UNWRAPPED);
      __pyx_t_1 = (__pyx_t_2 != 0);
      if (__pyx_t_1) {

        /* "uvloop/sslproto.pyx":197
 *             elif self._state is _UNWRAPPED:
 *                 # Drain possible plaintext data after close_notify.
 *                 appdata.append(self._incoming.read())             # <<<<<<<<<<<<<<
 *         except (ssl_SSLError, ssl_CertificateError) as exc:
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_incoming, __pyx_n_s_read); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 197, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        if (__pyx_t_10) {
          __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 197, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        } else {
          __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 197, __pyx_L6_error)
        }
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_appdata, __pyx_t_4); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 197, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "uvloop/sslproto.pyx":195
 *                     self._shutdown_cb()
 * 
 *             elif self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *                 # Drain possible plaintext data after close_notify.
 *                 appdata.append(self._incoming.read())
 */
      }
      __pyx_L15:;

      /* "uvloop/sslproto.pyx":168
 *         ssldata = []
 *         appdata = []
 *         try:             # <<<<<<<<<<<<<<
 *             if self._state is _DO_HANDSHAKE:
 *                 # Call do_handshake() until it doesn't raise anymore.
 */
    }
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/sslproto.pyx":198
 *                 # Drain possible plaintext data after close_notify.
 *                 appdata.append(self._incoming.read())
 *         except (ssl_SSLError, ssl_CertificateError) as exc:             # <<<<<<<<<<<<<<
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,
 */
    __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6uvloop_4loop_ssl_SSLError) || __Pyx_PyErr_ExceptionMatches(__pyx_v_6uvloop_4loop_ssl_CertificateError);
    if (__pyx_t_12) {
      __Pyx_AddTraceback("uvloop.loop._SSLPipe.feed_ssldata", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_10) < 0) __PYX_ERR(0, 198, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_3);
      __pyx_v_exc = __pyx_t_3;
      /*try:*/ {

        /* "uvloop/sslproto.pyx":199
 *                 appdata.append(self._incoming.read())
 *         except (ssl_SSLError, ssl_CertificateError) as exc:
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0             # <<<<<<<<<<<<<<
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,
 *                              ssl_SSL_ERROR_SYSCALL):
 */
        __pyx_t_6 = __Pyx_GetAttr3(__pyx_v_exc, __pyx_n_u_errno, __pyx_int_0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 199, __pyx_L25_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 199, __pyx_L25_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_errno = ((int)__pyx_t_12);

        /* "uvloop/sslproto.pyx":200
 *         except (ssl_SSLError, ssl_CertificateError) as exc:
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,             # <<<<<<<<<<<<<<
 *                              ssl_SSL_ERROR_SYSCALL):
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:
 */
        __pyx_t_12 = __pyx_v_errno;
        __pyx_t_2 = ((__pyx_t_12 != __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ) != 0);
        if (__pyx_t_2) {
        } else {
          __pyx_t_1 = __pyx_t_2;
          goto __pyx_L28_bool_binop_done;
        }
        __pyx_t_2 = ((__pyx_t_12 != __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_WRITE) != 0);
        if (__pyx_t_2) {
        } else {
          __pyx_t_1 = __pyx_t_2;
          goto __pyx_L28_bool_binop_done;
        }

        /* "uvloop/sslproto.pyx":201
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,
 *                              ssl_SSL_ERROR_SYSCALL):             # <<<<<<<<<<<<<<
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:
 *                     self._handshake_cb(exc)
 */
        __pyx_t_2 = ((__pyx_t_12 != __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_SYSCALL) != 0);
        __pyx_t_1 = __pyx_t_2;
        __pyx_L28_bool_binop_done:;

        /* "uvloop/sslproto.pyx":200
 *         except (ssl_SSLError, ssl_CertificateError) as exc:
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,             # <<<<<<<<<<<<<<
 *                              ssl_SSL_ERROR_SYSCALL):
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:
 */
        __pyx_t_2 = (__pyx_t_1 != 0);
        if (__pyx_t_2) {

          /* "uvloop/sslproto.pyx":202
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,
 *                              ssl_SSL_ERROR_SYSCALL):
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:             # <<<<<<<<<<<<<<
 *                     self._handshake_cb(exc)
 *                 raise
 */
          __pyx_t_1 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__DO_HANDSHAKE);
          __pyx_t_13 = (__pyx_t_1 != 0);
          if (__pyx_t_13) {
          } else {
            __pyx_t_2 = __pyx_t_13;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_v_self->_handshake_cb); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 202, __pyx_L25_error)
          __pyx_t_2 = __pyx_t_13;
          __pyx_L32_bool_binop_done:;
          if (__pyx_t_2) {

            /* "uvloop/sslproto.pyx":203
 *                              ssl_SSL_ERROR_SYSCALL):
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:
 *                     self._handshake_cb(exc)             # <<<<<<<<<<<<<<
 *                 raise
 *             self._need_ssldata = (errno == ssl_SSL_ERROR_WANT_READ)
 */
            __Pyx_INCREF(__pyx_v_self->_handshake_cb);
            __pyx_t_5 = __pyx_v_self->_handshake_cb; __pyx_t_14 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
              __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_5);
              if (likely(__pyx_t_14)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                __Pyx_INCREF(__pyx_t_14);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_5, function);
              }
            }
            if (!__pyx_t_14) {
              __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_exc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 203, __pyx_L25_error)
              __Pyx_GOTREF(__pyx_t_6);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_5)) {
                PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
                __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 203, __pyx_L25_error)
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_GOTREF(__pyx_t_6);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
                PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
                __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 203, __pyx_L25_error)
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_GOTREF(__pyx_t_6);
              } else
              #endif
              {
                __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 203, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_15);
                __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
                __Pyx_INCREF(__pyx_v_exc);
                __Pyx_GIVEREF(__pyx_v_exc);
                PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_v_exc);
                __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_15, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 203, __pyx_L25_error)
                __Pyx_GOTREF(__pyx_t_6);
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "uvloop/sslproto.pyx":202
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,
 *                              ssl_SSL_ERROR_SYSCALL):
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:             # <<<<<<<<<<<<<<
 *                     self._handshake_cb(exc)
 *                 raise
 */
          }

          /* "uvloop/sslproto.pyx":204
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:
 *                     self._handshake_cb(exc)
 *                 raise             # <<<<<<<<<<<<<<
 *             self._need_ssldata = (errno == ssl_SSL_ERROR_WANT_READ)
 * 
 */
          __Pyx_GIVEREF(__pyx_t_4);
          __Pyx_GIVEREF(__pyx_t_3);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_3, __pyx_t_10);
          __pyx_t_4 = 0; __pyx_t_3 = 0; __pyx_t_10 = 0; 
          __PYX_ERR(0, 204, __pyx_L25_error)

          /* "uvloop/sslproto.pyx":200
 *         except (ssl_SSLError, ssl_CertificateError) as exc:
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,             # <<<<<<<<<<<<<<
 *                              ssl_SSL_ERROR_SYSCALL):
 *                 if self._state is _DO_HANDSHAKE and self._handshake_cb:
 */
        }

        /* "uvloop/sslproto.pyx":205
 *                     self._handshake_cb(exc)
 *                 raise
 *             self._need_ssldata = (errno == ssl_SSL_ERROR_WANT_READ)             # <<<<<<<<<<<<<<
 * 
 *         # Check for record level data that needs to be sent back.
 */
        __pyx_v_self->_need_ssldata = (__pyx_v_errno == __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ);
      }

      /* "uvloop/sslproto.pyx":198
 *                 # Drain possible plaintext data after close_notify.
 *                 appdata.append(self._incoming.read())
 *         except (ssl_SSLError, ssl_CertificateError) as exc:             # <<<<<<<<<<<<<<
 *             errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *             if errno not in (ssl_SSL_ERROR_WANT_READ, ssl_SSL_ERROR_WANT_WRITE,
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L26;
        }
        __pyx_L25_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __pyx_t_12 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
          }
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
          __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
          __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
          goto __pyx_L8_except_error;
        }
        __pyx_L26:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/sslproto.pyx":168
 *         ssldata = []
 *         appdata = []
 *         try:             # <<<<<<<<<<<<<<
 *             if self._state is _DO_HANDSHAKE:
 *                 # Call do_handshake() until it doesn't raise anymore.
 */
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L1_error;
    __pyx_L10_try_return:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    goto __pyx_L0;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
    __pyx_L11_try_end:;
  }

  /* "uvloop/sslproto.pyx":209
 *         # Check for record level data that needs to be sent back.
 *         # Happens for the initial handshake and renegotiations.
 *         if self._outgoing.pending:             # <<<<<<<<<<<<<<
 *             ssldata.append(self._outgoing.read())
 *         return (ssldata, appdata)
 */
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_outgoing, __pyx_n_s_pending); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 209, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":210
 *         # Happens for the initial handshake and renegotiations.
 *         if self._outgoing.pending:
 *             ssldata.append(self._outgoing.read())             # <<<<<<<<<<<<<<
 *         return (ssldata, appdata)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_outgoing, __pyx_n_s_read); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 210, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_10 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 210, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_ssldata, __pyx_t_10); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 210, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "uvloop/sslproto.pyx":209
 *         # Check for record level data that needs to be sent back.
 *         # Happens for the initial handshake and renegotiations.
 *         if self._outgoing.pending:             # <<<<<<<<<<<<<<
 *             ssldata.append(self._outgoing.read())
 *         return (ssldata, appdata)
 */
  }

  /* "uvloop/sslproto.pyx":211
 *         if self._outgoing.pending:
 *             ssldata.append(self._outgoing.read())
 *         return (ssldata, appdata)             # <<<<<<<<<<<<<<
 * 
 *     cdef feed_appdata(self, data, int offset=0):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_INCREF(__pyx_v_ssldata);
  __Pyx_GIVEREF(__pyx_v_ssldata);
  PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_ssldata);
  __Pyx_INCREF(__pyx_v_appdata);
  __Pyx_GIVEREF(__pyx_v_appdata);
  PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_v_appdata);
  __pyx_r = __pyx_t_10;
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":134
 *         assert appdata == [] or appdata == [b'']
 * 
 *     cdef feed_ssldata(self, data, bint only_handshake=False):             # <<<<<<<<<<<<<<
 *         """Feed SSL record level data into the pipe.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.feed_ssldata", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_appdata);
  __Pyx_XDECREF(__pyx_v_ssldata);
  __Pyx_XDECREF(__pyx_v_chunk);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":213
 *         return (ssldata, appdata)
 * 
 *     cdef feed_appdata(self, data, int offset=0):             # <<<<<<<<<<<<<<
 *         """Feed plaintext data into the pipe.
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_8_SSLPipe_feed_appdata(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v_data, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_appdata *__pyx_optional_args) {
  int __pyx_v_offset = ((int)0);
  int __pyx_v_errno;
  PyObject *__pyx_v_ssldata = NULL;
  PyObject *__pyx_v_view = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  int __pyx_t_22;
  __Pyx_RefNannySetupContext("feed_appdata", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_offset = __pyx_optional_args->offset;
    }
  }

  /* "uvloop/sslproto.pyx":230
 *         cdef:
 *             int errno
 *         assert 0 <= offset <= len(data)             # <<<<<<<<<<<<<<
 *         if self._state is _UNWRAPPED:
 *             # pass through data in unwrapped mode
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_1 = (0 <= __pyx_v_offset);
    if (__pyx_t_1) {
      __pyx_t_2 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 230, __pyx_L1_error)
      __pyx_t_1 = (__pyx_v_offset <= __pyx_t_2);
    }
    if (unlikely(!(__pyx_t_1 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 230, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/sslproto.pyx":231
 *             int errno
 *         assert 0 <= offset <= len(data)
 *         if self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             # pass through data in unwrapped mode
 *             if offset < len(data):
 */
  __pyx_t_1 = (__pyx_v_self->_state == __pyx_v_6uvloop_4loop__UNWRAPPED);
  __pyx_t_3 = (__pyx_t_1 != 0);
  if (__pyx_t_3) {

    /* "uvloop/sslproto.pyx":233
 *         if self._state is _UNWRAPPED:
 *             # pass through data in unwrapped mode
 *             if offset < len(data):             # <<<<<<<<<<<<<<
 *                 ssldata = [data[offset:]]
 *             else:
 */
    __pyx_t_2 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 233, __pyx_L1_error)
    __pyx_t_3 = ((__pyx_v_offset < __pyx_t_2) != 0);
    if (__pyx_t_3) {

      /* "uvloop/sslproto.pyx":234
 *             # pass through data in unwrapped mode
 *             if offset < len(data):
 *                 ssldata = [data[offset:]]             # <<<<<<<<<<<<<<
 *             else:
 *                 ssldata = []
 */
      __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_data, __pyx_v_offset, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 234, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4);
      PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_v_ssldata = ((PyObject*)__pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/sslproto.pyx":233
 *         if self._state is _UNWRAPPED:
 *             # pass through data in unwrapped mode
 *             if offset < len(data):             # <<<<<<<<<<<<<<
 *                 ssldata = [data[offset:]]
 *             else:
 */
      goto __pyx_L4;
    }

    /* "uvloop/sslproto.pyx":236
 *                 ssldata = [data[offset:]]
 *             else:
 *                 ssldata = []             # <<<<<<<<<<<<<<
 *             return (ssldata, len(data))
 * 
 */
    /*else*/ {
      __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 236, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_v_ssldata = ((PyObject*)__pyx_t_5);
      __pyx_t_5 = 0;
    }
    __pyx_L4:;

    /* "uvloop/sslproto.pyx":237
 *             else:
 *                 ssldata = []
 *             return (ssldata, len(data))             # <<<<<<<<<<<<<<
 * 
 *         ssldata = []
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 237, __pyx_L1_error)
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_ssldata);
    __Pyx_GIVEREF(__pyx_v_ssldata);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_ssldata);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":231
 *             int errno
 *         assert 0 <= offset <= len(data)
 *         if self._state is _UNWRAPPED:             # <<<<<<<<<<<<<<
 *             # pass through data in unwrapped mode
 *             if offset < len(data):
 */
  }

  /* "uvloop/sslproto.pyx":239
 *             return (ssldata, len(data))
 * 
 *         ssldata = []             # <<<<<<<<<<<<<<
 *         view = memoryview(data)
 *         while True:
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_ssldata = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "uvloop/sslproto.pyx":240
 * 
 *         ssldata = []
 *         view = memoryview(data)             # <<<<<<<<<<<<<<
 *         while True:
 *             self._need_ssldata = False
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_view = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "uvloop/sslproto.pyx":241
 *         ssldata = []
 *         view = memoryview(data)
 *         while True:             # <<<<<<<<<<<<<<
 *             self._need_ssldata = False
 *             try:
 */
  while (1) {

    /* "uvloop/sslproto.pyx":242
 *         view = memoryview(data)
 *         while True:
 *             self._need_ssldata = False             # <<<<<<<<<<<<<<
 *             try:
 *                 if offset < len(view):
 */
    __pyx_v_self->_need_ssldata = 0;

    /* "uvloop/sslproto.pyx":243
 *         while True:
 *             self._need_ssldata = False
 *             try:             # <<<<<<<<<<<<<<
 *                 if offset < len(view):
 *                     offset += self._sslobj.write(view[offset:])
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      /*try:*/ {

        /* "uvloop/sslproto.pyx":244
 *             self._need_ssldata = False
 *             try:
 *                 if offset < len(view):             # <<<<<<<<<<<<<<
 *                     offset += self._sslobj.write(view[offset:])
 *             except ssl_SSLError as exc:
 */
        __pyx_t_2 = PyObject_Length(__pyx_v_view); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 244, __pyx_L7_error)
        __pyx_t_3 = ((__pyx_v_offset < __pyx_t_2) != 0);
        if (__pyx_t_3) {

          /* "uvloop/sslproto.pyx":245
 *             try:
 *                 if offset < len(view):
 *                     offset += self._sslobj.write(view[offset:])             # <<<<<<<<<<<<<<
 *             except ssl_SSLError as exc:
 *                 errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 */
          __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 245, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_sslobj, __pyx_n_s_write); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 245, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_9);
          __pyx_t_10 = __Pyx_PyObject_GetSlice(__pyx_v_view, __pyx_v_offset, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 245, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
            if (likely(__pyx_t_11)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_9, function);
            }
          }
          if (!__pyx_t_11) {
            __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L7_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_GOTREF(__pyx_t_4);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_10};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
              PyObject *__pyx_temp[2] = {__pyx_t_11, __pyx_t_10};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 245, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_11); __pyx_t_11 = NULL;
              __Pyx_GIVEREF(__pyx_t_10);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_t_10);
              __pyx_t_10 = 0;
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_t_9 = PyNumber_InPlaceAdd(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 245, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_t_9); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 245, __pyx_L7_error)
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __pyx_v_offset = __pyx_t_13;

          /* "uvloop/sslproto.pyx":244
 *             self._need_ssldata = False
 *             try:
 *                 if offset < len(view):             # <<<<<<<<<<<<<<
 *                     offset += self._sslobj.write(view[offset:])
 *             except ssl_SSLError as exc:
 */
        }

        /* "uvloop/sslproto.pyx":243
 *         while True:
 *             self._need_ssldata = False
 *             try:             # <<<<<<<<<<<<<<
 *                 if offset < len(view):
 *                     offset += self._sslobj.write(view[offset:])
 */
      }
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L14_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/sslproto.pyx":246
 *                 if offset < len(view):
 *                     offset += self._sslobj.write(view[offset:])
 *             except ssl_SSLError as exc:             # <<<<<<<<<<<<<<
 *                 errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *                 # It is not allowed to call write() after unwrap() until the
 */
      __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6uvloop_4loop_ssl_SSLError);
      if (__pyx_t_13) {
        __Pyx_AddTraceback("uvloop.loop._SSLPipe.feed_appdata", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 246, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_v_exc = __pyx_t_4;
        /*try:*/ {

          /* "uvloop/sslproto.pyx":247
 *                     offset += self._sslobj.write(view[offset:])
 *             except ssl_SSLError as exc:
 *                 errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0             # <<<<<<<<<<<<<<
 *                 # It is not allowed to call write() after unwrap() until the
 *                 # close_notify is acknowledged. We return the condition to the
 */
          __pyx_t_12 = __Pyx_GetAttr3(__pyx_v_exc, __pyx_n_u_errno, __pyx_int_0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 247, __pyx_L21_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_PyInt_As_int(__pyx_t_12); if (unlikely((__pyx_t_13 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 247, __pyx_L21_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_v_errno = ((int)__pyx_t_13);

          /* "uvloop/sslproto.pyx":251
 *                 # close_notify is acknowledged. We return the condition to the
 *                 # caller as a short write.
 *                 if exc.reason == 'PROTOCOL_IS_SHUTDOWN':             # <<<<<<<<<<<<<<
 *                     exc.errno = errno = ssl_SSL_ERROR_WANT_READ
 *                 if errno not in (ssl_SSL_ERROR_WANT_READ,
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_exc, __pyx_n_s_reason); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 251, __pyx_L21_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_12, __pyx_n_u_PROTOCOL_IS_SHUTDOWN, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 251, __pyx_L21_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_3) {

            /* "uvloop/sslproto.pyx":252
 *                 # caller as a short write.
 *                 if exc.reason == 'PROTOCOL_IS_SHUTDOWN':
 *                     exc.errno = errno = ssl_SSL_ERROR_WANT_READ             # <<<<<<<<<<<<<<
 *                 if errno not in (ssl_SSL_ERROR_WANT_READ,
 *                                  ssl_SSL_ERROR_WANT_WRITE,
 */
            __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 252, __pyx_L21_error)
            __Pyx_GOTREF(__pyx_t_12);
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_exc, __pyx_n_s_errno, __pyx_t_12) < 0) __PYX_ERR(0, 252, __pyx_L21_error)
            __pyx_v_errno = __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "uvloop/sslproto.pyx":251
 *                 # close_notify is acknowledged. We return the condition to the
 *                 # caller as a short write.
 *                 if exc.reason == 'PROTOCOL_IS_SHUTDOWN':             # <<<<<<<<<<<<<<
 *                     exc.errno = errno = ssl_SSL_ERROR_WANT_READ
 *                 if errno not in (ssl_SSL_ERROR_WANT_READ,
 */
          }

          /* "uvloop/sslproto.pyx":253
 *                 if exc.reason == 'PROTOCOL_IS_SHUTDOWN':
 *                     exc.errno = errno = ssl_SSL_ERROR_WANT_READ
 *                 if errno not in (ssl_SSL_ERROR_WANT_READ,             # <<<<<<<<<<<<<<
 *                                  ssl_SSL_ERROR_WANT_WRITE,
 *                                  ssl_SSL_ERROR_SYSCALL):
 */
          __pyx_t_13 = __pyx_v_errno;
          __pyx_t_1 = ((__pyx_t_13 != __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ) != 0);
          if (__pyx_t_1) {
          } else {
            __pyx_t_3 = __pyx_t_1;
            goto __pyx_L25_bool_binop_done;
          }

          /* "uvloop/sslproto.pyx":254
 *                     exc.errno = errno = ssl_SSL_ERROR_WANT_READ
 *                 if errno not in (ssl_SSL_ERROR_WANT_READ,
 *                                  ssl_SSL_ERROR_WANT_WRITE,             # <<<<<<<<<<<<<<
 *                                  ssl_SSL_ERROR_SYSCALL):
 *                     raise
 */
          __pyx_t_1 = ((__pyx_t_13 != __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_WRITE) != 0);
          if (__pyx_t_1) {
          } else {
            __pyx_t_3 = __pyx_t_1;
            goto __pyx_L25_bool_binop_done;
          }

          /* "uvloop/sslproto.pyx":253
 *                 if exc.reason == 'PROTOCOL_IS_SHUTDOWN':
 *                     exc.errno = errno = ssl_SSL_ERROR_WANT_READ
 *                 if errno not in (ssl_SSL_ERROR_WANT_READ,             # <<<<<<<<<<<<<<
 *                                  ssl_SSL_ERROR_WANT_WRITE,
 *                                  ssl_SSL_ERROR_SYSCALL):
 */
          __pyx_t_1 = ((__pyx_t_13 != __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_SYSCALL) != 0);
          __pyx_t_3 = __pyx_t_1;
          __pyx_L25_bool_binop_done:;
          __pyx_t_1 = (__pyx_t_3 != 0);
          if (unlikely(__pyx_t_1)) {

            /* "uvloop/sslproto.pyx":256
 *                                  ssl_SSL_ERROR_WANT_WRITE,
 *                                  ssl_SSL_ERROR_SYSCALL):
 *                     raise             # <<<<<<<<<<<<<<
 *                 self._need_ssldata = (errno == ssl_SSL_ERROR_WANT_READ)
 * 
 */
            __Pyx_GIVEREF(__pyx_t_9);
            __Pyx_GIVEREF(__pyx_t_4);
            __Pyx_XGIVEREF(__pyx_t_5);
            __Pyx_ErrRestoreWithState(__pyx_t_9, __pyx_t_4, __pyx_t_5);
            __pyx_t_9 = 0; __pyx_t_4 = 0; __pyx_t_5 = 0; 
            __PYX_ERR(0, 256, __pyx_L21_error)

            /* "uvloop/sslproto.pyx":253
 *                 if exc.reason == 'PROTOCOL_IS_SHUTDOWN':
 *                     exc.errno = errno = ssl_SSL_ERROR_WANT_READ
 *                 if errno not in (ssl_SSL_ERROR_WANT_READ,             # <<<<<<<<<<<<<<
 *                                  ssl_SSL_ERROR_WANT_WRITE,
 *                                  ssl_SSL_ERROR_SYSCALL):
 */
          }

          /* "uvloop/sslproto.pyx":257
 *                                  ssl_SSL_ERROR_SYSCALL):
 *                     raise
 *                 self._need_ssldata = (errno == ssl_SSL_ERROR_WANT_READ)             # <<<<<<<<<<<<<<
 * 
 *             # See if there's any record level data back for us.
 */
          __pyx_v_self->_need_ssldata = (__pyx_v_errno == __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ);
        }

        /* "uvloop/sslproto.pyx":246
 *                 if offset < len(view):
 *                     offset += self._sslobj.write(view[offset:])
 *             except ssl_SSLError as exc:             # <<<<<<<<<<<<<<
 *                 errno = <int>getattr(exc, 'errno', 0)  # SSL_ERROR_NONE = 0
 *                 # It is not allowed to call write() after unwrap() until the
 */
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            goto __pyx_L22;
          }
          __pyx_L21_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_16);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __pyx_t_13 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
            }
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
            __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
            __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
            goto __pyx_L9_except_error;
          }
          __pyx_L22:;
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        goto __pyx_L8_exception_handled;
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/sslproto.pyx":243
 *         while True:
 *             self._need_ssldata = False
 *             try:             # <<<<<<<<<<<<<<
 *                 if offset < len(view):
 *                     offset += self._sslobj.write(view[offset:])
 */
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      goto __pyx_L1_error;
      __pyx_L8_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
      __pyx_L14_try_end:;
    }

    /* "uvloop/sslproto.pyx":260
 * 
 *             # See if there's any record level data back for us.
 *             if self._outgoing.pending:             # <<<<<<<<<<<<<<
 *                 ssldata.append(self._outgoing.read())
 *             if offset == len(view) or self._need_ssldata:
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_outgoing, __pyx_n_s_pending); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 260, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 260, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_1) {

      /* "uvloop/sslproto.pyx":261
 *             # See if there's any record level data back for us.
 *             if self._outgoing.pending:
 *                 ssldata.append(self._outgoing.read())             # <<<<<<<<<<<<<<
 *             if offset == len(view) or self._need_ssldata:
 *                 break
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->_outgoing, __pyx_n_s_read); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 261, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (__pyx_t_9) {
        __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 261, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else {
        __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 261, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_22 = __Pyx_PyList_Append(__pyx_v_ssldata, __pyx_t_5); if (unlikely(__pyx_t_22 == ((int)-1))) __PYX_ERR(0, 261, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/sslproto.pyx":260
 * 
 *             # See if there's any record level data back for us.
 *             if self._outgoing.pending:             # <<<<<<<<<<<<<<
 *                 ssldata.append(self._outgoing.read())
 *             if offset == len(view) or self._need_ssldata:
 */
    }

    /* "uvloop/sslproto.pyx":262
 *             if self._outgoing.pending:
 *                 ssldata.append(self._outgoing.read())
 *             if offset == len(view) or self._need_ssldata:             # <<<<<<<<<<<<<<
 *                 break
 *         return (ssldata, offset)
 */
    __pyx_t_2 = PyObject_Length(__pyx_v_view); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 262, __pyx_L1_error)
    __pyx_t_3 = ((__pyx_v_offset == __pyx_t_2) != 0);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_1 = __pyx_t_3;
      goto __pyx_L34_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->_need_ssldata != 0);
    __pyx_t_1 = __pyx_t_3;
    __pyx_L34_bool_binop_done:;
    if (__pyx_t_1) {

      /* "uvloop/sslproto.pyx":263
 *                 ssldata.append(self._outgoing.read())
 *             if offset == len(view) or self._need_ssldata:
 *                 break             # <<<<<<<<<<<<<<
 *         return (ssldata, offset)
 * 
 */
      goto __pyx_L6_break;

      /* "uvloop/sslproto.pyx":262
 *             if self._outgoing.pending:
 *                 ssldata.append(self._outgoing.read())
 *             if offset == len(view) or self._need_ssldata:             # <<<<<<<<<<<<<<
 *                 break
 *         return (ssldata, offset)
 */
    }
  }
  __pyx_L6_break:;

  /* "uvloop/sslproto.pyx":264
 *             if offset == len(view) or self._need_ssldata:
 *                 break
 *         return (ssldata, offset)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_offset); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_ssldata);
  __Pyx_GIVEREF(__pyx_v_ssldata);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_ssldata);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":213
 *         return (ssldata, appdata)
 * 
 *     cdef feed_appdata(self, data, int offset=0):             # <<<<<<<<<<<<<<
 *         """Feed plaintext data into the pipe.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.feed_appdata", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ssldata);
  __Pyx_XDECREF(__pyx_v_view);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._context, self._handshake_cb, self._incoming, self._need_ssldata, self._outgoing, self._server_hostname, self._server_side, self._shutdown_cb, self._sslobj, self._state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8_SSLPipe_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_8_SSLPipe_2__reduce_cython__[] = "_SSLPipe.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_8_SSLPipe_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8_SSLPipe_2__reduce_cython__(((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8_SSLPipe_2__reduce_cython__(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self) {
  int __pyx_v_use_setstate;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_v__dict = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     cdef bint use_setstate
 *     state = (self._context, self._handshake_cb, self._incoming, self._need_ssldata, self._outgoing, self._server_hostname, self._server_side, self._shutdown_cb, self._sslobj, self._state)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_self->_need_ssldata); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(10); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_self->_context);
  __Pyx_GIVEREF(__pyx_v_self->_context);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->_context);
  __Pyx_INCREF(__pyx_v_self->_handshake_cb);
  __Pyx_GIVEREF(__pyx_v_self->_handshake_cb);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->_handshake_cb);
  __Pyx_INCREF(__pyx_v_self->_incoming);
  __Pyx_GIVEREF(__pyx_v_self->_incoming);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_self->_incoming);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->_outgoing);
  __Pyx_GIVEREF(__pyx_v_self->_outgoing);
  PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_v_self->_outgoing);
  __Pyx_INCREF(__pyx_v_self->_server_hostname);
  __Pyx_GIVEREF(__pyx_v_self->_server_hostname);
  PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_v_self->_server_hostname);
  __Pyx_INCREF(__pyx_v_self->_server_side);
  __Pyx_GIVEREF(__pyx_v_self->_server_side);
  PyTuple_SET_ITEM(__pyx_t_2, 6, __pyx_v_self->_server_side);
  __Pyx_INCREF(__pyx_v_self->_shutdown_cb);
  __Pyx_GIVEREF(__pyx_v_self->_shutdown_cb);
  PyTuple_SET_ITEM(__pyx_t_2, 7, __pyx_v_self->_shutdown_cb);
  __Pyx_INCREF(__pyx_v_self->_sslobj);
  __Pyx_GIVEREF(__pyx_v_self->_sslobj);
  PyTuple_SET_ITEM(__pyx_t_2, 8, __pyx_v_self->_sslobj);
  __Pyx_INCREF(__pyx_v_self->_state);
  __Pyx_GIVEREF(__pyx_v_self->_state);
  PyTuple_SET_ITEM(__pyx_t_2, 9, __pyx_v_self->_state);
  __pyx_t_1 = 0;
  __pyx_v_state = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "(tree fragment)":4
 *     cdef bint use_setstate
 *     state = (self._context, self._handshake_cb, self._incoming, self._need_ssldata, self._outgoing, self._server_hostname, self._server_side, self._shutdown_cb, self._sslobj, self._state)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_2 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v__dict = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "(tree fragment)":5
 *     state = (self._context, self._handshake_cb, self._incoming, self._need_ssldata, self._outgoing, self._server_hostname, self._server_side, self._shutdown_cb, self._sslobj, self._state)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "(tree fragment)":6
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v__dict);
    __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;

    /* "(tree fragment)":7
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self._context is not None or self._handshake_cb is not None or self._incoming is not None or self._outgoing is not None or self._server_hostname is not None or self._server_side is not None or self._shutdown_cb is not None or self._sslobj is not None or self._state is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":5
 *     state = (self._context, self._handshake_cb, self._incoming, self._need_ssldata, self._outgoing, self._server_hostname, self._server_side, self._shutdown_cb, self._sslobj, self._state)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":9
 *         use_setstate = True
 *     else:
 *         use_setstate = self._context is not None or self._handshake_cb is not None or self._incoming is not None or self._outgoing is not None or self._server_hostname is not None or self._server_side is not None or self._shutdown_cb is not None or self._sslobj is not None or self._state is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, None), state
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_self->_context != Py_None);
    __pyx_t_5 = (__pyx_t_3 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_handshake_cb != Py_None);
    __pyx_t_3 = (__pyx_t_5 != 0);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->_incoming != Py_None);
    __pyx_t_5 = (__pyx_t_3 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_outgoing != Py_None);
    __pyx_t_3 = (__pyx_t_5 != 0);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->_server_hostname != Py_None);
    __pyx_t_5 = (__pyx_t_3 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_server_side != Py_None);
    __pyx_t_3 = (__pyx_t_5 != 0);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->_shutdown_cb != Py_None);
    __pyx_t_5 = (__pyx_t_3 != 0);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_4 = __pyx_t_5;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_self->_sslobj != Py_None);
    __pyx_t_3 = (__pyx_t_5 != 0);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_4 = __pyx_t_3;
      goto __pyx_L4_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->_state != Py_None);
    __pyx_t_5 = (__pyx_t_3 != 0);
    __pyx_t_4 = __pyx_t_5;
    __pyx_L4_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_4;
  }
  __pyx_L3:;

  /* "(tree fragment)":10
 *     else:
 *         use_setstate = self._context is not None or self._handshake_cb is not None or self._incoming is not None or self._outgoing is not None or self._server_hostname is not None or self._server_side is not None or self._shutdown_cb is not None or self._sslobj is not None or self._state is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, None), state
 *     else:
 */
  __pyx_t_4 = (__pyx_v_use_setstate != 0);
  if (__pyx_t_4) {

    /* "(tree fragment)":11
 *         use_setstate = self._context is not None or self._handshake_cb is not None or self._incoming is not None or self._outgoing is not None or self._server_hostname is not None or self._server_side is not None or self._shutdown_cb is not None or self._sslobj is not None or self._state is not None
 *     if use_setstate:
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle__SSLPipe); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_59579947);
    __Pyx_GIVEREF(__pyx_int_59579947);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_59579947);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    PyTuple_SET_ITEM(__pyx_t_2, 2, Py_None);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 11, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_2);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_v_state);
    __pyx_t_1 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":10
 *     else:
 *         use_setstate = self._context is not None or self._handshake_cb is not None or self._incoming is not None or self._outgoing is not None or self._server_hostname is not None or self._server_side is not None or self._shutdown_cb is not None or self._sslobj is not None or self._state is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, None), state
 *     else:
 */
  }

  /* "(tree fragment)":13
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, None), state
 *     else:
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle__SSLPipe__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_pyx_unpickle__SSLPipe); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_INCREF(__pyx_int_59579947);
    __Pyx_GIVEREF(__pyx_int_59579947);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_59579947);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_state);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_2 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef bint use_setstate
 *     state = (self._context, self._handshake_cb, self._incoming, self._need_ssldata, self._outgoing, self._server_hostname, self._server_side, self._shutdown_cb, self._sslobj, self._state)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle__SSLPipe__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_8_SSLPipe_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_8_SSLPipe_4__setstate_cython__[] = "_SSLPipe.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_8_SSLPipe_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_8_SSLPipe_4__setstate_cython__(((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_8_SSLPipe_4__setstate_cython__(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":15
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle__SSLPipe__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(9, 15, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6uvloop_4loop___pyx_unpickle__SSLPipe__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":14
 *     else:
 *         return __pyx_unpickle__SSLPipe, (type(self), 0x38d1e2b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle__SSLPipe__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._SSLPipe.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":272
 *     # _sendfile_compatible = constants._SendfileMode.FALLBACK
 * 
 *     def __init__(self, loop, ssl_protocol):             # <<<<<<<<<<<<<<
 *         self._loop = loop
 *         # SSLProtocol instance
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport___init__[] = "_SSLProtocolTransport.__init__(self, loop, ssl_protocol)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_1__init__ = {"__init__", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_1__init__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport___init__};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_loop = 0;
  PyObject *__pyx_v_ssl_protocol = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_loop,&__pyx_n_s_ssl_protocol,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(0, 272, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ssl_protocol)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(0, 272, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 272, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_loop = values[1];
    __pyx_v_ssl_protocol = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 272, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport___init__(__pyx_self, __pyx_v_self, __pyx_v_loop, __pyx_v_ssl_protocol);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_loop, PyObject *__pyx_v_ssl_protocol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "uvloop/sslproto.pyx":273
 * 
 *     def __init__(self, loop, ssl_protocol):
 *         self._loop = loop             # <<<<<<<<<<<<<<
 *         # SSLProtocol instance
 *         self._ssl_protocol = ssl_protocol
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_loop_2, __pyx_v_loop) < 0) __PYX_ERR(0, 273, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":275
 *         self._loop = loop
 *         # SSLProtocol instance
 *         self._ssl_protocol = ssl_protocol             # <<<<<<<<<<<<<<
 *         self._closed = False
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2, __pyx_v_ssl_protocol) < 0) __PYX_ERR(0, 275, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":276
 *         # SSLProtocol instance
 *         self._ssl_protocol = ssl_protocol
 *         self._closed = False             # <<<<<<<<<<<<<<
 * 
 *     def get_extra_info(self, name, default=None):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_closed, Py_False) < 0) __PYX_ERR(0, 276, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":272
 *     # _sendfile_compatible = constants._SendfileMode.FALLBACK
 * 
 *     def __init__(self, loop, ssl_protocol):             # <<<<<<<<<<<<<<
 *         self._loop = loop
 *         # SSLProtocol instance
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":278
 *         self._closed = False
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         """Get optional transport information."""
 *         return self._ssl_protocol._get_extra_info(name, default)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_3get_extra_info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_2get_extra_info[] = "_SSLProtocolTransport.get_extra_info(self, name, default=None)\nGet optional transport information.";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_3get_extra_info = {"get_extra_info", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_3get_extra_info, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_2get_extra_info};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_3get_extra_info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_extra_info (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_name_2,&__pyx_n_s_default,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_extra_info", 0, 2, 3, 1); __PYX_ERR(0, 278, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_extra_info") < 0)) __PYX_ERR(0, 278, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_default = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_extra_info", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 278, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_2get_extra_info(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_2get_extra_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("get_extra_info", 0);

  /* "uvloop/sslproto.pyx":280
 *     def get_extra_info(self, name, default=None):
 *         """Get optional transport information."""
 *         return self._ssl_protocol._get_extra_info(name, default)             # <<<<<<<<<<<<<<
 * 
 *     def set_protocol(self, protocol):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_extra_info_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_default};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_name, __pyx_v_default};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_name);
    __Pyx_GIVEREF(__pyx_v_name);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_name);
    __Pyx_INCREF(__pyx_v_default);
    __Pyx_GIVEREF(__pyx_v_default);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_default);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 280, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":278
 *         self._closed = False
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         """Get optional transport information."""
 *         return self._ssl_protocol._get_extra_info(name, default)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":282
 *         return self._ssl_protocol._get_extra_info(name, default)
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_5set_protocol(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_4set_protocol[] = "_SSLProtocolTransport.set_protocol(self, protocol)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_5set_protocol = {"set_protocol", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_5set_protocol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_4set_protocol};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_5set_protocol(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_protocol = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_protocol (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_protocol,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_protocol)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("set_protocol", 1, 2, 2, 1); __PYX_ERR(0, 282, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_protocol") < 0)) __PYX_ERR(0, 282, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_protocol = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_protocol", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 282, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.set_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_4set_protocol(__pyx_self, __pyx_v_self, __pyx_v_protocol);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_4set_protocol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_protocol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("set_protocol", 0);

  /* "uvloop/sslproto.pyx":283
 * 
 *     def set_protocol(self, protocol):
 *         self._ssl_protocol._set_app_protocol(protocol)             # <<<<<<<<<<<<<<
 * 
 *     def get_protocol(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_app_protocol); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_protocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_protocol};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_v_protocol};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2); __pyx_t_2 = NULL;
      __Pyx_INCREF(__pyx_v_protocol);
      __Pyx_GIVEREF(__pyx_v_protocol);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v_protocol);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":282
 *         return self._ssl_protocol._get_extra_info(name, default)
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.set_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":285
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._ssl_protocol._app_protocol
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_7get_protocol(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_6get_protocol[] = "_SSLProtocolTransport.get_protocol(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_7get_protocol = {"get_protocol", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_7get_protocol, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_6get_protocol};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_7get_protocol(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_protocol (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_6get_protocol(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_6get_protocol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_protocol", 0);

  /* "uvloop/sslproto.pyx":286
 * 
 *     def get_protocol(self):
 *         return self._ssl_protocol._app_protocol             # <<<<<<<<<<<<<<
 * 
 *     def is_closing(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":285
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._ssl_protocol._app_protocol
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.get_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":288
 *         return self._ssl_protocol._app_protocol
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closed
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_9is_closing(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_8is_closing[] = "_SSLProtocolTransport.is_closing(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_9is_closing = {"is_closing", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_9is_closing, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_8is_closing};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_9is_closing(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_closing (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_8is_closing(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_8is_closing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("is_closing", 0);

  /* "uvloop/sslproto.pyx":289
 * 
 *     def is_closing(self):
 *         return self._closed             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_closed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":288
 *         return self._ssl_protocol._app_protocol
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closed
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.is_closing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":291
 *         return self._closed
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         """Close the transport.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_11close(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_10close[] = "_SSLProtocolTransport.close(self)\nClose the transport.\n\n        Buffered data will be flushed asynchronously.  No more data\n        will be received.  After all buffered data is flushed, the\n        protocol's connection_lost() method will (eventually) called\n        with None as its argument.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_11close = {"close", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_11close, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_10close};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_11close(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_10close(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_10close(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("close", 0);

  /* "uvloop/sslproto.pyx":299
 *         with None as its argument.
 *         """
 *         self._closed = True             # <<<<<<<<<<<<<<
 *         self._ssl_protocol._start_shutdown()
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_closed, Py_True) < 0) __PYX_ERR(0, 299, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":300
 *         """
 *         self._closed = True
 *         self._ssl_protocol._start_shutdown()             # <<<<<<<<<<<<<<
 * 
 *     def __del__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_start_shutdown); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":291
 *         return self._closed
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         """Close the transport.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":302
 *         self._ssl_protocol._start_shutdown()
 * 
 *     def __del__(self):             # <<<<<<<<<<<<<<
 *         if not self._closed:
 *             _warn_with_source(
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_13__del__(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_12__del__[] = "_SSLProtocolTransport.__del__(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_13__del__ = {"__del__", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_13__del__, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_12__del__};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_13__del__(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_12__del__(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_12__del__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__del__", 0);

  /* "uvloop/sslproto.pyx":303
 * 
 *     def __del__(self):
 *         if not self._closed:             # <<<<<<<<<<<<<<
 *             _warn_with_source(
 *                 "unclosed transport {!r}".format(self),
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_closed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 303, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = ((!__pyx_t_2) != 0);
  if (__pyx_t_3) {

    /* "uvloop/sslproto.pyx":305
 *         if not self._closed:
 *             _warn_with_source(
 *                 "unclosed transport {!r}".format(self),             # <<<<<<<<<<<<<<
 *                 ResourceWarning, self)
 *             self.close()
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_unclosed_transport_r, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 305, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 305, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_self);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 305, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/sslproto.pyx":306
 *             _warn_with_source(
 *                 "unclosed transport {!r}".format(self),
 *                 ResourceWarning, self)             # <<<<<<<<<<<<<<
 *             self.close()
 * 
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ResourceWarning); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 306, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "uvloop/sslproto.pyx":304
 *     def __del__(self):
 *         if not self._closed:
 *             _warn_with_source(             # <<<<<<<<<<<<<<
 *                 "unclosed transport {!r}".format(self),
 *                 ResourceWarning, self)
 */
    __pyx_t_6 = __pyx_f_6uvloop_4loop__warn_with_source(__pyx_t_1, __pyx_t_4, __pyx_v_self); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 304, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/sslproto.pyx":307
 *                 "unclosed transport {!r}".format(self),
 *                 ResourceWarning, self)
 *             self.close()             # <<<<<<<<<<<<<<
 * 
 *     def is_reading(self):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_close); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_1) {
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 307, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      __pyx_t_6 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 307, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/sslproto.pyx":303
 * 
 *     def __del__(self):
 *         if not self._closed:             # <<<<<<<<<<<<<<
 *             _warn_with_source(
 *                 "unclosed transport {!r}".format(self),
 */
  }

  /* "uvloop/sslproto.pyx":302
 *         self._ssl_protocol._start_shutdown()
 * 
 *     def __del__(self):             # <<<<<<<<<<<<<<
 *         if not self._closed:
 *             _warn_with_source(
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.__del__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":309
 *             self.close()
 * 
 *     def is_reading(self):             # <<<<<<<<<<<<<<
 *         tr = self._ssl_protocol._transport
 *         if tr is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_15is_reading(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_14is_reading[] = "_SSLProtocolTransport.is_reading(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_15is_reading = {"is_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_15is_reading, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_14is_reading};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_15is_reading(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_14is_reading(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_14is_reading(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_tr = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("is_reading", 0);

  /* "uvloop/sslproto.pyx":310
 * 
 *     def is_reading(self):
 *         tr = self._ssl_protocol._transport             # <<<<<<<<<<<<<<
 *         if tr is None:
 *             raise RuntimeError('SSL transport has not been initialized yet')
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_tr = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "uvloop/sslproto.pyx":311
 *     def is_reading(self):
 *         tr = self._ssl_protocol._transport
 *         if tr is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('SSL transport has not been initialized yet')
 *         return tr.is_reading()
 */
  __pyx_t_3 = (__pyx_v_tr == Py_None);
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (unlikely(__pyx_t_4)) {

    /* "uvloop/sslproto.pyx":312
 *         tr = self._ssl_protocol._transport
 *         if tr is None:
 *             raise RuntimeError('SSL transport has not been initialized yet')             # <<<<<<<<<<<<<<
 *         return tr.is_reading()
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__258, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 312, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":311
 *     def is_reading(self):
 *         tr = self._ssl_protocol._transport
 *         if tr is None:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('SSL transport has not been initialized yet')
 *         return tr.is_reading()
 */
  }

  /* "uvloop/sslproto.pyx":313
 *         if tr is None:
 *             raise RuntimeError('SSL transport has not been initialized yet')
 *         return tr.is_reading()             # <<<<<<<<<<<<<<
 * 
 *     def pause_reading(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_tr, __pyx_n_s_is_reading); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 313, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 313, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":309
 *             self.close()
 * 
 *     def is_reading(self):             # <<<<<<<<<<<<<<
 *         tr = self._ssl_protocol._transport
 *         if tr is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.is_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tr);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":315
 *         return tr.is_reading()
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         """Pause the receiving end.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_17pause_reading(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_16pause_reading[] = "_SSLProtocolTransport.pause_reading(self)\nPause the receiving end.\n\n        No data will be passed to the protocol's data_received()\n        method until resume_reading() is called.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_17pause_reading = {"pause_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_17pause_reading, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_16pause_reading};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_17pause_reading(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pause_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_16pause_reading(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_16pause_reading(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("pause_reading", 0);

  /* "uvloop/sslproto.pyx":321
 *         method until resume_reading() is called.
 *         """
 *         self._ssl_protocol._transport.pause_reading()             # <<<<<<<<<<<<<<
 * 
 *     def resume_reading(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_pause_reading); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 321, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 321, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":315
 *         return tr.is_reading()
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         """Pause the receiving end.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.pause_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":323
 *         self._ssl_protocol._transport.pause_reading()
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         """Resume the receiving end.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_19resume_reading(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_18resume_reading[] = "_SSLProtocolTransport.resume_reading(self)\nResume the receiving end.\n\n        Data received will once again be passed to the protocol's\n        data_received() method.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_19resume_reading = {"resume_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_19resume_reading, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_18resume_reading};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_19resume_reading(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resume_reading (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_18resume_reading(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_18resume_reading(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("resume_reading", 0);

  /* "uvloop/sslproto.pyx":329
 *         data_received() method.
 *         """
 *         self._ssl_protocol._transport.resume_reading()             # <<<<<<<<<<<<<<
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_resume_reading); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":323
 *         self._ssl_protocol._transport.pause_reading()
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         """Resume the receiving end.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.resume_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":331
 *         self._ssl_protocol._transport.resume_reading()
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         """Set the high- and low-water limits for write flow control.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_21set_write_buffer_limits(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_20set_write_buffer_limits[] = "_SSLProtocolTransport.set_write_buffer_limits(self, high=None, low=None)\nSet the high- and low-water limits for write flow control.\n\n        These two values control when to call the protocol's\n        pause_writing() and resume_writing() methods.  If specified,\n        the low-water limit must be less than or equal to the\n        high-water limit.  Neither value can be negative.\n\n        The defaults are implementation-specific.  If only the\n        high-water limit is given, the low-water limit defaults to an\n        implementation-specific value less than or equal to the\n        high-water limit.  Setting high to zero forces low to zero as\n        well, and causes pause_writing() to be called whenever the\n        buffer becomes non-empty.  Setting low to zero causes\n        resume_writing() to be called only once the buffer is empty.\n        Use of zero for either limit is generally sub-optimal as it\n        reduces opportunities for doing I/O and computation\n        concurrently.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_21set_write_buffer_limits = {"set_write_buffer_limits", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_21set_write_buffer_limits, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_20set_write_buffer_limits};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_21set_write_buffer_limits(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_high = 0;
  PyObject *__pyx_v_low = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_write_buffer_limits (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_high_2,&__pyx_n_s_low,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_high_2);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_low);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set_write_buffer_limits") < 0)) __PYX_ERR(0, 331, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_high = values[1];
    __pyx_v_low = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_write_buffer_limits", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 331, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.set_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_20set_write_buffer_limits(__pyx_self, __pyx_v_self, __pyx_v_high, __pyx_v_low);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_20set_write_buffer_limits(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_high, PyObject *__pyx_v_low) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("set_write_buffer_limits", 0);

  /* "uvloop/sslproto.pyx":350
 *         concurrently.
 *         """
 *         self._ssl_protocol._transport.set_write_buffer_limits(high, low)             # <<<<<<<<<<<<<<
 * 
 *     def get_write_buffer_size(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_set_write_buffer_limits); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_high, __pyx_v_low};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_high, __pyx_v_low};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_high);
    __Pyx_GIVEREF(__pyx_v_high);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_high);
    __Pyx_INCREF(__pyx_v_low);
    __Pyx_GIVEREF(__pyx_v_low);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_low);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":331
 *         self._ssl_protocol._transport.resume_reading()
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         """Set the high- and low-water limits for write flow control.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.set_write_buffer_limits", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":352
 *         self._ssl_protocol._transport.set_write_buffer_limits(high, low)
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         """Return the current size of the write buffer."""
 *         return self._ssl_protocol._transport.get_write_buffer_size()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_23get_write_buffer_size(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_22get_write_buffer_size[] = "_SSLProtocolTransport.get_write_buffer_size(self)\nReturn the current size of the write buffer.";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_23get_write_buffer_size = {"get_write_buffer_size", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_23get_write_buffer_size, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_22get_write_buffer_size};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_23get_write_buffer_size(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_write_buffer_size (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_22get_write_buffer_size(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_22get_write_buffer_size(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("get_write_buffer_size", 0);

  /* "uvloop/sslproto.pyx":354
 *     def get_write_buffer_size(self):
 *         """Return the current size of the write buffer."""
 *         return self._ssl_protocol._transport.get_write_buffer_size()             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get_write_buffer_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 354, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 354, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":352
 *         self._ssl_protocol._transport.set_write_buffer_limits(high, low)
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         """Return the current size of the write buffer."""
 *         return self._ssl_protocol._transport.get_write_buffer_size()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.get_write_buffer_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":357
 * 
 *     @property
 *     def _protocol_paused(self):             # <<<<<<<<<<<<<<
 *         # Required for sendfile fallback pause_writing/resume_writing logic
 *         return self._ssl_protocol._transport._protocol_paused
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_25_protocol_paused(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_24_protocol_paused[] = "_SSLProtocolTransport._protocol_paused(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_25_protocol_paused = {"_protocol_paused", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_25_protocol_paused, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_24_protocol_paused};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_25_protocol_paused(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_protocol_paused (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_24_protocol_paused(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_24_protocol_paused(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_protocol_paused", 0);

  /* "uvloop/sslproto.pyx":359
 *     def _protocol_paused(self):
 *         # Required for sendfile fallback pause_writing/resume_writing logic
 *         return self._ssl_protocol._transport._protocol_paused             # <<<<<<<<<<<<<<
 * 
 *     def write(self, data):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_protocol_paused); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":357
 * 
 *     @property
 *     def _protocol_paused(self):             # <<<<<<<<<<<<<<
 *         # Required for sendfile fallback pause_writing/resume_writing logic
 *         return self._ssl_protocol._transport._protocol_paused
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport._protocol_paused", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":361
 *         return self._ssl_protocol._transport._protocol_paused
 * 
 *     def write(self, data):             # <<<<<<<<<<<<<<
 *         """Write some data bytes to the transport.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_27write(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_26write[] = "_SSLProtocolTransport.write(self, data)\nWrite some data bytes to the transport.\n\n        This does not block; it buffers the data and arranges for it\n        to be sent out asynchronously.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_27write = {"write", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_27write, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_26write};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_27write(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_data,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("write", 1, 2, 2, 1); __PYX_ERR(0, 361, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "write") < 0)) __PYX_ERR(0, 361, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("write", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 361, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_26write(__pyx_self, __pyx_v_self, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_26write(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("write", 0);

  /* "uvloop/sslproto.pyx":367
 *         to be sent out asynchronously.
 *         """
 *         if not isinstance(data, (bytes, bytearray, memoryview)):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"data: expecting a bytes-like instance, "
 *                             f"got {type(data).__name__}")
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyBytes_Check(__pyx_v_data); 
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (!__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyByteArray_Check(__pyx_v_data); 
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_data, __pyx_t_1); 
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = ((!(__pyx_t_2 != 0)) != 0);
  if (unlikely(__pyx_t_4)) {

    /* "uvloop/sslproto.pyx":369
 *         if not isinstance(data, (bytes, bytearray, memoryview)):
 *             raise TypeError(f"data: expecting a bytes-like instance, "
 *                             f"got {type(data).__name__}")             # <<<<<<<<<<<<<<
 *         if not data:
 *             return
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_data)), __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":368
 *         """
 *         if not isinstance(data, (bytes, bytearray, memoryview)):
 *             raise TypeError(f"data: expecting a bytes-like instance, "             # <<<<<<<<<<<<<<
 *                             f"got {type(data).__name__}")
 *         if not data:
 */
    __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_kp_u_data_expecting_a_bytes_like_inst, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 368, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(0, 368, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":367
 *         to be sent out asynchronously.
 *         """
 *         if not isinstance(data, (bytes, bytearray, memoryview)):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"data: expecting a bytes-like instance, "
 *                             f"got {type(data).__name__}")
 */
  }

  /* "uvloop/sslproto.pyx":370
 *             raise TypeError(f"data: expecting a bytes-like instance, "
 *                             f"got {type(data).__name__}")
 *         if not data:             # <<<<<<<<<<<<<<
 *             return
 *         self._ssl_protocol._write_appdata(data)
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 370, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_4) != 0);
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":371
 *                             f"got {type(data).__name__}")
 *         if not data:
 *             return             # <<<<<<<<<<<<<<
 *         self._ssl_protocol._write_appdata(data)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":370
 *             raise TypeError(f"data: expecting a bytes-like instance, "
 *                             f"got {type(data).__name__}")
 *         if not data:             # <<<<<<<<<<<<<<
 *             return
 *         self._ssl_protocol._write_appdata(data)
 */
  }

  /* "uvloop/sslproto.pyx":372
 *         if not data:
 *             return
 *         self._ssl_protocol._write_appdata(data)             # <<<<<<<<<<<<<<
 * 
 *     def can_write_eof(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_write_appdata); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  if (!__pyx_t_1) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 372, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_data};
      __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 372, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_data};
      __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 372, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_5);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 372, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
      __Pyx_INCREF(__pyx_v_data);
      __Pyx_GIVEREF(__pyx_v_data);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_data);
      __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 372, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/sslproto.pyx":361
 *         return self._ssl_protocol._transport._protocol_paused
 * 
 *     def write(self, data):             # <<<<<<<<<<<<<<
 *         """Write some data bytes to the transport.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":374
 *         self._ssl_protocol._write_appdata(data)
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         """Return True if this transport supports write_eof(), False if not."""
 *         return False
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_29can_write_eof(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_28can_write_eof[] = "_SSLProtocolTransport.can_write_eof(self)\nReturn True if this transport supports write_eof(), False if not.";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_29can_write_eof = {"can_write_eof", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_29can_write_eof, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_28can_write_eof};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_29can_write_eof(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("can_write_eof (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_28can_write_eof(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_28can_write_eof(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("can_write_eof", 0);

  /* "uvloop/sslproto.pyx":376
 *     def can_write_eof(self):
 *         """Return True if this transport supports write_eof(), False if not."""
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     def abort(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "uvloop/sslproto.pyx":374
 *         self._ssl_protocol._write_appdata(data)
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         """Return True if this transport supports write_eof(), False if not."""
 *         return False
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":378
 *         return False
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         """Close the transport immediately.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_31abort(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_30abort[] = "_SSLProtocolTransport.abort(self)\nClose the transport immediately.\n\n        Buffered data will be lost.  No more data will be received.\n        The protocol's connection_lost() method will (eventually) be\n        called with None as its argument.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_31abort = {"abort", (PyCFunction)__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_31abort, METH_O, __pyx_doc_6uvloop_4loop_21_SSLProtocolTransport_30abort};
static PyObject *__pyx_pw_6uvloop_4loop_21_SSLProtocolTransport_31abort(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("abort (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_30abort(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_21_SSLProtocolTransport_30abort(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("abort", 0);

  /* "uvloop/sslproto.pyx":385
 *         called with None as its argument.
 *         """
 *         self._ssl_protocol._abort()             # <<<<<<<<<<<<<<
 *         self._closed = True
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_protocol_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_abort); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 385, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 385, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":386
 *         """
 *         self._ssl_protocol._abort()
 *         self._closed = True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_closed, Py_True) < 0) __PYX_ERR(0, 386, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":378
 *         return False
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         """Close the transport immediately.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop._SSLProtocolTransport.abort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":396
 *     """
 * 
 *     def __init__(self, loop, app_protocol, sslcontext, waiter,             # <<<<<<<<<<<<<<
 *                  server_side=False, server_hostname=None,
 *                  call_connection_made=True,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol___init__[] = "SSLProtocol.__init__(self, loop, app_protocol, sslcontext, waiter, server_side=False, server_hostname=None, call_connection_made=True, ssl_handshake_timeout=None)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_1__init__ = {"__init__", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_1__init__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol___init__};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_loop = 0;
  PyObject *__pyx_v_app_protocol = 0;
  PyObject *__pyx_v_sslcontext = 0;
  PyObject *__pyx_v_waiter = 0;
  PyObject *__pyx_v_server_side = 0;
  PyObject *__pyx_v_server_hostname = 0;
  PyObject *__pyx_v_call_connection_made = 0;
  PyObject *__pyx_v_ssl_handshake_timeout = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_loop,&__pyx_n_s_app_protocol_2,&__pyx_n_s_sslcontext,&__pyx_n_s_waiter,&__pyx_n_s_server_side,&__pyx_n_s_server_hostname,&__pyx_n_s_call_connection_made,&__pyx_n_s_ssl_handshake_timeout,0};
    PyObject* values[9] = {0,0,0,0,0,0,0,0,0};

    /* "uvloop/sslproto.pyx":397
 * 
 *     def __init__(self, loop, app_protocol, sslcontext, waiter,
 *                  server_side=False, server_hostname=None,             # <<<<<<<<<<<<<<
 *                  call_connection_made=True,
 *                  ssl_handshake_timeout=None):
 */
    values[5] = ((PyObject *)((PyObject *)Py_False));
    values[6] = ((PyObject *)((PyObject *)Py_None));

    /* "uvloop/sslproto.pyx":398
 *     def __init__(self, loop, app_protocol, sslcontext, waiter,
 *                  server_side=False, server_hostname=None,
 *                  call_connection_made=True,             # <<<<<<<<<<<<<<
 *                  ssl_handshake_timeout=None):
 *         if ssl_handshake_timeout is None:
 */
    values[7] = ((PyObject *)((PyObject *)Py_True));

    /* "uvloop/sslproto.pyx":399
 *                  server_side=False, server_hostname=None,
 *                  call_connection_made=True,
 *                  ssl_handshake_timeout=None):             # <<<<<<<<<<<<<<
 *         if ssl_handshake_timeout is None:
 *             ssl_handshake_timeout = SSL_HANDSHAKE_TIMEOUT
 */
    values[8] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 5, 9, 1); __PYX_ERR(0, 396, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_app_protocol_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 5, 9, 2); __PYX_ERR(0, 396, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sslcontext)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 5, 9, 3); __PYX_ERR(0, 396, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_waiter)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 5, 9, 4); __PYX_ERR(0, 396, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_server_side);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_server_hostname);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_call_connection_made);
          if (value) { values[7] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ssl_handshake_timeout);
          if (value) { values[8] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 396, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_loop = values[1];
    __pyx_v_app_protocol = values[2];
    __pyx_v_sslcontext = values[3];
    __pyx_v_waiter = values[4];
    __pyx_v_server_side = values[5];
    __pyx_v_server_hostname = values[6];
    __pyx_v_call_connection_made = values[7];
    __pyx_v_ssl_handshake_timeout = values[8];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 5, 9, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 396, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol___init__(__pyx_self, __pyx_v_self, __pyx_v_loop, __pyx_v_app_protocol, __pyx_v_sslcontext, __pyx_v_waiter, __pyx_v_server_side, __pyx_v_server_hostname, __pyx_v_call_connection_made, __pyx_v_ssl_handshake_timeout);

  /* "uvloop/sslproto.pyx":396
 *     """
 * 
 *     def __init__(self, loop, app_protocol, sslcontext, waiter,             # <<<<<<<<<<<<<<
 *                  server_side=False, server_hostname=None,
 *                  call_connection_made=True,
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_loop, PyObject *__pyx_v_app_protocol, PyObject *__pyx_v_sslcontext, PyObject *__pyx_v_waiter, PyObject *__pyx_v_server_side, PyObject *__pyx_v_server_hostname, PyObject *__pyx_v_call_connection_made, PyObject *__pyx_v_ssl_handshake_timeout) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_sslcontext);
  __Pyx_INCREF(__pyx_v_ssl_handshake_timeout);

  /* "uvloop/sslproto.pyx":400
 *                  call_connection_made=True,
 *                  ssl_handshake_timeout=None):
 *         if ssl_handshake_timeout is None:             # <<<<<<<<<<<<<<
 *             ssl_handshake_timeout = SSL_HANDSHAKE_TIMEOUT
 *         elif ssl_handshake_timeout <= 0:
 */
  __pyx_t_1 = (__pyx_v_ssl_handshake_timeout == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":401
 *                  ssl_handshake_timeout=None):
 *         if ssl_handshake_timeout is None:
 *             ssl_handshake_timeout = SSL_HANDSHAKE_TIMEOUT             # <<<<<<<<<<<<<<
 *         elif ssl_handshake_timeout <= 0:
 *             raise ValueError(
 */
    __Pyx_INCREF(__pyx_float_60_0);
    __Pyx_DECREF_SET(__pyx_v_ssl_handshake_timeout, __pyx_float_60_0);

    /* "uvloop/sslproto.pyx":400
 *                  call_connection_made=True,
 *                  ssl_handshake_timeout=None):
 *         if ssl_handshake_timeout is None:             # <<<<<<<<<<<<<<
 *             ssl_handshake_timeout = SSL_HANDSHAKE_TIMEOUT
 *         elif ssl_handshake_timeout <= 0:
 */
    goto __pyx_L3;
  }

  /* "uvloop/sslproto.pyx":402
 *         if ssl_handshake_timeout is None:
 *             ssl_handshake_timeout = SSL_HANDSHAKE_TIMEOUT
 *         elif ssl_handshake_timeout <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 f"ssl_handshake_timeout should be a positive number, "
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_ssl_handshake_timeout, __pyx_int_0, Py_LE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 402, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 402, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/sslproto.pyx":405
 *             raise ValueError(
 *                 f"ssl_handshake_timeout should be a positive number, "
 *                 f"got {ssl_handshake_timeout}")             # <<<<<<<<<<<<<<
 * 
 *         if not sslcontext:
 */
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_v_ssl_handshake_timeout, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 405, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/sslproto.pyx":404
 *         elif ssl_handshake_timeout <= 0:
 *             raise ValueError(
 *                 f"ssl_handshake_timeout should be a positive number, "             # <<<<<<<<<<<<<<
 *                 f"got {ssl_handshake_timeout}")
 * 
 */
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_ssl_handshake_timeout_should_be, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/sslproto.pyx":403
 *             ssl_handshake_timeout = SSL_HANDSHAKE_TIMEOUT
 *         elif ssl_handshake_timeout <= 0:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 f"ssl_handshake_timeout should be a positive number, "
 *                 f"got {ssl_handshake_timeout}")
 */
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 403, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 403, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":402
 *         if ssl_handshake_timeout is None:
 *             ssl_handshake_timeout = SSL_HANDSHAKE_TIMEOUT
 *         elif ssl_handshake_timeout <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 f"ssl_handshake_timeout should be a positive number, "
 */
  }
  __pyx_L3:;

  /* "uvloop/sslproto.pyx":407
 *                 f"got {ssl_handshake_timeout}")
 * 
 *         if not sslcontext:             # <<<<<<<<<<<<<<
 *             sslcontext = _create_transport_context(
 *                 server_side, server_hostname)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_sslcontext); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 407, __pyx_L1_error)
  __pyx_t_1 = ((!__pyx_t_2) != 0);
  if (__pyx_t_1) {

    /* "uvloop/sslproto.pyx":408
 * 
 *         if not sslcontext:
 *             sslcontext = _create_transport_context(             # <<<<<<<<<<<<<<
 *                 server_side, server_hostname)
 * 
 */
    __pyx_t_3 = __pyx_f_6uvloop_4loop__create_transport_context(__pyx_v_server_side, __pyx_v_server_hostname); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_sslcontext, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/sslproto.pyx":407
 *                 f"got {ssl_handshake_timeout}")
 * 
 *         if not sslcontext:             # <<<<<<<<<<<<<<
 *             sslcontext = _create_transport_context(
 *                 server_side, server_hostname)
 */
  }

  /* "uvloop/sslproto.pyx":411
 *                 server_side, server_hostname)
 * 
 *         self._server_side = server_side             # <<<<<<<<<<<<<<
 *         if server_hostname and not server_side:
 *             self._server_hostname = server_hostname
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_server_side_2, __pyx_v_server_side) < 0) __PYX_ERR(0, 411, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":412
 * 
 *         self._server_side = server_side
 *         if server_hostname and not server_side:             # <<<<<<<<<<<<<<
 *             self._server_hostname = server_hostname
 *         else:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_server_hostname); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 412, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_server_side); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 412, __pyx_L1_error)
  __pyx_t_5 = ((!__pyx_t_2) != 0);
  __pyx_t_1 = __pyx_t_5;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/sslproto.pyx":413
 *         self._server_side = server_side
 *         if server_hostname and not server_side:
 *             self._server_hostname = server_hostname             # <<<<<<<<<<<<<<
 *         else:
 *             self._server_hostname = None
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_server_hostname_2, __pyx_v_server_hostname) < 0) __PYX_ERR(0, 413, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":412
 * 
 *         self._server_side = server_side
 *         if server_hostname and not server_side:             # <<<<<<<<<<<<<<
 *             self._server_hostname = server_hostname
 *         else:
 */
    goto __pyx_L5;
  }

  /* "uvloop/sslproto.pyx":415
 *             self._server_hostname = server_hostname
 *         else:
 *             self._server_hostname = None             # <<<<<<<<<<<<<<
 *         self._sslcontext = sslcontext
 *         # SSL-specific extra info. More info are set when the handshake
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_server_hostname_2, Py_None) < 0) __PYX_ERR(0, 415, __pyx_L1_error)
  }
  __pyx_L5:;

  /* "uvloop/sslproto.pyx":416
 *         else:
 *             self._server_hostname = None
 *         self._sslcontext = sslcontext             # <<<<<<<<<<<<<<
 *         # SSL-specific extra info. More info are set when the handshake
 *         # completes.
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_sslcontext_2, __pyx_v_sslcontext) < 0) __PYX_ERR(0, 416, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":419
 *         # SSL-specific extra info. More info are set when the handshake
 *         # completes.
 *         self._extra = dict(sslcontext=sslcontext)             # <<<<<<<<<<<<<<
 * 
 *         # App data write buffering
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_sslcontext, __pyx_v_sslcontext) < 0) __PYX_ERR(0, 419, __pyx_L1_error)
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_extra, __pyx_t_3) < 0) __PYX_ERR(0, 419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":422
 * 
 *         # App data write buffering
 *         self._write_backlog = col_deque()             # <<<<<<<<<<<<<<
 *         self._write_buffer_size = 0
 * 
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_col_deque);
  __pyx_t_4 = __pyx_v_6uvloop_4loop_col_deque; __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 422, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 422, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_write_backlog, __pyx_t_3) < 0) __PYX_ERR(0, 422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":423
 *         # App data write buffering
 *         self._write_backlog = col_deque()
 *         self._write_buffer_size = 0             # <<<<<<<<<<<<<<
 * 
 *         self._waiter = waiter
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_write_buffer_size, __pyx_int_0) < 0) __PYX_ERR(0, 423, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":425
 *         self._write_buffer_size = 0
 * 
 *         self._waiter = waiter             # <<<<<<<<<<<<<<
 *         self._loop = loop
 *         self._set_app_protocol(app_protocol)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_waiter_2, __pyx_v_waiter) < 0) __PYX_ERR(0, 425, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":426
 * 
 *         self._waiter = waiter
 *         self._loop = loop             # <<<<<<<<<<<<<<
 *         self._set_app_protocol(app_protocol)
 *         self._app_transport = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_loop_2, __pyx_v_loop) < 0) __PYX_ERR(0, 426, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":427
 *         self._waiter = waiter
 *         self._loop = loop
 *         self._set_app_protocol(app_protocol)             # <<<<<<<<<<<<<<
 *         self._app_transport = None
 *         # _SSLPipe instance (None until the connection is made)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_set_app_protocol); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_app_protocol); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_app_protocol};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v_app_protocol};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 427, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v_app_protocol);
      __Pyx_GIVEREF(__pyx_v_app_protocol);
      PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_v_app_protocol);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 427, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":428
 *         self._loop = loop
 *         self._set_app_protocol(app_protocol)
 *         self._app_transport = None             # <<<<<<<<<<<<<<
 *         # _SSLPipe instance (None until the connection is made)
 *         self._sslpipe = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_app_transport, Py_None) < 0) __PYX_ERR(0, 428, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":430
 *         self._app_transport = None
 *         # _SSLPipe instance (None until the connection is made)
 *         self._sslpipe = None             # <<<<<<<<<<<<<<
 *         self._session_established = False
 *         self._in_handshake = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe, Py_None) < 0) __PYX_ERR(0, 430, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":431
 *         # _SSLPipe instance (None until the connection is made)
 *         self._sslpipe = None
 *         self._session_established = False             # <<<<<<<<<<<<<<
 *         self._in_handshake = False
 *         self._in_shutdown = False
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_session_established, Py_False) < 0) __PYX_ERR(0, 431, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":432
 *         self._sslpipe = None
 *         self._session_established = False
 *         self._in_handshake = False             # <<<<<<<<<<<<<<
 *         self._in_shutdown = False
 *         # transport, ex: SelectorSocketTransport
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_in_handshake, Py_False) < 0) __PYX_ERR(0, 432, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":433
 *         self._session_established = False
 *         self._in_handshake = False
 *         self._in_shutdown = False             # <<<<<<<<<<<<<<
 *         # transport, ex: SelectorSocketTransport
 *         self._transport = None
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_in_shutdown, Py_False) < 0) __PYX_ERR(0, 433, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":435
 *         self._in_shutdown = False
 *         # transport, ex: SelectorSocketTransport
 *         self._transport = None             # <<<<<<<<<<<<<<
 *         self._call_connection_made = call_connection_made
 *         self._ssl_handshake_timeout = ssl_handshake_timeout
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_transport_3, Py_None) < 0) __PYX_ERR(0, 435, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":436
 *         # transport, ex: SelectorSocketTransport
 *         self._transport = None
 *         self._call_connection_made = call_connection_made             # <<<<<<<<<<<<<<
 *         self._ssl_handshake_timeout = ssl_handshake_timeout
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_call_connection_made_2, __pyx_v_call_connection_made) < 0) __PYX_ERR(0, 436, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":437
 *         self._transport = None
 *         self._call_connection_made = call_connection_made
 *         self._ssl_handshake_timeout = ssl_handshake_timeout             # <<<<<<<<<<<<<<
 * 
 *     def _set_app_protocol(self, app_protocol):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_ssl_handshake_timeout_2, __pyx_v_ssl_handshake_timeout) < 0) __PYX_ERR(0, 437, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":396
 *     """
 * 
 *     def __init__(self, loop, app_protocol, sslcontext, waiter,             # <<<<<<<<<<<<<<
 *                  server_side=False, server_hostname=None,
 *                  call_connection_made=True,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sslcontext);
  __Pyx_XDECREF(__pyx_v_ssl_handshake_timeout);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":439
 *         self._ssl_handshake_timeout = ssl_handshake_timeout
 * 
 *     def _set_app_protocol(self, app_protocol):             # <<<<<<<<<<<<<<
 *         self._app_protocol = app_protocol
 *         self._app_protocol_is_buffer = (
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_3_set_app_protocol(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_2_set_app_protocol[] = "SSLProtocol._set_app_protocol(self, app_protocol)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_3_set_app_protocol = {"_set_app_protocol", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_3_set_app_protocol, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_2_set_app_protocol};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_3_set_app_protocol(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_app_protocol = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_set_app_protocol (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_app_protocol_2,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_app_protocol_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_set_app_protocol", 1, 2, 2, 1); __PYX_ERR(0, 439, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_set_app_protocol") < 0)) __PYX_ERR(0, 439, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_app_protocol = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_set_app_protocol", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 439, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._set_app_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_2_set_app_protocol(__pyx_self, __pyx_v_self, __pyx_v_app_protocol);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_2_set_app_protocol(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_app_protocol) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_set_app_protocol", 0);

  /* "uvloop/sslproto.pyx":440
 * 
 *     def _set_app_protocol(self, app_protocol):
 *         self._app_protocol = app_protocol             # <<<<<<<<<<<<<<
 *         self._app_protocol_is_buffer = (
 *             not hasattr(app_protocol, 'data_received') and
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol, __pyx_v_app_protocol) < 0) __PYX_ERR(0, 440, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":442
 *         self._app_protocol = app_protocol
 *         self._app_protocol_is_buffer = (
 *             not hasattr(app_protocol, 'data_received') and             # <<<<<<<<<<<<<<
 *             hasattr(app_protocol, 'get_buffer')
 *         )
 */
  __pyx_t_2 = __Pyx_HasAttr(__pyx_v_app_protocol, __pyx_n_u_data_received); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 442, __pyx_L1_error)
  __pyx_t_3 = (!(__pyx_t_2 != 0));
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L3_bool_binop_done;
  }

  /* "uvloop/sslproto.pyx":443
 *         self._app_protocol_is_buffer = (
 *             not hasattr(app_protocol, 'data_received') and
 *             hasattr(app_protocol, 'get_buffer')             # <<<<<<<<<<<<<<
 *         )
 * 
 */
  __pyx_t_3 = __Pyx_HasAttr(__pyx_v_app_protocol, __pyx_n_u_get_buffer); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 443, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __pyx_t_4;
  __pyx_t_4 = 0;
  __pyx_L3_bool_binop_done:;

  /* "uvloop/sslproto.pyx":441
 *     def _set_app_protocol(self, app_protocol):
 *         self._app_protocol = app_protocol
 *         self._app_protocol_is_buffer = (             # <<<<<<<<<<<<<<
 *             not hasattr(app_protocol, 'data_received') and
 *             hasattr(app_protocol, 'get_buffer')
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol_is_buffer, __pyx_t_1) < 0) __PYX_ERR(0, 441, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":439
 *         self._ssl_handshake_timeout = ssl_handshake_timeout
 * 
 *     def _set_app_protocol(self, app_protocol):             # <<<<<<<<<<<<<<
 *         self._app_protocol = app_protocol
 *         self._app_protocol_is_buffer = (
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._set_app_protocol", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":446
 *         )
 * 
 *     def _wakeup_waiter(self, exc=None):             # <<<<<<<<<<<<<<
 *         if self._waiter is None:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_5_wakeup_waiter(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_4_wakeup_waiter[] = "SSLProtocol._wakeup_waiter(self, exc=None)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_5_wakeup_waiter = {"_wakeup_waiter", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_5_wakeup_waiter, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_4_wakeup_waiter};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_5_wakeup_waiter(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exc = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_wakeup_waiter (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_exc,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_exc);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_wakeup_waiter") < 0)) __PYX_ERR(0, 446, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exc = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_wakeup_waiter", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 446, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._wakeup_waiter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_4_wakeup_waiter(__pyx_self, __pyx_v_self, __pyx_v_exc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_4_wakeup_waiter(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_wakeup_waiter", 0);

  /* "uvloop/sslproto.pyx":447
 * 
 *     def _wakeup_waiter(self, exc=None):
 *         if self._waiter is None:             # <<<<<<<<<<<<<<
 *             return
 *         if not self._waiter.cancelled():
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_waiter_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/sslproto.pyx":448
 *     def _wakeup_waiter(self, exc=None):
 *         if self._waiter is None:
 *             return             # <<<<<<<<<<<<<<
 *         if not self._waiter.cancelled():
 *             if exc is not None:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":447
 * 
 *     def _wakeup_waiter(self, exc=None):
 *         if self._waiter is None:             # <<<<<<<<<<<<<<
 *             return
 *         if not self._waiter.cancelled():
 */
  }

  /* "uvloop/sslproto.pyx":449
 *         if self._waiter is None:
 *             return
 *         if not self._waiter.cancelled():             # <<<<<<<<<<<<<<
 *             if exc is not None:
 *                 self._waiter.set_exception(exc)
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_waiter_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_cancelled); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((!__pyx_t_3) != 0);
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":450
 *             return
 *         if not self._waiter.cancelled():
 *             if exc is not None:             # <<<<<<<<<<<<<<
 *                 self._waiter.set_exception(exc)
 *             else:
 */
    __pyx_t_2 = (__pyx_v_exc != Py_None);
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "uvloop/sslproto.pyx":451
 *         if not self._waiter.cancelled():
 *             if exc is not None:
 *                 self._waiter.set_exception(exc)             # <<<<<<<<<<<<<<
 *             else:
 *                 self._waiter.set_result(None)
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_waiter_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_set_exception); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_exc};
          __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_exc};
          __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_1);
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 451, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_GIVEREF(__pyx_v_exc);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_exc);
          __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/sslproto.pyx":450
 *             return
 *         if not self._waiter.cancelled():
 *             if exc is not None:             # <<<<<<<<<<<<<<
 *                 self._waiter.set_exception(exc)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "uvloop/sslproto.pyx":453
 *                 self._waiter.set_exception(exc)
 *             else:
 *                 self._waiter.set_result(None)             # <<<<<<<<<<<<<<
 *         self._waiter = None
 * 
 */
    /*else*/ {
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_waiter_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_set_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__259, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "uvloop/sslproto.pyx":449
 *         if self._waiter is None:
 *             return
 *         if not self._waiter.cancelled():             # <<<<<<<<<<<<<<
 *             if exc is not None:
 *                 self._waiter.set_exception(exc)
 */
  }

  /* "uvloop/sslproto.pyx":454
 *             else:
 *                 self._waiter.set_result(None)
 *         self._waiter = None             # <<<<<<<<<<<<<<
 * 
 *     def connection_made(self, transport):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_waiter_2, Py_None) < 0) __PYX_ERR(0, 454, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":446
 *         )
 * 
 *     def _wakeup_waiter(self, exc=None):             # <<<<<<<<<<<<<<
 *         if self._waiter is None:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._wakeup_waiter", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":456
 *         self._waiter = None
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is made.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_7connection_made(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_6connection_made[] = "SSLProtocol.connection_made(self, transport)\nCalled when the low-level connection is made.\n\n        Start the SSL handshake.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_7connection_made = {"connection_made", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_7connection_made, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_6connection_made};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_7connection_made(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_transport = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connection_made (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_transport,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_transport)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("connection_made", 1, 2, 2, 1); __PYX_ERR(0, 456, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "connection_made") < 0)) __PYX_ERR(0, 456, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_transport = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connection_made", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 456, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_6connection_made(__pyx_self, __pyx_v_self, __pyx_v_transport);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_6connection_made(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_transport) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("connection_made", 0);

  /* "uvloop/sslproto.pyx":461
 *         Start the SSL handshake.
 *         """
 *         self._transport = transport             # <<<<<<<<<<<<<<
 *         self._sslpipe = _SSLPipe(self._sslcontext,
 *                                  self._server_side,
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_transport_3, __pyx_v_transport) < 0) __PYX_ERR(0, 461, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":462
 *         """
 *         self._transport = transport
 *         self._sslpipe = _SSLPipe(self._sslcontext,             # <<<<<<<<<<<<<<
 *                                  self._server_side,
 *                                  self._server_hostname)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_sslcontext_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/sslproto.pyx":463
 *         self._transport = transport
 *         self._sslpipe = _SSLPipe(self._sslcontext,
 *                                  self._server_side,             # <<<<<<<<<<<<<<
 *                                  self._server_hostname)
 *         self._start_handshake()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_server_side_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/sslproto.pyx":464
 *         self._sslpipe = _SSLPipe(self._sslcontext,
 *                                  self._server_side,
 *                                  self._server_hostname)             # <<<<<<<<<<<<<<
 *         self._start_handshake()
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_server_hostname_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "uvloop/sslproto.pyx":462
 *         """
 *         self._transport = transport
 *         self._sslpipe = _SSLPipe(self._sslcontext,             # <<<<<<<<<<<<<<
 *                                  self._server_side,
 *                                  self._server_hostname)
 */
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop__SSLPipe), __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe, __pyx_t_3) < 0) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":465
 *                                  self._server_side,
 *                                  self._server_hostname)
 *         self._start_handshake()             # <<<<<<<<<<<<<<
 * 
 *     def connection_lost(self, exc):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_start_handshake); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 465, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":456
 *         self._waiter = None
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is made.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.connection_made", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":467
 *         self._start_handshake()
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is lost or closed.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_9connection_lost(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_8connection_lost[] = "SSLProtocol.connection_lost(self, exc)\nCalled when the low-level connection is lost or closed.\n\n        The argument is an exception object or None (the latter\n        meaning a regular EOF is received or the connection was\n        aborted or closed).\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_9connection_lost = {"connection_lost", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_9connection_lost, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_8connection_lost};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_9connection_lost(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exc = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connection_lost (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_exc,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_exc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("connection_lost", 1, 2, 2, 1); __PYX_ERR(0, 467, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "connection_lost") < 0)) __PYX_ERR(0, 467, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_exc = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connection_lost", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 467, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.connection_lost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_8connection_lost(__pyx_self, __pyx_v_self, __pyx_v_exc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_8connection_lost(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("connection_lost", 0);

  /* "uvloop/sslproto.pyx":474
 *         aborted or closed).
 *         """
 *         if self._session_established:             # <<<<<<<<<<<<<<
 *             self._session_established = False
 *             self._loop.call_soon(self._app_protocol.connection_lost, exc)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_session_established); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":475
 *         """
 *         if self._session_established:
 *             self._session_established = False             # <<<<<<<<<<<<<<
 *             self._loop.call_soon(self._app_protocol.connection_lost, exc)
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_session_established, Py_False) < 0) __PYX_ERR(0, 475, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":476
 *         if self._session_established:
 *             self._session_established = False
 *             self._loop.call_soon(self._app_protocol.connection_lost, exc)             # <<<<<<<<<<<<<<
 * 
 *         self._transport = None
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_call_soon); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_connection_lost); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 476, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_5, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_5, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_t_5);
      __Pyx_INCREF(__pyx_v_exc);
      __Pyx_GIVEREF(__pyx_v_exc);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_exc);
      __pyx_t_5 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 476, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":474
 *         aborted or closed).
 *         """
 *         if self._session_established:             # <<<<<<<<<<<<<<
 *             self._session_established = False
 *             self._loop.call_soon(self._app_protocol.connection_lost, exc)
 */
  }

  /* "uvloop/sslproto.pyx":478
 *             self._loop.call_soon(self._app_protocol.connection_lost, exc)
 * 
 *         self._transport = None             # <<<<<<<<<<<<<<
 *         self._app_transport = None
 *         self._wakeup_waiter(exc)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_transport_3, Py_None) < 0) __PYX_ERR(0, 478, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":479
 * 
 *         self._transport = None
 *         self._app_transport = None             # <<<<<<<<<<<<<<
 *         self._wakeup_waiter(exc)
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_app_transport, Py_None) < 0) __PYX_ERR(0, 479, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":480
 *         self._transport = None
 *         self._app_transport = None
 *         self._wakeup_waiter(exc)             # <<<<<<<<<<<<<<
 * 
 *     def pause_writing(self):
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wakeup_waiter); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (!__pyx_t_7) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_exc};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
      __Pyx_INCREF(__pyx_v_exc);
      __Pyx_GIVEREF(__pyx_v_exc);
      PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_exc);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":467
 *         self._start_handshake()
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is lost or closed.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.connection_lost", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":482
 *         self._wakeup_waiter(exc)
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer goes over
 *         the high-water mark.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_11pause_writing(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_10pause_writing[] = "SSLProtocol.pause_writing(self)\nCalled when the low-level transport's buffer goes over\n        the high-water mark.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_11pause_writing = {"pause_writing", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_11pause_writing, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_10pause_writing};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_11pause_writing(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pause_writing (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_10pause_writing(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_10pause_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("pause_writing", 0);

  /* "uvloop/sslproto.pyx":486
 *         the high-water mark.
 *         """
 *         self._app_protocol.pause_writing()             # <<<<<<<<<<<<<<
 * 
 *     def resume_writing(self):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_pause_writing); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 486, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":482
 *         self._wakeup_waiter(exc)
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer goes over
 *         the high-water mark.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.pause_writing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":488
 *         self._app_protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer drains below
 *         the low-water mark.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_13resume_writing(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_12resume_writing[] = "SSLProtocol.resume_writing(self)\nCalled when the low-level transport's buffer drains below\n        the low-water mark.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_13resume_writing = {"resume_writing", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_13resume_writing, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_12resume_writing};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_13resume_writing(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("resume_writing (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_12resume_writing(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_12resume_writing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("resume_writing", 0);

  /* "uvloop/sslproto.pyx":492
 *         the low-water mark.
 *         """
 *         self._app_protocol.resume_writing()             # <<<<<<<<<<<<<<
 * 
 *     def data_received(self, data):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_resume_writing); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 492, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 492, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":488
 *         self._app_protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer drains below
 *         the low-water mark.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.resume_writing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":494
 *         self._app_protocol.resume_writing()
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         """Called when some SSL data is received.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_15data_received(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_14data_received[] = "SSLProtocol.data_received(self, data)\nCalled when some SSL data is received.\n\n        The argument is a bytes object.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_15data_received = {"data_received", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_15data_received, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_14data_received};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_15data_received(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("data_received (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_data,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("data_received", 1, 2, 2, 1); __PYX_ERR(0, 494, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "data_received") < 0)) __PYX_ERR(0, 494, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("data_received", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 494, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.data_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_14data_received(__pyx_self, __pyx_v_self, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_14data_received(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_v_ssldata = NULL;
  PyObject *__pyx_v_appdata = NULL;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_v_chunk = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  int __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_UCS4 __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  char const *__pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *(*__pyx_t_25)(PyObject *);
  PyObject *__pyx_t_26 = NULL;
  char const *__pyx_t_27;
  __Pyx_RefNannySetupContext("data_received", 0);

  /* "uvloop/sslproto.pyx":499
 *         The argument is a bytes object.
 *         """
 *         if self._sslpipe is None:             # <<<<<<<<<<<<<<
 *             # transport closing, sslpipe is destroyed
 *             return
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/sslproto.pyx":501
 *         if self._sslpipe is None:
 *             # transport closing, sslpipe is destroyed
 *             return             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":499
 *         The argument is a bytes object.
 *         """
 *         if self._sslpipe is None:             # <<<<<<<<<<<<<<
 *             # transport closing, sslpipe is destroyed
 *             return
 */
  }

  /* "uvloop/sslproto.pyx":503
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             ssldata, appdata = (<_SSLPipe>self._sslpipe).feed_ssldata(data)
 *         except ssl_SSLError as e:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/sslproto.pyx":504
 * 
 *         try:
 *             ssldata, appdata = (<_SSLPipe>self._sslpipe).feed_ssldata(data)             # <<<<<<<<<<<<<<
 *         except ssl_SSLError as e:
 *             msg = (
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *)((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_t_1)->__pyx_vtab)->feed_ssldata(((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_t_1), __pyx_v_data, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 504, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_7))) || (PyList_CheckExact(__pyx_t_7))) {
        PyObject* sequence = __pyx_t_7;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 504, __pyx_L4_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        #else
        __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 504, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 504, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 504, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
        index = 0; __pyx_t_1 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_1)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_1);
        index = 1; __pyx_t_8 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_8)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_8);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 2) < 0) __PYX_ERR(0, 504, __pyx_L4_error)
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L11_unpacking_done;
        __pyx_L10_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(0, 504, __pyx_L4_error)
        __pyx_L11_unpacking_done:;
      }
      __pyx_v_ssldata = __pyx_t_1;
      __pyx_t_1 = 0;
      __pyx_v_appdata = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "uvloop/sslproto.pyx":503
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             ssldata, appdata = (<_SSLPipe>self._sslpipe).feed_ssldata(data)
 *         except ssl_SSLError as e:
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/sslproto.pyx":505
 *         try:
 *             ssldata, appdata = (<_SSLPipe>self._sslpipe).feed_ssldata(data)
 *         except ssl_SSLError as e:             # <<<<<<<<<<<<<<
 *             msg = (
 *                 f'SSL error errno:{getattr(e, "errno", "missing")} '
 */
    __pyx_t_11 = __Pyx_PyErr_ExceptionMatches(__pyx_v_6uvloop_4loop_ssl_SSLError);
    if (__pyx_t_11) {
      __Pyx_AddTraceback("uvloop.loop.SSLProtocol.data_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 505, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_8);
      __pyx_v_e = __pyx_t_8;
      /*try:*/ {

        /* "uvloop/sslproto.pyx":507
 *         except ssl_SSLError as e:
 *             msg = (
 *                 f'SSL error errno:{getattr(e, "errno", "missing")} '             # <<<<<<<<<<<<<<
 *                 f'reason: {getattr(e, "reason", "missing")}'
 *             )
 */
        __pyx_t_9 = PyTuple_New(4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 507, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_12 = 0;
        __pyx_t_13 = 127;
        __Pyx_INCREF(__pyx_kp_u_SSL_error_errno);
        __pyx_t_12 += 16;
        __Pyx_GIVEREF(__pyx_kp_u_SSL_error_errno);
        PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_kp_u_SSL_error_errno);
        __pyx_t_14 = __Pyx_GetAttr3(__pyx_v_e, __pyx_n_u_errno, __pyx_n_u_missing); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 507, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_15 = __Pyx_PyObject_FormatSimple(__pyx_t_14, __pyx_empty_unicode); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 507, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_15) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_15) : __pyx_t_13;
        __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_15);
        __Pyx_GIVEREF(__pyx_t_15);
        PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_15);
        __pyx_t_15 = 0;
        __Pyx_INCREF(__pyx_kp_u_reason_2);
        __pyx_t_12 += 9;
        __Pyx_GIVEREF(__pyx_kp_u_reason_2);
        PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_kp_u_reason_2);

        /* "uvloop/sslproto.pyx":508
 *             msg = (
 *                 f'SSL error errno:{getattr(e, "errno", "missing")} '
 *                 f'reason: {getattr(e, "reason", "missing")}'             # <<<<<<<<<<<<<<
 *             )
 *             self._fatal_error(e, msg)
 */
        __pyx_t_15 = __Pyx_GetAttr3(__pyx_v_e, __pyx_n_u_reason, __pyx_n_u_missing); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 508, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_14 = __Pyx_PyObject_FormatSimple(__pyx_t_15, __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 508, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_13 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) > __pyx_t_13) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_14) : __pyx_t_13;
        __pyx_t_12 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_9, 3, __pyx_t_14);
        __pyx_t_14 = 0;

        /* "uvloop/sslproto.pyx":507
 *         except ssl_SSLError as e:
 *             msg = (
 *                 f'SSL error errno:{getattr(e, "errno", "missing")} '             # <<<<<<<<<<<<<<
 *                 f'reason: {getattr(e, "reason", "missing")}'
 *             )
 */
        __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_9, 4, __pyx_t_12, __pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 507, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_v_msg = ((PyObject*)__pyx_t_14);
        __pyx_t_14 = 0;

        /* "uvloop/sslproto.pyx":510
 *                 f'reason: {getattr(e, "reason", "missing")}'
 *             )
 *             self._fatal_error(e, msg)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fatal_error); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 510, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_15 = NULL;
        __pyx_t_11 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_15)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
            __pyx_t_11 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_9)) {
          PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_e, __pyx_v_msg};
          __pyx_t_14 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 510, __pyx_L17_error)
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_GOTREF(__pyx_t_14);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
          PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_e, __pyx_v_msg};
          __pyx_t_14 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 510, __pyx_L17_error)
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_GOTREF(__pyx_t_14);
        } else
        #endif
        {
          __pyx_t_16 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 510, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_16);
          if (__pyx_t_15) {
            __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_15); __pyx_t_15 = NULL;
          }
          __Pyx_INCREF(__pyx_v_e);
          __Pyx_GIVEREF(__pyx_v_e);
          PyTuple_SET_ITEM(__pyx_t_16, 0+__pyx_t_11, __pyx_v_e);
          __Pyx_INCREF(__pyx_v_msg);
          __Pyx_GIVEREF(__pyx_v_msg);
          PyTuple_SET_ITEM(__pyx_t_16, 1+__pyx_t_11, __pyx_v_msg);
          __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_16, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 510, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        }
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "uvloop/sslproto.pyx":511
 *             )
 *             self._fatal_error(e, msg)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         self._transport.writelines(ssldata)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L16_return;
      }

      /* "uvloop/sslproto.pyx":505
 *         try:
 *             ssldata, appdata = (<_SSLPipe>self._sslpipe).feed_ssldata(data)
 *         except ssl_SSLError as e:             # <<<<<<<<<<<<<<
 *             msg = (
 *                 f'SSL error errno:{getattr(e, "errno", "missing")} '
 */
      /*finally:*/ {
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_23);
          __Pyx_XGOTREF(__pyx_t_24);
          __pyx_t_11 = __pyx_lineno; __pyx_t_17 = __pyx_clineno; __pyx_t_18 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e);
            __pyx_v_e = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_23);
            __Pyx_XGIVEREF(__pyx_t_24);
            __Pyx_ExceptionReset(__pyx_t_22, __pyx_t_23, __pyx_t_24);
          }
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_ErrRestore(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0;
          __pyx_lineno = __pyx_t_11; __pyx_clineno = __pyx_t_17; __pyx_filename = __pyx_t_18;
          goto __pyx_L6_except_error;
        }
        __pyx_L16_return: {
          __pyx_t_24 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_e);
          __pyx_v_e = NULL;
          __pyx_r = __pyx_t_24;
          __pyx_t_24 = 0;
          goto __pyx_L7_except_return;
        }
      }
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/sslproto.pyx":503
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             ssldata, appdata = (<_SSLPipe>self._sslpipe).feed_ssldata(data)
 *         except ssl_SSLError as e:
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L7_except_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
    __pyx_L9_try_end:;
  }

  /* "uvloop/sslproto.pyx":513
 *             return
 * 
 *         self._transport.writelines(ssldata)             # <<<<<<<<<<<<<<
 * 
 *         for chunk in appdata:
 */
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_writelines); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  if (!__pyx_t_8) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_ssldata); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_ssldata};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
      PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_ssldata};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_8); __pyx_t_8 = NULL;
      __Pyx_INCREF(__pyx_v_ssldata);
      __Pyx_GIVEREF(__pyx_v_ssldata);
      PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_v_ssldata);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_14, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":515
 *         self._transport.writelines(ssldata)
 * 
 *         for chunk in appdata:             # <<<<<<<<<<<<<<
 *             if chunk:
 *                 try:
 */
  if (likely(PyList_CheckExact(__pyx_v_appdata)) || PyTuple_CheckExact(__pyx_v_appdata)) {
    __pyx_t_1 = __pyx_v_appdata; __Pyx_INCREF(__pyx_t_1); __pyx_t_12 = 0;
    __pyx_t_25 = NULL;
  } else {
    __pyx_t_12 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_appdata); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_25 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 515, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_25)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_7); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 515, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 515, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        if (__pyx_t_12 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_12); __Pyx_INCREF(__pyx_t_7); __pyx_t_12++; if (unlikely(0 < 0)) __PYX_ERR(0, 515, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 515, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_25(__pyx_t_1);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 515, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_chunk, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/sslproto.pyx":516
 * 
 *         for chunk in appdata:
 *             if chunk:             # <<<<<<<<<<<<<<
 *                 try:
 *                     if self._app_protocol_is_buffer:
 */
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_chunk); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 516, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "uvloop/sslproto.pyx":517
 *         for chunk in appdata:
 *             if chunk:
 *                 try:             # <<<<<<<<<<<<<<
 *                     if self._app_protocol_is_buffer:
 *                         _feed_data_to_bufferred_proto(
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_5, &__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_4);
        /*try:*/ {

          /* "uvloop/sslproto.pyx":518
 *             if chunk:
 *                 try:
 *                     if self._app_protocol_is_buffer:             # <<<<<<<<<<<<<<
 *                         _feed_data_to_bufferred_proto(
 *                             self._app_protocol, chunk)
 */
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol_is_buffer); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 518, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 518, __pyx_L26_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (__pyx_t_3) {

            /* "uvloop/sslproto.pyx":520
 *                     if self._app_protocol_is_buffer:
 *                         _feed_data_to_bufferred_proto(
 *                             self._app_protocol, chunk)             # <<<<<<<<<<<<<<
 *                     else:
 *                         self._app_protocol.data_received(chunk)
 */
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 520, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_7);

            /* "uvloop/sslproto.pyx":519
 *                 try:
 *                     if self._app_protocol_is_buffer:
 *                         _feed_data_to_bufferred_proto(             # <<<<<<<<<<<<<<
 *                             self._app_protocol, chunk)
 *                     else:
 */
            __pyx_t_14 = __pyx_f_6uvloop_4loop__feed_data_to_bufferred_proto(__pyx_t_7, __pyx_v_chunk); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 519, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

            /* "uvloop/sslproto.pyx":518
 *             if chunk:
 *                 try:
 *                     if self._app_protocol_is_buffer:             # <<<<<<<<<<<<<<
 *                         _feed_data_to_bufferred_proto(
 *                             self._app_protocol, chunk)
 */
            goto __pyx_L34;
          }

          /* "uvloop/sslproto.pyx":522
 *                             self._app_protocol, chunk)
 *                     else:
 *                         self._app_protocol.data_received(chunk)             # <<<<<<<<<<<<<<
 *                 except Exception as ex:
 *                     self._fatal_error(
 */
          /*else*/ {
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 522, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_data_received); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 522, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_7 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_8, function);
              }
            }
            if (!__pyx_t_7) {
              __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_chunk); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 522, __pyx_L26_error)
              __Pyx_GOTREF(__pyx_t_14);
            } else {
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_8)) {
                PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_chunk};
                __pyx_t_14 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 522, __pyx_L26_error)
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_GOTREF(__pyx_t_14);
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
                PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_v_chunk};
                __pyx_t_14 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 522, __pyx_L26_error)
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                __Pyx_GOTREF(__pyx_t_14);
              } else
              #endif
              {
                __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 522, __pyx_L26_error)
                __Pyx_GOTREF(__pyx_t_9);
                __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_7); __pyx_t_7 = NULL;
                __Pyx_INCREF(__pyx_v_chunk);
                __Pyx_GIVEREF(__pyx_v_chunk);
                PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_v_chunk);
                __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 522, __pyx_L26_error)
                __Pyx_GOTREF(__pyx_t_14);
                __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
              }
            }
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          }
          __pyx_L34:;

          /* "uvloop/sslproto.pyx":517
 *         for chunk in appdata:
 *             if chunk:
 *                 try:             # <<<<<<<<<<<<<<
 *                     if self._app_protocol_is_buffer:
 *                         _feed_data_to_bufferred_proto(
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L33_try_end;
        __pyx_L26_error:;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "uvloop/sslproto.pyx":523
 *                     else:
 *                         self._app_protocol.data_received(chunk)
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     self._fatal_error(
 *                         ex, 'application protocol failed to receive SSL data')
 */
        __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
        if (__pyx_t_17) {
          __Pyx_AddTraceback("uvloop.loop.SSLProtocol.data_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_14, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(0, 523, __pyx_L28_except_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __pyx_v_ex = __pyx_t_8;
          /*try:*/ {

            /* "uvloop/sslproto.pyx":524
 *                         self._app_protocol.data_received(chunk)
 *                 except Exception as ex:
 *                     self._fatal_error(             # <<<<<<<<<<<<<<
 *                         ex, 'application protocol failed to receive SSL data')
 *                     return
 */
            __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fatal_error); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 524, __pyx_L40_error)
            __Pyx_GOTREF(__pyx_t_16);

            /* "uvloop/sslproto.pyx":525
 *                 except Exception as ex:
 *                     self._fatal_error(
 *                         ex, 'application protocol failed to receive SSL data')             # <<<<<<<<<<<<<<
 *                     return
 *             else:
 */
            __pyx_t_15 = NULL;
            __pyx_t_17 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
              __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
              if (likely(__pyx_t_15)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                __Pyx_INCREF(__pyx_t_15);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_16, function);
                __pyx_t_17 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_ex, __pyx_kp_u_application_protocol_failed_to_r};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_17, 2+__pyx_t_17); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 524, __pyx_L40_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_16)) {
              PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_ex, __pyx_kp_u_application_protocol_failed_to_r};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_16, __pyx_temp+1-__pyx_t_17, 2+__pyx_t_17); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 524, __pyx_L40_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            {
              __pyx_t_26 = PyTuple_New(2+__pyx_t_17); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 524, __pyx_L40_error)
              __Pyx_GOTREF(__pyx_t_26);
              if (__pyx_t_15) {
                __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_26, 0, __pyx_t_15); __pyx_t_15 = NULL;
              }
              __Pyx_INCREF(__pyx_v_ex);
              __Pyx_GIVEREF(__pyx_v_ex);
              PyTuple_SET_ITEM(__pyx_t_26, 0+__pyx_t_17, __pyx_v_ex);
              __Pyx_INCREF(__pyx_kp_u_application_protocol_failed_to_r);
              __Pyx_GIVEREF(__pyx_kp_u_application_protocol_failed_to_r);
              PyTuple_SET_ITEM(__pyx_t_26, 1+__pyx_t_17, __pyx_kp_u_application_protocol_failed_to_r);
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_26, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 524, __pyx_L40_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
            }
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "uvloop/sslproto.pyx":526
 *                     self._fatal_error(
 *                         ex, 'application protocol failed to receive SSL data')
 *                     return             # <<<<<<<<<<<<<<
 *             else:
 *                 self._start_shutdown()
 */
            __Pyx_XDECREF(__pyx_r);
            __pyx_r = Py_None; __Pyx_INCREF(Py_None);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            goto __pyx_L39_return;
          }

          /* "uvloop/sslproto.pyx":523
 *                     else:
 *                         self._app_protocol.data_received(chunk)
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     self._fatal_error(
 *                         ex, 'application protocol failed to receive SSL data')
 */
          /*finally:*/ {
            __pyx_L40_error:;
            /*exception exit:*/{
              __Pyx_PyThreadState_declare
              __Pyx_PyThreadState_assign
              __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0;
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
              if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_24, &__pyx_t_23, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_24, &__pyx_t_23, &__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_24);
              __Pyx_XGOTREF(__pyx_t_23);
              __Pyx_XGOTREF(__pyx_t_22);
              __Pyx_XGOTREF(__pyx_t_21);
              __Pyx_XGOTREF(__pyx_t_20);
              __Pyx_XGOTREF(__pyx_t_19);
              __pyx_t_17 = __pyx_lineno; __pyx_t_11 = __pyx_clineno; __pyx_t_27 = __pyx_filename;
              {
                __Pyx_DECREF(__pyx_v_ex);
                __pyx_v_ex = NULL;
              }
              if (PY_MAJOR_VERSION >= 3) {
                __Pyx_XGIVEREF(__pyx_t_21);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_20, __pyx_t_19);
              }
              __Pyx_XGIVEREF(__pyx_t_24);
              __Pyx_XGIVEREF(__pyx_t_23);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ErrRestore(__pyx_t_24, __pyx_t_23, __pyx_t_22);
              __pyx_t_24 = 0; __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0;
              __pyx_lineno = __pyx_t_17; __pyx_clineno = __pyx_t_11; __pyx_filename = __pyx_t_27;
              goto __pyx_L28_except_error;
            }
            __pyx_L39_return: {
              __pyx_t_19 = __pyx_r;
              __pyx_r = 0;
              __Pyx_DECREF(__pyx_v_ex);
              __pyx_v_ex = NULL;
              __pyx_r = __pyx_t_19;
              __pyx_t_19 = 0;
              goto __pyx_L29_except_return;
            }
          }
        }
        goto __pyx_L28_except_error;
        __pyx_L28_except_error:;

        /* "uvloop/sslproto.pyx":517
 *         for chunk in appdata:
 *             if chunk:
 *                 try:             # <<<<<<<<<<<<<<
 *                     if self._app_protocol_is_buffer:
 *                         _feed_data_to_bufferred_proto(
 */
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        goto __pyx_L1_error;
        __pyx_L29_except_return:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_5, __pyx_t_4);
        goto __pyx_L0;
        __pyx_L33_try_end:;
      }

      /* "uvloop/sslproto.pyx":516
 * 
 *         for chunk in appdata:
 *             if chunk:             # <<<<<<<<<<<<<<
 *                 try:
 *                     if self._app_protocol_is_buffer:
 */
      goto __pyx_L25;
    }

    /* "uvloop/sslproto.pyx":528
 *                     return
 *             else:
 *                 self._start_shutdown()             # <<<<<<<<<<<<<<
 *                 break
 * 
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_start_shutdown); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 528, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_14 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      if (__pyx_t_14) {
        __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_14); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 528, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      } else {
        __pyx_t_9 = __Pyx_PyObject_CallNoArg(__pyx_t_8); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 528, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "uvloop/sslproto.pyx":529
 *             else:
 *                 self._start_shutdown()
 *                 break             # <<<<<<<<<<<<<<
 * 
 *     def eof_received(self):
 */
      goto __pyx_L24_break;
    }
    __pyx_L25:;

    /* "uvloop/sslproto.pyx":515
 *         self._transport.writelines(ssldata)
 * 
 *         for chunk in appdata:             # <<<<<<<<<<<<<<
 *             if chunk:
 *                 try:
 */
  }
  __pyx_L24_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":494
 *         self._app_protocol.resume_writing()
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         """Called when some SSL data is received.
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.data_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ssldata);
  __Pyx_XDECREF(__pyx_v_appdata);
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XDECREF(__pyx_v_chunk);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":531
 *                 break
 * 
 *     def eof_received(self):             # <<<<<<<<<<<<<<
 *         """Called when the other end of the low-level stream
 *         is half-closed.
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_17eof_received(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_16eof_received[] = "SSLProtocol.eof_received(self)\nCalled when the other end of the low-level stream\n        is half-closed.\n\n        If this returns a false value (including None), the transport\n        will close itself.  If it returns a true value, closing the\n        transport is up to the protocol.\n        ";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_17eof_received = {"eof_received", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_17eof_received, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_16eof_received};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_17eof_received(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("eof_received (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_16eof_received(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_16eof_received(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_keep_open = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  char const *__pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("eof_received", 0);

  /* "uvloop/sslproto.pyx":539
 *         transport is up to the protocol.
 *         """
 *         try:             # <<<<<<<<<<<<<<
 *             if self._loop.get_debug():
 *                 aio_logger.debug("%r received EOF", self)
 */
  /*try:*/ {

    /* "uvloop/sslproto.pyx":540
 *         """
 *         try:
 *             if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *                 aio_logger.debug("%r received EOF", self)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 540, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 540, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_2) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L4_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 540, __pyx_L4_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "uvloop/sslproto.pyx":541
 *         try:
 *             if self._loop.get_debug():
 *                 aio_logger.debug("%r received EOF", self)             # <<<<<<<<<<<<<<
 * 
 *             self._wakeup_waiter(ConnectionResetError)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 541, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = NULL;
      __pyx_t_5 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
          __pyx_t_5 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_kp_u_r_received_EOF, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_kp_u_r_received_EOF, __pyx_v_self};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 541, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__pyx_t_2) {
          __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_r_received_EOF);
        __Pyx_GIVEREF(__pyx_kp_u_r_received_EOF);
        PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u_r_received_EOF);
        __Pyx_INCREF(__pyx_v_self);
        __Pyx_GIVEREF(__pyx_v_self);
        PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_self);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/sslproto.pyx":540
 *         """
 *         try:
 *             if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *                 aio_logger.debug("%r received EOF", self)
 * 
 */
    }

    /* "uvloop/sslproto.pyx":543
 *                 aio_logger.debug("%r received EOF", self)
 * 
 *             self._wakeup_waiter(ConnectionResetError)             # <<<<<<<<<<<<<<
 * 
 *             if not self._in_handshake:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wakeup_waiter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 543, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionResetError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 543, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_2) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_2, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L4_error)
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 543, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2); __pyx_t_2 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":545
 *             self._wakeup_waiter(ConnectionResetError)
 * 
 *             if not self._in_handshake:             # <<<<<<<<<<<<<<
 *                 keep_open = self._app_protocol.eof_received()
 *                 if keep_open:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_in_handshake); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 545, __pyx_L4_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_8 = ((!__pyx_t_4) != 0);
    if (__pyx_t_8) {

      /* "uvloop/sslproto.pyx":546
 * 
 *             if not self._in_handshake:
 *                 keep_open = self._app_protocol.eof_received()             # <<<<<<<<<<<<<<
 *                 if keep_open:
 *                     aio_logger.warning('returning true from eof_received() '
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 546, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_eof_received); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 546, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      if (__pyx_t_3) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L4_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_keep_open = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "uvloop/sslproto.pyx":547
 *             if not self._in_handshake:
 *                 keep_open = self._app_protocol.eof_received()
 *                 if keep_open:             # <<<<<<<<<<<<<<
 *                     aio_logger.warning('returning true from eof_received() '
 *                                        'has no effect when using ssl')
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_keep_open); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 547, __pyx_L4_error)
      if (__pyx_t_8) {

        /* "uvloop/sslproto.pyx":548
 *                 keep_open = self._app_protocol.eof_received()
 *                 if keep_open:
 *                     aio_logger.warning('returning true from eof_received() '             # <<<<<<<<<<<<<<
 *                                        'has no effect when using ssl')
 *         finally:
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_warning); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 548, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__260, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 548, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "uvloop/sslproto.pyx":547
 *             if not self._in_handshake:
 *                 keep_open = self._app_protocol.eof_received()
 *                 if keep_open:             # <<<<<<<<<<<<<<
 *                     aio_logger.warning('returning true from eof_received() '
 *                                        'has no effect when using ssl')
 */
      }

      /* "uvloop/sslproto.pyx":545
 *             self._wakeup_waiter(ConnectionResetError)
 * 
 *             if not self._in_handshake:             # <<<<<<<<<<<<<<
 *                 keep_open = self._app_protocol.eof_received()
 *                 if keep_open:
 */
    }
  }

  /* "uvloop/sslproto.pyx":551
 *                                        'has no effect when using ssl')
 *         finally:
 *             self._transport.close()             # <<<<<<<<<<<<<<
 * 
 *     def _get_extra_info(self, name, default=None):
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 551, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_1) {
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 551, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 551, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_14, &__pyx_t_15, &__pyx_t_16);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13) < 0)) __Pyx_ErrFetch(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_15);
      __Pyx_XGOTREF(__pyx_t_16);
      __pyx_t_5 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_10 = __pyx_filename;
      {
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 551, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_close); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 551, __pyx_L10_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        if (__pyx_t_3) {
          __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 551, __pyx_L10_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else {
          __pyx_t_7 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 551, __pyx_L10_error)
        }
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      }
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestore(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_10;
      goto __pyx_L1_error;
      __pyx_L10_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_15, __pyx_t_16);
      }
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_14 = 0; __pyx_t_15 = 0; __pyx_t_16 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "uvloop/sslproto.pyx":531
 *                 break
 * 
 *     def eof_received(self):             # <<<<<<<<<<<<<<
 *         """Called when the other end of the low-level stream
 *         is half-closed.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol.eof_received", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_keep_open);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":553
 *             self._transport.close()
 * 
 *     def _get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if name in self._extra:
 *             return self._extra[name]
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_19_get_extra_info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_18_get_extra_info[] = "SSLProtocol._get_extra_info(self, name, default=None)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_19_get_extra_info = {"_get_extra_info", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_19_get_extra_info, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_18_get_extra_info};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_19_get_extra_info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_default = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_extra_info (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_name_2,&__pyx_n_s_default,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name_2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_get_extra_info", 0, 2, 3, 1); __PYX_ERR(0, 553, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_default);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_get_extra_info") < 0)) __PYX_ERR(0, 553, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_name = values[1];
    __pyx_v_default = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_extra_info", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 553, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_18_get_extra_info(__pyx_self, __pyx_v_self, __pyx_v_name, __pyx_v_default);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_18_get_extra_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_name, PyObject *__pyx_v_default) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_get_extra_info", 0);

  /* "uvloop/sslproto.pyx":554
 * 
 *     def _get_extra_info(self, name, default=None):
 *         if name in self._extra:             # <<<<<<<<<<<<<<
 *             return self._extra[name]
 *         elif self._transport is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_extra); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_name, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 554, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/sslproto.pyx":555
 *     def _get_extra_info(self, name, default=None):
 *         if name in self._extra:
 *             return self._extra[name]             # <<<<<<<<<<<<<<
 *         elif self._transport is not None:
 *             return self._transport.get_extra_info(name, default)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_extra); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":554
 * 
 *     def _get_extra_info(self, name, default=None):
 *         if name in self._extra:             # <<<<<<<<<<<<<<
 *             return self._extra[name]
 *         elif self._transport is not None:
 */
  }

  /* "uvloop/sslproto.pyx":556
 *         if name in self._extra:
 *             return self._extra[name]
 *         elif self._transport is not None:             # <<<<<<<<<<<<<<
 *             return self._transport.get_extra_info(name, default)
 *         else:
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = (__pyx_t_4 != Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = (__pyx_t_3 != 0);
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":557
 *             return self._extra[name]
 *         elif self._transport is not None:
 *             return self._transport.get_extra_info(name, default)             # <<<<<<<<<<<<<<
 *         else:
 *             return default
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_extra_info); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 557, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_name, __pyx_v_default};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_v_name, __pyx_v_default};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_1) {
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
      }
      __Pyx_INCREF(__pyx_v_name);
      __Pyx_GIVEREF(__pyx_v_name);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_name);
      __Pyx_INCREF(__pyx_v_default);
      __Pyx_GIVEREF(__pyx_v_default);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_default);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 557, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":556
 *         if name in self._extra:
 *             return self._extra[name]
 *         elif self._transport is not None:             # <<<<<<<<<<<<<<
 *             return self._transport.get_extra_info(name, default)
 *         else:
 */
  }

  /* "uvloop/sslproto.pyx":559
 *             return self._transport.get_extra_info(name, default)
 *         else:
 *             return default             # <<<<<<<<<<<<<<
 * 
 *     def _mark_closed(self):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_default);
    __pyx_r = __pyx_v_default;
    goto __pyx_L0;
  }

  /* "uvloop/sslproto.pyx":553
 *             self._transport.close()
 * 
 *     def _get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if name in self._extra:
 *             return self._extra[name]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._get_extra_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":561
 *             return default
 * 
 *     def _mark_closed(self):             # <<<<<<<<<<<<<<
 *         self._closed = True
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_21_mark_closed(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_20_mark_closed[] = "SSLProtocol._mark_closed(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_21_mark_closed = {"_mark_closed", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_21_mark_closed, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_20_mark_closed};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_21_mark_closed(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_mark_closed (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_20_mark_closed(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_20_mark_closed(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_mark_closed", 0);

  /* "uvloop/sslproto.pyx":562
 * 
 *     def _mark_closed(self):
 *         self._closed = True             # <<<<<<<<<<<<<<
 * 
 *     def _start_shutdown(self):
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_closed, Py_True) < 0) __PYX_ERR(0, 562, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":561
 *             return default
 * 
 *     def _mark_closed(self):             # <<<<<<<<<<<<<<
 *         self._closed = True
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._mark_closed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":564
 *         self._closed = True
 * 
 *     def _start_shutdown(self):             # <<<<<<<<<<<<<<
 *         if self._in_shutdown:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_23_start_shutdown(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_22_start_shutdown[] = "SSLProtocol._start_shutdown(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_23_start_shutdown = {"_start_shutdown", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_23_start_shutdown, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_22_start_shutdown};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_23_start_shutdown(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_start_shutdown (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_22_start_shutdown(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_22_start_shutdown(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_start_shutdown", 0);

  /* "uvloop/sslproto.pyx":565
 * 
 *     def _start_shutdown(self):
 *         if self._in_shutdown:             # <<<<<<<<<<<<<<
 *             return
 *         if self._in_handshake:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_in_shutdown); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":566
 *     def _start_shutdown(self):
 *         if self._in_shutdown:
 *             return             # <<<<<<<<<<<<<<
 *         if self._in_handshake:
 *             self._abort()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":565
 * 
 *     def _start_shutdown(self):
 *         if self._in_shutdown:             # <<<<<<<<<<<<<<
 *             return
 *         if self._in_handshake:
 */
  }

  /* "uvloop/sslproto.pyx":567
 *         if self._in_shutdown:
 *             return
 *         if self._in_handshake:             # <<<<<<<<<<<<<<
 *             self._abort()
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_in_handshake); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":568
 *             return
 *         if self._in_handshake:
 *             self._abort()             # <<<<<<<<<<<<<<
 *         else:
 *             self._in_shutdown = True
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_abort); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":567
 *         if self._in_shutdown:
 *             return
 *         if self._in_handshake:             # <<<<<<<<<<<<<<
 *             self._abort()
 *         else:
 */
    goto __pyx_L4;
  }

  /* "uvloop/sslproto.pyx":570
 *             self._abort()
 *         else:
 *             self._in_shutdown = True             # <<<<<<<<<<<<<<
 *             self._write_appdata(b'')
 * 
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_in_shutdown, Py_True) < 0) __PYX_ERR(0, 570, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":571
 *         else:
 *             self._in_shutdown = True
 *             self._write_appdata(b'')             # <<<<<<<<<<<<<<
 * 
 *     def _write_appdata(self, data):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_appdata); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__261, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 571, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "uvloop/sslproto.pyx":564
 *         self._closed = True
 * 
 *     def _start_shutdown(self):             # <<<<<<<<<<<<<<
 *         if self._in_shutdown:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._start_shutdown", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":573
 *             self._write_appdata(b'')
 * 
 *     def _write_appdata(self, data):             # <<<<<<<<<<<<<<
 *         self._write_backlog.append((data, 0))
 *         self._write_buffer_size += len(data)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_25_write_appdata(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_24_write_appdata[] = "SSLProtocol._write_appdata(self, data)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_25_write_appdata = {"_write_appdata", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_25_write_appdata, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_24_write_appdata};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_25_write_appdata(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_write_appdata (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_data,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_write_appdata", 1, 2, 2, 1); __PYX_ERR(0, 573, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_write_appdata") < 0)) __PYX_ERR(0, 573, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_data = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_write_appdata", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 573, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._write_appdata", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_24_write_appdata(__pyx_self, __pyx_v_self, __pyx_v_data);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_24_write_appdata(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_write_appdata", 0);

  /* "uvloop/sslproto.pyx":574
 * 
 *     def _write_appdata(self, data):
 *         self._write_backlog.append((data, 0))             # <<<<<<<<<<<<<<
 *         self._write_buffer_size += len(data)
 *         self._process_write_backlog()
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_backlog); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_data);
  __Pyx_GIVEREF(__pyx_v_data);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_data);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_int_0);
  __pyx_t_3 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_t_2); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/sslproto.pyx":575
 *     def _write_appdata(self, data):
 *         self._write_backlog.append((data, 0))
 *         self._write_buffer_size += len(data)             # <<<<<<<<<<<<<<
 *         self._process_write_backlog()
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_buffer_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(0, 575, __pyx_L1_error)
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyNumber_InPlaceAdd(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_write_buffer_size, __pyx_t_5) < 0) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/sslproto.pyx":576
 *         self._write_backlog.append((data, 0))
 *         self._write_buffer_size += len(data)
 *         self._process_write_backlog()             # <<<<<<<<<<<<<<
 * 
 *     def _start_handshake(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_process_write_backlog); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 576, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_5 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 576, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/sslproto.pyx":573
 *             self._write_appdata(b'')
 * 
 *     def _write_appdata(self, data):             # <<<<<<<<<<<<<<
 *         self._write_backlog.append((data, 0))
 *         self._write_buffer_size += len(data)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._write_appdata", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":578
 *         self._process_write_backlog()
 * 
 *     def _start_handshake(self):             # <<<<<<<<<<<<<<
 *         if self._loop.get_debug():
 *             aio_logger.debug("%r starts SSL handshake", self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_27_start_handshake(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_26_start_handshake[] = "SSLProtocol._start_handshake(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_27_start_handshake = {"_start_handshake", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_27_start_handshake, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_26_start_handshake};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_27_start_handshake(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_start_handshake (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_26_start_handshake(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_26_start_handshake(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_start_handshake", 0);

  /* "uvloop/sslproto.pyx":579
 * 
 *     def _start_handshake(self):
 *         if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *             aio_logger.debug("%r starts SSL handshake", self)
 *             self._handshake_start_time = self._loop.time()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 579, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 579, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "uvloop/sslproto.pyx":580
 *     def _start_handshake(self):
 *         if self._loop.get_debug():
 *             aio_logger.debug("%r starts SSL handshake", self)             # <<<<<<<<<<<<<<
 *             self._handshake_start_time = self._loop.time()
 *         else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_kp_u_r_starts_SSL_handshake, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_kp_u_r_starts_SSL_handshake, __pyx_v_self};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_2) {
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_u_r_starts_SSL_handshake);
      __Pyx_GIVEREF(__pyx_kp_u_r_starts_SSL_handshake);
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u_r_starts_SSL_handshake);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_self);
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":581
 *         if self._loop.get_debug():
 *             aio_logger.debug("%r starts SSL handshake", self)
 *             self._handshake_start_time = self._loop.time()             # <<<<<<<<<<<<<<
 *         else:
 *             self._handshake_start_time = None
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_handshake_start_time, __pyx_t_1) < 0) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":579
 * 
 *     def _start_handshake(self):
 *         if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *             aio_logger.debug("%r starts SSL handshake", self)
 *             self._handshake_start_time = self._loop.time()
 */
    goto __pyx_L3;
  }

  /* "uvloop/sslproto.pyx":583
 *             self._handshake_start_time = self._loop.time()
 *         else:
 *             self._handshake_start_time = None             # <<<<<<<<<<<<<<
 *         self._in_handshake = True
 *         # (b'', 1) is a special value in _process_write_backlog() to do
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_handshake_start_time, Py_None) < 0) __PYX_ERR(0, 583, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "uvloop/sslproto.pyx":584
 *         else:
 *             self._handshake_start_time = None
 *         self._in_handshake = True             # <<<<<<<<<<<<<<
 *         # (b'', 1) is a special value in _process_write_backlog() to do
 *         # the SSL handshake
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_in_handshake, Py_True) < 0) __PYX_ERR(0, 584, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":587
 *         # (b'', 1) is a special value in _process_write_backlog() to do
 *         # the SSL handshake
 *         self._write_backlog.append((b'', 1))             # <<<<<<<<<<<<<<
 *         self._handshake_timeout_handle = \
 *             self._loop.call_later(self._ssl_handshake_timeout,
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_backlog); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_Append(__pyx_t_1, __pyx_tuple__262); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":589
 *         self._write_backlog.append((b'', 1))
 *         self._handshake_timeout_handle = \
 *             self._loop.call_later(self._ssl_handshake_timeout,             # <<<<<<<<<<<<<<
 *                                   self._check_handshake_timeout)
 *         self._process_write_backlog()
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_call_later); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_handshake_timeout_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/sslproto.pyx":590
 *         self._handshake_timeout_handle = \
 *             self._loop.call_later(self._ssl_handshake_timeout,
 *                                   self._check_handshake_timeout)             # <<<<<<<<<<<<<<
 *         self._process_write_backlog()
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_check_handshake_timeout); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_t_6, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_9 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_5, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":588
 *         # the SSL handshake
 *         self._write_backlog.append((b'', 1))
 *         self._handshake_timeout_handle = \             # <<<<<<<<<<<<<<
 *             self._loop.call_later(self._ssl_handshake_timeout,
 *                                   self._check_handshake_timeout)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_handshake_timeout_handle, __pyx_t_1) < 0) __PYX_ERR(0, 588, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":591
 *             self._loop.call_later(self._ssl_handshake_timeout,
 *                                   self._check_handshake_timeout)
 *         self._process_write_backlog()             # <<<<<<<<<<<<<<
 * 
 *     def _check_handshake_timeout(self):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_process_write_backlog); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_9) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 591, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 591, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":578
 *         self._process_write_backlog()
 * 
 *     def _start_handshake(self):             # <<<<<<<<<<<<<<
 *         if self._loop.get_debug():
 *             aio_logger.debug("%r starts SSL handshake", self)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._start_handshake", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":593
 *         self._process_write_backlog()
 * 
 *     def _check_handshake_timeout(self):             # <<<<<<<<<<<<<<
 *         if self._in_handshake is True:
 *             msg = (
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_29_check_handshake_timeout(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_28_check_handshake_timeout[] = "SSLProtocol._check_handshake_timeout(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_29_check_handshake_timeout = {"_check_handshake_timeout", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_29_check_handshake_timeout, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_28_check_handshake_timeout};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_29_check_handshake_timeout(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_check_handshake_timeout (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_28_check_handshake_timeout(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_28_check_handshake_timeout(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("_check_handshake_timeout", 0);

  /* "uvloop/sslproto.pyx":594
 * 
 *     def _check_handshake_timeout(self):
 *         if self._in_handshake is True:             # <<<<<<<<<<<<<<
 *             msg = (
 *                 f"SSL handshake is taking longer than "
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_in_handshake); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_True);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/sslproto.pyx":596
 *         if self._in_handshake is True:
 *             msg = (
 *                 f"SSL handshake is taking longer than "             # <<<<<<<<<<<<<<
 *                 f"{self._ssl_handshake_timeout} seconds: "
 *                 f"aborting the connection"
 */
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_SSL_handshake_is_taking_longer_t);
    __pyx_t_4 += 36;
    __Pyx_GIVEREF(__pyx_kp_u_SSL_handshake_is_taking_longer_t);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_SSL_handshake_is_taking_longer_t);

    /* "uvloop/sslproto.pyx":597
 *             msg = (
 *                 f"SSL handshake is taking longer than "
 *                 f"{self._ssl_handshake_timeout} seconds: "             # <<<<<<<<<<<<<<
 *                 f"aborting the connection"
 *             )
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_ssl_handshake_timeout_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_kp_u_seconds_aborting_the_connection);
    __pyx_t_4 += 33;
    __Pyx_GIVEREF(__pyx_kp_u_seconds_aborting_the_connection);
    PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_seconds_aborting_the_connection);

    /* "uvloop/sslproto.pyx":596
 *         if self._in_handshake is True:
 *             msg = (
 *                 f"SSL handshake is taking longer than "             # <<<<<<<<<<<<<<
 *                 f"{self._ssl_handshake_timeout} seconds: "
 *                 f"aborting the connection"
 */
    __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 596, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_msg = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "uvloop/sslproto.pyx":600
 *                 f"aborting the connection"
 *             )
 *             self._fatal_error(ConnectionAbortedError(msg))             # <<<<<<<<<<<<<<
 * 
 *     def _on_handshake_complete(self, handshake_exc):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fatal_error); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionAbortedError); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_msg); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_8); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 600, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_7);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_9, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 600, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "uvloop/sslproto.pyx":594
 * 
 *     def _check_handshake_timeout(self):
 *         if self._in_handshake is True:             # <<<<<<<<<<<<<<
 *             msg = (
 *                 f"SSL handshake is taking longer than "
 */
  }

  /* "uvloop/sslproto.pyx":593
 *         self._process_write_backlog()
 * 
 *     def _check_handshake_timeout(self):             # <<<<<<<<<<<<<<
 *         if self._in_handshake is True:
 *             msg = (
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._check_handshake_timeout", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":602
 *             self._fatal_error(ConnectionAbortedError(msg))
 * 
 *     def _on_handshake_complete(self, handshake_exc):             # <<<<<<<<<<<<<<
 *         self._in_handshake = False
 *         self._handshake_timeout_handle.cancel()
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_31_on_handshake_complete(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_30_on_handshake_complete[] = "SSLProtocol._on_handshake_complete(self, handshake_exc)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_31_on_handshake_complete = {"_on_handshake_complete", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_31_on_handshake_complete, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_30_on_handshake_complete};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_31_on_handshake_complete(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_handshake_exc = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_on_handshake_complete (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_handshake_exc,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_handshake_exc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_on_handshake_complete", 1, 2, 2, 1); __PYX_ERR(0, 602, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_on_handshake_complete") < 0)) __PYX_ERR(0, 602, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_handshake_exc = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_on_handshake_complete", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 602, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._on_handshake_complete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_30_on_handshake_complete(__pyx_self, __pyx_v_self, __pyx_v_handshake_exc);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_30_on_handshake_complete(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_handshake_exc) {
  PyObject *__pyx_v_sslobj = NULL;
  PyObject *__pyx_v_peercert = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_v_dt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  __Pyx_RefNannySetupContext("_on_handshake_complete", 0);

  /* "uvloop/sslproto.pyx":603
 * 
 *     def _on_handshake_complete(self, handshake_exc):
 *         self._in_handshake = False             # <<<<<<<<<<<<<<
 *         self._handshake_timeout_handle.cancel()
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_in_handshake, Py_False) < 0) __PYX_ERR(0, 603, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":604
 *     def _on_handshake_complete(self, handshake_exc):
 *         self._in_handshake = False
 *         self._handshake_timeout_handle.cancel()             # <<<<<<<<<<<<<<
 * 
 *         sslobj = (<_SSLPipe>self._sslpipe)._sslobj
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_handshake_timeout_handle); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_cancel); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":606
 *         self._handshake_timeout_handle.cancel()
 * 
 *         sslobj = (<_SSLPipe>self._sslpipe)._sslobj             # <<<<<<<<<<<<<<
 *         try:
 *             if handshake_exc is not None:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = ((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_t_1)->_sslobj;
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_sslobj = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/sslproto.pyx":607
 * 
 *         sslobj = (<_SSLPipe>self._sslpipe)._sslobj
 *         try:             # <<<<<<<<<<<<<<
 *             if handshake_exc is not None:
 *                 raise handshake_exc
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "uvloop/sslproto.pyx":608
 *         sslobj = (<_SSLPipe>self._sslpipe)._sslobj
 *         try:
 *             if handshake_exc is not None:             # <<<<<<<<<<<<<<
 *                 raise handshake_exc
 * 
 */
      __pyx_t_7 = (__pyx_v_handshake_exc != Py_None);
      __pyx_t_8 = (__pyx_t_7 != 0);
      if (unlikely(__pyx_t_8)) {

        /* "uvloop/sslproto.pyx":609
 *         try:
 *             if handshake_exc is not None:
 *                 raise handshake_exc             # <<<<<<<<<<<<<<
 * 
 *             peercert = sslobj.getpeercert()
 */
        __Pyx_Raise(__pyx_v_handshake_exc, 0, 0, 0);
        __PYX_ERR(0, 609, __pyx_L3_error)

        /* "uvloop/sslproto.pyx":608
 *         sslobj = (<_SSLPipe>self._sslpipe)._sslobj
 *         try:
 *             if handshake_exc is not None:             # <<<<<<<<<<<<<<
 *                 raise handshake_exc
 * 
 */
      }

      /* "uvloop/sslproto.pyx":611
 *                 raise handshake_exc
 * 
 *             peercert = sslobj.getpeercert()             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             if isinstance(exc, ssl_CertificateError):
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_sslobj, __pyx_n_s_getpeercert); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 611, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      if (__pyx_t_2) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 611, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else {
        __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 611, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_peercert = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "uvloop/sslproto.pyx":607
 * 
 *         sslobj = (<_SSLPipe>self._sslpipe)._sslobj
 *         try:             # <<<<<<<<<<<<<<
 *             if handshake_exc is not None:
 *                 raise handshake_exc
 */
    }
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/sslproto.pyx":612
 * 
 *             peercert = sslobj.getpeercert()
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             if isinstance(exc, ssl_CertificateError):
 *                 msg = 'SSL handshake failed on verifying the certificate'
 */
    __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_9) {
      __Pyx_AddTraceback("uvloop.loop.SSLProtocol._on_handshake_complete", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_1, &__pyx_t_2) < 0) __PYX_ERR(0, 612, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_v_exc = __pyx_t_1;
      /*try:*/ {

        /* "uvloop/sslproto.pyx":613
 *             peercert = sslobj.getpeercert()
 *         except Exception as exc:
 *             if isinstance(exc, ssl_CertificateError):             # <<<<<<<<<<<<<<
 *                 msg = 'SSL handshake failed on verifying the certificate'
 *             else:
 */
        __pyx_t_10 = __pyx_v_6uvloop_4loop_ssl_CertificateError;
        __Pyx_INCREF(__pyx_t_10);
        __pyx_t_8 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_10); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 613, __pyx_L15_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_7 = (__pyx_t_8 != 0);
        if (__pyx_t_7) {

          /* "uvloop/sslproto.pyx":614
 *         except Exception as exc:
 *             if isinstance(exc, ssl_CertificateError):
 *                 msg = 'SSL handshake failed on verifying the certificate'             # <<<<<<<<<<<<<<
 *             else:
 *                 msg = 'SSL handshake failed'
 */
          __Pyx_INCREF(__pyx_kp_u_SSL_handshake_failed_on_verifyin);
          __pyx_v_msg = __pyx_kp_u_SSL_handshake_failed_on_verifyin;

          /* "uvloop/sslproto.pyx":613
 *             peercert = sslobj.getpeercert()
 *         except Exception as exc:
 *             if isinstance(exc, ssl_CertificateError):             # <<<<<<<<<<<<<<
 *                 msg = 'SSL handshake failed on verifying the certificate'
 *             else:
 */
          goto __pyx_L17;
        }

        /* "uvloop/sslproto.pyx":616
 *                 msg = 'SSL handshake failed on verifying the certificate'
 *             else:
 *                 msg = 'SSL handshake failed'             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, msg)
 *             return
 */
        /*else*/ {
          __Pyx_INCREF(__pyx_kp_u_SSL_handshake_failed);
          __pyx_v_msg = __pyx_kp_u_SSL_handshake_failed;
        }
        __pyx_L17:;

        /* "uvloop/sslproto.pyx":617
 *             else:
 *                 msg = 'SSL handshake failed'
 *             self._fatal_error(exc, msg)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fatal_error); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 617, __pyx_L15_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_12 = NULL;
        __pyx_t_9 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_11, function);
            __pyx_t_9 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_11)) {
          PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_v_exc, __pyx_v_msg};
          __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 617, __pyx_L15_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
          PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_v_exc, __pyx_v_msg};
          __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 617, __pyx_L15_error)
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_10);
        } else
        #endif
        {
          __pyx_t_13 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 617, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_13);
          if (__pyx_t_12) {
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
          }
          __Pyx_INCREF(__pyx_v_exc);
          __Pyx_GIVEREF(__pyx_v_exc);
          PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_9, __pyx_v_exc);
          __Pyx_INCREF(__pyx_v_msg);
          __Pyx_GIVEREF(__pyx_v_msg);
          PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_9, __pyx_v_msg);
          __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 617, __pyx_L15_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "uvloop/sslproto.pyx":618
 *                 msg = 'SSL handshake failed'
 *             self._fatal_error(exc, msg)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self._loop.get_debug():
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L14_return;
      }

      /* "uvloop/sslproto.pyx":612
 * 
 *             peercert = sslobj.getpeercert()
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             if isinstance(exc, ssl_CertificateError):
 *                 msg = 'SSL handshake failed on verifying the certificate'
 */
      /*finally:*/ {
        __pyx_L15_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_9 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
          goto __pyx_L5_except_error;
        }
        __pyx_L14_return: {
          __pyx_t_21 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          __pyx_r = __pyx_t_21;
          __pyx_t_21 = 0;
          goto __pyx_L6_except_return;
        }
      }
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "uvloop/sslproto.pyx":607
 * 
 *         sslobj = (<_SSLPipe>self._sslpipe)._sslobj
 *         try:             # <<<<<<<<<<<<<<
 *             if handshake_exc is not None:
 *                 raise handshake_exc
 */
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "uvloop/sslproto.pyx":620
 *             return
 * 
 *         if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *             dt = self._loop.time() - self._handshake_start_time
 *             aio_logger.debug("%r: SSL handshake took %.1f ms", self, dt * 1e3)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_debug); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_1) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 620, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_7) {

    /* "uvloop/sslproto.pyx":621
 * 
 *         if self._loop.get_debug():
 *             dt = self._loop.time() - self._handshake_start_time             # <<<<<<<<<<<<<<
 *             aio_logger.debug("%r: SSL handshake took %.1f ms", self, dt * 1e3)
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (__pyx_t_3) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_handshake_start_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 621, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_dt = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "uvloop/sslproto.pyx":622
 *         if self._loop.get_debug():
 *             dt = self._loop.time() - self._handshake_start_time
 *             aio_logger.debug("%r: SSL handshake took %.1f ms", self, dt * 1e3)             # <<<<<<<<<<<<<<
 * 
 *         # Add extra info that becomes available after handshake.
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyNumber_Multiply(__pyx_v_dt, __pyx_float_1e3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_10 = NULL;
    __pyx_t_14 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_14 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_r_SSL_handshake_took_1f_ms, __pyx_v_self, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_r_SSL_handshake_took_1f_ms, __pyx_v_self, __pyx_t_2};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_11 = PyTuple_New(3+__pyx_t_14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      if (__pyx_t_10) {
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_10); __pyx_t_10 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_u_r_SSL_handshake_took_1f_ms);
      __Pyx_GIVEREF(__pyx_kp_u_r_SSL_handshake_took_1f_ms);
      PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_14, __pyx_kp_u_r_SSL_handshake_took_1f_ms);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_14, __pyx_v_self);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_11, 2+__pyx_t_14, __pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_11, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/sslproto.pyx":620
 *             return
 * 
 *         if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *             dt = self._loop.time() - self._handshake_start_time
 *             aio_logger.debug("%r: SSL handshake took %.1f ms", self, dt * 1e3)
 */
  }

  /* "uvloop/sslproto.pyx":625
 * 
 *         # Add extra info that becomes available after handshake.
 *         self._extra.update(peercert=peercert,             # <<<<<<<<<<<<<<
 *                            cipher=sslobj.cipher(),
 *                            compression=sslobj.compression(),
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_extra); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_update); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_peercert, __pyx_v_peercert) < 0) __PYX_ERR(0, 625, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":626
 *         # Add extra info that becomes available after handshake.
 *         self._extra.update(peercert=peercert,
 *                            cipher=sslobj.cipher(),             # <<<<<<<<<<<<<<
 *                            compression=sslobj.compression(),
 *                            ssl_object=sslobj)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sslobj, __pyx_n_s_cipher); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_10) {
    __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 626, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  } else {
    __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 626, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_cipher, __pyx_t_11) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "uvloop/sslproto.pyx":627
 *         self._extra.update(peercert=peercert,
 *                            cipher=sslobj.cipher(),
 *                            compression=sslobj.compression(),             # <<<<<<<<<<<<<<
 *                            ssl_object=sslobj)
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_sslobj, __pyx_n_s_compression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_10) {
    __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 627, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  } else {
    __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 627, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_compression, __pyx_t_11) < 0) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "uvloop/sslproto.pyx":628
 *                            cipher=sslobj.cipher(),
 *                            compression=sslobj.compression(),
 *                            ssl_object=sslobj)             # <<<<<<<<<<<<<<
 * 
 *         self._app_transport = _SSLProtocolTransport(self._loop, self)
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ssl_object, __pyx_v_sslobj) < 0) __PYX_ERR(0, 625, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":625
 * 
 *         # Add extra info that becomes available after handshake.
 *         self._extra.update(peercert=peercert,             # <<<<<<<<<<<<<<
 *                            cipher=sslobj.cipher(),
 *                            compression=sslobj.compression(),
 */
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "uvloop/sslproto.pyx":630
 *                            ssl_object=sslobj)
 * 
 *         self._app_transport = _SSLProtocolTransport(self._loop, self)             # <<<<<<<<<<<<<<
 * 
 *         if self._call_connection_made:
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_SSLProtocolTransport); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  __pyx_t_14 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_14 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_1, __pyx_v_self};
    __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 630, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_t_1, __pyx_v_self};
    __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 630, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  #endif
  {
    __pyx_t_10 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_14, __pyx_t_1);
    __Pyx_INCREF(__pyx_v_self);
    __Pyx_GIVEREF(__pyx_v_self);
    PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_14, __pyx_v_self);
    __pyx_t_1 = 0;
    __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_app_transport, __pyx_t_11) < 0) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "uvloop/sslproto.pyx":632
 *         self._app_transport = _SSLProtocolTransport(self._loop, self)
 * 
 *         if self._call_connection_made:             # <<<<<<<<<<<<<<
 *             self._app_protocol.connection_made(self._app_transport)
 *         self._wakeup_waiter()
 */
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_call_connection_made_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (__pyx_t_7) {

    /* "uvloop/sslproto.pyx":633
 * 
 *         if self._call_connection_made:
 *             self._app_protocol.connection_made(self._app_transport)             # <<<<<<<<<<<<<<
 *         self._wakeup_waiter()
 *         self._session_established = True
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_protocol); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_connection_made); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_app_transport); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_3); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 633, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_11);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_3};
        __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 633, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_3};
        __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 633, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else
      #endif
      {
        __pyx_t_2 = PyTuple_New(1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 633, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_2, 0+1, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_2, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 633, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

    /* "uvloop/sslproto.pyx":632
 *         self._app_transport = _SSLProtocolTransport(self._loop, self)
 * 
 *         if self._call_connection_made:             # <<<<<<<<<<<<<<
 *             self._app_protocol.connection_made(self._app_transport)
 *         self._wakeup_waiter()
 */
  }

  /* "uvloop/sslproto.pyx":634
 *         if self._call_connection_made:
 *             self._app_protocol.connection_made(self._app_transport)
 *         self._wakeup_waiter()             # <<<<<<<<<<<<<<
 *         self._session_established = True
 *         # In case transport.write() was already called. Don't call
 */
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_wakeup_waiter); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 634, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_11 = __Pyx_PyObject_CallNoArg(__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 634, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "uvloop/sslproto.pyx":635
 *             self._app_protocol.connection_made(self._app_transport)
 *         self._wakeup_waiter()
 *         self._session_established = True             # <<<<<<<<<<<<<<
 *         # In case transport.write() was already called. Don't call
 *         # immediately _process_write_backlog(), but schedule it:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_session_established, Py_True) < 0) __PYX_ERR(0, 635, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":641
 *         # _process_write_backlog(), and _process_write_backlog() is not
 *         # reentrant.
 *         self._loop.call_soon(self._process_write_backlog)             # <<<<<<<<<<<<<<
 * 
 *     def _process_write_backlog(self):
 */
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_call_soon); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_process_write_backlog); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_3) {
    __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 641, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_GOTREF(__pyx_t_11);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_10};
      __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 641, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_t_10};
      __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 641, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3); __pyx_t_3 = NULL;
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_t_10);
      __pyx_t_10 = 0;
      __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 641, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "uvloop/sslproto.pyx":602
 *             self._fatal_error(ConnectionAbortedError(msg))
 * 
 *     def _on_handshake_complete(self, handshake_exc):             # <<<<<<<<<<<<<<
 *         self._in_handshake = False
 *         self._handshake_timeout_handle.cancel()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._on_handshake_complete", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sslobj);
  __Pyx_XDECREF(__pyx_v_peercert);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":643
 *         self._loop.call_soon(self._process_write_backlog)
 * 
 *     def _process_write_backlog(self):             # <<<<<<<<<<<<<<
 *         # Try to make progress on the write backlog.
 *         if self._transport is None or self._sslpipe is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_33_process_write_backlog(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_32_process_write_backlog[] = "SSLProtocol._process_write_backlog(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_33_process_write_backlog = {"_process_write_backlog", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_33_process_write_backlog, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_32_process_write_backlog};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_33_process_write_backlog(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_process_write_backlog (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_32_process_write_backlog(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_32_process_write_backlog(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v_sslpipe = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_offset = NULL;
  PyObject *__pyx_v_ssldata = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  int __pyx_t_15;
  struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_appdata __pyx_t_16;
  struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_do_handshake __pyx_t_17;
  struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_shutdown __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  int __pyx_t_23;
  char const *__pyx_t_24;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  __Pyx_RefNannySetupContext("_process_write_backlog", 0);

  /* "uvloop/sslproto.pyx":645
 *     def _process_write_backlog(self):
 *         # Try to make progress on the write backlog.
 *         if self._transport is None or self._sslpipe is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (!__pyx_t_4) {
  } else {
    __pyx_t_1 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = (__pyx_t_2 == Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/sslproto.pyx":646
 *         # Try to make progress on the write backlog.
 *         if self._transport is None or self._sslpipe is None:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/sslproto.pyx":645
 *     def _process_write_backlog(self):
 *         # Try to make progress on the write backlog.
 *         if self._transport is None or self._sslpipe is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/sslproto.pyx":649
 * 
 *         cdef:
 *             _SSLPipe sslpipe = <_SSLPipe>self._sslpipe             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __pyx_t_2;
  __Pyx_INCREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_sslpipe = ((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "uvloop/sslproto.pyx":651
 *             _SSLPipe sslpipe = <_SSLPipe>self._sslpipe
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             for i in range(len(self._write_backlog)):
 *                 data, offset = self._write_backlog[0]
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "uvloop/sslproto.pyx":652
 * 
 *         try:
 *             for i in range(len(self._write_backlog)):             # <<<<<<<<<<<<<<
 *                 data, offset = self._write_backlog[0]
 *                 if data:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_backlog); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 652, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(0, 652, __pyx_L6_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_10 = __pyx_t_9;
      for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
        __pyx_v_i = __pyx_t_11;

        /* "uvloop/sslproto.pyx":653
 *         try:
 *             for i in range(len(self._write_backlog)):
 *                 data, offset = self._write_backlog[0]             # <<<<<<<<<<<<<<
 *                 if data:
 *                     ssldata, offset = sslpipe.feed_appdata(data, offset)
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_backlog); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 653, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 653, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
          PyObject* sequence = __pyx_t_2;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 653, __pyx_L6_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_12);
          #else
          __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 653, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_12 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 653, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_12);
          #endif
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_13 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 653, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_14 = Py_TYPE(__pyx_t_13)->tp_iternext;
          index = 0; __pyx_t_5 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_5)) goto __pyx_L14_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_5);
          index = 1; __pyx_t_12 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L14_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_12);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 2) < 0) __PYX_ERR(0, 653, __pyx_L6_error)
          __pyx_t_14 = NULL;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L15_unpacking_done;
          __pyx_L14_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_14 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 653, __pyx_L6_error)
          __pyx_L15_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_data, __pyx_t_5);
        __pyx_t_5 = 0;
        __Pyx_XDECREF_SET(__pyx_v_offset, __pyx_t_12);
        __pyx_t_12 = 0;

        /* "uvloop/sslproto.pyx":654
 *             for i in range(len(self._write_backlog)):
 *                 data, offset = self._write_backlog[0]
 *                 if data:             # <<<<<<<<<<<<<<
 *                     ssldata, offset = sslpipe.feed_appdata(data, offset)
 *                 elif offset:
 */
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 654, __pyx_L6_error)
        if (__pyx_t_1) {

          /* "uvloop/sslproto.pyx":655
 *                 data, offset = self._write_backlog[0]
 *                 if data:
 *                     ssldata, offset = sslpipe.feed_appdata(data, offset)             # <<<<<<<<<<<<<<
 *                 elif offset:
 *                     ssldata = sslpipe.do_handshake(self._on_handshake_complete)
 */
          __pyx_t_15 = __Pyx_PyInt_As_int(__pyx_v_offset); if (unlikely((__pyx_t_15 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 655, __pyx_L6_error)
          __pyx_t_16.__pyx_n = 1;
          __pyx_t_16.offset = __pyx_t_15;
          __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *)__pyx_v_sslpipe->__pyx_vtab)->feed_appdata(__pyx_v_sslpipe, __pyx_v_data, &__pyx_t_16); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 655, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
            PyObject* sequence = __pyx_t_2;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 655, __pyx_L6_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_12 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_12 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(__pyx_t_5);
            #else
            __pyx_t_12 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 655, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 655, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_5);
            #endif
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_13 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 655, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_14 = Py_TYPE(__pyx_t_13)->tp_iternext;
            index = 0; __pyx_t_12 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_12)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_12);
            index = 1; __pyx_t_5 = __pyx_t_14(__pyx_t_13); if (unlikely(!__pyx_t_5)) goto __pyx_L17_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_5);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_14(__pyx_t_13), 2) < 0) __PYX_ERR(0, 655, __pyx_L6_error)
            __pyx_t_14 = NULL;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L18_unpacking_done;
            __pyx_L17_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_14 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 655, __pyx_L6_error)
            __pyx_L18_unpacking_done:;
          }
          __Pyx_XDECREF_SET(__pyx_v_ssldata, __pyx_t_12);
          __pyx_t_12 = 0;
          __Pyx_DECREF_SET(__pyx_v_offset, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "uvloop/sslproto.pyx":654
 *             for i in range(len(self._write_backlog)):
 *                 data, offset = self._write_backlog[0]
 *                 if data:             # <<<<<<<<<<<<<<
 *                     ssldata, offset = sslpipe.feed_appdata(data, offset)
 *                 elif offset:
 */
          goto __pyx_L16;
        }

        /* "uvloop/sslproto.pyx":656
 *                 if data:
 *                     ssldata, offset = sslpipe.feed_appdata(data, offset)
 *                 elif offset:             # <<<<<<<<<<<<<<
 *                     ssldata = sslpipe.do_handshake(self._on_handshake_complete)
 *                     offset = 1
 */
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_offset); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 656, __pyx_L6_error)
        if (__pyx_t_1) {

          /* "uvloop/sslproto.pyx":657
 *                     ssldata, offset = sslpipe.feed_appdata(data, offset)
 *                 elif offset:
 *                     ssldata = sslpipe.do_handshake(self._on_handshake_complete)             # <<<<<<<<<<<<<<
 *                     offset = 1
 *                 else:
 */
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_on_handshake_complete); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 657, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_17.__pyx_n = 1;
          __pyx_t_17.callback = __pyx_t_2;
          __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *)__pyx_v_sslpipe->__pyx_vtab)->do_handshake(__pyx_v_sslpipe, &__pyx_t_17); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 657, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF_SET(__pyx_v_ssldata, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "uvloop/sslproto.pyx":658
 *                 elif offset:
 *                     ssldata = sslpipe.do_handshake(self._on_handshake_complete)
 *                     offset = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     ssldata = sslpipe.shutdown(self._finalize)
 */
          __Pyx_INCREF(__pyx_int_1);
          __Pyx_DECREF_SET(__pyx_v_offset, __pyx_int_1);

          /* "uvloop/sslproto.pyx":656
 *                 if data:
 *                     ssldata, offset = sslpipe.feed_appdata(data, offset)
 *                 elif offset:             # <<<<<<<<<<<<<<
 *                     ssldata = sslpipe.do_handshake(self._on_handshake_complete)
 *                     offset = 1
 */
          goto __pyx_L16;
        }

        /* "uvloop/sslproto.pyx":660
 *                     offset = 1
 *                 else:
 *                     ssldata = sslpipe.shutdown(self._finalize)             # <<<<<<<<<<<<<<
 *                     offset = 1
 * 
 */
        /*else*/ {
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_finalize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 660, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_18.__pyx_n = 1;
          __pyx_t_18.callback = __pyx_t_5;
          __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe *)__pyx_v_sslpipe->__pyx_vtab)->shutdown(__pyx_v_sslpipe, &__pyx_t_18); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 660, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF_SET(__pyx_v_ssldata, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "uvloop/sslproto.pyx":661
 *                 else:
 *                     ssldata = sslpipe.shutdown(self._finalize)
 *                     offset = 1             # <<<<<<<<<<<<<<
 * 
 *                 self._transport.writelines(ssldata)
 */
          __Pyx_INCREF(__pyx_int_1);
          __Pyx_DECREF_SET(__pyx_v_offset, __pyx_int_1);
        }
        __pyx_L16:;

        /* "uvloop/sslproto.pyx":663
 *                     offset = 1
 * 
 *                 self._transport.writelines(ssldata)             # <<<<<<<<<<<<<<
 * 
 *                 if offset < len(data):
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 663, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_writelines); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 663, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_12);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_12, function);
          }
        }
        if (!__pyx_t_5) {
          __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_ssldata); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_12)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_ssldata};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L6_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
            PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_ssldata};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L6_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          {
            __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 663, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_5); __pyx_t_5 = NULL;
            __Pyx_INCREF(__pyx_v_ssldata);
            __Pyx_GIVEREF(__pyx_v_ssldata);
            PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_ssldata);
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 663, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/sslproto.pyx":665
 *                 self._transport.writelines(ssldata)
 * 
 *                 if offset < len(data):             # <<<<<<<<<<<<<<
 *                     self._write_backlog[0] = (data, offset)
 *                     # A short write means that a write is blocked on a read
 */
        __pyx_t_19 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 665, __pyx_L6_error)
        __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_19); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 665, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_12 = PyObject_RichCompare(__pyx_v_offset, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 665, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 665, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (__pyx_t_1) {

          /* "uvloop/sslproto.pyx":666
 * 
 *                 if offset < len(data):
 *                     self._write_backlog[0] = (data, offset)             # <<<<<<<<<<<<<<
 *                     # A short write means that a write is blocked on a read
 *                     # We need to enable reading if it is paused!
 */
          __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_INCREF(__pyx_v_data);
          __Pyx_GIVEREF(__pyx_v_data);
          PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_data);
          __Pyx_INCREF(__pyx_v_offset);
          __Pyx_GIVEREF(__pyx_v_offset);
          PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_v_offset);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_backlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          if (unlikely(__Pyx_SetItemInt(__pyx_t_2, 0, __pyx_t_12, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0)) __PYX_ERR(0, 666, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "uvloop/sslproto.pyx":669
 *                     # A short write means that a write is blocked on a read
 *                     # We need to enable reading if it is paused!
 *                     assert sslpipe._need_ssldata             # <<<<<<<<<<<<<<
 *                     if self._transport._paused:
 *                         self._transport.resume_reading()
 */
          #ifndef CYTHON_WITHOUT_ASSERTIONS
          if (unlikely(!Py_OptimizeFlag)) {
            if (unlikely(!(__pyx_v_sslpipe->_need_ssldata != 0))) {
              PyErr_SetNone(PyExc_AssertionError);
              __PYX_ERR(0, 669, __pyx_L6_error)
            }
          }
          #endif

          /* "uvloop/sslproto.pyx":670
 *                     # We need to enable reading if it is paused!
 *                     assert sslpipe._need_ssldata
 *                     if self._transport._paused:             # <<<<<<<<<<<<<<
 *                         self._transport.resume_reading()
 *                     break
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 670, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_paused); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 670, __pyx_L6_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_1) {

            /* "uvloop/sslproto.pyx":671
 *                     assert sslpipe._need_ssldata
 *                     if self._transport._paused:
 *                         self._transport.resume_reading()             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 671, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_resume_reading); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 671, __pyx_L6_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_12 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_13, function);
              }
            }
            if (__pyx_t_12) {
              __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_12); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L6_error)
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            } else {
              __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 671, __pyx_L6_error)
            }
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "uvloop/sslproto.pyx":670
 *                     # We need to enable reading if it is paused!
 *                     assert sslpipe._need_ssldata
 *                     if self._transport._paused:             # <<<<<<<<<<<<<<
 *                         self._transport.resume_reading()
 *                     break
 */
          }

          /* "uvloop/sslproto.pyx":672
 *                     if self._transport._paused:
 *                         self._transport.resume_reading()
 *                     break             # <<<<<<<<<<<<<<
 * 
 *                 # An entire chunk from the backlog was processed. We can
 */
          goto __pyx_L13_break;

          /* "uvloop/sslproto.pyx":665
 *                 self._transport.writelines(ssldata)
 * 
 *                 if offset < len(data):             # <<<<<<<<<<<<<<
 *                     self._write_backlog[0] = (data, offset)
 *                     # A short write means that a write is blocked on a read
 */
        }

        /* "uvloop/sslproto.pyx":676
 *                 # An entire chunk from the backlog was processed. We can
 *                 # delete it and reduce the outstanding buffer size.
 *                 del self._write_backlog[0]             # <<<<<<<<<<<<<<
 *                 self._write_buffer_size -= len(data)
 *         except Exception as exc:
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_backlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 676, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely(__Pyx_DelItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1) < 0)) __PYX_ERR(0, 676, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "uvloop/sslproto.pyx":677
 *                 # delete it and reduce the outstanding buffer size.
 *                 del self._write_backlog[0]
 *                 self._write_buffer_size -= len(data)             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             if self._in_handshake:
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_write_buffer_size); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 677, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_19 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_19 == ((Py_ssize_t)-1))) __PYX_ERR(0, 677, __pyx_L6_error)
        __pyx_t_13 = PyInt_FromSsize_t(__pyx_t_19); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 677, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_12 = PyNumber_InPlaceSubtract(__pyx_t_2, __pyx_t_13); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 677, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_write_buffer_size, __pyx_t_12) < 0) __PYX_ERR(0, 677, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __pyx_L13_break:;

      /* "uvloop/sslproto.pyx":651
 *             _SSLPipe sslpipe = <_SSLPipe>self._sslpipe
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             for i in range(len(self._write_backlog)):
 *                 data, offset = self._write_backlog[0]
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L11_try_end;
    __pyx_L6_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "uvloop/sslproto.pyx":678
 *                 del self._write_backlog[0]
 *                 self._write_buffer_size -= len(data)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             if self._in_handshake:
 *                 # Exceptions will be re-raised in _on_handshake_complete.
 */
    __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_15) {
      __Pyx_AddTraceback("uvloop.loop.SSLProtocol._process_write_backlog", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_2) < 0) __PYX_ERR(0, 678, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_13);
      __pyx_v_exc = __pyx_t_13;
      /*try:*/ {

        /* "uvloop/sslproto.pyx":679
 *                 self._write_buffer_size -= len(data)
 *         except Exception as exc:
 *             if self._in_handshake:             # <<<<<<<<<<<<<<
 *                 # Exceptions will be re-raised in _on_handshake_complete.
 *                 self._on_handshake_complete(exc)
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_in_handshake); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 679, __pyx_L26_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 679, __pyx_L26_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (__pyx_t_1) {

          /* "uvloop/sslproto.pyx":681
 *             if self._in_handshake:
 *                 # Exceptions will be re-raised in _on_handshake_complete.
 *                 self._on_handshake_complete(exc)             # <<<<<<<<<<<<<<
 *             else:
 *                 self._fatal_error(exc, 'Fatal error on SSL transport')
 */
          __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_on_handshake_complete); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 681, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_20);
          __pyx_t_21 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_20))) {
            __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_20);
            if (likely(__pyx_t_21)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
              __Pyx_INCREF(__pyx_t_21);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_20, function);
            }
          }
          if (!__pyx_t_21) {
            __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_20, __pyx_v_exc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_5);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_20)) {
              PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_v_exc};
              __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_20, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L26_error)
              __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_20)) {
              PyObject *__pyx_temp[2] = {__pyx_t_21, __pyx_v_exc};
              __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_20, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L26_error)
              __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
              __Pyx_GOTREF(__pyx_t_5);
            } else
            #endif
            {
              __pyx_t_22 = PyTuple_New(1+1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 681, __pyx_L26_error)
              __Pyx_GOTREF(__pyx_t_22);
              __Pyx_GIVEREF(__pyx_t_21); PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_21); __pyx_t_21 = NULL;
              __Pyx_INCREF(__pyx_v_exc);
              __Pyx_GIVEREF(__pyx_v_exc);
              PyTuple_SET_ITEM(__pyx_t_22, 0+1, __pyx_v_exc);
              __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_20, __pyx_t_22, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L26_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "uvloop/sslproto.pyx":679
 *                 self._write_buffer_size -= len(data)
 *         except Exception as exc:
 *             if self._in_handshake:             # <<<<<<<<<<<<<<
 *                 # Exceptions will be re-raised in _on_handshake_complete.
 *                 self._on_handshake_complete(exc)
 */
          goto __pyx_L28;
        }

        /* "uvloop/sslproto.pyx":683
 *                 self._on_handshake_complete(exc)
 *             else:
 *                 self._fatal_error(exc, 'Fatal error on SSL transport')             # <<<<<<<<<<<<<<
 * 
 *     def _fatal_error(self, exc, message='Fatal error on transport'):
 */
        /*else*/ {
          __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_fatal_error); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 683, __pyx_L26_error)
          __Pyx_GOTREF(__pyx_t_20);
          __pyx_t_22 = NULL;
          __pyx_t_15 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_20))) {
            __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_20);
            if (likely(__pyx_t_22)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
              __Pyx_INCREF(__pyx_t_22);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_20, function);
              __pyx_t_15 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_20)) {
            PyObject *__pyx_temp[3] = {__pyx_t_22, __pyx_v_exc, __pyx_kp_u_Fatal_error_on_SSL_transport};
            __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 683, __pyx_L26_error)
            __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
            __Pyx_GOTREF(__pyx_t_5);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_20)) {
            PyObject *__pyx_temp[3] = {__pyx_t_22, __pyx_v_exc, __pyx_kp_u_Fatal_error_on_SSL_transport};
            __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_20, __pyx_temp+1-__pyx_t_15, 2+__pyx_t_15); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 683, __pyx_L26_error)
            __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
            __Pyx_GOTREF(__pyx_t_5);
          } else
          #endif
          {
            __pyx_t_21 = PyTuple_New(2+__pyx_t_15); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 683, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_21);
            if (__pyx_t_22) {
              __Pyx_GIVEREF(__pyx_t_22); PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_22); __pyx_t_22 = NULL;
            }
            __Pyx_INCREF(__pyx_v_exc);
            __Pyx_GIVEREF(__pyx_v_exc);
            PyTuple_SET_ITEM(__pyx_t_21, 0+__pyx_t_15, __pyx_v_exc);
            __Pyx_INCREF(__pyx_kp_u_Fatal_error_on_SSL_transport);
            __Pyx_GIVEREF(__pyx_kp_u_Fatal_error_on_SSL_transport);
            PyTuple_SET_ITEM(__pyx_t_21, 1+__pyx_t_15, __pyx_kp_u_Fatal_error_on_SSL_transport);
            __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_20, __pyx_t_21, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 683, __pyx_L26_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
          }
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_L28:;
      }

      /* "uvloop/sslproto.pyx":678
 *                 del self._write_backlog[0]
 *                 self._write_buffer_size -= len(data)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             if self._in_handshake:
 *                 # Exceptions will be re-raised in _on_handshake_complete.
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L27;
        }
        __pyx_L26_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0;
          __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
          __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_28, &__pyx_t_29, &__pyx_t_30);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27) < 0)) __Pyx_ErrFetch(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
          __Pyx_XGOTREF(__pyx_t_25);
          __Pyx_XGOTREF(__pyx_t_26);
          __Pyx_XGOTREF(__pyx_t_27);
          __Pyx_XGOTREF(__pyx_t_28);
          __Pyx_XGOTREF(__pyx_t_29);
          __Pyx_XGOTREF(__pyx_t_30);
          __pyx_t_15 = __pyx_lineno; __pyx_t_23 = __pyx_clineno; __pyx_t_24 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_28);
            __Pyx_XGIVEREF(__pyx_t_29);
            __Pyx_XGIVEREF(__pyx_t_30);
            __Pyx_ExceptionReset(__pyx_t_28, __pyx_t_29, __pyx_t_30);
          }
          __Pyx_XGIVEREF(__pyx_t_25);
          __Pyx_XGIVEREF(__pyx_t_26);
          __Pyx_XGIVEREF(__pyx_t_27);
          __Pyx_ErrRestore(__pyx_t_25, __pyx_t_26, __pyx_t_27);
          __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0; __pyx_t_28 = 0; __pyx_t_29 = 0; __pyx_t_30 = 0;
          __pyx_lineno = __pyx_t_15; __pyx_clineno = __pyx_t_23; __pyx_filename = __pyx_t_24;
          goto __pyx_L8_except_error;
        }
        __pyx_L27:;
      }
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L7_exception_handled;
    }
    goto __pyx_L8_except_error;
    __pyx_L8_except_error:;

    /* "uvloop/sslproto.pyx":651
 *             _SSLPipe sslpipe = <_SSLPipe>self._sslpipe
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             for i in range(len(self._write_backlog)):
 *                 data, offset = self._write_backlog[0]
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L7_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L11_try_end:;
  }

  /* "uvloop/sslproto.pyx":643
 *         self._loop.call_soon(self._process_write_backlog)
 * 
 *     def _process_write_backlog(self):             # <<<<<<<<<<<<<<
 *         # Try to make progress on the write backlog.
 *         if self._transport is None or self._sslpipe is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._process_write_backlog", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_sslpipe);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_offset);
  __Pyx_XDECREF(__pyx_v_ssldata);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":685
 *                 self._fatal_error(exc, 'Fatal error on SSL transport')
 * 
 *     def _fatal_error(self, exc, message='Fatal error on transport'):             # <<<<<<<<<<<<<<
 *         if self._transport:
 *             self._transport._force_close(exc)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_35_fatal_error(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_34_fatal_error[] = "SSLProtocol._fatal_error(self, exc, message=u'Fatal error on transport')";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_35_fatal_error = {"_fatal_error", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_35_fatal_error, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_11SSLProtocol_34_fatal_error};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_35_fatal_error(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_exc = 0;
  PyObject *__pyx_v_message = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_fatal_error (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_exc,&__pyx_n_s_message,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject*)__pyx_kp_u_Fatal_error_on_transport_2));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_exc)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_fatal_error", 0, 2, 3, 1); __PYX_ERR(0, 685, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_message);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_fatal_error") < 0)) __PYX_ERR(0, 685, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_exc = values[1];
    __pyx_v_message = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_fatal_error", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 685, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_34_fatal_error(__pyx_self, __pyx_v_self, __pyx_v_exc, __pyx_v_message);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_34_fatal_error(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_exc, PyObject *__pyx_v_message) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("_fatal_error", 0);

  /* "uvloop/sslproto.pyx":686
 * 
 *     def _fatal_error(self, exc, message='Fatal error on transport'):
 *         if self._transport:             # <<<<<<<<<<<<<<
 *             self._transport._force_close(exc)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":687
 *     def _fatal_error(self, exc, message='Fatal error on transport'):
 *         if self._transport:
 *             self._transport._force_close(exc)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(exc, (BrokenPipeError,
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_force_close); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 687, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_exc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_exc};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_1);
      } else
      #endif
      {
        __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 687, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_exc);
        __Pyx_GIVEREF(__pyx_v_exc);
        PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_exc);
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":686
 * 
 *     def _fatal_error(self, exc, message='Fatal error on transport'):
 *         if self._transport:             # <<<<<<<<<<<<<<
 *             self._transport._force_close(exc)
 * 
 */
  }

  /* "uvloop/sslproto.pyx":689
 *             self._transport._force_close(exc)
 * 
 *         if isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_BrokenPipeError); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/sslproto.pyx":690
 * 
 *         if isinstance(exc, (BrokenPipeError,
 *                             ConnectionResetError,             # <<<<<<<<<<<<<<
 *                             ConnectionAbortedError)):
 *             if self._loop.get_debug():
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionResetError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "uvloop/sslproto.pyx":691
 *         if isinstance(exc, (BrokenPipeError,
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):             # <<<<<<<<<<<<<<
 *             if self._loop.get_debug():
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_ConnectionAbortedError); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);

  /* "uvloop/sslproto.pyx":689
 *             self._transport._force_close(exc)
 * 
 *         if isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):
 */
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_1); 
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (!__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }

  /* "uvloop/sslproto.pyx":690
 * 
 *         if isinstance(exc, (BrokenPipeError,
 *                             ConnectionResetError,             # <<<<<<<<<<<<<<
 *                             ConnectionAbortedError)):
 *             if self._loop.get_debug():
 */
  __pyx_t_7 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_4); 
  __pyx_t_6 = (__pyx_t_7 != 0);
  if (!__pyx_t_6) {
  } else {
    __pyx_t_2 = __pyx_t_6;
    goto __pyx_L5_bool_binop_done;
  }

  /* "uvloop/sslproto.pyx":691
 *         if isinstance(exc, (BrokenPipeError,
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):             # <<<<<<<<<<<<<<
 *             if self._loop.get_debug():
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)
 */
  __pyx_t_6 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_5); 
  __pyx_t_7 = (__pyx_t_6 != 0);
  __pyx_t_2 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/sslproto.pyx":689
 *             self._transport._force_close(exc)
 * 
 *         if isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):
 */
  __pyx_t_7 = (__pyx_t_2 != 0);
  if (__pyx_t_7) {

    /* "uvloop/sslproto.pyx":692
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):
 *             if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)
 *         elif not isinstance(exc, aio_CancelledError):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get_debug); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_7) {

      /* "uvloop/sslproto.pyx":693
 *                             ConnectionAbortedError)):
 *             if self._loop.get_debug():
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)             # <<<<<<<<<<<<<<
 *         elif not isinstance(exc, aio_CancelledError):
 *             self._loop.call_exception_handler({
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 693, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_kp_u_r_s);
      __Pyx_GIVEREF(__pyx_kp_u_r_s);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_r_s);
      __Pyx_INCREF(__pyx_v_self);
      __Pyx_GIVEREF(__pyx_v_self);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_self);
      __Pyx_INCREF(__pyx_v_message);
      __Pyx_GIVEREF(__pyx_v_message);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_message);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 693, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_exc_info, Py_True) < 0) __PYX_ERR(0, 693, __pyx_L1_error)
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 693, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/sslproto.pyx":692
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):
 *             if self._loop.get_debug():             # <<<<<<<<<<<<<<
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)
 *         elif not isinstance(exc, aio_CancelledError):
 */
    }

    /* "uvloop/sslproto.pyx":689
 *             self._transport._force_close(exc)
 * 
 *         if isinstance(exc, (BrokenPipeError,             # <<<<<<<<<<<<<<
 *                             ConnectionResetError,
 *                             ConnectionAbortedError)):
 */
    goto __pyx_L4;
  }

  /* "uvloop/sslproto.pyx":694
 *             if self._loop.get_debug():
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)
 *         elif not isinstance(exc, aio_CancelledError):             # <<<<<<<<<<<<<<
 *             self._loop.call_exception_handler({
 *                 'message': message,
 */
  __pyx_t_3 = __pyx_v_6uvloop_4loop_aio_CancelledError;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_7 = PyObject_IsInstance(__pyx_v_exc, __pyx_t_3); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = ((!(__pyx_t_7 != 0)) != 0);
  if (__pyx_t_2) {

    /* "uvloop/sslproto.pyx":695
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)
 *         elif not isinstance(exc, aio_CancelledError):
 *             self._loop.call_exception_handler({             # <<<<<<<<<<<<<<
 *                 'message': message,
 *                 'exception': exc,
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_loop_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_call_exception_handler); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/sslproto.pyx":696
 *         elif not isinstance(exc, aio_CancelledError):
 *             self._loop.call_exception_handler({
 *                 'message': message,             # <<<<<<<<<<<<<<
 *                 'exception': exc,
 *                 'transport': self._transport,
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_message, __pyx_v_message) < 0) __PYX_ERR(0, 696, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":697
 *             self._loop.call_exception_handler({
 *                 'message': message,
 *                 'exception': exc,             # <<<<<<<<<<<<<<
 *                 'transport': self._transport,
 *                 'protocol': self,
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_exception, __pyx_v_exc) < 0) __PYX_ERR(0, 696, __pyx_L1_error)

    /* "uvloop/sslproto.pyx":698
 *                 'message': message,
 *                 'exception': exc,
 *                 'transport': self._transport,             # <<<<<<<<<<<<<<
 *                 'protocol': self,
 *             })
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_transport, __pyx_t_1) < 0) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":699
 *                 'exception': exc,
 *                 'transport': self._transport,
 *                 'protocol': self,             # <<<<<<<<<<<<<<
 *             })
 * 
 */
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_protocol, __pyx_v_self) < 0) __PYX_ERR(0, 696, __pyx_L1_error)
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_1) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 695, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 695, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 695, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1); __pyx_t_1 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 695, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/sslproto.pyx":694
 *             if self._loop.get_debug():
 *                 aio_logger.debug("%r: %s", self, message, exc_info=True)
 *         elif not isinstance(exc, aio_CancelledError):             # <<<<<<<<<<<<<<
 *             self._loop.call_exception_handler({
 *                 'message': message,
 */
  }
  __pyx_L4:;

  /* "uvloop/sslproto.pyx":685
 *                 self._fatal_error(exc, 'Fatal error on SSL transport')
 * 
 *     def _fatal_error(self, exc, message='Fatal error on transport'):             # <<<<<<<<<<<<<<
 *         if self._transport:
 *             self._transport._force_close(exc)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._fatal_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":702
 *             })
 * 
 *     def _finalize(self):             # <<<<<<<<<<<<<<
 *         self._sslpipe = None
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_37_finalize(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_36_finalize[] = "SSLProtocol._finalize(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_37_finalize = {"_finalize", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_37_finalize, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_36_finalize};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_37_finalize(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_finalize (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_36_finalize(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_36_finalize(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("_finalize", 0);

  /* "uvloop/sslproto.pyx":703
 * 
 *     def _finalize(self):
 *         self._sslpipe = None             # <<<<<<<<<<<<<<
 * 
 *         if self._transport is not None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_sslpipe, Py_None) < 0) __PYX_ERR(0, 703, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":705
 *         self._sslpipe = None
 * 
 *         if self._transport is not None:             # <<<<<<<<<<<<<<
 *             self._transport.close()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/sslproto.pyx":706
 * 
 *         if self._transport is not None:
 *             self._transport.close()             # <<<<<<<<<<<<<<
 * 
 *     def _abort(self):
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_close); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 706, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 706, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 706, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/sslproto.pyx":705
 *         self._sslpipe = None
 * 
 *         if self._transport is not None:             # <<<<<<<<<<<<<<
 *             self._transport.close()
 * 
 */
  }

  /* "uvloop/sslproto.pyx":702
 *             })
 * 
 *     def _finalize(self):             # <<<<<<<<<<<<<<
 *         self._sslpipe = None
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._finalize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":708
 *             self._transport.close()
 * 
 *     def _abort(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._transport is not None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_39_abort(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_6uvloop_4loop_11SSLProtocol_38_abort[] = "SSLProtocol._abort(self)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_11SSLProtocol_39_abort = {"_abort", (PyCFunction)__pyx_pw_6uvloop_4loop_11SSLProtocol_39_abort, METH_O, __pyx_doc_6uvloop_4loop_11SSLProtocol_38_abort};
static PyObject *__pyx_pw_6uvloop_4loop_11SSLProtocol_39_abort(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_abort (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_11SSLProtocol_38_abort(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_11SSLProtocol_38_abort(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("_abort", 0);

  /* "uvloop/sslproto.pyx":709
 * 
 *     def _abort(self):
 *         try:             # <<<<<<<<<<<<<<
 *             if self._transport is not None:
 *                 self._transport.abort()
 */
  /*try:*/ {

    /* "uvloop/sslproto.pyx":710
 *     def _abort(self):
 *         try:
 *             if self._transport is not None:             # <<<<<<<<<<<<<<
 *                 self._transport.abort()
 *         finally:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 710, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 != Py_None);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "uvloop/sslproto.pyx":711
 *         try:
 *             if self._transport is not None:
 *                 self._transport.abort()             # <<<<<<<<<<<<<<
 *         finally:
 *             self._finalize()
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_transport_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 711, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_abort_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 711, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 711, __pyx_L4_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 711, __pyx_L4_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/sslproto.pyx":710
 *     def _abort(self):
 *         try:
 *             if self._transport is not None:             # <<<<<<<<<<<<<<
 *                 self._transport.abort()
 *         finally:
 */
    }
  }

  /* "uvloop/sslproto.pyx":713
 *                 self._transport.abort()
 *         finally:
 *             self._finalize()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_finalize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 713, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_4) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L1_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L5;
    }
    __pyx_L4_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_finalize); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 713, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (__pyx_t_4) {
          __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        } else {
          __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 713, __pyx_L8_error)
        }
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
      __pyx_L8_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "uvloop/sslproto.pyx":708
 *             self._transport.close()
 * 
 *     def _abort(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._transport is not None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.SSLProtocol._abort", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/sslproto.pyx":716
 * 
 * 
 * cdef _feed_data_to_bufferred_proto(proto, data):             # <<<<<<<<<<<<<<
 *     data_len = len(data)
 *     while data_len:
 */

static PyObject *__pyx_f_6uvloop_4loop__feed_data_to_bufferred_proto(PyObject *__pyx_v_proto, PyObject *__pyx_v_data) {
  Py_ssize_t __pyx_v_data_len;
  PyObject *__pyx_v_buf = NULL;
  Py_ssize_t __pyx_v_buf_len;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("_feed_data_to_bufferred_proto", 0);
  __Pyx_INCREF(__pyx_v_data);

  /* "uvloop/sslproto.pyx":717
 * 
 * cdef _feed_data_to_bufferred_proto(proto, data):
 *     data_len = len(data)             # <<<<<<<<<<<<<<
 *     while data_len:
 *         buf = proto.get_buffer(data_len)
 */
  __pyx_t_1 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 717, __pyx_L1_error)
  __pyx_v_data_len = __pyx_t_1;

  /* "uvloop/sslproto.pyx":718
 * cdef _feed_data_to_bufferred_proto(proto, data):
 *     data_len = len(data)
 *     while data_len:             # <<<<<<<<<<<<<<
 *         buf = proto.get_buffer(data_len)
 *         buf_len = len(buf)
 */
  while (1) {
    __pyx_t_2 = (__pyx_v_data_len != 0);
    if (!__pyx_t_2) break;

    /* "uvloop/sslproto.pyx":719
 *     data_len = len(data)
 *     while data_len:
 *         buf = proto.get_buffer(data_len)             # <<<<<<<<<<<<<<
 *         buf_len = len(buf)
 *         if not buf_len:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_proto, __pyx_n_s_get_buffer); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_data_len); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 719, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_6) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 719, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 719, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_t_5};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 719, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 719, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6); __pyx_t_6 = NULL;
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 0+1, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 719, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF_SET(__pyx_v_buf, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/sslproto.pyx":720
 *     while data_len:
 *         buf = proto.get_buffer(data_len)
 *         buf_len = len(buf)             # <<<<<<<<<<<<<<
 *         if not buf_len:
 *             raise RuntimeError('get_buffer() returned an empty buffer')
 */
    __pyx_t_1 = PyObject_Length(__pyx_v_buf); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 720, __pyx_L1_error)
    __pyx_v_buf_len = __pyx_t_1;

    /* "uvloop/sslproto.pyx":721
 *         buf = proto.get_buffer(data_len)
 *         buf_len = len(buf)
 *         if not buf_len:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('get_buffer() returned an empty buffer')
 * 
 */
    __pyx_t_2 = ((!(__pyx_v_buf_len != 0)) != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/sslproto.pyx":722
 *         buf_len = len(buf)
 *         if not buf_len:
 *             raise RuntimeError('get_buffer() returned an empty buffer')             # <<<<<<<<<<<<<<
 * 
 *         if buf_len >= data_len:
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__263, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 722, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(0, 722, __pyx_L1_error)

      /* "uvloop/sslproto.pyx":721
 *         buf = proto.get_buffer(data_len)
 *         buf_len = len(buf)
 *         if not buf_len:             # <<<<<<<<<<<<<<
 *             raise RuntimeError('get_buffer() returned an empty buffer')
 * 
 */
    }

    /* "uvloop/sslproto.pyx":724
 *             raise RuntimeError('get_buffer() returned an empty buffer')
 * 
 *         if buf_len >= data_len:             # <<<<<<<<<<<<<<
 *             buf[:data_len] = data
 *             proto.buffer_updated(data_len)
 */
    __pyx_t_2 = ((__pyx_v_buf_len >= __pyx_v_data_len) != 0);
    if (__pyx_t_2) {

      /* "uvloop/sslproto.pyx":725
 * 
 *         if buf_len >= data_len:
 *             buf[:data_len] = data             # <<<<<<<<<<<<<<
 *             proto.buffer_updated(data_len)
 *             return
 */
      if (__Pyx_PyObject_SetSlice(__pyx_v_buf, __pyx_v_data, 0, __pyx_v_data_len, NULL, NULL, NULL, 0, 1, 1) < 0) __PYX_ERR(0, 725, __pyx_L1_error)

      /* "uvloop/sslproto.pyx":726
 *         if buf_len >= data_len:
 *             buf[:data_len] = data
 *             proto.buffer_updated(data_len)             # <<<<<<<<<<<<<<
 *             return
 *         else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_proto, __pyx_n_s_buffer_updated); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyInt_FromSsize_t(__pyx_v_data_len); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 726, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_7};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 726, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_7};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 726, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        {
          __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 726, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_GIVEREF(__pyx_t_7);
          PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_7);
          __pyx_t_7 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 726, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/sslproto.pyx":727
 *             buf[:data_len] = data
 *             proto.buffer_updated(data_len)
 *             return             # <<<<<<<<<<<<<<
 *         else:
 *             buf[:buf_len] = data[:buf_len]
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "uvloop/sslproto.pyx":724
 *             raise RuntimeError('get_buffer() returned an empty buffer')
 * 
 *         if buf_len >= data_len:             # <<<<<<<<<<<<<<
 *             buf[:data_len] = data
 *             proto.buffer_updated(data_len)
 */
    }

    /* "uvloop/sslproto.pyx":729
 *             return
 *         else:
 *             buf[:buf_len] = data[:buf_len]             # <<<<<<<<<<<<<<
 *             proto.buffer_updated(buf_len)
 *             data = data[buf_len:]
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_data, 0, __pyx_v_buf_len, NULL, NULL, NULL, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 729, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (__Pyx_PyObject_SetSlice(__pyx_v_buf, __pyx_t_3, 0, __pyx_v_buf_len, NULL, NULL, NULL, 0, 1, 1) < 0) __PYX_ERR(0, 729, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/sslproto.pyx":730
 *         else:
 *             buf[:buf_len] = data[:buf_len]
 *             proto.buffer_updated(buf_len)             # <<<<<<<<<<<<<<
 *             data = data[buf_len:]
 *             data_len = len(data)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_proto, __pyx_n_s_buffer_updated); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_buf_len); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 730, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_7) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 730, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 730, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 730, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        } else
        #endif
        {
          __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 730, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7); __pyx_t_7 = NULL;
          __Pyx_GIVEREF(__pyx_t_6);
          PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 730, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/sslproto.pyx":731
 *             buf[:buf_len] = data[:buf_len]
 *             proto.buffer_updated(buf_len)
 *             data = data[buf_len:]             # <<<<<<<<<<<<<<
 *             data_len = len(data)
 */
      __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_v_data, __pyx_v_buf_len, 0, NULL, NULL, NULL, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 731, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF_SET(__pyx_v_data, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "uvloop/sslproto.pyx":732
 *             proto.buffer_updated(buf_len)
 *             data = data[buf_len:]
 *             data_len = len(data)             # <<<<<<<<<<<<<<
 */
      __pyx_t_1 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 732, __pyx_L1_error)
      __pyx_v_data_len = __pyx_t_1;
    }
  }

  /* "uvloop/sslproto.pyx":716
 * 
 * 
 * cdef _feed_data_to_bufferred_proto(proto, data):             # <<<<<<<<<<<<<<
 *     data_len = len(data)
 *     while data_len:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("uvloop.loop._feed_data_to_bufferred_proto", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_buf);
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":4
 * cdef class UDPTransport(UVBaseTransport):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.sock = None
 *         self.poll = None
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_12UDPTransport_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_12UDPTransport_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6uvloop_4loop_12UDPTransport___cinit__(((struct __pyx_obj_6uvloop_4loop_UDPTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_12UDPTransport___cinit__(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/handles/udp.pyx":5
 * 
 *     def __cinit__(self):
 *         self.sock = None             # <<<<<<<<<<<<<<
 *         self.poll = None
 *         self.buffer = col_deque()
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->sock);
  __Pyx_DECREF(__pyx_v_self->sock);
  __pyx_v_self->sock = Py_None;

  /* "uvloop/handles/udp.pyx":6
 *     def __cinit__(self):
 *         self.sock = None
 *         self.poll = None             # <<<<<<<<<<<<<<
 *         self.buffer = col_deque()
 *         self._has_handle = 0
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->poll);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->poll));
  __pyx_v_self->poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)Py_None);

  /* "uvloop/handles/udp.pyx":7
 *         self.sock = None
 *         self.poll = None
 *         self.buffer = col_deque()             # <<<<<<<<<<<<<<
 *         self._has_handle = 0
 * 
 */
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_col_deque);
  __pyx_t_2 = __pyx_v_6uvloop_4loop_col_deque; __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 7, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 7, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->buffer);
  __Pyx_DECREF(__pyx_v_self->buffer);
  __pyx_v_self->buffer = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":8
 *         self.poll = None
 *         self.buffer = col_deque()
 *         self._has_handle = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef _init(self, Loop loop, object sock, object r_addr):
 */
  __pyx_v_self->__pyx_base.__pyx_base.__pyx_base._has_handle = 0;

  /* "uvloop/handles/udp.pyx":4
 * cdef class UDPTransport(UVBaseTransport):
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.sock = None
 *         self.poll = None
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":10
 *         self._has_handle = 0
 * 
 *     cdef _init(self, Loop loop, object sock, object r_addr):             # <<<<<<<<<<<<<<
 *         self._start_init(loop)
 *         try:
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__init(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_sock, PyObject *__pyx_v_r_addr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("_init", 0);

  /* "uvloop/handles/udp.pyx":11
 * 
 *     cdef _init(self, Loop loop, object sock, object r_addr):
 *         self._start_init(loop)             # <<<<<<<<<<<<<<
 *         try:
 *             # It's important to incref the socket in case it
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._start_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":12
 *     cdef _init(self, Loop loop, object sock, object r_addr):
 *         self._start_init(loop)
 *         try:             # <<<<<<<<<<<<<<
 *             # It's important to incref the socket in case it
 *             # was created outside of uvloop,
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/handles/udp.pyx":16
 *             # was created outside of uvloop,
 *             # i.e. `look.create_datagram_endpoint(sock=sock)`.
 *             socket_inc_io_ref(sock)             # <<<<<<<<<<<<<<
 * 
 *             self.sock = sock
 */
      __pyx_t_1 = __pyx_f_6uvloop_4loop_socket_inc_io_ref(__pyx_v_sock); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 16, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/udp.pyx":18
 *             socket_inc_io_ref(sock)
 * 
 *             self.sock = sock             # <<<<<<<<<<<<<<
 *             self.address = r_addr
 *             self.poll = UVPoll.new(loop, sock.fileno())
 */
      __Pyx_INCREF(__pyx_v_sock);
      __Pyx_GIVEREF(__pyx_v_sock);
      __Pyx_GOTREF(__pyx_v_self->sock);
      __Pyx_DECREF(__pyx_v_self->sock);
      __pyx_v_self->sock = __pyx_v_sock;

      /* "uvloop/handles/udp.pyx":19
 * 
 *             self.sock = sock
 *             self.address = r_addr             # <<<<<<<<<<<<<<
 *             self.poll = UVPoll.new(loop, sock.fileno())
 *             self._finish_init()
 */
      __Pyx_INCREF(__pyx_v_r_addr);
      __Pyx_GIVEREF(__pyx_v_r_addr);
      __Pyx_GOTREF(__pyx_v_self->address);
      __Pyx_DECREF(__pyx_v_self->address);
      __pyx_v_self->address = __pyx_v_r_addr;

      /* "uvloop/handles/udp.pyx":20
 *             self.sock = sock
 *             self.address = r_addr
 *             self.poll = UVPoll.new(loop, sock.fileno())             # <<<<<<<<<<<<<<
 *             self._finish_init()
 *         except:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 20, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (__pyx_t_6) {
        __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 20, __pyx_L3_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 20, __pyx_L3_error)
      }
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(22, 20, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = ((PyObject *)__pyx_f_6uvloop_4loop_6UVPoll_new(__pyx_v_loop, __pyx_t_7)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 20, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->poll);
      __Pyx_DECREF(((PyObject *)__pyx_v_self->poll));
      __pyx_v_self->poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "uvloop/handles/udp.pyx":21
 *             self.address = r_addr
 *             self.poll = UVPoll.new(loop, sock.fileno())
 *             self._finish_init()             # <<<<<<<<<<<<<<
 *         except:
 *             self._free()
 */
      __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._finish_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 21, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "uvloop/handles/udp.pyx":12
 *     cdef _init(self, Loop loop, object sock, object r_addr):
 *         self._start_init(loop)
 *         try:             # <<<<<<<<<<<<<<
 *             # It's important to incref the socket in case it
 *             # was created outside of uvloop,
 */
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/udp.pyx":22
 *             self.poll = UVPoll.new(loop, sock.fileno())
 *             self._finish_init()
 *         except:             # <<<<<<<<<<<<<<
 *             self._free()
 *             self._abort_init()
 */
    /*except:*/ {
      __Pyx_AddTraceback("uvloop.loop.UDPTransport._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(22, 22, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);

      /* "uvloop/handles/udp.pyx":23
 *             self._finish_init()
 *         except:
 *             self._free()             # <<<<<<<<<<<<<<
 *             self._abort_init()
 *             raise
 */
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._free(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 23, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/handles/udp.pyx":24
 *         except:
 *             self._free()
 *             self._abort_init()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
      __pyx_t_8 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._abort_init(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 24, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/handles/udp.pyx":25
 *             self._free()
 *             self._abort_init()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *     cdef size_t _get_write_buffer_size(self):
 */
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_5, __pyx_t_6);
      __pyx_t_1 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0; 
      __PYX_ERR(22, 25, __pyx_L5_except_error)
    }
    __pyx_L5_except_error:;

    /* "uvloop/handles/udp.pyx":12
 *     cdef _init(self, Loop loop, object sock, object r_addr):
 *         self._start_init(loop)
 *         try:             # <<<<<<<<<<<<<<
 *             # It's important to incref the socket in case it
 *             # was created outside of uvloop,
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "uvloop/handles/udp.pyx":10
 *         self._has_handle = 0
 * 
 *     cdef _init(self, Loop loop, object sock, object r_addr):             # <<<<<<<<<<<<<<
 *         self._start_init(loop)
 *         try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":27
 *             raise
 * 
 *     cdef size_t _get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         cdef int size = 0
 *         for data, addr in self.buffer:
 */

static size_t __pyx_f_6uvloop_4loop_12UDPTransport__get_write_buffer_size(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  int __pyx_v_size;
  PyObject *__pyx_v_data = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_addr = NULL;
  size_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  Py_ssize_t __pyx_t_9;
  __Pyx_RefNannySetupContext("_get_write_buffer_size", 0);

  /* "uvloop/handles/udp.pyx":28
 * 
 *     cdef size_t _get_write_buffer_size(self):
 *         cdef int size = 0             # <<<<<<<<<<<<<<
 *         for data, addr in self.buffer:
 *             size += len(data)
 */
  __pyx_v_size = 0;

  /* "uvloop/handles/udp.pyx":29
 *     cdef size_t _get_write_buffer_size(self):
 *         cdef int size = 0
 *         for data, addr in self.buffer:             # <<<<<<<<<<<<<<
 *             size += len(data)
 *         return size
 */
  if (likely(PyList_CheckExact(__pyx_v_self->buffer)) || PyTuple_CheckExact(__pyx_v_self->buffer)) {
    __pyx_t_1 = __pyx_v_self->buffer; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_self->buffer); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 29, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 29, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(22, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(22, 29, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 29, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(22, 29, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
      PyObject* sequence = __pyx_t_4;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(22, 29, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_6 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 29, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 29, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      #endif
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_7 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 29, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
      index = 0; __pyx_t_5 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_6);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) __PYX_ERR(22, 29, __pyx_L1_error)
      __pyx_t_8 = NULL;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(22, 29, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_data, __pyx_t_5);
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_addr, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "uvloop/handles/udp.pyx":30
 *         cdef int size = 0
 *         for data, addr in self.buffer:
 *             size += len(data)             # <<<<<<<<<<<<<<
 *         return size
 * 
 */
    __pyx_t_9 = PyObject_Length(__pyx_v_data); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(22, 30, __pyx_L1_error)
    __pyx_v_size = (__pyx_v_size + __pyx_t_9);

    /* "uvloop/handles/udp.pyx":29
 *     cdef size_t _get_write_buffer_size(self):
 *         cdef int size = 0
 *         for data, addr in self.buffer:             # <<<<<<<<<<<<<<
 *             size += len(data)
 *         return size
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":31
 *         for data, addr in self.buffer:
 *             size += len(data)
 *         return size             # <<<<<<<<<<<<<<
 * 
 *     cdef _fileno(self):
 */
  __pyx_r = __pyx_v_size;
  goto __pyx_L0;

  /* "uvloop/handles/udp.pyx":27
 *             raise
 * 
 *     cdef size_t _get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         cdef int size = 0
 *         for data, addr in self.buffer:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_WriteUnraisable("uvloop.loop.UDPTransport._get_write_buffer_size", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_addr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":33
 *         return size
 * 
 *     cdef _fileno(self):             # <<<<<<<<<<<<<<
 *         return self.sock.fileno()
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__fileno(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("_fileno", 0);

  /* "uvloop/handles/udp.pyx":34
 * 
 *     cdef _fileno(self):
 *         return self.sock.fileno()             # <<<<<<<<<<<<<<
 * 
 *     cdef bint _is_reading(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (__pyx_t_3) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 34, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 34, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/udp.pyx":33
 *         return size
 * 
 *     cdef _fileno(self):             # <<<<<<<<<<<<<<
 *         return self.sock.fileno()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._fileno", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":36
 *         return self.sock.fileno()
 * 
 *     cdef bint _is_reading(self):             # <<<<<<<<<<<<<<
 *         return self.poll is not None and self.poll.is_reading()
 * 
 */

static int __pyx_f_6uvloop_4loop_12UDPTransport__is_reading(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_is_reading", 0);

  /* "uvloop/handles/udp.pyx":37
 * 
 *     cdef bint _is_reading(self):
 *         return self.poll is not None and self.poll.is_reading()             # <<<<<<<<<<<<<<
 * 
 *     cdef _start_reading(self):
 */
  __pyx_t_2 = (((PyObject *)__pyx_v_self->poll) != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->poll->__pyx_base.__pyx_vtab)->is_reading(__pyx_v_self->poll); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(22, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "uvloop/handles/udp.pyx":36
 *         return self.sock.fileno()
 * 
 *     cdef bint _is_reading(self):             # <<<<<<<<<<<<<<
 *         return self.poll is not None and self.poll.is_reading()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("uvloop.loop.UDPTransport._is_reading", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":39
 *         return self.poll is not None and self.poll.is_reading()
 * 
 *     cdef _start_reading(self):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__start_reading(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_start_reading", 0);

  /* "uvloop/handles/udp.pyx":40
 * 
 *     cdef _start_reading(self):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 * 
 *         self.poll.start_reading(
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":44
 *         self.poll.start_reading(
 *             new_MethodHandle(
 *                 self._loop,             # <<<<<<<<<<<<<<
 *                 "UDPTransport._on_read_ready",
 *                 <method_t>self._on_read_ready,
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop);
  __Pyx_INCREF(__pyx_t_1);

  /* "uvloop/handles/udp.pyx":43
 * 
 *         self.poll.start_reading(
 *             new_MethodHandle(             # <<<<<<<<<<<<<<
 *                 self._loop,
 *                 "UDPTransport._on_read_ready",
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_new_MethodHandle(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_1), __pyx_kp_u_UDPTransport__on_read_ready, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_on_read_ready), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(22, 43, __pyx_L1_error)

  /* "uvloop/handles/udp.pyx":42
 *         self._ensure_alive()
 * 
 *         self.poll.start_reading(             # <<<<<<<<<<<<<<
 *             new_MethodHandle(
 *                 self._loop,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->poll->__pyx_base.__pyx_vtab)->start_reading(__pyx_v_self->poll, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_2)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":39
 *         return self.poll is not None and self.poll.is_reading()
 * 
 *     cdef _start_reading(self):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._start_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":49
 *                 self))
 * 
 *     cdef _stop_reading(self):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         self.poll.stop_reading()
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__stop_reading(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("_stop_reading", 0);

  /* "uvloop/handles/udp.pyx":50
 * 
 *     cdef _stop_reading(self):
 *         self._ensure_alive()             # <<<<<<<<<<<<<<
 *         self.poll.stop_reading()
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._ensure_alive(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":51
 *     cdef _stop_reading(self):
 *         self._ensure_alive()
 *         self.poll.stop_reading()             # <<<<<<<<<<<<<<
 * 
 *     cdef _on_read_ready(self):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->poll->__pyx_base.__pyx_vtab)->stop_reading(__pyx_v_self->poll); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":49
 *                 self))
 * 
 *     cdef _stop_reading(self):             # <<<<<<<<<<<<<<
 *         self._ensure_alive()
 *         self.poll.stop_reading()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._stop_reading", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":53
 *         self.poll.stop_reading()
 * 
 *     cdef _on_read_ready(self):             # <<<<<<<<<<<<<<
 *         if self._conn_lost:
 *             return
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__on_read_ready(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_addr = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  char const *__pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  char const *__pyx_t_22;
  __Pyx_RefNannySetupContext("_on_read_ready", 0);

  /* "uvloop/handles/udp.pyx":54
 * 
 *     cdef _on_read_ready(self):
 *         if self._conn_lost:             # <<<<<<<<<<<<<<
 *             return
 *         try:
 */
  __pyx_t_1 = (__pyx_v_self->__pyx_base._conn_lost != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/udp.pyx":55
 *     cdef _on_read_ready(self):
 *         if self._conn_lost:
 *             return             # <<<<<<<<<<<<<<
 *         try:
 *             data, addr = self.sock.recvfrom(UV_STREAM_RECV_BUF_SIZE)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/udp.pyx":54
 * 
 *     cdef _on_read_ready(self):
 *         if self._conn_lost:             # <<<<<<<<<<<<<<
 *             return
 *         try:
 */
  }

  /* "uvloop/handles/udp.pyx":56
 *         if self._conn_lost:
 *             return
 *         try:             # <<<<<<<<<<<<<<
 *             data, addr = self.sock.recvfrom(UV_STREAM_RECV_BUF_SIZE)
 *         except (BlockingIOError, InterruptedError):
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "uvloop/handles/udp.pyx":57
 *             return
 *         try:
 *             data, addr = self.sock.recvfrom(UV_STREAM_RECV_BUF_SIZE)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             pass
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_recvfrom); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 57, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__264, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 57, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_6))) || (PyList_CheckExact(__pyx_t_6))) {
        PyObject* sequence = __pyx_t_6;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(22, 57, __pyx_L4_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        #else
        __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 57, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 57, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_8 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 57, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
        index = 0; __pyx_t_5 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_5)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 1; __pyx_t_7 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_7)) goto __pyx_L10_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) __PYX_ERR(22, 57, __pyx_L4_error)
        __pyx_t_9 = NULL;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L11_unpacking_done;
        __pyx_L10_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        __PYX_ERR(22, 57, __pyx_L4_error)
        __pyx_L11_unpacking_done:;
      }
      __pyx_v_data = __pyx_t_5;
      __pyx_t_5 = 0;
      __pyx_v_addr = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "uvloop/handles/udp.pyx":56
 *         if self._conn_lost:
 *             return
 *         try:             # <<<<<<<<<<<<<<
 *             data, addr = self.sock.recvfrom(UV_STREAM_RECV_BUF_SIZE)
 *         except (BlockingIOError, InterruptedError):
 */
    }

    /* "uvloop/handles/udp.pyx":65
 *             self._fatal_error(exc, 'Fatal read error on datagram transport')
 *         else:
 *             self._protocol.datagram_received(data, addr)             # <<<<<<<<<<<<<<
 * 
 *     cdef _on_write_ready(self):
 */
    /*else:*/ {
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._protocol, __pyx_n_s_datagram_received); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 65, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_data, __pyx_v_addr};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 65, __pyx_L6_except_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_data, __pyx_v_addr};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 65, __pyx_L6_except_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_6);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 65, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_v_data);
        __Pyx_GIVEREF(__pyx_v_data);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_10, __pyx_v_data);
        __Pyx_INCREF(__pyx_v_addr);
        __Pyx_GIVEREF(__pyx_v_addr);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_10, __pyx_v_addr);
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 65, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/handles/udp.pyx":58
 *         try:
 *             data, addr = self.sock.recvfrom(UV_STREAM_RECV_BUF_SIZE)
 *         except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *             pass
 *         except OSError as exc:
 */
    __Pyx_ErrFetch(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 58, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 58, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_5) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_6, __pyx_t_11);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_ErrRestore(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_t_6 = 0; __pyx_t_7 = 0; __pyx_t_8 = 0;
    if (__pyx_t_10) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L5_exception_handled;
    }

    /* "uvloop/handles/udp.pyx":60
 *         except (BlockingIOError, InterruptedError):
 *             pass
 *         except OSError as exc:             # <<<<<<<<<<<<<<
 *             self._protocol.error_received(exc)
 *         except Exception as exc:
 */
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
    if (__pyx_t_10) {
      __Pyx_AddTraceback("uvloop.loop.UDPTransport._on_read_ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6) < 0) __PYX_ERR(22, 60, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_exc = __pyx_t_7;
      /*try:*/ {

        /* "uvloop/handles/udp.pyx":61
 *             pass
 *         except OSError as exc:
 *             self._protocol.error_received(exc)             # <<<<<<<<<<<<<<
 *         except Exception as exc:
 *             self._fatal_error(exc, 'Fatal read error on datagram transport')
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._protocol, __pyx_n_s_error_received); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 61, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (!__pyx_t_12) {
          __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_exc); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 61, __pyx_L17_error)
          __Pyx_GOTREF(__pyx_t_11);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_exc};
            __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 61, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_11);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_12, __pyx_v_exc};
            __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 61, __pyx_L17_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_11);
          } else
          #endif
          {
            __pyx_t_13 = PyTuple_New(1+1); if (unlikely(!__pyx_t_13)) __PYX_ERR(22, 61, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
            __Pyx_INCREF(__pyx_v_exc);
            __Pyx_GIVEREF(__pyx_v_exc);
            PyTuple_SET_ITEM(__pyx_t_13, 0+1, __pyx_v_exc);
            __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_13, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 61, __pyx_L17_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }

      /* "uvloop/handles/udp.pyx":60
 *         except (BlockingIOError, InterruptedError):
 *             pass
 *         except OSError as exc:             # <<<<<<<<<<<<<<
 *             self._protocol.error_received(exc)
 *         except Exception as exc:
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L18;
        }
        __pyx_L17_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __pyx_t_10 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
          }
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
          __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
          goto __pyx_L6_except_error;
        }
        __pyx_L18:;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L5_exception_handled;
    }

    /* "uvloop/handles/udp.pyx":62
 *         except OSError as exc:
 *             self._protocol.error_received(exc)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, 'Fatal read error on datagram transport')
 *         else:
 */
    __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_14) {
      __Pyx_AddTraceback("uvloop.loop.UDPTransport._on_read_ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(22, 62, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_v_exc = __pyx_t_7;
      /*try:*/ {

        /* "uvloop/handles/udp.pyx":63
 *             self._protocol.error_received(exc)
 *         except Exception as exc:
 *             self._fatal_error(exc, 'Fatal read error on datagram transport')             # <<<<<<<<<<<<<<
 *         else:
 *             self._protocol.datagram_received(data, addr)
 */
        __pyx_t_11 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, __pyx_kp_u_Fatal_read_error_on_datagram_tra, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 63, __pyx_L28_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }

      /* "uvloop/handles/udp.pyx":62
 *         except OSError as exc:
 *             self._protocol.error_received(exc)
 *         except Exception as exc:             # <<<<<<<<<<<<<<
 *             self._fatal_error(exc, 'Fatal read error on datagram transport')
 *         else:
 */
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_DECREF(__pyx_v_exc);
          __pyx_v_exc = NULL;
          goto __pyx_L29;
        }
        __pyx_L28_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_17, &__pyx_t_16);
          if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_20, &__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_19);
          __Pyx_XGOTREF(__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_16);
          __pyx_t_14 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
          }
          if (PY_MAJOR_VERSION >= 3) {
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_16);
            __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_17, __pyx_t_16);
          }
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_19);
          __Pyx_ErrRestore(__pyx_t_21, __pyx_t_20, __pyx_t_19);
          __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0; __pyx_t_16 = 0;
          __pyx_lineno = __pyx_t_14; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_22;
          goto __pyx_L6_except_error;
        }
        __pyx_L29:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "uvloop/handles/udp.pyx":56
 *         if self._conn_lost:
 *             return
 *         try:             # <<<<<<<<<<<<<<
 *             data, addr = self.sock.recvfrom(UV_STREAM_RECV_BUF_SIZE)
 *         except (BlockingIOError, InterruptedError):
 */
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    __pyx_L9_try_end:;
  }

  /* "uvloop/handles/udp.pyx":53
 *         self.poll.stop_reading()
 * 
 *     cdef _on_read_ready(self):             # <<<<<<<<<<<<<<
 *         if self._conn_lost:
 *             return
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._on_read_ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_addr);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":67
 *             self._protocol.datagram_received(data, addr)
 * 
 *     cdef _on_write_ready(self):             # <<<<<<<<<<<<<<
 *         while self.buffer:
 *             data, addr = self.buffer.popleft()
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__on_write_ready(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_v_data = NULL;
  PyObject *__pyx_v_addr = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  char const *__pyx_t_23;
  int __pyx_t_24;
  __Pyx_RefNannySetupContext("_on_write_ready", 0);

  /* "uvloop/handles/udp.pyx":68
 * 
 *     cdef _on_write_ready(self):
 *         while self.buffer:             # <<<<<<<<<<<<<<
 *             data, addr = self.buffer.popleft()
 *             try:
 */
  while (1) {
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->buffer); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(22, 68, __pyx_L1_error)
    if (!__pyx_t_1) break;

    /* "uvloop/handles/udp.pyx":69
 *     cdef _on_write_ready(self):
 *         while self.buffer:
 *             data, addr = self.buffer.popleft()             # <<<<<<<<<<<<<<
 *             try:
 *                 if self.address:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->buffer, __pyx_n_s_popleft); if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (__pyx_t_4) {
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 69, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else {
      __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 69, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(22, 69, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 69, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 69, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_5 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 69, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(22, 69, __pyx_L1_error)
      __pyx_t_6 = NULL;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(22, 69, __pyx_L1_error)
      __pyx_L6_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_data, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_addr, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "uvloop/handles/udp.pyx":70
 *         while self.buffer:
 *             data, addr = self.buffer.popleft()
 *             try:             # <<<<<<<<<<<<<<
 *                 if self.address:
 *                     self.sock.send(data)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "uvloop/handles/udp.pyx":71
 *             data, addr = self.buffer.popleft()
 *             try:
 *                 if self.address:             # <<<<<<<<<<<<<<
 *                     self.sock.send(data)
 *                 else:
 */
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->address); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(22, 71, __pyx_L7_error)
        if (__pyx_t_1) {

          /* "uvloop/handles/udp.pyx":72
 *             try:
 *                 if self.address:
 *                     self.sock.send(data)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self.sock.sendto(data, addr)
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_send); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 72, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_3)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
            }
          }
          if (!__pyx_t_3) {
            __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 72, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_4)) {
              PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_data};
              __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 72, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
              PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_data};
              __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 72, __pyx_L7_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_2);
            } else
            #endif
            {
              __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 72, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
              __Pyx_INCREF(__pyx_v_data);
              __Pyx_GIVEREF(__pyx_v_data);
              PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_data);
              __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 72, __pyx_L7_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "uvloop/handles/udp.pyx":71
 *             data, addr = self.buffer.popleft()
 *             try:
 *                 if self.address:             # <<<<<<<<<<<<<<
 *                     self.sock.send(data)
 *                 else:
 */
          goto __pyx_L15;
        }

        /* "uvloop/handles/udp.pyx":74
 *                     self.sock.send(data)
 *                 else:
 *                     self.sock.sendto(data, addr)             # <<<<<<<<<<<<<<
 *             except (BlockingIOError, InterruptedError):
 *                 self.buffer.appendleft((data, addr))  # Try again later.
 */
        /*else*/ {
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_sendto); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 74, __pyx_L7_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = NULL;
          __pyx_t_10 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_10 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_data, __pyx_v_addr};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 74, __pyx_L7_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
            PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_data, __pyx_v_addr};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 74, __pyx_L7_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          {
            __pyx_t_3 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 74, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_3);
            if (__pyx_t_5) {
              __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5); __pyx_t_5 = NULL;
            }
            __Pyx_INCREF(__pyx_v_data);
            __Pyx_GIVEREF(__pyx_v_data);
            PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_10, __pyx_v_data);
            __Pyx_INCREF(__pyx_v_addr);
            __Pyx_GIVEREF(__pyx_v_addr);
            PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_10, __pyx_v_addr);
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 74, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __pyx_L15:;

        /* "uvloop/handles/udp.pyx":70
 *         while self.buffer:
 *             data, addr = self.buffer.popleft()
 *             try:             # <<<<<<<<<<<<<<
 *                 if self.address:
 *                     self.sock.send(data)
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L14_try_end;
      __pyx_L7_error:;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/udp.pyx":75
 *                 else:
 *                     self.sock.sendto(data, addr)
 *             except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *                 self.buffer.appendleft((data, addr))  # Try again later.
 *                 break
 */
      __Pyx_ErrFetch(&__pyx_t_2, &__pyx_t_4, &__pyx_t_3);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 75, __pyx_L9_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 75, __pyx_L9_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_5) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_2, __pyx_t_11);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_ErrRestore(__pyx_t_2, __pyx_t_4, __pyx_t_3);
      __pyx_t_2 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0;
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.UDPTransport._on_write_ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_2) < 0) __PYX_ERR(22, 75, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_2);

        /* "uvloop/handles/udp.pyx":76
 *                     self.sock.sendto(data, addr)
 *             except (BlockingIOError, InterruptedError):
 *                 self.buffer.appendleft((data, addr))  # Try again later.             # <<<<<<<<<<<<<<
 *                 break
 *             except OSError as exc:
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->buffer, __pyx_n_s_appendleft); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 76, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = PyTuple_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(22, 76, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_INCREF(__pyx_v_data);
        __Pyx_GIVEREF(__pyx_v_data);
        PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_data);
        __Pyx_INCREF(__pyx_v_addr);
        __Pyx_GIVEREF(__pyx_v_addr);
        PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_v_addr);
        __pyx_t_13 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        if (!__pyx_t_13) {
          __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 76, __pyx_L9_except_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_GOTREF(__pyx_t_11);
        } else {
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_12};
            __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 76, __pyx_L9_except_error)
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
            PyObject *__pyx_temp[2] = {__pyx_t_13, __pyx_t_12};
            __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 76, __pyx_L9_except_error)
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          } else
          #endif
          {
            __pyx_t_14 = PyTuple_New(1+1); if (unlikely(!__pyx_t_14)) __PYX_ERR(22, 76, __pyx_L9_except_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_13); __pyx_t_13 = NULL;
            __Pyx_GIVEREF(__pyx_t_12);
            PyTuple_SET_ITEM(__pyx_t_14, 0+1, __pyx_t_12);
            __pyx_t_12 = 0;
            __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_14, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 76, __pyx_L9_except_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          }
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "uvloop/handles/udp.pyx":77
 *             except (BlockingIOError, InterruptedError):
 *                 self.buffer.appendleft((data, addr))  # Try again later.
 *                 break             # <<<<<<<<<<<<<<
 *             except OSError as exc:
 *                 self._protocol.error_received(exc)
 */
        goto __pyx_L16_except_break;
        __pyx_L16_except_break:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L12_try_break;
      }

      /* "uvloop/handles/udp.pyx":78
 *                 self.buffer.appendleft((data, addr))  # Try again later.
 *                 break
 *             except OSError as exc:             # <<<<<<<<<<<<<<
 *                 self._protocol.error_received(exc)
 *                 return
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.UDPTransport._on_write_ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_4, &__pyx_t_3) < 0) __PYX_ERR(22, 78, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_v_exc = __pyx_t_4;
        /*try:*/ {

          /* "uvloop/handles/udp.pyx":79
 *                 break
 *             except OSError as exc:
 *                 self._protocol.error_received(exc)             # <<<<<<<<<<<<<<
 *                 return
 *             except Exception as exc:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._protocol, __pyx_n_s_error_received); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 79, __pyx_L23_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          if (!__pyx_t_14) {
            __pyx_t_11 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_exc); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 79, __pyx_L23_error)
            __Pyx_GOTREF(__pyx_t_11);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
              __pyx_t_11 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 79, __pyx_L23_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_11);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
              __pyx_t_11 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 79, __pyx_L23_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_11);
            } else
            #endif
            {
              __pyx_t_12 = PyTuple_New(1+1); if (unlikely(!__pyx_t_12)) __PYX_ERR(22, 79, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_14); __pyx_t_14 = NULL;
              __Pyx_INCREF(__pyx_v_exc);
              __Pyx_GIVEREF(__pyx_v_exc);
              PyTuple_SET_ITEM(__pyx_t_12, 0+1, __pyx_v_exc);
              __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_12, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 79, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "uvloop/handles/udp.pyx":80
 *             except OSError as exc:
 *                 self._protocol.error_received(exc)
 *                 return             # <<<<<<<<<<<<<<
 *             except Exception as exc:
 *                 self._fatal_error(
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_r = Py_None; __Pyx_INCREF(Py_None);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L22_return;
        }

        /* "uvloop/handles/udp.pyx":78
 *                 self.buffer.appendleft((data, addr))  # Try again later.
 *                 break
 *             except OSError as exc:             # <<<<<<<<<<<<<<
 *                 self._protocol.error_received(exc)
 *                 return
 */
        /*finally:*/ {
          __pyx_L23_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_10 = __pyx_lineno; __pyx_t_15 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_15; __pyx_filename = __pyx_t_16;
            goto __pyx_L9_except_error;
          }
          __pyx_L22_return: {
            __pyx_t_22 = __pyx_r;
            __pyx_r = 0;
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            __pyx_r = __pyx_t_22;
            __pyx_t_22 = 0;
            goto __pyx_L10_except_return;
          }
        }
      }

      /* "uvloop/handles/udp.pyx":81
 *                 self._protocol.error_received(exc)
 *                 return
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._fatal_error(
 *                     exc, 'Fatal write error on datagram transport')
 */
      __pyx_t_15 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_15) {
        __Pyx_AddTraceback("uvloop.loop.UDPTransport._on_write_ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_2) < 0) __PYX_ERR(22, 81, __pyx_L9_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __pyx_v_exc = __pyx_t_4;
        /*try:*/ {

          /* "uvloop/handles/udp.pyx":82
 *                 return
 *             except Exception as exc:
 *                 self._fatal_error(             # <<<<<<<<<<<<<<
 *                     exc, 'Fatal write error on datagram transport')
 *                 return
 */
          __pyx_t_11 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, __pyx_kp_u_Fatal_write_error_on_datagram_tr, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(22, 82, __pyx_L34_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "uvloop/handles/udp.pyx":84
 *                 self._fatal_error(
 *                     exc, 'Fatal write error on datagram transport')
 *                 return             # <<<<<<<<<<<<<<
 * 
 *         self._maybe_resume_protocol()  # May append to buffer.
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_r = Py_None; __Pyx_INCREF(Py_None);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L33_return;
        }

        /* "uvloop/handles/udp.pyx":81
 *                 self._protocol.error_received(exc)
 *                 return
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._fatal_error(
 *                     exc, 'Fatal write error on datagram transport')
 */
        /*finally:*/ {
          __pyx_L34_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_17);
            __pyx_t_15 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_23 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_18, __pyx_t_17);
            }
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ErrRestore(__pyx_t_22, __pyx_t_21, __pyx_t_20);
            __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
            __pyx_lineno = __pyx_t_15; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_23;
            goto __pyx_L9_except_error;
          }
          __pyx_L33_return: {
            __pyx_t_17 = __pyx_r;
            __pyx_r = 0;
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            __pyx_r = __pyx_t_17;
            __pyx_t_17 = 0;
            goto __pyx_L10_except_return;
          }
        }
      }
      goto __pyx_L9_except_error;
      __pyx_L9_except_error:;

      /* "uvloop/handles/udp.pyx":70
 *         while self.buffer:
 *             data, addr = self.buffer.popleft()
 *             try:             # <<<<<<<<<<<<<<
 *                 if self.address:
 *                     self.sock.send(data)
 */
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L1_error;
      __pyx_L12_try_break:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L4_break;
      __pyx_L10_except_return:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L0;
      __pyx_L14_try_end:;
    }
  }
  __pyx_L4_break:;

  /* "uvloop/handles/udp.pyx":86
 *                 return
 * 
 *         self._maybe_resume_protocol()  # May append to buffer.             # <<<<<<<<<<<<<<
 *         if not self.buffer:
 *             self.poll.stop_writing()
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._maybe_resume_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/udp.pyx":87
 * 
 *         self._maybe_resume_protocol()  # May append to buffer.
 *         if not self.buffer:             # <<<<<<<<<<<<<<
 *             self.poll.stop_writing()
 *             if self._closing:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->buffer); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(22, 87, __pyx_L1_error)
  __pyx_t_24 = ((!__pyx_t_1) != 0);
  if (__pyx_t_24) {

    /* "uvloop/handles/udp.pyx":88
 *         self._maybe_resume_protocol()  # May append to buffer.
 *         if not self.buffer:
 *             self.poll.stop_writing()             # <<<<<<<<<<<<<<
 *             if self._closing:
 *                 self._call_connection_lost(None)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->poll->__pyx_base.__pyx_vtab)->stop_writing(__pyx_v_self->poll); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/udp.pyx":89
 *         if not self.buffer:
 *             self.poll.stop_writing()
 *             if self._closing:             # <<<<<<<<<<<<<<
 *                 self._call_connection_lost(None)
 * 
 */
    __pyx_t_24 = (__pyx_v_self->__pyx_base._closing != 0);
    if (__pyx_t_24) {

      /* "uvloop/handles/udp.pyx":90
 *             self.poll.stop_writing()
 *             if self._closing:
 *                 self._call_connection_lost(None)             # <<<<<<<<<<<<<<
 * 
 *     cdef _new_socket(self):
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._call_connection_lost(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self), Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 90, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "uvloop/handles/udp.pyx":89
 *         if not self.buffer:
 *             self.poll.stop_writing()
 *             if self._closing:             # <<<<<<<<<<<<<<
 *                 self._call_connection_lost(None)
 * 
 */
    }

    /* "uvloop/handles/udp.pyx":87
 * 
 *         self._maybe_resume_protocol()  # May append to buffer.
 *         if not self.buffer:             # <<<<<<<<<<<<<<
 *             self.poll.stop_writing()
 *             if self._closing:
 */
  }

  /* "uvloop/handles/udp.pyx":67
 *             self._protocol.datagram_received(data, addr)
 * 
 *     cdef _on_write_ready(self):             # <<<<<<<<<<<<<<
 *         while self.buffer:
 *             data, addr = self.buffer.popleft()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._on_write_ready", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_addr);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":92
 *                 self._call_connection_lost(None)
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return PseudoSocket(self.sock.family, self.sock.type,
 *                             self.sock.proto, self.sock.fileno())
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__new_socket(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_new_socket", 0);

  /* "uvloop/handles/udp.pyx":93
 * 
 *     cdef _new_socket(self):
 *         return PseudoSocket(self.sock.family, self.sock.type,             # <<<<<<<<<<<<<<
 *                             self.sock.proto, self.sock.fileno())
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_family); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "uvloop/handles/udp.pyx":94
 *     cdef _new_socket(self):
 *         return PseudoSocket(self.sock.family, self.sock.type,
 *                             self.sock.proto, self.sock.fileno())             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_proto); if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_fileno); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  if (__pyx_t_6) {
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 94, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 94, __pyx_L1_error)
  }
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "uvloop/handles/udp.pyx":93
 * 
 *     cdef _new_socket(self):
 *         return PseudoSocket(self.sock.family, self.sock.type,             # <<<<<<<<<<<<<<
 *                             self.sock.proto, self.sock.fileno())
 * 
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_4);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_6uvloop_4loop_PseudoSocket), __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "uvloop/handles/udp.pyx":92
 *                 self._call_connection_lost(None)
 * 
 *     cdef _new_socket(self):             # <<<<<<<<<<<<<<
 *         return PseudoSocket(self.sock.family, self.sock.type,
 *                             self.sock.proto, self.sock.fileno())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._new_socket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":97
 * 
 *     @staticmethod
 *     cdef UDPTransport new(Loop loop, object sock, object r_addr):             # <<<<<<<<<<<<<<
 *         cdef UDPTransport udp
 *         udp = UDPTransport.__new__(UDPTransport)
 */

static struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_f_6uvloop_4loop_12UDPTransport_new(struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop, PyObject *__pyx_v_sock, PyObject *__pyx_v_r_addr) {
  struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_udp = 0;
  struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("new", 0);

  /* "uvloop/handles/udp.pyx":99
 *     cdef UDPTransport new(Loop loop, object sock, object r_addr):
 *         cdef UDPTransport udp
 *         udp = UDPTransport.__new__(UDPTransport)             # <<<<<<<<<<<<<<
 *         udp._init(loop, sock, r_addr)
 *         return udp
 */
  __pyx_t_1 = ((PyObject *)__pyx_tp_new_6uvloop_4loop_UDPTransport(((PyTypeObject *)__pyx_ptype_6uvloop_4loop_UDPTransport), __pyx_empty_tuple, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 99, __pyx_L1_error)
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_v_udp = ((struct __pyx_obj_6uvloop_4loop_UDPTransport *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":100
 *         cdef UDPTransport udp
 *         udp = UDPTransport.__new__(UDPTransport)
 *         udp._init(loop, sock, r_addr)             # <<<<<<<<<<<<<<
 *         return udp
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_udp->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_init(__pyx_v_udp, __pyx_v_loop, __pyx_v_sock, __pyx_v_r_addr); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":101
 *         udp = UDPTransport.__new__(UDPTransport)
 *         udp._init(loop, sock, r_addr)
 *         return udp             # <<<<<<<<<<<<<<
 * 
 *     cdef _dealloc_impl(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_udp));
  __pyx_r = __pyx_v_udp;
  goto __pyx_L0;

  /* "uvloop/handles/udp.pyx":97
 * 
 *     @staticmethod
 *     cdef UDPTransport new(Loop loop, object sock, object r_addr):             # <<<<<<<<<<<<<<
 *         cdef UDPTransport udp
 *         udp = UDPTransport.__new__(UDPTransport)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport.new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_udp);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":103
 *         return udp
 * 
 *     cdef _dealloc_impl(self):             # <<<<<<<<<<<<<<
 *         if self._closed == 0:
 *             self._warn_unclosed()
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__dealloc_impl(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("_dealloc_impl", 0);

  /* "uvloop/handles/udp.pyx":104
 * 
 *     cdef _dealloc_impl(self):
 *         if self._closed == 0:             # <<<<<<<<<<<<<<
 *             self._warn_unclosed()
 *             self._close()
 */
  __pyx_t_1 = ((__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._closed == 0) != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/udp.pyx":105
 *     cdef _dealloc_impl(self):
 *         if self._closed == 0:
 *             self._warn_unclosed()             # <<<<<<<<<<<<<<
 *             self._close()
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._warn_unclosed(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/udp.pyx":106
 *         if self._closed == 0:
 *             self._warn_unclosed()
 *             self._close()             # <<<<<<<<<<<<<<
 * 
 *         # It is unsafe to call `self.poll._close()` here as
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "uvloop/handles/udp.pyx":104
 * 
 *     cdef _dealloc_impl(self):
 *         if self._closed == 0:             # <<<<<<<<<<<<<<
 *             self._warn_unclosed()
 *             self._close()
 */
  }

  /* "uvloop/handles/udp.pyx":113
 *         # zombie Python object.  So we do nothing.
 * 
 *         UVHandle._dealloc_impl(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _free(self):
 */
  __pyx_t_2 = __pyx_f_6uvloop_4loop_8UVHandle__dealloc_impl(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(22, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/handles/udp.pyx":103
 *         return udp
 * 
 *     cdef _dealloc_impl(self):             # <<<<<<<<<<<<<<
 *         if self._closed == 0:
 *             self._warn_unclosed()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._dealloc_impl", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":115
 *         UVHandle._dealloc_impl(self)
 * 
 *     cdef _free(self):             # <<<<<<<<<<<<<<
 *         if self.poll is not None:
 *             self.poll._close()
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__free(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("_free", 0);

  /* "uvloop/handles/udp.pyx":116
 * 
 *     cdef _free(self):
 *         if self.poll is not None:             # <<<<<<<<<<<<<<
 *             self.poll._close()
 *             self.poll = None
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_self->poll) != Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/udp.pyx":117
 *     cdef _free(self):
 *         if self.poll is not None:
 *             self.poll._close()             # <<<<<<<<<<<<<<
 *             self.poll = None
 * 
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->poll->__pyx_base.__pyx_vtab)->__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self->poll)); if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/handles/udp.pyx":118
 *         if self.poll is not None:
 *             self.poll._close()
 *             self.poll = None             # <<<<<<<<<<<<<<
 * 
 *         if self.sock is not None:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->poll);
    __Pyx_DECREF(((PyObject *)__pyx_v_self->poll));
    __pyx_v_self->poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)Py_None);

    /* "uvloop/handles/udp.pyx":116
 * 
 *     cdef _free(self):
 *         if self.poll is not None:             # <<<<<<<<<<<<<<
 *             self.poll._close()
 *             self.poll = None
 */
  }

  /* "uvloop/handles/udp.pyx":120
 *             self.poll = None
 * 
 *         if self.sock is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 socket_dec_io_ref(self.sock)
 */
  __pyx_t_2 = (__pyx_v_self->sock != Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "uvloop/handles/udp.pyx":121
 * 
 *         if self.sock is not None:
 *             try:             # <<<<<<<<<<<<<<
 *                 socket_dec_io_ref(self.sock)
 *                 self.sock.close()
 */
    /*try:*/ {

      /* "uvloop/handles/udp.pyx":122
 *         if self.sock is not None:
 *             try:
 *                 socket_dec_io_ref(self.sock)             # <<<<<<<<<<<<<<
 *                 self.sock.close()
 *             finally:
 */
      __pyx_t_3 = __pyx_v_self->sock;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_4 = __pyx_f_6uvloop_4loop_socket_dec_io_ref(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 122, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/handles/udp.pyx":123
 *             try:
 *                 socket_dec_io_ref(self.sock)
 *                 self.sock.close()             # <<<<<<<<<<<<<<
 *             finally:
 *                 self.sock = None
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_close); if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 123, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      if (__pyx_t_5) {
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 123, __pyx_L6_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 123, __pyx_L6_error)
      }
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }

    /* "uvloop/handles/udp.pyx":125
 *                 self.sock.close()
 *             finally:
 *                 self.sock = None             # <<<<<<<<<<<<<<
 * 
 *         UVBaseTransport._free(self)
 */
    /*finally:*/ {
      /*normal exit:*/{
        __Pyx_INCREF(Py_None);
        __Pyx_GIVEREF(Py_None);
        __Pyx_GOTREF(__pyx_v_self->sock);
        __Pyx_DECREF(__pyx_v_self->sock);
        __pyx_v_self->sock = Py_None;
        goto __pyx_L7;
      }
      __pyx_L6_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
        if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_14);
        __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
        {
          __Pyx_INCREF(Py_None);
          __Pyx_GIVEREF(Py_None);
          __Pyx_GOTREF(__pyx_v_self->sock);
          __Pyx_DECREF(__pyx_v_self->sock);
          __pyx_v_self->sock = Py_None;
        }
        if (PY_MAJOR_VERSION >= 3) {
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
        }
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
        __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
        goto __pyx_L1_error;
      }
      __pyx_L7:;
    }

    /* "uvloop/handles/udp.pyx":120
 *             self.poll = None
 * 
 *         if self.sock is not None:             # <<<<<<<<<<<<<<
 *             try:
 *                 socket_dec_io_ref(self.sock)
 */
  }

  /* "uvloop/handles/udp.pyx":127
 *                 self.sock = None
 * 
 *         UVBaseTransport._free(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _close(self):
 */
  __pyx_t_4 = __pyx_vtabptr_6uvloop_4loop_UVBaseTransport->__pyx_base.__pyx_base._free(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "uvloop/handles/udp.pyx":115
 *         UVHandle._dealloc_impl(self)
 * 
 *     cdef _free(self):             # <<<<<<<<<<<<<<
 *         if self.poll is not None:
 *             self.poll._close()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._free", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":129
 *         UVBaseTransport._free(self)
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         self._free()
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_12UDPTransport__close(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_close", 0);

  /* "uvloop/handles/udp.pyx":130
 * 
 *     cdef _close(self):
 *         self._free()             # <<<<<<<<<<<<<<
 * 
 *         if UVLOOP_DEBUG:
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._free(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":132
 *         self._free()
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_handles_closed.update([
 *                 self.__class__.__name__])
 */
  __pyx_t_2 = (UVLOOP_DEBUG != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/udp.pyx":133
 * 
 *         if UVLOOP_DEBUG:
 *             self._loop._debug_handles_closed.update([             # <<<<<<<<<<<<<<
 *                 self.__class__.__name__])
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop->_debug_handles_closed, __pyx_n_s_update); if (unlikely(!__pyx_t_3)) __PYX_ERR(22, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "uvloop/handles/udp.pyx":134
 *         if UVLOOP_DEBUG:
 *             self._loop._debug_handles_closed.update([
 *                 self.__class__.__name__])             # <<<<<<<<<<<<<<
 * 
 *         UVSocketHandle._close(<UVSocketHandle>self)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/handles/udp.pyx":133
 * 
 *         if UVLOOP_DEBUG:
 *             self._loop._debug_handles_closed.update([             # <<<<<<<<<<<<<<
 *                 self.__class__.__name__])
 * 
 */
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(22, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 133, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 133, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 133, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 133, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 133, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/udp.pyx":132
 *         self._free()
 * 
 *         if UVLOOP_DEBUG:             # <<<<<<<<<<<<<<
 *             self._loop._debug_handles_closed.update([
 *                 self.__class__.__name__])
 */
  }

  /* "uvloop/handles/udp.pyx":136
 *                 self.__class__.__name__])
 * 
 *         UVSocketHandle._close(<UVSocketHandle>self)             # <<<<<<<<<<<<<<
 * 
 *     def sendto(self, data, addr=None):
 */
  __pyx_t_1 = __pyx_f_6uvloop_4loop_14UVSocketHandle__close(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)__pyx_v_self)); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/udp.pyx":129
 *         UVBaseTransport._free(self)
 * 
 *     cdef _close(self):             # <<<<<<<<<<<<<<
 *         self._free()
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport._close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/handles/udp.pyx":138
 *         UVSocketHandle._close(<UVSocketHandle>self)
 * 
 *     def sendto(self, data, addr=None):             # <<<<<<<<<<<<<<
 *         if not isinstance(data, (bytes, bytearray, memoryview)):
 *             raise TypeError('data argument must be a bytes-like object, '
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12UDPTransport_3sendto(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_12UDPTransport_2sendto[] = "UDPTransport.sendto(self, data, addr=None)";
static PyObject *__pyx_pw_6uvloop_4loop_12UDPTransport_3sendto(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_v_addr = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sendto (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_data,&__pyx_n_s_addr,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_addr);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "sendto") < 0)) __PYX_ERR(22, 138, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_data = values[0];
    __pyx_v_addr = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sendto", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(22, 138, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.UDPTransport.sendto", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_12UDPTransport_2sendto(((struct __pyx_obj_6uvloop_4loop_UDPTransport *)__pyx_v_self), __pyx_v_data, __pyx_v_addr);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12UDPTransport_2sendto(struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self, PyObject *__pyx_v_data, PyObject *__pyx_v_addr) {
  PyObject *__pyx_v_addrinfo = NULL;
  PyObject *__pyx_v_exc = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  char const *__pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  char const *__pyx_t_23;
  int __pyx_t_24;
  __Pyx_RefNannySetupContext("sendto", 0);

  /* "uvloop/handles/udp.pyx":139
 * 
 *     def sendto(self, data, addr=None):
 *         if not isinstance(data, (bytes, bytearray, memoryview)):             # <<<<<<<<<<<<<<
 *             raise TypeError('data argument must be a bytes-like object, '
 *                             'not {!r}'.format(type(data).__name__))
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_memoryview); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyBytes_Check(__pyx_v_data); 
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (!__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyByteArray_Check(__pyx_v_data); 
  __pyx_t_3 = (__pyx_t_4 != 0);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = PyObject_IsInstance(__pyx_v_data, __pyx_t_1); 
  __pyx_t_4 = (__pyx_t_3 != 0);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = ((!(__pyx_t_2 != 0)) != 0);
  if (unlikely(__pyx_t_4)) {

    /* "uvloop/handles/udp.pyx":141
 *         if not isinstance(data, (bytes, bytearray, memoryview)):
 *             raise TypeError('data argument must be a bytes-like object, '
 *                             'not {!r}'.format(type(data).__name__))             # <<<<<<<<<<<<<<
 *         if not data:
 *             return
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_data_argument_must_be_a_bytes_li, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_data)), __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 141, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
      }
    }
    if (!__pyx_t_7) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 141, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 141, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[2] = {__pyx_t_7, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 141, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 141, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_7); __pyx_t_7 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 141, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/handles/udp.pyx":140
 *     def sendto(self, data, addr=None):
 *         if not isinstance(data, (bytes, bytearray, memoryview)):
 *             raise TypeError('data argument must be a bytes-like object, '             # <<<<<<<<<<<<<<
 *                             'not {!r}'.format(type(data).__name__))
 *         if not data:
 */
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(22, 140, __pyx_L1_error)

    /* "uvloop/handles/udp.pyx":139
 * 
 *     def sendto(self, data, addr=None):
 *         if not isinstance(data, (bytes, bytearray, memoryview)):             # <<<<<<<<<<<<<<
 *             raise TypeError('data argument must be a bytes-like object, '
 *                             'not {!r}'.format(type(data).__name__))
 */
  }

  /* "uvloop/handles/udp.pyx":142
 *             raise TypeError('data argument must be a bytes-like object, '
 *                             'not {!r}'.format(type(data).__name__))
 *         if not data:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_data); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(22, 142, __pyx_L1_error)
  __pyx_t_2 = ((!__pyx_t_4) != 0);
  if (__pyx_t_2) {

    /* "uvloop/handles/udp.pyx":143
 *                             'not {!r}'.format(type(data).__name__))
 *         if not data:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if self.address and addr not in (None, self.address):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/udp.pyx":142
 *             raise TypeError('data argument must be a bytes-like object, '
 *                             'not {!r}'.format(type(data).__name__))
 *         if not data:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/handles/udp.pyx":145
 *             return
 * 
 *         if self.address and addr not in (None, self.address):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'Invalid address: must be None or {}'.format(self.address))
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_self->address); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(22, 145, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L9_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_addr);
  __pyx_t_5 = __pyx_v_addr;
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_5, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 145, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(22, 145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_4 = __pyx_t_3;
    goto __pyx_L11_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_5, __pyx_v_self->address, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 145, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(22, 145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __pyx_t_3;
  __pyx_L11_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L9_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "uvloop/handles/udp.pyx":147
 *         if self.address and addr not in (None, self.address):
 *             raise ValueError(
 *                 'Invalid address: must be None or {}'.format(self.address))             # <<<<<<<<<<<<<<
 * 
 *         if addr is not None:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_Invalid_address_must_be_None_or, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_self->address); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->address};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 147, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_v_self->address};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 147, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_INCREF(__pyx_v_self->address);
        __Pyx_GIVEREF(__pyx_v_self->address);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_self->address);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/handles/udp.pyx":146
 * 
 *         if self.address and addr not in (None, self.address):
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'Invalid address: must be None or {}'.format(self.address))
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(22, 146, __pyx_L1_error)

    /* "uvloop/handles/udp.pyx":145
 *             return
 * 
 *         if self.address and addr not in (None, self.address):             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 'Invalid address: must be None or {}'.format(self.address))
 */
  }

  /* "uvloop/handles/udp.pyx":149
 *                 'Invalid address: must be None or {}'.format(self.address))
 * 
 *         if addr is not None:             # <<<<<<<<<<<<<<
 *             addrinfo = __static_getaddrinfo_pyaddr(
 *                 addr[0], addr[1],
 */
  __pyx_t_2 = (__pyx_v_addr != Py_None);
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/udp.pyx":151
 *         if addr is not None:
 *             addrinfo = __static_getaddrinfo_pyaddr(
 *                 addr[0], addr[1],             # <<<<<<<<<<<<<<
 *                 uv.AF_UNSPEC, self.sock.type, self.sock.proto, 0)
 *             if addrinfo is None:
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_addr, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_addr, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "uvloop/handles/udp.pyx":152
 *             addrinfo = __static_getaddrinfo_pyaddr(
 *                 addr[0], addr[1],
 *                 uv.AF_UNSPEC, self.sock.type, self.sock.proto, 0)             # <<<<<<<<<<<<<<
 *             if addrinfo is None:
 *                 raise ValueError(
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(22, 152, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_proto); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_10 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(22, 152, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "uvloop/handles/udp.pyx":150
 * 
 *         if addr is not None:
 *             addrinfo = __static_getaddrinfo_pyaddr(             # <<<<<<<<<<<<<<
 *                 addr[0], addr[1],
 *                 uv.AF_UNSPEC, self.sock.type, self.sock.proto, 0)
 */
    __pyx_t_6 = __pyx_f_6uvloop_4loop___static_getaddrinfo_pyaddr(__pyx_t_1, __pyx_t_5, AF_UNSPEC, __pyx_t_9, __pyx_t_10, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_addrinfo = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "uvloop/handles/udp.pyx":153
 *                 addr[0], addr[1],
 *                 uv.AF_UNSPEC, self.sock.type, self.sock.proto, 0)
 *             if addrinfo is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'UDP.sendto(): address {!r} requires a DNS lookup'.format(
 */
    __pyx_t_3 = (__pyx_v_addrinfo == Py_None);
    __pyx_t_2 = (__pyx_t_3 != 0);
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/handles/udp.pyx":155
 *             if addrinfo is None:
 *                 raise ValueError(
 *                     'UDP.sendto(): address {!r} requires a DNS lookup'.format(             # <<<<<<<<<<<<<<
 *                         addr))
 *             if addrinfo[0] != self.sock.family:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_UDP_sendto_address_r_requires_a, __pyx_n_s_format); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 155, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);

      /* "uvloop/handles/udp.pyx":156
 *                 raise ValueError(
 *                     'UDP.sendto(): address {!r} requires a DNS lookup'.format(
 *                         addr))             # <<<<<<<<<<<<<<
 *             if addrinfo[0] != self.sock.family:
 *                 raise ValueError(
 */
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      if (!__pyx_t_1) {
        __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_addr); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 155, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_addr};
          __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 155, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_6);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
          PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_addr};
          __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 155, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_GOTREF(__pyx_t_6);
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 155, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_1); __pyx_t_1 = NULL;
          __Pyx_INCREF(__pyx_v_addr);
          __Pyx_GIVEREF(__pyx_v_addr);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_addr);
          __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 155, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/handles/udp.pyx":154
 *                 uv.AF_UNSPEC, self.sock.type, self.sock.proto, 0)
 *             if addrinfo is None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'UDP.sendto(): address {!r} requires a DNS lookup'.format(
 *                         addr))
 */
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 154, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(22, 154, __pyx_L1_error)

      /* "uvloop/handles/udp.pyx":153
 *                 addr[0], addr[1],
 *                 uv.AF_UNSPEC, self.sock.type, self.sock.proto, 0)
 *             if addrinfo is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'UDP.sendto(): address {!r} requires a DNS lookup'.format(
 */
    }

    /* "uvloop/handles/udp.pyx":157
 *                     'UDP.sendto(): address {!r} requires a DNS lookup'.format(
 *                         addr))
 *             if addrinfo[0] != self.sock.family:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'UDP.sendto(): {!r} socket family mismatch'.format(
 */
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_addrinfo, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_family); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_5, __pyx_t_6, Py_NE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 157, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(22, 157, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(__pyx_t_2)) {

      /* "uvloop/handles/udp.pyx":159
 *             if addrinfo[0] != self.sock.family:
 *                 raise ValueError(
 *                     'UDP.sendto(): {!r} socket family mismatch'.format(             # <<<<<<<<<<<<<<
 *                         addr))
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_kp_u_UDP_sendto_r_socket_family_misma, __pyx_n_s_format); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);

      /* "uvloop/handles/udp.pyx":160
 *                 raise ValueError(
 *                     'UDP.sendto(): {!r} socket family mismatch'.format(
 *                         addr))             # <<<<<<<<<<<<<<
 * 
 *         if self._conn_lost and self._address:
 */
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_addr); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 159, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_addr};
          __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 159, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_addr};
          __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 159, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_8);
        } else
        #endif
        {
          __pyx_t_1 = PyTuple_New(1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 159, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_v_addr);
          __Pyx_GIVEREF(__pyx_v_addr);
          PyTuple_SET_ITEM(__pyx_t_1, 0+1, __pyx_v_addr);
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 159, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "uvloop/handles/udp.pyx":158
 *                         addr))
 *             if addrinfo[0] != self.sock.family:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'UDP.sendto(): {!r} socket family mismatch'.format(
 *                         addr))
 */
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 158, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(22, 158, __pyx_L1_error)

      /* "uvloop/handles/udp.pyx":157
 *                     'UDP.sendto(): address {!r} requires a DNS lookup'.format(
 *                         addr))
 *             if addrinfo[0] != self.sock.family:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     'UDP.sendto(): {!r} socket family mismatch'.format(
 */
    }

    /* "uvloop/handles/udp.pyx":149
 *                 'Invalid address: must be None or {}'.format(self.address))
 * 
 *         if addr is not None:             # <<<<<<<<<<<<<<
 *             addrinfo = __static_getaddrinfo_pyaddr(
 *                 addr[0], addr[1],
 */
  }

  /* "uvloop/handles/udp.pyx":162
 *                         addr))
 * 
 *         if self._conn_lost and self._address:             # <<<<<<<<<<<<<<
 *             if self._conn_lost >= LOG_THRESHOLD_FOR_CONNLOST_WRITES:
 *                 aio_logger.warning('socket.send() raised exception.')
 */
  __pyx_t_3 = (__pyx_v_self->__pyx_base._conn_lost != 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L17_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_address_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(22, 162, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_2 = __pyx_t_3;
  __pyx_L17_bool_binop_done:;
  if (__pyx_t_2) {

    /* "uvloop/handles/udp.pyx":163
 * 
 *         if self._conn_lost and self._address:
 *             if self._conn_lost >= LOG_THRESHOLD_FOR_CONNLOST_WRITES:             # <<<<<<<<<<<<<<
 *                 aio_logger.warning('socket.send() raised exception.')
 *             self._conn_lost += 1
 */
    __pyx_t_2 = ((__pyx_v_self->__pyx_base._conn_lost >= 5) != 0);
    if (__pyx_t_2) {

      /* "uvloop/handles/udp.pyx":164
 *         if self._conn_lost and self._address:
 *             if self._conn_lost >= LOG_THRESHOLD_FOR_CONNLOST_WRITES:
 *                 aio_logger.warning('socket.send() raised exception.')             # <<<<<<<<<<<<<<
 *             self._conn_lost += 1
 *             return
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_6uvloop_4loop_aio_logger, __pyx_n_s_warning); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__265, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/handles/udp.pyx":163
 * 
 *         if self._conn_lost and self._address:
 *             if self._conn_lost >= LOG_THRESHOLD_FOR_CONNLOST_WRITES:             # <<<<<<<<<<<<<<
 *                 aio_logger.warning('socket.send() raised exception.')
 *             self._conn_lost += 1
 */
    }

    /* "uvloop/handles/udp.pyx":165
 *             if self._conn_lost >= LOG_THRESHOLD_FOR_CONNLOST_WRITES:
 *                 aio_logger.warning('socket.send() raised exception.')
 *             self._conn_lost += 1             # <<<<<<<<<<<<<<
 *             return
 * 
 */
    __pyx_v_self->__pyx_base._conn_lost = (__pyx_v_self->__pyx_base._conn_lost + 1);

    /* "uvloop/handles/udp.pyx":166
 *                 aio_logger.warning('socket.send() raised exception.')
 *             self._conn_lost += 1
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if not self.buffer:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/handles/udp.pyx":162
 *                         addr))
 * 
 *         if self._conn_lost and self._address:             # <<<<<<<<<<<<<<
 *             if self._conn_lost >= LOG_THRESHOLD_FOR_CONNLOST_WRITES:
 *                 aio_logger.warning('socket.send() raised exception.')
 */
  }

  /* "uvloop/handles/udp.pyx":168
 *             return
 * 
 *         if not self.buffer:             # <<<<<<<<<<<<<<
 *             # Attempt to send it right away first.
 *             try:
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_self->buffer); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(22, 168, __pyx_L1_error)
  __pyx_t_3 = ((!__pyx_t_2) != 0);
  if (__pyx_t_3) {

    /* "uvloop/handles/udp.pyx":170
 *         if not self.buffer:
 *             # Attempt to send it right away first.
 *             try:             # <<<<<<<<<<<<<<
 *                 if self.address:
 *                     self.sock.send(data)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      /*try:*/ {

        /* "uvloop/handles/udp.pyx":171
 *             # Attempt to send it right away first.
 *             try:
 *                 if self.address:             # <<<<<<<<<<<<<<
 *                     self.sock.send(data)
 *                 else:
 */
        __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_self->address); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(22, 171, __pyx_L21_error)
        if (__pyx_t_3) {

          /* "uvloop/handles/udp.pyx":172
 *             try:
 *                 if self.address:
 *                     self.sock.send(data)             # <<<<<<<<<<<<<<
 *                 else:
 *                     self.sock.sendto(data, addr)
 */
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_send); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 172, __pyx_L21_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_1 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
            }
          }
          if (!__pyx_t_1) {
            __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_data); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 172, __pyx_L21_error)
            __Pyx_GOTREF(__pyx_t_8);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_data};
              __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 172, __pyx_L21_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
              PyObject *__pyx_temp[2] = {__pyx_t_1, __pyx_v_data};
              __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 172, __pyx_L21_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_8);
            } else
            #endif
            {
              __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 172, __pyx_L21_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1); __pyx_t_1 = NULL;
              __Pyx_INCREF(__pyx_v_data);
              __Pyx_GIVEREF(__pyx_v_data);
              PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_v_data);
              __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 172, __pyx_L21_error)
              __Pyx_GOTREF(__pyx_t_8);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

          /* "uvloop/handles/udp.pyx":171
 *             # Attempt to send it right away first.
 *             try:
 *                 if self.address:             # <<<<<<<<<<<<<<
 *                     self.sock.send(data)
 *                 else:
 */
          goto __pyx_L27;
        }

        /* "uvloop/handles/udp.pyx":174
 *                     self.sock.send(data)
 *                 else:
 *                     self.sock.sendto(data, addr)             # <<<<<<<<<<<<<<
 *                 return
 *             except (BlockingIOError, InterruptedError):
 */
        /*else*/ {
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->sock, __pyx_n_s_sendto); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 174, __pyx_L21_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = NULL;
          __pyx_t_10 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_6, function);
              __pyx_t_10 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_data, __pyx_v_addr};
            __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 174, __pyx_L21_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
            PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_data, __pyx_v_addr};
            __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 174, __pyx_L21_error)
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_GOTREF(__pyx_t_8);
          } else
          #endif
          {
            __pyx_t_1 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(22, 174, __pyx_L21_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (__pyx_t_5) {
              __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5); __pyx_t_5 = NULL;
            }
            __Pyx_INCREF(__pyx_v_data);
            __Pyx_GIVEREF(__pyx_v_data);
            PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_10, __pyx_v_data);
            __Pyx_INCREF(__pyx_v_addr);
            __Pyx_GIVEREF(__pyx_v_addr);
            PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_10, __pyx_v_addr);
            __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 174, __pyx_L21_error)
            __Pyx_GOTREF(__pyx_t_8);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
        __pyx_L27:;

        /* "uvloop/handles/udp.pyx":175
 *                 else:
 *                     self.sock.sendto(data, addr)
 *                 return             # <<<<<<<<<<<<<<
 *             except (BlockingIOError, InterruptedError):
 *                 self.poll.start_writing(
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L25_try_return;

        /* "uvloop/handles/udp.pyx":170
 *         if not self.buffer:
 *             # Attempt to send it right away first.
 *             try:             # <<<<<<<<<<<<<<
 *                 if self.address:
 *                     self.sock.send(data)
 */
      }
      __pyx_L21_error:;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "uvloop/handles/udp.pyx":176
 *                     self.sock.sendto(data, addr)
 *                 return
 *             except (BlockingIOError, InterruptedError):             # <<<<<<<<<<<<<<
 *                 self.poll.start_writing(
 *                     new_MethodHandle(
 */
      __Pyx_ErrFetch(&__pyx_t_8, &__pyx_t_6, &__pyx_t_1);
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_BlockingIOError); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 176, __pyx_L23_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_InterruptedError); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 176, __pyx_L23_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_8, __pyx_t_5) || __Pyx_PyErr_GivenExceptionMatches(__pyx_t_8, __pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_ErrRestore(__pyx_t_8, __pyx_t_6, __pyx_t_1);
      __pyx_t_8 = 0; __pyx_t_6 = 0; __pyx_t_1 = 0;
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.UDPTransport.sendto", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(22, 176, __pyx_L23_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_8);

        /* "uvloop/handles/udp.pyx":179
 *                 self.poll.start_writing(
 *                     new_MethodHandle(
 *                         self._loop,             # <<<<<<<<<<<<<<
 *                         "UDPTransport._on_write_ready",
 *                         <method_t>self._on_write_ready,
 */
        __pyx_t_7 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base._loop);
        __Pyx_INCREF(__pyx_t_7);

        /* "uvloop/handles/udp.pyx":178
 *             except (BlockingIOError, InterruptedError):
 *                 self.poll.start_writing(
 *                     new_MethodHandle(             # <<<<<<<<<<<<<<
 *                         self._loop,
 *                         "UDPTransport._on_write_ready",
 */
        __pyx_t_5 = __pyx_f_6uvloop_4loop_new_MethodHandle(((struct __pyx_obj_6uvloop_4loop_Loop *)__pyx_t_7), __pyx_kp_u_UDPTransport__on_write_ready, ((__pyx_t_6uvloop_4loop_method_t)((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->_on_write_ready), ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 178, __pyx_L23_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_6uvloop_4loop_Handle))))) __PYX_ERR(22, 178, __pyx_L23_except_error)

        /* "uvloop/handles/udp.pyx":177
 *                 return
 *             except (BlockingIOError, InterruptedError):
 *                 self.poll.start_writing(             # <<<<<<<<<<<<<<
 *                     new_MethodHandle(
 *                         self._loop,
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVPoll *)__pyx_v_self->poll->__pyx_base.__pyx_vtab)->start_writing(__pyx_v_self->poll, ((struct __pyx_obj_6uvloop_4loop_Handle *)__pyx_t_5)); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 177, __pyx_L23_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L22_exception_handled;
      }

      /* "uvloop/handles/udp.pyx":183
 *                         <method_t>self._on_write_ready,
 *                         self))
 *             except OSError as exc:             # <<<<<<<<<<<<<<
 *                 self._protocol.error_received(exc)
 *                 return
 */
      __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_OSError);
      if (__pyx_t_10) {
        __Pyx_AddTraceback("uvloop.loop.UDPTransport.sendto", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_6, &__pyx_t_1) < 0) __PYX_ERR(22, 183, __pyx_L23_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_exc = __pyx_t_6;
        /*try:*/ {

          /* "uvloop/handles/udp.pyx":184
 *                         self))
 *             except OSError as exc:
 *                 self._protocol.error_received(exc)             # <<<<<<<<<<<<<<
 *                 return
 *             except Exception as exc:
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base._protocol, __pyx_n_s_error_received); if (unlikely(!__pyx_t_5)) __PYX_ERR(22, 184, __pyx_L35_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          if (!__pyx_t_14) {
            __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_exc); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 184, __pyx_L35_error)
            __Pyx_GOTREF(__pyx_t_7);
          } else {
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
              __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 184, __pyx_L35_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
              PyObject *__pyx_temp[2] = {__pyx_t_14, __pyx_v_exc};
              __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 184, __pyx_L35_error)
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_GOTREF(__pyx_t_7);
            } else
            #endif
            {
              __pyx_t_15 = PyTuple_New(1+1); if (unlikely(!__pyx_t_15)) __PYX_ERR(22, 184, __pyx_L35_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
              __Pyx_INCREF(__pyx_v_exc);
              __Pyx_GIVEREF(__pyx_v_exc);
              PyTuple_SET_ITEM(__pyx_t_15, 0+1, __pyx_v_exc);
              __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_15, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 184, __pyx_L35_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            }
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "uvloop/handles/udp.pyx":185
 *             except OSError as exc:
 *                 self._protocol.error_received(exc)
 *                 return             # <<<<<<<<<<<<<<
 *             except Exception as exc:
 *                 self._fatal_error(
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_r = Py_None; __Pyx_INCREF(Py_None);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L34_return;
        }

        /* "uvloop/handles/udp.pyx":183
 *                         <method_t>self._on_write_ready,
 *                         self))
 *             except OSError as exc:             # <<<<<<<<<<<<<<
 *                 self._protocol.error_received(exc)
 *                 return
 */
        /*finally:*/ {
          __pyx_L35_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19) < 0)) __Pyx_ErrFetch(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_22);
            __pyx_t_10 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_16 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_20);
              __Pyx_XGIVEREF(__pyx_t_21);
              __Pyx_XGIVEREF(__pyx_t_22);
              __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
            }
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ErrRestore(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0;
            __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_16;
            goto __pyx_L23_except_error;
          }
          __pyx_L34_return: {
            __pyx_t_22 = __pyx_r;
            __pyx_r = 0;
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            __pyx_r = __pyx_t_22;
            __pyx_t_22 = 0;
            goto __pyx_L24_except_return;
          }
        }
      }

      /* "uvloop/handles/udp.pyx":186
 *                 self._protocol.error_received(exc)
 *                 return
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._fatal_error(
 *                     exc, 'Fatal write error on datagram transport')
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
      if (__pyx_t_9) {
        __Pyx_AddTraceback("uvloop.loop.UDPTransport.sendto", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(22, 186, __pyx_L23_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_6);
        __pyx_v_exc = __pyx_t_6;
        /*try:*/ {

          /* "uvloop/handles/udp.pyx":187
 *                 return
 *             except Exception as exc:
 *                 self._fatal_error(             # <<<<<<<<<<<<<<
 *                     exc, 'Fatal write error on datagram transport')
 *                 return
 */
          __pyx_t_7 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base.__pyx_base._fatal_error(((struct __pyx_obj_6uvloop_4loop_UVHandle *)__pyx_v_self), __pyx_v_exc, __pyx_kp_u_Fatal_write_error_on_datagram_tr, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(22, 187, __pyx_L46_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "uvloop/handles/udp.pyx":189
 *                 self._fatal_error(
 *                     exc, 'Fatal write error on datagram transport')
 *                 return             # <<<<<<<<<<<<<<
 * 
 *         # Ensure that what we buffer is immutable.
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_r = Py_None; __Pyx_INCREF(Py_None);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L45_return;
        }

        /* "uvloop/handles/udp.pyx":186
 *                 self._protocol.error_received(exc)
 *                 return
 *             except Exception as exc:             # <<<<<<<<<<<<<<
 *                 self._fatal_error(
 *                     exc, 'Fatal write error on datagram transport')
 */
        /*finally:*/ {
          __pyx_L46_error:;
          /*exception exit:*/{
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_18, &__pyx_t_17);
            if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_21, &__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_22);
            __Pyx_XGOTREF(__pyx_t_21);
            __Pyx_XGOTREF(__pyx_t_20);
            __Pyx_XGOTREF(__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_17);
            __pyx_t_9 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_23 = __pyx_filename;
            {
              __Pyx_DECREF(__pyx_v_exc);
              __pyx_v_exc = NULL;
            }
            if (PY_MAJOR_VERSION >= 3) {
              __Pyx_XGIVEREF(__pyx_t_19);
              __Pyx_XGIVEREF(__pyx_t_18);
              __Pyx_XGIVEREF(__pyx_t_17);
              __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_18, __pyx_t_17);
            }
            __Pyx_XGIVEREF(__pyx_t_22);
            __Pyx_XGIVEREF(__pyx_t_21);
            __Pyx_XGIVEREF(__pyx_t_20);
            __Pyx_ErrRestore(__pyx_t_22, __pyx_t_21, __pyx_t_20);
            __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0; __pyx_t_17 = 0;
            __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_23;
            goto __pyx_L23_except_error;
          }
          __pyx_L45_return: {
            __pyx_t_17 = __pyx_r;
            __pyx_r = 0;
            __Pyx_DECREF(__pyx_v_exc);
            __pyx_v_exc = NULL;
            __pyx_r = __pyx_t_17;
            __pyx_t_17 = 0;
            goto __pyx_L24_except_return;
          }
        }
      }
      goto __pyx_L23_except_error;
      __pyx_L23_except_error:;

      /* "uvloop/handles/udp.pyx":170
 *         if not self.buffer:
 *             # Attempt to send it right away first.
 *             try:             # <<<<<<<<<<<<<<
 *                 if self.address:
 *                     self.sock.send(data)
 */
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L1_error;
      __pyx_L25_try_return:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L0;
      __pyx_L24_except_return:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L0;
      __pyx_L22_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
    }

    /* "uvloop/handles/udp.pyx":168
 *             return
 * 
 *         if not self.buffer:             # <<<<<<<<<<<<<<
 *             # Attempt to send it right away first.
 *             try:
 */
  }

  /* "uvloop/handles/udp.pyx":192
 * 
 *         # Ensure that what we buffer is immutable.
 *         self.buffer.append((bytes(data), addr))             # <<<<<<<<<<<<<<
 *         self._maybe_pause_protocol()
 */
  __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyBytes_Type)), __pyx_v_data); if (unlikely(!__pyx_t_8)) __PYX_ERR(22, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_8);
  __Pyx_INCREF(__pyx_v_addr);
  __Pyx_GIVEREF(__pyx_v_addr);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_v_addr);
  __pyx_t_8 = 0;
  __pyx_t_24 = __Pyx_PyObject_Append(__pyx_v_self->buffer, __pyx_t_6); if (unlikely(__pyx_t_24 == ((int)-1))) __PYX_ERR(22, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/handles/udp.pyx":193
 *         # Ensure that what we buffer is immutable.
 *         self.buffer.append((bytes(data), addr))
 *         self._maybe_pause_protocol()             # <<<<<<<<<<<<<<
 */
  __pyx_t_6 = ((struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._maybe_pause_protocol(((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)__pyx_v_self)); if (unlikely(!__pyx_t_6)) __PYX_ERR(22, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/handles/udp.pyx":138
 *         UVSocketHandle._close(<UVSocketHandle>self)
 * 
 *     def sendto(self, data, addr=None):             # <<<<<<<<<<<<<<
 *         if not isinstance(data, (bytes, bytearray, memoryview)):
 *             raise TypeError('data argument must be a bytes-like object, '
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport.sendto", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_addrinfo);
  __Pyx_XDECREF(__pyx_v_exc);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12UDPTransport_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_12UDPTransport_4__reduce_cython__[] = "UDPTransport.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_12UDPTransport_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12UDPTransport_4__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_UDPTransport *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12UDPTransport_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__266, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_12UDPTransport_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_12UDPTransport_6__setstate_cython__[] = "UDPTransport.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_12UDPTransport_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_12UDPTransport_6__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_UDPTransport *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_12UDPTransport_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_UDPTransport *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__267, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.UDPTransport.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":2
 * cdef class Server:
 *     def __cinit__(self, Loop loop):             # <<<<<<<<<<<<<<
 *         self._loop = loop
 *         self._servers = []
 */

/* Python wrapper */
static int __pyx_pw_6uvloop_4loop_6Server_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6uvloop_4loop_6Server_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_loop,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_loop)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) __PYX_ERR(23, 2, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(23, 2, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.Server.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_loop), __pyx_ptype_6uvloop_4loop_Loop, 1, "loop", 0))) __PYX_ERR(23, 2, __pyx_L1_error)
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server___cinit__(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self), __pyx_v_loop);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6uvloop_4loop_6Server___cinit__(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_loop) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "uvloop/server.pyx":3
 * cdef class Server:
 *     def __cinit__(self, Loop loop):
 *         self._loop = loop             # <<<<<<<<<<<<<<
 *         self._servers = []
 *         self._waiters = []
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_loop));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_loop));
  __Pyx_GOTREF(__pyx_v_self->_loop);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->_loop));
  __pyx_v_self->_loop = __pyx_v_loop;

  /* "uvloop/server.pyx":4
 *     def __cinit__(self, Loop loop):
 *         self._loop = loop
 *         self._servers = []             # <<<<<<<<<<<<<<
 *         self._waiters = []
 *         self._active_count = 0
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(23, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_servers);
  __Pyx_DECREF(__pyx_v_self->_servers);
  __pyx_v_self->_servers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/server.pyx":5
 *         self._loop = loop
 *         self._servers = []
 *         self._waiters = []             # <<<<<<<<<<<<<<
 *         self._active_count = 0
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(23, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->_waiters);
  __Pyx_DECREF(__pyx_v_self->_waiters);
  __pyx_v_self->_waiters = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/server.pyx":6
 *         self._servers = []
 *         self._waiters = []
 *         self._active_count = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef _add_server(self, UVStreamServer srv):
 */
  __pyx_v_self->_active_count = 0;

  /* "uvloop/server.pyx":2
 * cdef class Server:
 *     def __cinit__(self, Loop loop):             # <<<<<<<<<<<<<<
 *         self._loop = loop
 *         self._servers = []
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Server.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":8
 *         self._active_count = 0
 * 
 *     cdef _add_server(self, UVStreamServer srv):             # <<<<<<<<<<<<<<
 *         self._servers.append(srv)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_6Server__add_server(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self, struct __pyx_obj_6uvloop_4loop_UVStreamServer *__pyx_v_srv) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_add_server", 0);

  /* "uvloop/server.pyx":9
 * 
 *     cdef _add_server(self, UVStreamServer srv):
 *         self._servers.append(srv)             # <<<<<<<<<<<<<<
 * 
 *     cdef _wakeup(self):
 */
  if (unlikely(__pyx_v_self->_servers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(23, 9, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyList_Append(__pyx_v_self->_servers, ((PyObject *)__pyx_v_srv)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(23, 9, __pyx_L1_error)

  /* "uvloop/server.pyx":8
 *         self._active_count = 0
 * 
 *     cdef _add_server(self, UVStreamServer srv):             # <<<<<<<<<<<<<<
 *         self._servers.append(srv)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Server._add_server", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":11
 *         self._servers.append(srv)
 * 
 *     cdef _wakeup(self):             # <<<<<<<<<<<<<<
 *         cdef list waiters
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_6Server__wakeup(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_v_waiters = 0;
  PyObject *__pyx_v_waiter = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("_wakeup", 0);

  /* "uvloop/server.pyx":14
 *         cdef list waiters
 * 
 *         waiters = self._waiters             # <<<<<<<<<<<<<<
 *         self._waiters = None
 *         for waiter in waiters:
 */
  __pyx_t_1 = __pyx_v_self->_waiters;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_waiters = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/server.pyx":15
 * 
 *         waiters = self._waiters
 *         self._waiters = None             # <<<<<<<<<<<<<<
 *         for waiter in waiters:
 *             if not waiter.done():
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_waiters);
  __Pyx_DECREF(__pyx_v_self->_waiters);
  __pyx_v_self->_waiters = ((PyObject*)Py_None);

  /* "uvloop/server.pyx":16
 *         waiters = self._waiters
 *         self._waiters = None
 *         for waiter in waiters:             # <<<<<<<<<<<<<<
 *             if not waiter.done():
 *                 waiter.set_result(waiter)
 */
  if (unlikely(__pyx_v_waiters == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(23, 16, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_waiters; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(23, 16, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 16, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_waiter, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/server.pyx":17
 *         self._waiters = None
 *         for waiter in waiters:
 *             if not waiter.done():             # <<<<<<<<<<<<<<
 *                 waiter.set_result(waiter)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_done); if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 17, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 17, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 17, __pyx_L1_error)
    }
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(23, 17, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = ((!__pyx_t_6) != 0);
    if (__pyx_t_7) {

      /* "uvloop/server.pyx":18
 *         for waiter in waiters:
 *             if not waiter.done():
 *                 waiter.set_result(waiter)             # <<<<<<<<<<<<<<
 * 
 *     cdef _attach(self):
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_waiter, __pyx_n_s_set_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 18, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      if (!__pyx_t_5) {
        __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_waiter); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 18, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      } else {
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_waiter};
          __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 18, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_v_waiter};
          __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 18, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_GOTREF(__pyx_t_3);
        } else
        #endif
        {
          __pyx_t_8 = PyTuple_New(1+1); if (unlikely(!__pyx_t_8)) __PYX_ERR(23, 18, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
          __Pyx_INCREF(__pyx_v_waiter);
          __Pyx_GIVEREF(__pyx_v_waiter);
          PyTuple_SET_ITEM(__pyx_t_8, 0+1, __pyx_v_waiter);
          __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_8, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 18, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        }
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/server.pyx":17
 *         self._waiters = None
 *         for waiter in waiters:
 *             if not waiter.done():             # <<<<<<<<<<<<<<
 *                 waiter.set_result(waiter)
 * 
 */
    }

    /* "uvloop/server.pyx":16
 *         waiters = self._waiters
 *         self._waiters = None
 *         for waiter in waiters:             # <<<<<<<<<<<<<<
 *             if not waiter.done():
 *                 waiter.set_result(waiter)
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/server.pyx":11
 *         self._servers.append(srv)
 * 
 *     cdef _wakeup(self):             # <<<<<<<<<<<<<<
 *         cdef list waiters
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("uvloop.loop.Server._wakeup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_waiters);
  __Pyx_XDECREF(__pyx_v_waiter);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":20
 *                 waiter.set_result(waiter)
 * 
 *     cdef _attach(self):             # <<<<<<<<<<<<<<
 *         assert self._servers is not None
 *         self._active_count += 1
 */

static PyObject *__pyx_f_6uvloop_4loop_6Server__attach(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_attach", 0);

  /* "uvloop/server.pyx":21
 * 
 *     cdef _attach(self):
 *         assert self._servers is not None             # <<<<<<<<<<<<<<
 *         self._active_count += 1
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_1 = (__pyx_v_self->_servers != ((PyObject*)Py_None));
    if (unlikely(!(__pyx_t_1 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(23, 21, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/server.pyx":22
 *     cdef _attach(self):
 *         assert self._servers is not None
 *         self._active_count += 1             # <<<<<<<<<<<<<<
 * 
 *     cdef _detach(self):
 */
  __pyx_v_self->_active_count = (__pyx_v_self->_active_count + 1);

  /* "uvloop/server.pyx":20
 *                 waiter.set_result(waiter)
 * 
 *     cdef _attach(self):             # <<<<<<<<<<<<<<
 *         assert self._servers is not None
 *         self._active_count += 1
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Server._attach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":24
 *         self._active_count += 1
 * 
 *     cdef _detach(self):             # <<<<<<<<<<<<<<
 *         assert self._active_count > 0
 *         self._active_count -= 1
 */

static PyObject *__pyx_f_6uvloop_4loop_6Server__detach(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("_detach", 0);

  /* "uvloop/server.pyx":25
 * 
 *     cdef _detach(self):
 *         assert self._active_count > 0             # <<<<<<<<<<<<<<
 *         self._active_count -= 1
 *         if self._active_count == 0 and self._servers is None:
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!((__pyx_v_self->_active_count > 0) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(23, 25, __pyx_L1_error)
    }
  }
  #endif

  /* "uvloop/server.pyx":26
 *     cdef _detach(self):
 *         assert self._active_count > 0
 *         self._active_count -= 1             # <<<<<<<<<<<<<<
 *         if self._active_count == 0 and self._servers is None:
 *             self._wakeup()
 */
  __pyx_v_self->_active_count = (__pyx_v_self->_active_count - 1);

  /* "uvloop/server.pyx":27
 *         assert self._active_count > 0
 *         self._active_count -= 1
 *         if self._active_count == 0 and self._servers is None:             # <<<<<<<<<<<<<<
 *             self._wakeup()
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->_active_count == 0) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->_servers == ((PyObject*)Py_None));
  __pyx_t_3 = (__pyx_t_2 != 0);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/server.pyx":28
 *         self._active_count -= 1
 *         if self._active_count == 0 and self._servers is None:
 *             self._wakeup()             # <<<<<<<<<<<<<<
 * 
 *     cdef _ref(self):
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_v_self->__pyx_vtab)->_wakeup(__pyx_v_self); if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 28, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/server.pyx":27
 *         assert self._active_count > 0
 *         self._active_count -= 1
 *         if self._active_count == 0 and self._servers is None:             # <<<<<<<<<<<<<<
 *             self._wakeup()
 * 
 */
  }

  /* "uvloop/server.pyx":24
 *         self._active_count += 1
 * 
 *     cdef _detach(self):             # <<<<<<<<<<<<<<
 *         assert self._active_count > 0
 *         self._active_count -= 1
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Server._detach", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":30
 *             self._wakeup()
 * 
 *     cdef _ref(self):             # <<<<<<<<<<<<<<
 *         # Keep the server object alive while it's not explicitly closed.
 *         self._loop._servers.add(self)
 */

static PyObject *__pyx_f_6uvloop_4loop_6Server__ref(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_ref", 0);

  /* "uvloop/server.pyx":32
 *     cdef _ref(self):
 *         # Keep the server object alive while it's not explicitly closed.
 *         self._loop._servers.add(self)             # <<<<<<<<<<<<<<
 * 
 *     cdef _unref(self):
 */
  if (unlikely(__pyx_v_self->_loop->_servers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "add");
    __PYX_ERR(23, 32, __pyx_L1_error)
  }
  __pyx_t_1 = PySet_Add(__pyx_v_self->_loop->_servers, ((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(23, 32, __pyx_L1_error)

  /* "uvloop/server.pyx":30
 *             self._wakeup()
 * 
 *     cdef _ref(self):             # <<<<<<<<<<<<<<
 *         # Keep the server object alive while it's not explicitly closed.
 *         self._loop._servers.add(self)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Server._ref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":34
 *         self._loop._servers.add(self)
 * 
 *     cdef _unref(self):             # <<<<<<<<<<<<<<
 *         self._loop._servers.discard(self)
 * 
 */

static PyObject *__pyx_f_6uvloop_4loop_6Server__unref(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_unref", 0);

  /* "uvloop/server.pyx":35
 * 
 *     cdef _unref(self):
 *         self._loop._servers.discard(self)             # <<<<<<<<<<<<<<
 * 
 *     # Public API
 */
  if (unlikely(__pyx_v_self->_loop->_servers == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "discard");
    __PYX_ERR(23, 35, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PySet_Discard(__pyx_v_self->_loop->_servers, ((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(23, 35, __pyx_L1_error)

  /* "uvloop/server.pyx":34
 *         self._loop._servers.add(self)
 * 
 *     cdef _unref(self):             # <<<<<<<<<<<<<<
 *         self._loop._servers.discard(self)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Server._unref", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":39
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s sockets=%r>' % (self.__class__.__name__, self.sockets)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Server_3__repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_6Server_3__repr__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server_2__repr__(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Server_2__repr__(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__repr__", 0);

  /* "uvloop/server.pyx":40
 * 
 *     def __repr__(self):
 *         return '<%s sockets=%r>' % (self.__class__.__name__, self.sockets)             # <<<<<<<<<<<<<<
 * 
 *     def get_loop(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(23, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u__128);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__128);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u__128);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_class); if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) __PYX_ERR(23, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Unicode(__pyx_t_5), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_sockets);
  __pyx_t_2 += 9;
  __Pyx_GIVEREF(__pyx_kp_u_sockets);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_sockets);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_sockets_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_4), __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(23, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_3) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_3;
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__130);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__130);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u__130);
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(23, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "uvloop/server.pyx":39
 *     # Public API
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return '<%s sockets=%r>' % (self.__class__.__name__, self.sockets)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.Server.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":42
 *         return '<%s sockets=%r>' % (self.__class__.__name__, self.sockets)
 * 
 *     def get_loop(self):             # <<<<<<<<<<<<<<
 *         return self._loop
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Server_5get_loop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Server_4get_loop[] = "Server.get_loop(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6Server_5get_loop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_loop (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server_4get_loop(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Server_4get_loop(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_loop", 0);

  /* "uvloop/server.pyx":43
 * 
 *     def get_loop(self):
 *         return self._loop             # <<<<<<<<<<<<<<
 * 
 *     @cython.iterable_coroutine
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->_loop));
  __pyx_r = ((PyObject *)__pyx_v_self->_loop);
  goto __pyx_L0;

  /* "uvloop/server.pyx":42
 *         return '<%s sockets=%r>' % (self.__class__.__name__, self.sockets)
 * 
 *     def get_loop(self):             # <<<<<<<<<<<<<<
 *         return self._loop
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_6Server_8generator20(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/server.pyx":46
 * 
 *     @cython.iterable_coroutine
 *     async def wait_closed(self):             # <<<<<<<<<<<<<<
 *         if self._waiters is None:
 *             return
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Server_7wait_closed(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Server_6wait_closed[] = "Server.wait_closed(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6Server_7wait_closed(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wait_closed (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server_6wait_closed(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Server_6wait_closed(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wait_closed", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_28_wait_closed(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_28_wait_closed, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(23, 46, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_6Server_8generator20, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_wait_closed, __pyx_n_s_Server_wait_closed, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(23, 46, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop.Server.wait_closed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_6Server_8generator20(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *__pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wait_closed", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L5_resume_from_await;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(23, 46, __pyx_L1_error)

  /* "uvloop/server.pyx":47
 *     @cython.iterable_coroutine
 *     async def wait_closed(self):
 *         if self._waiters is None:             # <<<<<<<<<<<<<<
 *             return
 *         waiter = self._loop._new_future()
 */
  __pyx_t_1 = (__pyx_cur_scope->__pyx_v_self->_waiters == ((PyObject*)Py_None));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/server.pyx":48
 *     async def wait_closed(self):
 *         if self._waiters is None:
 *             return             # <<<<<<<<<<<<<<
 *         waiter = self._loop._new_future()
 *         self._waiters.append(waiter)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = NULL;
    goto __pyx_L0;

    /* "uvloop/server.pyx":47
 *     @cython.iterable_coroutine
 *     async def wait_closed(self):
 *         if self._waiters is None:             # <<<<<<<<<<<<<<
 *             return
 *         waiter = self._loop._new_future()
 */
  }

  /* "uvloop/server.pyx":49
 *         if self._waiters is None:
 *             return
 *         waiter = self._loop._new_future()             # <<<<<<<<<<<<<<
 *         self._waiters.append(waiter)
 *         await waiter
 */
  __pyx_t_3 = __pyx_f_6uvloop_4loop_4Loop__new_future(__pyx_cur_scope->__pyx_v_self->_loop); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_cur_scope->__pyx_v_waiter = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "uvloop/server.pyx":50
 *             return
 *         waiter = self._loop._new_future()
 *         self._waiters.append(waiter)             # <<<<<<<<<<<<<<
 *         await waiter
 * 
 */
  if (unlikely(__pyx_cur_scope->__pyx_v_self->_waiters == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(23, 50, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_self->_waiters, __pyx_cur_scope->__pyx_v_waiter); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(23, 50, __pyx_L1_error)

  /* "uvloop/server.pyx":51
 *         waiter = self._loop._new_future()
 *         self._waiters.append(waiter)
 *         await waiter             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __pyx_r = __Pyx_Coroutine_Yield_From(__pyx_generator, __pyx_cur_scope->__pyx_v_waiter);
  __Pyx_XGOTREF(__pyx_r);
  if (likely(__pyx_r)) {
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, awaiting value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L5_resume_from_await:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(23, 51, __pyx_L1_error)
  } else {
    PyObject* exc_type = __Pyx_PyErr_Occurred();
    if (exc_type) {
      if (likely(exc_type == PyExc_StopIteration || (exc_type != PyExc_GeneratorExit && __Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))) PyErr_Clear();
      else __PYX_ERR(23, 51, __pyx_L1_error)
    }
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "uvloop/server.pyx":46
 * 
 *     @cython.iterable_coroutine
 *     async def wait_closed(self):             # <<<<<<<<<<<<<<
 *         if self._waiters is None:
 *             return
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("wait_closed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":53
 *         await waiter
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         cdef list servers
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Server_10close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Server_9close[] = "Server.close(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6Server_10close(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("close (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server_9close(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Server_9close(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_v_servers = 0;
  PyObject *__pyx_v_server = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  char const *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  __Pyx_RefNannySetupContext("close", 0);

  /* "uvloop/server.pyx":56
 *         cdef list servers
 * 
 *         if self._servers is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_servers == ((PyObject*)Py_None));
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "uvloop/server.pyx":57
 * 
 *         if self._servers is None:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/server.pyx":56
 *         cdef list servers
 * 
 *         if self._servers is None:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
  }

  /* "uvloop/server.pyx":59
 *             return
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             servers = self._servers
 *             self._servers = None
 */
  /*try:*/ {

    /* "uvloop/server.pyx":60
 * 
 *         try:
 *             servers = self._servers             # <<<<<<<<<<<<<<
 *             self._servers = None
 * 
 */
    __pyx_t_3 = __pyx_v_self->_servers;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_servers = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "uvloop/server.pyx":61
 *         try:
 *             servers = self._servers
 *             self._servers = None             # <<<<<<<<<<<<<<
 * 
 *             for server in servers:
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->_servers);
    __Pyx_DECREF(__pyx_v_self->_servers);
    __pyx_v_self->_servers = ((PyObject*)Py_None);

    /* "uvloop/server.pyx":63
 *             self._servers = None
 * 
 *             for server in servers:             # <<<<<<<<<<<<<<
 *                 (<UVStreamServer>server)._close()
 * 
 */
    if (unlikely(__pyx_v_servers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(23, 63, __pyx_L5_error)
    }
    __pyx_t_3 = __pyx_v_servers; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    for (;;) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_5); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(23, 63, __pyx_L5_error)
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_5)) __PYX_ERR(23, 63, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_server, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "uvloop/server.pyx":64
 * 
 *             for server in servers:
 *                 (<UVStreamServer>server)._close()             # <<<<<<<<<<<<<<
 * 
 *             if self._active_count == 0:
 */
      __pyx_t_5 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_server)->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._close(((struct __pyx_obj_6uvloop_4loop_UVHandle *)((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_server))); if (unlikely(!__pyx_t_5)) __PYX_ERR(23, 64, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "uvloop/server.pyx":63
 *             self._servers = None
 * 
 *             for server in servers:             # <<<<<<<<<<<<<<
 *                 (<UVStreamServer>server)._close()
 * 
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "uvloop/server.pyx":66
 *                 (<UVStreamServer>server)._close()
 * 
 *             if self._active_count == 0:             # <<<<<<<<<<<<<<
 *                 self._wakeup()
 *         finally:
 */
    __pyx_t_2 = ((__pyx_v_self->_active_count == 0) != 0);
    if (__pyx_t_2) {

      /* "uvloop/server.pyx":67
 * 
 *             if self._active_count == 0:
 *                 self._wakeup()             # <<<<<<<<<<<<<<
 *         finally:
 *             self._unref()
 */
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_v_self->__pyx_vtab)->_wakeup(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 67, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "uvloop/server.pyx":66
 *                 (<UVStreamServer>server)._close()
 * 
 *             if self._active_count == 0:             # <<<<<<<<<<<<<<
 *                 self._wakeup()
 *         finally:
 */
    }
  }

  /* "uvloop/server.pyx":69
 *                 self._wakeup()
 *         finally:
 *             self._unref()             # <<<<<<<<<<<<<<
 * 
 *     property sockets:
 */
  /*finally:*/ {
    /*normal exit:*/{
      __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_v_self->__pyx_vtab)->_unref(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 69, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0)) __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __pyx_t_6 = __pyx_lineno; __pyx_t_7 = __pyx_clineno; __pyx_t_8 = __pyx_filename;
      {
        __pyx_t_3 = ((struct __pyx_vtabstruct_6uvloop_4loop_Server *)__pyx_v_self->__pyx_vtab)->_unref(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(23, 69, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_11);
      __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      __pyx_lineno = __pyx_t_6; __pyx_clineno = __pyx_t_7; __pyx_filename = __pyx_t_8;
      goto __pyx_L1_error;
      __pyx_L11_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L6:;
  }

  /* "uvloop/server.pyx":53
 *         await waiter
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         cdef list servers
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("uvloop.loop.Server.close", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_servers);
  __Pyx_XDECREF(__pyx_v_server);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/server.pyx":72
 * 
 *     property sockets:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             cdef list sockets = []
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Server_7sockets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6uvloop_4loop_6Server_7sockets_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server_7sockets___get__(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Server_7sockets___get__(struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_v_sockets = 0;
  PyObject *__pyx_v_server = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "uvloop/server.pyx":73
 *     property sockets:
 *         def __get__(self):
 *             cdef list sockets = []             # <<<<<<<<<<<<<<
 * 
 *             # Guard against `self._servers is None`
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(23, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_sockets = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/server.pyx":76
 * 
 *             # Guard against `self._servers is None`
 *             if self._servers:             # <<<<<<<<<<<<<<
 *                 for server in self._servers:
 *                     sockets.append(
 */
  __pyx_t_2 = (__pyx_v_self->_servers != Py_None)&&(PyList_GET_SIZE(__pyx_v_self->_servers) != 0);
  if (__pyx_t_2) {

    /* "uvloop/server.pyx":77
 *             # Guard against `self._servers is None`
 *             if self._servers:
 *                 for server in self._servers:             # <<<<<<<<<<<<<<
 *                     sockets.append(
 *                         (<UVStreamServer>server)._get_socket()
 */
    if (unlikely(__pyx_v_self->_servers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(23, 77, __pyx_L1_error)
    }
    __pyx_t_1 = __pyx_v_self->_servers; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    for (;;) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_4); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(23, 77, __pyx_L1_error)
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 77, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_server, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "uvloop/server.pyx":79
 *                 for server in self._servers:
 *                     sockets.append(
 *                         (<UVStreamServer>server)._get_socket()             # <<<<<<<<<<<<<<
 *                     )
 * 
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer *)((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_server)->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._get_socket(((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)__pyx_v_server))); if (unlikely(!__pyx_t_4)) __PYX_ERR(23, 79, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "uvloop/server.pyx":78
 *             if self._servers:
 *                 for server in self._servers:
 *                     sockets.append(             # <<<<<<<<<<<<<<
 *                         (<UVStreamServer>server)._get_socket()
 *                     )
 */
      __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_sockets, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(23, 78, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "uvloop/server.pyx":77
 *             # Guard against `self._servers is None`
 *             if self._servers:
 *                 for server in self._servers:             # <<<<<<<<<<<<<<
 *                     sockets.append(
 *                         (<UVStreamServer>server)._get_socket()
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "uvloop/server.pyx":76
 * 
 *             # Guard against `self._servers is None`
 *             if self._servers:             # <<<<<<<<<<<<<<
 *                 for server in self._servers:
 *                     sockets.append(
 */
  }

  /* "uvloop/server.pyx":82
 *                     )
 * 
 *             return sockets             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_sockets);
  __pyx_r = __pyx_v_sockets;
  goto __pyx_L0;

  /* "uvloop/server.pyx":72
 * 
 *     property sockets:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             cdef list sockets = []
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("uvloop.loop.Server.sockets.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_sockets);
  __Pyx_XDECREF(__pyx_v_server);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Server_12__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Server_11__reduce_cython__[] = "Server.__reduce_cython__(self)";
static PyObject *__pyx_pw_6uvloop_4loop_6Server_12__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server_11__reduce_cython__(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Server_11__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__268, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Server.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6Server_14__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static char __pyx_doc_6uvloop_4loop_6Server_13__setstate_cython__[] = "Server.__setstate_cython__(self, __pyx_state)";
static PyObject *__pyx_pw_6uvloop_4loop_6Server_14__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop_6Server_13__setstate_cython__(((struct __pyx_obj_6uvloop_4loop_Server *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_6Server_13__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6uvloop_4loop_Server *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__269, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(9, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("uvloop.loop.Server.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":3042
 * 
 * 
 * cdef void __atfork_child() nogil:             # <<<<<<<<<<<<<<
 *     # See CPython/posixmodule.c for details
 *     global __forking
 */

static void __pyx_f_6uvloop_4loop___atfork_child(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif
  __Pyx_RefNannySetupContext("__atfork_child", 1);

  /* "uvloop/loop.pyx":3044
 * cdef void __atfork_child() nogil:
 *     # See CPython/posixmodule.c for details
 *     global __forking             # <<<<<<<<<<<<<<
 * 
 *     with gil:
 */
  /*try:*/ {

    /* "uvloop/loop.pyx":3046
 *     global __forking
 * 
 *     with gil:             # <<<<<<<<<<<<<<
 *         if (__forking and
 *                 __forking_loop is not None and
 */
    {
        #ifdef WITH_THREAD
        PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
        #endif
        /*try:*/ {

          /* "uvloop/loop.pyx":3047
 * 
 *     with gil:
 *         if (__forking and             # <<<<<<<<<<<<<<
 *                 __forking_loop is not None and
 *                 __forking_loop.active_process_handler is not None):
 */
          __pyx_t_2 = (__pyx_v_6uvloop_4loop___forking != 0);
          if (__pyx_t_2) {
          } else {
            __pyx_t_1 = __pyx_t_2;
            goto __pyx_L10_bool_binop_done;
          }

          /* "uvloop/loop.pyx":3048
 *     with gil:
 *         if (__forking and
 *                 __forking_loop is not None and             # <<<<<<<<<<<<<<
 *                 __forking_loop.active_process_handler is not None):
 * 
 */
          __pyx_t_2 = (((PyObject *)__pyx_v_6uvloop_4loop___forking_loop) != Py_None);
          __pyx_t_3 = (__pyx_t_2 != 0);
          if (__pyx_t_3) {
          } else {
            __pyx_t_1 = __pyx_t_3;
            goto __pyx_L10_bool_binop_done;
          }

          /* "uvloop/loop.pyx":3049
 *         if (__forking and
 *                 __forking_loop is not None and
 *                 __forking_loop.active_process_handler is not None):             # <<<<<<<<<<<<<<
 * 
 *             __forking_loop.active_process_handler._after_fork()
 */
          __pyx_t_3 = (((PyObject *)__pyx_v_6uvloop_4loop___forking_loop->active_process_handler) != Py_None);
          __pyx_t_2 = (__pyx_t_3 != 0);
          __pyx_t_1 = __pyx_t_2;
          __pyx_L10_bool_binop_done:;

          /* "uvloop/loop.pyx":3047
 * 
 *     with gil:
 *         if (__forking and             # <<<<<<<<<<<<<<
 *                 __forking_loop is not None and
 *                 __forking_loop.active_process_handler is not None):
 */
          if (__pyx_t_1) {

            /* "uvloop/loop.pyx":3051
 *                 __forking_loop.active_process_handler is not None):
 * 
 *             __forking_loop.active_process_handler._after_fork()             # <<<<<<<<<<<<<<
 * 
 * 
 */
            __pyx_t_4 = ((struct __pyx_vtabstruct_6uvloop_4loop_UVProcess *)__pyx_v_6uvloop_4loop___forking_loop->active_process_handler->__pyx_base.__pyx_vtab)->_after_fork(__pyx_v_6uvloop_4loop___forking_loop->active_process_handler); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3051, __pyx_L7_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "uvloop/loop.pyx":3047
 * 
 *     with gil:
 *         if (__forking and             # <<<<<<<<<<<<<<
 *                 __forking_loop is not None and
 *                 __forking_loop.active_process_handler is not None):
 */
          }
        }

        /* "uvloop/loop.pyx":3046
 *     global __forking
 * 
 *     with gil:             # <<<<<<<<<<<<<<
 *         if (__forking and
 *                 __forking_loop is not None and
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_PyGILState_Release(__pyx_gilstate_save);
            #endif
            goto __pyx_L8;
          }
          __pyx_L7_error: {
            #ifdef WITH_THREAD
            __Pyx_PyGILState_Release(__pyx_gilstate_save);
            #endif
            goto __pyx_L4_error;
          }
          __pyx_L8:;
        }
    }
  }

  /* "uvloop/loop.pyx":3044
 * cdef void __atfork_child() nogil:
 *     # See CPython/posixmodule.c for details
 *     global __forking             # <<<<<<<<<<<<<<
 * 
 *     with gil:
 */
  /*finally:*/ {
    /*normal exit:*/{
      #ifdef WITH_THREAD
      __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
      #endif
      goto __pyx_L5;
    }
    __pyx_L4_error: {
      #ifdef WITH_THREAD
      __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
      #endif
      goto __pyx_L1_error;
    }
    __pyx_L5:;
  }

  /* "uvloop/loop.pyx":3042
 * 
 * 
 * cdef void __atfork_child() nogil:             # <<<<<<<<<<<<<<
 *     # See CPython/posixmodule.c for details
 *     global __forking
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("uvloop.loop.__atfork_child", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 1);
  __pyx_L0:;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "uvloop/loop.pyx":3054
 * 
 * 
 * cdef __install_atfork():             # <<<<<<<<<<<<<<
 *     global __atfork_installed
 *     if __atfork_installed:
 */

static PyObject *__pyx_f_6uvloop_4loop___install_atfork(void) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__install_atfork", 0);

  /* "uvloop/loop.pyx":3056
 * cdef __install_atfork():
 *     global __atfork_installed
 *     if __atfork_installed:             # <<<<<<<<<<<<<<
 *         return
 *     __atfork_installed = 1
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop___atfork_installed != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":3057
 *     global __atfork_installed
 *     if __atfork_installed:
 *         return             # <<<<<<<<<<<<<<
 *     __atfork_installed = 1
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":3056
 * cdef __install_atfork():
 *     global __atfork_installed
 *     if __atfork_installed:             # <<<<<<<<<<<<<<
 *         return
 *     __atfork_installed = 1
 */
  }

  /* "uvloop/loop.pyx":3058
 *     if __atfork_installed:
 *         return
 *     __atfork_installed = 1             # <<<<<<<<<<<<<<
 * 
 *     cdef int err
 */
  __pyx_v_6uvloop_4loop___atfork_installed = 1;

  /* "uvloop/loop.pyx":3062
 *     cdef int err
 * 
 *     err = system.pthread_atfork(NULL, NULL, &__atfork_child)             # <<<<<<<<<<<<<<
 *     if err:
 *         __atfork_installed = 0
 */
  __pyx_v_err = pthread_atfork(NULL, NULL, (&__pyx_f_6uvloop_4loop___atfork_child));

  /* "uvloop/loop.pyx":3063
 * 
 *     err = system.pthread_atfork(NULL, NULL, &__atfork_child)
 *     if err:             # <<<<<<<<<<<<<<
 *         __atfork_installed = 0
 *         raise convert_error(-err)
 */
  __pyx_t_1 = (__pyx_v_err != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":3064
 *     err = system.pthread_atfork(NULL, NULL, &__atfork_child)
 *     if err:
 *         __atfork_installed = 0             # <<<<<<<<<<<<<<
 *         raise convert_error(-err)
 * 
 */
    __pyx_v_6uvloop_4loop___atfork_installed = 0;

    /* "uvloop/loop.pyx":3065
 *     if err:
 *         __atfork_installed = 0
 *         raise convert_error(-err)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error((-__pyx_v_err)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 3065, __pyx_L1_error)

    /* "uvloop/loop.pyx":3063
 * 
 *     err = system.pthread_atfork(NULL, NULL, &__atfork_child)
 *     if err:             # <<<<<<<<<<<<<<
 *         __atfork_installed = 0
 *         raise convert_error(-err)
 */
  }

  /* "uvloop/loop.pyx":3054
 * 
 * 
 * cdef __install_atfork():             # <<<<<<<<<<<<<<
 *     global __atfork_installed
 *     if __atfork_installed:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__install_atfork", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":3070
 * # Install PyMem* memory allocators
 * cdef vint __mem_installed = 0
 * cdef __install_pymem():             # <<<<<<<<<<<<<<
 *     global __mem_installed
 *     if __mem_installed:
 */

static PyObject *__pyx_f_6uvloop_4loop___install_pymem(void) {
  int __pyx_v_err;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("__install_pymem", 0);

  /* "uvloop/loop.pyx":3072
 * cdef __install_pymem():
 *     global __mem_installed
 *     if __mem_installed:             # <<<<<<<<<<<<<<
 *         return
 *     __mem_installed = 1
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop___mem_installed != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":3073
 *     global __mem_installed
 *     if __mem_installed:
 *         return             # <<<<<<<<<<<<<<
 *     __mem_installed = 1
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "uvloop/loop.pyx":3072
 * cdef __install_pymem():
 *     global __mem_installed
 *     if __mem_installed:             # <<<<<<<<<<<<<<
 *         return
 *     __mem_installed = 1
 */
  }

  /* "uvloop/loop.pyx":3074
 *     if __mem_installed:
 *         return
 *     __mem_installed = 1             # <<<<<<<<<<<<<<
 * 
 *     cdef int err
 */
  __pyx_v_6uvloop_4loop___mem_installed = 1;

  /* "uvloop/loop.pyx":3077
 * 
 *     cdef int err
 *     err = uv.uv_replace_allocator(<uv.uv_malloc_func>PyMem_RawMalloc,             # <<<<<<<<<<<<<<
 *                                   <uv.uv_realloc_func>PyMem_RawRealloc,
 *                                   <uv.uv_calloc_func>PyMem_RawCalloc,
 */
  __pyx_v_err = uv_replace_allocator(((uv_malloc_func)PyMem_RawMalloc), ((uv_realloc_func)PyMem_RawRealloc), ((uv_calloc_func)PyMem_RawCalloc), ((uv_free_func)PyMem_RawFree));

  /* "uvloop/loop.pyx":3081
 *                                   <uv.uv_calloc_func>PyMem_RawCalloc,
 *                                   <uv.uv_free_func>PyMem_RawFree)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         __mem_installed = 0
 *         raise convert_error(err)
 */
  __pyx_t_1 = ((__pyx_v_err < 0) != 0);
  if (unlikely(__pyx_t_1)) {

    /* "uvloop/loop.pyx":3082
 *                                   <uv.uv_free_func>PyMem_RawFree)
 *     if err < 0:
 *         __mem_installed = 0             # <<<<<<<<<<<<<<
 *         raise convert_error(err)
 * 
 */
    __pyx_v_6uvloop_4loop___mem_installed = 0;

    /* "uvloop/loop.pyx":3083
 *     if err < 0:
 *         __mem_installed = 0
 *         raise convert_error(err)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __pyx_f_6uvloop_4loop_convert_error(__pyx_v_err); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3083, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 3083, __pyx_L1_error)

    /* "uvloop/loop.pyx":3081
 *                                   <uv.uv_calloc_func>PyMem_RawCalloc,
 *                                   <uv.uv_free_func>PyMem_RawFree)
 *     if err < 0:             # <<<<<<<<<<<<<<
 *         __mem_installed = 0
 *         raise convert_error(err)
 */
  }

  /* "uvloop/loop.pyx":3070
 * # Install PyMem* memory allocators
 * cdef vint __mem_installed = 0
 * cdef __install_pymem():             # <<<<<<<<<<<<<<
 *     global __mem_installed
 *     if __mem_installed:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("uvloop.loop.__install_pymem", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":3086
 * 
 * 
 * cdef _set_signal_wakeup_fd(fd):             # <<<<<<<<<<<<<<
 *     if PY37 and fd >= 0:
 *         signal_set_wakeup_fd(fd, warn_on_full_buffer=False)
 */

static PyObject *__pyx_f_6uvloop_4loop__set_signal_wakeup_fd(PyObject *__pyx_v_fd) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_set_signal_wakeup_fd", 0);

  /* "uvloop/loop.pyx":3087
 * 
 * cdef _set_signal_wakeup_fd(fd):
 *     if PY37 and fd >= 0:             # <<<<<<<<<<<<<<
 *         signal_set_wakeup_fd(fd, warn_on_full_buffer=False)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_6uvloop_4loop_PY37 != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_fd, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3087, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(2, 3087, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":3088
 * cdef _set_signal_wakeup_fd(fd):
 *     if PY37 and fd >= 0:
 *         signal_set_wakeup_fd(fd, warn_on_full_buffer=False)             # <<<<<<<<<<<<<<
 *     else:
 *         signal_set_wakeup_fd(fd)
 */
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_fd);
    __Pyx_GIVEREF(__pyx_v_fd);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_fd);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_warn_on_full_buffer, Py_False) < 0) __PYX_ERR(2, 3088, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_signal_set_wakeup_fd, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "uvloop/loop.pyx":3087
 * 
 * cdef _set_signal_wakeup_fd(fd):
 *     if PY37 and fd >= 0:             # <<<<<<<<<<<<<<
 *         signal_set_wakeup_fd(fd, warn_on_full_buffer=False)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":3090
 *         signal_set_wakeup_fd(fd, warn_on_full_buffer=False)
 *     else:
 *         signal_set_wakeup_fd(fd)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_signal_set_wakeup_fd);
    __pyx_t_4 = __pyx_v_6uvloop_4loop_signal_set_wakeup_fd; __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    if (!__pyx_t_3) {
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_fd); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3090, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_fd};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3090, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[2] = {__pyx_t_3, __pyx_v_fd};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3090, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_5);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3090, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3); __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_v_fd);
        __Pyx_GIVEREF(__pyx_v_fd);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_v_fd);
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3090, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":3086
 * 
 * 
 * cdef _set_signal_wakeup_fd(fd):             # <<<<<<<<<<<<<<
 *     if PY37 and fd >= 0:
 *         signal_set_wakeup_fd(fd, warn_on_full_buffer=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop._set_signal_wakeup_fd", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "uvloop/loop.pyx":3093
 * 
 * 
 * cdef _warn_with_source(msg, cls, source):             # <<<<<<<<<<<<<<
 *     if PY36:
 *         warnings_warn(msg, cls, source=source)
 */

static PyObject *__pyx_f_6uvloop_4loop__warn_with_source(PyObject *__pyx_v_msg, PyObject *__pyx_v_cls, PyObject *__pyx_v_source) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("_warn_with_source", 0);

  /* "uvloop/loop.pyx":3094
 * 
 * cdef _warn_with_source(msg, cls, source):
 *     if PY36:             # <<<<<<<<<<<<<<
 *         warnings_warn(msg, cls, source=source)
 *     else:
 */
  __pyx_t_1 = (__pyx_v_6uvloop_4loop_PY36 != 0);
  if (__pyx_t_1) {

    /* "uvloop/loop.pyx":3095
 * cdef _warn_with_source(msg, cls, source):
 *     if PY36:
 *         warnings_warn(msg, cls, source=source)             # <<<<<<<<<<<<<<
 *     else:
 *         warnings_warn(msg, cls)
 */
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_msg);
    __Pyx_GIVEREF(__pyx_v_msg);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_msg);
    __Pyx_INCREF(__pyx_v_cls);
    __Pyx_GIVEREF(__pyx_v_cls);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_cls);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_source, __pyx_v_source) < 0) __PYX_ERR(2, 3095, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_v_6uvloop_4loop_warnings_warn, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "uvloop/loop.pyx":3094
 * 
 * cdef _warn_with_source(msg, cls, source):
 *     if PY36:             # <<<<<<<<<<<<<<
 *         warnings_warn(msg, cls, source=source)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "uvloop/loop.pyx":3097
 *         warnings_warn(msg, cls, source=source)
 *     else:
 *         warnings_warn(msg, cls)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_6uvloop_4loop_warnings_warn);
    __pyx_t_3 = __pyx_v_6uvloop_4loop_warnings_warn; __pyx_t_2 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_msg, __pyx_v_cls};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3097, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_msg, __pyx_v_cls};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3097, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    {
      __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3097, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (__pyx_t_2) {
        __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2); __pyx_t_2 = NULL;
      }
      __Pyx_INCREF(__pyx_v_msg);
      __Pyx_GIVEREF(__pyx_v_msg);
      PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_msg);
      __Pyx_INCREF(__pyx_v_cls);
      __Pyx_GIVEREF(__pyx_v_cls);
      PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_v_cls);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3097, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "uvloop/loop.pyx":3093
 * 
 * 
 * cdef _warn_with_source(msg, cls, source):             # <<<<<<<<<<<<<<
 *     if PY36:
 *         warnings_warn(msg, cls, source=source)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop._warn_with_source", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_6uvloop_4loop_2generator21(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "uvloop/loop.pyx":3103
 * 
 * @cython.iterable_coroutine
 * async def _test_coroutine_1():             # <<<<<<<<<<<<<<
 *     return 42
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_1_test_coroutine_1(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_6uvloop_4loop__test_coroutine_1[] = "_test_coroutine_1()";
static PyMethodDef __pyx_mdef_6uvloop_4loop_1_test_coroutine_1 = {"_test_coroutine_1", (PyCFunction)__pyx_pw_6uvloop_4loop_1_test_coroutine_1, METH_NOARGS, __pyx_doc_6uvloop_4loop__test_coroutine_1};
static PyObject *__pyx_pw_6uvloop_4loop_1_test_coroutine_1(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_test_coroutine_1 (wrapper)", 0);
  __pyx_r = __pyx_pf_6uvloop_4loop__test_coroutine_1(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop__test_coroutine_1(CYTHON_UNUSED PyObject *__pyx_self) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_test_coroutine_1", 0);
  __pyx_cur_scope = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 *)__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1(__pyx_ptype_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(2, 3103, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  {
    __pyx_CoroutineObject *gen = __Pyx_IterableCoroutine_New((__pyx_coroutine_body_t) __pyx_gb_6uvloop_4loop_2generator21, __pyx_codeobj__270, (PyObject *) __pyx_cur_scope, __pyx_n_s_test_coroutine_1, __pyx_n_s_test_coroutine_1, __pyx_n_s_uvloop_loop); if (unlikely(!gen)) __PYX_ERR(2, 3103, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("uvloop.loop._test_coroutine_1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_6uvloop_4loop_2generator21(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_test_coroutine_1", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(2, 3103, __pyx_L1_error)

  /* "uvloop/loop.pyx":3104
 * @cython.iterable_coroutine
 * async def _test_coroutine_1():
 *     return 42             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = NULL; __Pyx_ReturnWithStopIteration(__pyx_int_42);
  goto __pyx_L0;

  /* "uvloop/loop.pyx":3103
 * 
 * @cython.iterable_coroutine
 * async def _test_coroutine_1():             # <<<<<<<<<<<<<<
 *     return 42
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("_test_coroutine_1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x88c0b03:
 *         from pickle import PickleError as __pyx_PickleError
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_4__pyx_unpickle_PseudoSocket(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_3__pyx_unpickle_PseudoSocket[] = "__pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_4__pyx_unpickle_PseudoSocket = {"__pyx_unpickle_PseudoSocket", (PyCFunction)__pyx_pw_6uvloop_4loop_4__pyx_unpickle_PseudoSocket, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_3__pyx_unpickle_PseudoSocket};
static PyObject *__pyx_pw_6uvloop_4loop_4__pyx_unpickle_PseudoSocket(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_PseudoSocket (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_PseudoSocket", 1, 3, 3, 1); __PYX_ERR(9, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_PseudoSocket", 1, 3, 3, 2); __PYX_ERR(9, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_PseudoSocket") < 0)) __PYX_ERR(9, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(9, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_PseudoSocket", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(9, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.__pyx_unpickle_PseudoSocket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_3__pyx_unpickle_PseudoSocket(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_3__pyx_unpickle_PseudoSocket(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = NULL;
  PyObject *__pyx_v___pyx_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("__pyx_unpickle_PseudoSocket", 0);

  /* "(tree fragment)":2
 * def __pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x88c0b03:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x88c0b03) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":3
 * def __pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x88c0b03:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))" % __pyx_checksum)
 *     __pyx_result = PseudoSocket.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":4
 *     if __pyx_checksum != 0x88c0b03:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = PseudoSocket.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x88, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(9, 4, __pyx_L1_error)

    /* "(tree fragment)":2
 * def __pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x88c0b03:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":5
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))" % __pyx_checksum)
 *     __pyx_result = PseudoSocket.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6uvloop_4loop_PseudoSocket), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v___pyx_type);
      __Pyx_GIVEREF(__pyx_v___pyx_type);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v___pyx_type);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))" % __pyx_checksum)
 *     __pyx_result = PseudoSocket.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":7
 *     __pyx_result = PseudoSocket.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(9, 7, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_6uvloop_4loop___pyx_unpickle_PseudoSocket__set_state(((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x88c0b03 = (_family, _fd, _peername, _proto, _sockname, _type))" % __pyx_checksum)
 *     __pyx_result = PseudoSocket.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":8
 *     if __pyx_state is not None:
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x88c0b03:
 *         from pickle import PickleError as __pyx_PickleError
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.__pyx_unpickle_PseudoSocket", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":9
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_6uvloop_4loop___pyx_unpickle_PseudoSocket__set_state(struct __pyx_obj_6uvloop_4loop_PseudoSocket *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("__pyx_unpickle_PseudoSocket__set_state", 0);

  /* "(tree fragment)":10
 *     return __pyx_result
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->_family = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->_fd = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_peername);
  __Pyx_DECREF(__pyx_v___pyx_result->_peername);
  __pyx_v___pyx_result->_peername = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->_proto = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_sockname);
  __Pyx_DECREF(__pyx_v___pyx_result->_sockname);
  __pyx_v___pyx_result->_sockname = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->_type = __pyx_t_2;

  /* "(tree fragment)":11
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(9, 11, __pyx_L1_error)
  }
  __pyx_t_4 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(9, 11, __pyx_L1_error)
  __pyx_t_5 = ((__pyx_t_4 > 6) != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_3 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(9, 11, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "(tree fragment)":12
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[6])             # <<<<<<<<<<<<<<
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_7)) __PYX_ERR(9, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_update); if (unlikely(!__pyx_t_8)) __PYX_ERR(9, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(9, 12, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(9, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    if (!__pyx_t_9) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[2] = {__pyx_t_9, __pyx_t_7};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(1+1); if (unlikely(!__pyx_t_10)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_9); __pyx_t_9 = NULL;
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_10, 0+1, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":11
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[6])
 */
  }

  /* "(tree fragment)":9
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("uvloop.loop.__pyx_unpickle_PseudoSocket__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle__SSLPipe(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x38d1e2b:
 *         from pickle import PickleError as __pyx_PickleError
 */

/* Python wrapper */
static PyObject *__pyx_pw_6uvloop_4loop_6__pyx_unpickle__SSLPipe(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_6uvloop_4loop_5__pyx_unpickle__SSLPipe[] = "__pyx_unpickle__SSLPipe(__pyx_type, long __pyx_checksum, __pyx_state)";
static PyMethodDef __pyx_mdef_6uvloop_4loop_6__pyx_unpickle__SSLPipe = {"__pyx_unpickle__SSLPipe", (PyCFunction)__pyx_pw_6uvloop_4loop_6__pyx_unpickle__SSLPipe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_5__pyx_unpickle__SSLPipe};
static PyObject *__pyx_pw_6uvloop_4loop_6__pyx_unpickle__SSLPipe(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle__SSLPipe (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle__SSLPipe", 1, 3, 3, 1); __PYX_ERR(9, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle__SSLPipe", 1, 3, 3, 2); __PYX_ERR(9, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle__SSLPipe") < 0)) __PYX_ERR(9, 1, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(9, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle__SSLPipe", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(9, 1, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("uvloop.loop.__pyx_unpickle__SSLPipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6uvloop_4loop_5__pyx_unpickle__SSLPipe(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6uvloop_4loop_5__pyx_unpickle__SSLPipe(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = NULL;
  PyObject *__pyx_v___pyx_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  __Pyx_RefNannySetupContext("__pyx_unpickle__SSLPipe", 0);

  /* "(tree fragment)":2
 * def __pyx_unpickle__SSLPipe(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x38d1e2b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))" % __pyx_checksum)
 */
  __pyx_t_1 = ((__pyx_v___pyx_checksum != 0x38d1e2b) != 0);
  if (__pyx_t_1) {

    /* "(tree fragment)":3
 * def __pyx_unpickle__SSLPipe(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x38d1e2b:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))" % __pyx_checksum)
 *     __pyx_result = _SSLPipe.__new__(__pyx_type)
 */
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 3, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v___pyx_PickleError = __pyx_t_2;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":4
 *     if __pyx_checksum != 0x38d1e2b:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = _SSLPipe.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0x38, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 4, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_INCREF(__pyx_v___pyx_PickleError);
    __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    if (!__pyx_t_5) {
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
        PyObject *__pyx_temp[2] = {__pyx_t_5, __pyx_t_4};
        __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 4, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(9, 4, __pyx_L1_error)

    /* "(tree fragment)":2
 * def __pyx_unpickle__SSLPipe(__pyx_type, long __pyx_checksum, __pyx_state):
 *     if __pyx_checksum != 0x38d1e2b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))" % __pyx_checksum)
 */
  }

  /* "(tree fragment)":5
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))" % __pyx_checksum)
 *     __pyx_result = _SSLPipe.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle__SSLPipe__set_state(<_SSLPipe> __pyx_result, __pyx_state)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6uvloop_4loop__SSLPipe), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  if (!__pyx_t_6) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  } else {
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[2] = {__pyx_t_6, __pyx_v___pyx_type};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_3);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(1+1); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
      __Pyx_INCREF(__pyx_v___pyx_type);
      __Pyx_GIVEREF(__pyx_v___pyx_type);
      PyTuple_SET_ITEM(__pyx_t_4, 0+1, __pyx_v___pyx_type);
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 5, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v___pyx_result = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))" % __pyx_checksum)
 *     __pyx_result = _SSLPipe.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle__SSLPipe__set_state(<_SSLPipe> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_1 = (__pyx_v___pyx_state != Py_None);
  __pyx_t_7 = (__pyx_t_1 != 0);
  if (__pyx_t_7) {

    /* "(tree fragment)":7
 *     __pyx_result = _SSLPipe.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle__SSLPipe__set_state(<_SSLPipe> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle__SSLPipe__set_state(_SSLPipe __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(9, 7, __pyx_L1_error)
    __pyx_t_3 = __pyx_f_6uvloop_4loop___pyx_unpickle__SSLPipe__set_state(((struct __pyx_obj_6uvloop_4loop__SSLPipe *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0x38d1e2b = (_context, _handshake_cb, _incoming, _need_ssldata, _outgoing, _server_hostname, _server_side, _shutdown_cb, _sslobj, _state))" % __pyx_checksum)
 *     __pyx_result = _SSLPipe.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle__SSLPipe__set_state(<_SSLPipe> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":8
 *     if __pyx_state is not None:
 *         __pyx_unpickle__SSLPipe__set_state(<_SSLPipe> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle__SSLPipe__set_state(_SSLPipe __pyx_result, tuple __pyx_state):
 *     __pyx_result._context = __pyx_state[0]; __pyx_result._handshake_cb = __pyx_state[1]; __pyx_result._incoming = __pyx_state[2]; __pyx_result._need_ssldata = __pyx_state[3]; __pyx_result._outgoing = __pyx_state[4]; __pyx_result._server_hostname = __pyx_state[5]; __pyx_result._server_side = __pyx_state[6]; __pyx_result._shutdown_cb = __pyx_state[7]; __pyx_result._sslobj = __pyx_state[8]; __pyx_result._state = __pyx_state[9]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle__SSLPipe(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x38d1e2b:
 *         from pickle import PickleError as __pyx_PickleError
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("uvloop.loop.__pyx_unpickle__SSLPipe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":9
 *         __pyx_unpickle__SSLPipe__set_state(<_SSLPipe> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle__SSLPipe__set_state(_SSLPipe __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._context = __pyx_state[0]; __pyx_result._handshake_cb = __pyx_state[1]; __pyx_result._incoming = __pyx_state[2]; __pyx_result._need_ssldata = __pyx_state[3]; __pyx_result._outgoing = __pyx_state[4]; __pyx_result._server_hostname = __pyx_state[5]; __pyx_result._server_side = __pyx_state[6]; __pyx_result._shutdown_cb = __pyx_state[7]; __pyx_result._sslobj = __pyx_state[8]; __pyx_result._state = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_6uvloop_4loop___pyx_unpickle__SSLPipe__set_state(struct __pyx_obj_6uvloop_4loop__SSLPipe *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  __Pyx_RefNannySetupContext("__pyx_unpickle__SSLPipe__set_state", 0);

  /* "(tree fragment)":10
 *     return __pyx_result
 * cdef __pyx_unpickle__SSLPipe__set_state(_SSLPipe __pyx_result, tuple __pyx_state):
 *     __pyx_result._context = __pyx_state[0]; __pyx_result._handshake_cb = __pyx_state[1]; __pyx_result._incoming = __pyx_state[2]; __pyx_result._need_ssldata = __pyx_state[3]; __pyx_result._outgoing = __pyx_state[4]; __pyx_result._server_hostname = __pyx_state[5]; __pyx_result._server_side = __pyx_state[6]; __pyx_result._shutdown_cb = __pyx_state[7]; __pyx_result._sslobj = __pyx_state[8]; __pyx_result._state = __pyx_state[9]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_context);
  __Pyx_DECREF(__pyx_v___pyx_result->_context);
  __pyx_v___pyx_result->_context = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_handshake_cb);
  __Pyx_DECREF(__pyx_v___pyx_result->_handshake_cb);
  __pyx_v___pyx_result->_handshake_cb = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_incoming);
  __Pyx_DECREF(__pyx_v___pyx_result->_incoming);
  __pyx_v___pyx_result->_incoming = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v___pyx_result->_need_ssldata = __pyx_t_2;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_outgoing);
  __Pyx_DECREF(__pyx_v___pyx_result->_outgoing);
  __pyx_v___pyx_result->_outgoing = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 5, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_server_hostname);
  __Pyx_DECREF(__pyx_v___pyx_result->_server_hostname);
  __pyx_v___pyx_result->_server_hostname = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 6, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_server_side);
  __Pyx_DECREF(__pyx_v___pyx_result->_server_side);
  __pyx_v___pyx_result->_server_side = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 7, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_shutdown_cb);
  __Pyx_DECREF(__pyx_v___pyx_result->_shutdown_cb);
  __pyx_v___pyx_result->_shutdown_cb = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 8, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_sslobj);
  __Pyx_DECREF(__pyx_v___pyx_result->_sslobj);
  __pyx_v___pyx_result->_sslobj = __pyx_t_1;
  __pyx_t_1 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(9, 10, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 9, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->_state);
  __Pyx_DECREF(__pyx_v___pyx_result->_state);
  __pyx_v___pyx_result->_state = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":11
 * cdef __pyx_unpickle__SSLPipe__set_state(_SSLPipe __pyx_result, tuple __pyx_state):
 *     __pyx_result._context = __pyx_state[0]; __pyx_result._handshake_cb = __pyx_state[1]; __pyx_result._incoming = __pyx_state[2]; __pyx_result._need_ssldata = __pyx_state[3]; __pyx_result._outgoing = __pyx_state[4]; __pyx_result._server_hostname = __pyx_state[5]; __pyx_result._server_side = __pyx_state[6]; __pyx_result._shutdown_cb = __pyx_state[7]; __pyx_result._sslobj = __pyx_state[8]; __pyx_result._state = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(9, 11, __pyx_L1_error)
  }
  __pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(9, 11, __pyx_L1_error)
  __pyx_t_4 = ((__pyx_t_3 > 10) != 0);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(9, 11, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_4 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":12
 *     __pyx_result._context = __pyx_state[0]; __pyx_result._handshake_cb = __pyx_state[1]; __pyx_result._incoming = __pyx_state[2]; __pyx_result._need_ssldata = __pyx_state[3]; __pyx_result._outgoing = __pyx_state[4]; __pyx_result._server_hostname = __pyx_state[5]; __pyx_result._server_side = __pyx_state[6]; __pyx_result._shutdown_cb = __pyx_state[7]; __pyx_result._sslobj = __pyx_state[8]; __pyx_result._state = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[10])             # <<<<<<<<<<<<<<
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(9, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(9, 12, __pyx_L1_error)
    }
    __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 10, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 12, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    if (!__pyx_t_8) {
      __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_1);
    } else {
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[2] = {__pyx_t_8, __pyx_t_6};
        __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-1, 1+1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(1+1); if (unlikely(!__pyx_t_9)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_9, 0+1, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 12, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":11
 * cdef __pyx_unpickle__SSLPipe__set_state(_SSLPipe __pyx_result, tuple __pyx_state):
 *     __pyx_result._context = __pyx_state[0]; __pyx_result._handshake_cb = __pyx_state[1]; __pyx_result._incoming = __pyx_state[2]; __pyx_result._need_ssldata = __pyx_state[3]; __pyx_result._outgoing = __pyx_state[4]; __pyx_result._server_hostname = __pyx_state[5]; __pyx_result._server_side = __pyx_state[6]; __pyx_result._shutdown_cb = __pyx_state[7]; __pyx_result._sslobj = __pyx_state[8]; __pyx_result._state = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[10])
 */
  }

  /* "(tree fragment)":9
 *         __pyx_unpickle__SSLPipe__set_state(<_SSLPipe> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle__SSLPipe__set_state(_SSLPipe __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._context = __pyx_state[0]; __pyx_result._handshake_cb = __pyx_state[1]; __pyx_result._incoming = __pyx_state[2]; __pyx_result._need_ssldata = __pyx_state[3]; __pyx_result._outgoing = __pyx_state[4]; __pyx_result._server_hostname = __pyx_state[5]; __pyx_result._server_side = __pyx_state[6]; __pyx_result._shutdown_cb = __pyx_state[7]; __pyx_result._sslobj = __pyx_state[8]; __pyx_result._state = __pyx_state[9]
 *     if len(__pyx_state) > 10 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("uvloop.loop.__pyx_unpickle__SSLPipe__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):
 *     def wrap(Loop self, bint enabled):             # <<<<<<<<<<<<<<
 *         """wrap(self: 'Loop', enabled: bool)"""
 *         return f(self, enabled)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_1wrap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_wrap[] = "wrap(self: 'Loop', enabled: bool)";
static PyMethodDef __pyx_mdef_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_1wrap = {"wrap", (PyCFunction)__pyx_pw_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_1wrap, METH_VARARGS|METH_KEYWORDS, __pyx_doc_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_wrap};
static PyObject *__pyx_pw_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_1wrap(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self = 0;
  int __pyx_v_enabled;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrap (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self_2,&__pyx_n_s_enabled,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self_2)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_enabled)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("wrap", 1, 2, 2, 1); __PYX_ERR(9, 65, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "wrap") < 0)) __PYX_ERR(9, 65, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = ((struct __pyx_obj_6uvloop_4loop_Loop *)values[0]);
    __pyx_v_enabled = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_enabled == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 65, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("wrap", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(9, 65, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_object____Loop____bint___to_py.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_self), __pyx_ptype_6uvloop_4loop_Loop, 1, "self", 0))) __PYX_ERR(9, 65, __pyx_L1_error)
  __pyx_r = __pyx_pf_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_wrap(__pyx_self, __pyx_v_self, __pyx_v_enabled);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_wrap(PyObject *__pyx_self, struct __pyx_obj_6uvloop_4loop_Loop *__pyx_v_self, int __pyx_v_enabled) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *__pyx_cur_scope;
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("wrap", 0);
  __pyx_outer_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cfunc.to_py":67
 *     def wrap(Loop self, bint enabled):
 *         """wrap(self: 'Loop', enabled: bool)"""
 *         return f(self, enabled)             # <<<<<<<<<<<<<<
 *     return wrap
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_f(__pyx_v_self, __pyx_v_enabled); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):
 *     def wrap(Loop self, bint enabled):             # <<<<<<<<<<<<<<
 *         """wrap(self: 'Loop', enabled: bool)"""
 *         return f(self, enabled)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_object____Loop____bint___to_py.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):             # <<<<<<<<<<<<<<
 *     def wrap(Loop self, bint enabled):
 *         """wrap(self: 'Loop', enabled: bool)"""
 */

static PyObject *__Pyx_CFunc_object____Loop____bint___to_py(PyObject *(*__pyx_v_f)(struct __pyx_obj_6uvloop_4loop_Loop *, int)) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *__pyx_cur_scope;
  PyObject *__pyx_v_wrap = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__Pyx_CFunc_object____Loop____bint___to_py", 0);
  __pyx_cur_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py(__pyx_ptype___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(9, 64, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):
 *     def wrap(Loop self, bint enabled):             # <<<<<<<<<<<<<<
 *         """wrap(self: 'Loop', enabled: bool)"""
 *         return f(self, enabled)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_11cfunc_dot_to_py_42__Pyx_CFunc_object____Loop____bint___to_py_1wrap, 0, __pyx_n_s_Pyx_CFunc_object____Loop____bi, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cfunc_to_py, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_wrap = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cfunc.to_py":68
 *         """wrap(self: 'Loop', enabled: bool)"""
 *         return f(self, enabled)
 *     return wrap             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrap);
  __pyx_r = __pyx_v_wrap;
  goto __pyx_L0;

  /* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):             # <<<<<<<<<<<<<<
 *     def wrap(Loop self, bint enabled):
 *         """wrap(self: 'Loop', enabled: bool)"""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_object____Loop____bint___to_py", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrap);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_6uvloop_4loop_UVHandle __pyx_vtable_6uvloop_4loop_UVHandle;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVHandle(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVHandle *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVHandle *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_UVHandle;
  p->_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  p->_source_traceback = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_8UVHandle_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVHandle(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVHandle *p = (struct __pyx_obj_6uvloop_4loop_UVHandle *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_6uvloop_4loop_8UVHandle_5__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->_loop);
  Py_CLEAR(p->_source_traceback);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVHandle(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVHandle *p = (struct __pyx_obj_6uvloop_4loop_UVHandle *)o;
  if (p->_loop) {
    e = (*v)(((PyObject *)p->_loop), a); if (e) return e;
  }
  if (p->_source_traceback) {
    e = (*v)(p->_source_traceback, a); if (e) return e;
  }
  return 0;
}

static PyObject *__pyx_getprop_6uvloop_4loop_8UVHandle__source_traceback(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_8UVHandle_17_source_traceback_1__get__(o);
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVHandle[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVHandle_9__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_8UVHandle_8__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVHandle_11__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_8UVHandle_10__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6uvloop_4loop_UVHandle[] = {
  {(char *)"_source_traceback", __pyx_getprop_6uvloop_4loop_8UVHandle__source_traceback, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVHandle = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVHandle", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVHandle), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "UVHandle()\nA base class for all libuv handles.\n\n    Automatically manages memory deallocation and closing.\n\n    Important:\n\n       1. call \"_ensure_alive()\" before calling any libuv functions on\n          your handles.\n\n       2. call \"__ensure_handle_data\" in *all* libuv handle callbacks.\n    ", /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVHandle, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVHandle, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6uvloop_4loop_UVHandle, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVHandle, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVSocketHandle __pyx_vtable_6uvloop_4loop_UVSocketHandle;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVSocketHandle(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVSocketHandle *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVSocketHandle;
  p->_fileobj = Py_None; Py_INCREF(Py_None);
  p->__pyx___cached_socket = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_14UVSocketHandle_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVSocketHandle(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVSocketHandle *p = (struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_fileobj);
  Py_CLEAR(p->__pyx___cached_socket);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVSocketHandle(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVSocketHandle *p = (struct __pyx_obj_6uvloop_4loop_UVSocketHandle *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVHandle(o, v, a); if (e) return e;
  if (p->_fileobj) {
    e = (*v)(p->_fileobj, a); if (e) return e;
  }
  if (p->__pyx___cached_socket) {
    e = (*v)(p->__pyx___cached_socket, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVSocketHandle[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_14UVSocketHandle_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_14UVSocketHandle_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_14UVSocketHandle_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_14UVSocketHandle_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVSocketHandle = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVSocketHandle", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVSocketHandle), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVSocketHandle, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVSocketHandle, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVSocketHandle, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVSocketHandle, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVAsync __pyx_vtable_6uvloop_4loop_UVAsync;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVAsync(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVAsync *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVAsync *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVAsync;
  p->ctx = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVAsync(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVAsync *p = (struct __pyx_obj_6uvloop_4loop_UVAsync *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->ctx);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVAsync(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVAsync *p = (struct __pyx_obj_6uvloop_4loop_UVAsync *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVHandle(o, v, a); if (e) return e;
  if (p->ctx) {
    e = (*v)(p->ctx, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVAsync[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_7UVAsync_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_7UVAsync___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_7UVAsync_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_7UVAsync_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVAsync = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVAsync", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVAsync), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVAsync, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVAsync, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVAsync, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVAsync, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVTimer __pyx_vtable_6uvloop_4loop_UVTimer;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVTimer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVTimer *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVTimer *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVTimer;
  p->ctx = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVTimer(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVTimer *p = (struct __pyx_obj_6uvloop_4loop_UVTimer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->ctx);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVTimer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVTimer *p = (struct __pyx_obj_6uvloop_4loop_UVTimer *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVHandle(o, v, a); if (e) return e;
  if (p->ctx) {
    e = (*v)(p->ctx, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVTimer[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_7UVTimer_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_7UVTimer___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_7UVTimer_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_7UVTimer_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVTimer = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVTimer", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVTimer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVTimer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVTimer, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVTimer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVTimer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVIdle __pyx_vtable_6uvloop_4loop_UVIdle;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVIdle(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVIdle *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVIdle *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVIdle;
  p->h = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVIdle(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVIdle *p = (struct __pyx_obj_6uvloop_4loop_UVIdle *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->h);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVIdle(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVIdle *p = (struct __pyx_obj_6uvloop_4loop_UVIdle *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVHandle(o, v, a); if (e) return e;
  if (p->h) {
    e = (*v)(((PyObject *)p->h), a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVIdle[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6UVIdle_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_6UVIdle___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6UVIdle_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_6UVIdle_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVIdle = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVIdle", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVIdle), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVIdle, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVIdle, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVIdle, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVIdle, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVBaseTransport __pyx_vtable_6uvloop_4loop_UVBaseTransport;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVBaseTransport(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVBaseTransport *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVSocketHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVBaseTransport;
  p->_protocol_data_received = Py_None; Py_INCREF(Py_None);
  p->_protocol = Py_None; Py_INCREF(Py_None);
  p->_server = ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None); Py_INCREF(Py_None);
  p->_waiter = Py_None; Py_INCREF(Py_None);
  p->_extra_info = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_15UVBaseTransport_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVBaseTransport(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVBaseTransport *p = (struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  if (p->__weakref__) PyObject_ClearWeakRefs(o);
  Py_CLEAR(p->_protocol_data_received);
  Py_CLEAR(p->_protocol);
  Py_CLEAR(p->_server);
  Py_CLEAR(p->_waiter);
  Py_CLEAR(p->_extra_info);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVSocketHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVBaseTransport(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVBaseTransport *p = (struct __pyx_obj_6uvloop_4loop_UVBaseTransport *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVSocketHandle(o, v, a); if (e) return e;
  if (p->_protocol_data_received) {
    e = (*v)(p->_protocol_data_received, a); if (e) return e;
  }
  if (p->_protocol) {
    e = (*v)(p->_protocol, a); if (e) return e;
  }
  if (p->_server) {
    e = (*v)(((PyObject *)p->_server), a); if (e) return e;
  }
  if (p->_waiter) {
    e = (*v)(p->_waiter, a); if (e) return e;
  }
  if (p->_extra_info) {
    e = (*v)(p->_extra_info, a); if (e) return e;
  }
  return 0;
}

static PyObject *__pyx_getprop_6uvloop_4loop_15UVBaseTransport__paused(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_15UVBaseTransport_7_paused_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_15UVBaseTransport__closing(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_15UVBaseTransport_8_closing_1__get__(o);
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVBaseTransport[] = {
  {"get_protocol", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_3get_protocol, METH_NOARGS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_2get_protocol},
  {"set_protocol", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_5set_protocol, METH_O, __pyx_doc_6uvloop_4loop_15UVBaseTransport_4set_protocol},
  {"_force_close", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_7_force_close, METH_O, __pyx_doc_6uvloop_4loop_15UVBaseTransport_6_force_close},
  {"abort", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_9abort, METH_NOARGS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_8abort},
  {"close", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_11close, METH_NOARGS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_10close},
  {"is_closing", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_13is_closing, METH_NOARGS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_12is_closing},
  {"get_write_buffer_size", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_15get_write_buffer_size, METH_NOARGS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_14get_write_buffer_size},
  {"set_write_buffer_limits", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_17set_write_buffer_limits, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_16set_write_buffer_limits},
  {"get_write_buffer_limits", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_19get_write_buffer_limits, METH_NOARGS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_18get_write_buffer_limits},
  {"get_extra_info", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_21get_extra_info, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_20get_extra_info},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_23__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_15UVBaseTransport_22__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_15UVBaseTransport_25__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_15UVBaseTransport_24__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6uvloop_4loop_UVBaseTransport[] = {
  {(char *)"_paused", __pyx_getprop_6uvloop_4loop_15UVBaseTransport__paused, 0, (char *)0, 0},
  {(char *)"_closing", __pyx_getprop_6uvloop_4loop_15UVBaseTransport__closing, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVBaseTransport = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVBaseTransport", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVBaseTransport), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVBaseTransport, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVBaseTransport, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVBaseTransport, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6uvloop_4loop_UVBaseTransport, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVBaseTransport, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_Loop __pyx_vtable_6uvloop_4loop_Loop;

static PyObject *__pyx_tp_new_6uvloop_4loop_Loop(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_Loop *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_Loop *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_Loop;
  p->slow_callback_duration = Py_None; Py_INCREF(Py_None);
  p->_task_factory = Py_None; Py_INCREF(Py_None);
  p->_exception_handler = Py_None; Py_INCREF(Py_None);
  p->_default_executor = Py_None; Py_INCREF(Py_None);
  p->_ready = Py_None; Py_INCREF(Py_None);
  p->_queued_streams = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_servers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_transports = Py_None; Py_INCREF(Py_None);
  p->_processes = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_fd_to_reader_fileobj = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_fd_to_writer_fileobj = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_signals = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_signal_handlers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_ssock = Py_None; Py_INCREF(Py_None);
  p->_csock = Py_None; Py_INCREF(Py_None);
  p->_timers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_polls = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->active_process_handler = ((struct __pyx_obj_6uvloop_4loop_UVProcess *)Py_None); Py_INCREF(Py_None);
  p->handler_async = ((struct __pyx_obj_6uvloop_4loop_UVAsync *)Py_None); Py_INCREF(Py_None);
  p->handler_idle = ((struct __pyx_obj_6uvloop_4loop_UVIdle *)Py_None); Py_INCREF(Py_None);
  p->handler_check__exec_writes = ((struct __pyx_obj_6uvloop_4loop_UVCheck *)Py_None); Py_INCREF(Py_None);
  p->_last_error = Py_None; Py_INCREF(Py_None);
  p->_asyncgens = Py_None; Py_INCREF(Py_None);
  p->_debug_handles_total = Py_None; Py_INCREF(Py_None);
  p->_debug_handles_closed = Py_None; Py_INCREF(Py_None);
  p->_debug_handles_current = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_4Loop_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_Loop(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_Loop *p = (struct __pyx_obj_6uvloop_4loop_Loop *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_6uvloop_4loop_4Loop_5__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  if (p->__weakref__) PyObject_ClearWeakRefs(o);
  Py_CLEAR(p->slow_callback_duration);
  Py_CLEAR(p->_task_factory);
  Py_CLEAR(p->_exception_handler);
  Py_CLEAR(p->_default_executor);
  Py_CLEAR(p->_ready);
  Py_CLEAR(p->_queued_streams);
  Py_CLEAR(p->_servers);
  Py_CLEAR(p->_transports);
  Py_CLEAR(p->_processes);
  Py_CLEAR(p->_fd_to_reader_fileobj);
  Py_CLEAR(p->_fd_to_writer_fileobj);
  Py_CLEAR(p->_signals);
  Py_CLEAR(p->_signal_handlers);
  Py_CLEAR(p->_ssock);
  Py_CLEAR(p->_csock);
  Py_CLEAR(p->_timers);
  Py_CLEAR(p->_polls);
  Py_CLEAR(p->active_process_handler);
  Py_CLEAR(p->handler_async);
  Py_CLEAR(p->handler_idle);
  Py_CLEAR(p->handler_check__exec_writes);
  Py_CLEAR(p->_last_error);
  Py_CLEAR(p->_asyncgens);
  Py_CLEAR(p->_debug_handles_total);
  Py_CLEAR(p->_debug_handles_closed);
  Py_CLEAR(p->_debug_handles_current);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_Loop(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_Loop *p = (struct __pyx_obj_6uvloop_4loop_Loop *)o;
  if (p->slow_callback_duration) {
    e = (*v)(p->slow_callback_duration, a); if (e) return e;
  }
  if (p->_task_factory) {
    e = (*v)(p->_task_factory, a); if (e) return e;
  }
  if (p->_exception_handler) {
    e = (*v)(p->_exception_handler, a); if (e) return e;
  }
  if (p->_default_executor) {
    e = (*v)(p->_default_executor, a); if (e) return e;
  }
  if (p->_ready) {
    e = (*v)(p->_ready, a); if (e) return e;
  }
  if (p->_queued_streams) {
    e = (*v)(p->_queued_streams, a); if (e) return e;
  }
  if (p->_servers) {
    e = (*v)(p->_servers, a); if (e) return e;
  }
  if (p->_transports) {
    e = (*v)(p->_transports, a); if (e) return e;
  }
  if (p->_processes) {
    e = (*v)(p->_processes, a); if (e) return e;
  }
  if (p->_fd_to_reader_fileobj) {
    e = (*v)(p->_fd_to_reader_fileobj, a); if (e) return e;
  }
  if (p->_fd_to_writer_fileobj) {
    e = (*v)(p->_fd_to_writer_fileobj, a); if (e) return e;
  }
  if (p->_signals) {
    e = (*v)(p->_signals, a); if (e) return e;
  }
  if (p->_signal_handlers) {
    e = (*v)(p->_signal_handlers, a); if (e) return e;
  }
  if (p->_ssock) {
    e = (*v)(p->_ssock, a); if (e) return e;
  }
  if (p->_csock) {
    e = (*v)(p->_csock, a); if (e) return e;
  }
  if (p->_timers) {
    e = (*v)(p->_timers, a); if (e) return e;
  }
  if (p->_polls) {
    e = (*v)(p->_polls, a); if (e) return e;
  }
  if (p->active_process_handler) {
    e = (*v)(((PyObject *)p->active_process_handler), a); if (e) return e;
  }
  if (p->handler_async) {
    e = (*v)(((PyObject *)p->handler_async), a); if (e) return e;
  }
  if (p->handler_idle) {
    e = (*v)(((PyObject *)p->handler_idle), a); if (e) return e;
  }
  if (p->handler_check__exec_writes) {
    e = (*v)(((PyObject *)p->handler_check__exec_writes), a); if (e) return e;
  }
  if (p->_last_error) {
    e = (*v)(p->_last_error, a); if (e) return e;
  }
  if (p->_asyncgens) {
    e = (*v)(p->_asyncgens, a); if (e) return e;
  }
  if (p->_debug_handles_total) {
    e = (*v)(p->_debug_handles_total, a); if (e) return e;
  }
  if (p->_debug_handles_closed) {
    e = (*v)(p->_debug_handles_closed, a); if (e) return e;
  }
  if (p->_debug_handles_current) {
    e = (*v)(p->_debug_handles_current, a); if (e) return e;
  }
  return 0;
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop_print_debug_info(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_16print_debug_info_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop_slow_callback_duration(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_1__get__(o);
}

static int __pyx_setprop_6uvloop_4loop_4Loop_slow_callback_duration(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_3__set__(o, v);
  }
  else {
    return __pyx_pw_6uvloop_4loop_4Loop_22slow_callback_duration_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__closed(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_7_closed_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_cc(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_9_debug_cc_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_handles_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_20_debug_handles_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_handles_closed(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_21_debug_handles_closed_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_handles_current(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_22_debug_handles_current_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_uv_handles_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_23_debug_uv_handles_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_uv_handles_freed(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_23_debug_uv_handles_freed_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_cb_handles_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_23_debug_cb_handles_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_cb_handles_count(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_23_debug_cb_handles_count_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_cb_timer_handles_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_cb_timer_handles_count(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_29_debug_cb_timer_handles_count_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_shutdown_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_35_debug_stream_shutdown_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_listen_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_33_debug_stream_listen_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_cb_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_27_debug_stream_read_cb_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_cb_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_34_debug_stream_read_cb_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_eof_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_28_debug_stream_read_eof_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_eof_cb_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_38_debug_stream_read_eof_cb_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_31_debug_stream_read_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_tries(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_25_debug_stream_write_tries_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_32_debug_stream_write_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_ctx_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_29_debug_stream_write_ctx_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_ctx_cnt(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_27_debug_stream_write_ctx_cnt_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_cb_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_35_debug_stream_write_cb_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__poll_read_events_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_23_poll_read_events_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__poll_read_cb_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_26_poll_read_cb_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__poll_write_events_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_24_poll_write_events_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__poll_write_cb_errors_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_27_poll_write_cb_errors_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__sock_try_write_total(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_21_sock_try_write_total_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_4Loop__debug_exception_handler_cnt(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_4Loop_28_debug_exception_handler_cnt_1__get__(o);
}

static PyMethodDef __pyx_methods_6uvloop_4loop_Loop[] = {
  {"__sighandler", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_7__sighandler, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_6__sighandler},
  {"_get_backend_id", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_9_get_backend_id, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_8_get_backend_id},
  {"call_soon", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_13call_soon, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_12call_soon},
  {"call_soon_threadsafe", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_15call_soon_threadsafe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_14call_soon_threadsafe},
  {"call_later", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_17call_later, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_16call_later},
  {"call_at", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_19call_at, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_18call_at},
  {"time", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_21time, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_20time},
  {"stop", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_23stop, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_22stop},
  {"run_forever", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_25run_forever, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_24run_forever},
  {"close", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_27close, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_26close},
  {"get_debug", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_29get_debug, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_28get_debug},
  {"set_debug", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_31set_debug, METH_O, __pyx_doc_6uvloop_4loop_4Loop_30set_debug},
  {"is_running", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_33is_running, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_32is_running},
  {"is_closed", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_35is_closed, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_34is_closed},
  {"create_future", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_37create_future, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_36create_future},
  {"create_task", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_39create_task, METH_O, __pyx_doc_6uvloop_4loop_4Loop_38create_task},
  {"set_task_factory", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_41set_task_factory, METH_O, __pyx_doc_6uvloop_4loop_4Loop_40set_task_factory},
  {"get_task_factory", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_43get_task_factory, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_42get_task_factory},
  {"run_until_complete", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_45run_until_complete, METH_O, __pyx_doc_6uvloop_4loop_4Loop_44run_until_complete},
  {"getaddrinfo", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_47getaddrinfo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_46getaddrinfo},
  {"getnameinfo", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_50getnameinfo, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_49getnameinfo},
  {"start_tls", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_53start_tls, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_52start_tls},
  {"create_server", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_56create_server, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_55create_server},
  {"create_connection", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_59create_connection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_58create_connection},
  {"create_unix_server", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_62create_unix_server, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_61create_unix_server},
  {"create_unix_connection", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_65create_unix_connection, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_64create_unix_connection},
  {"default_exception_handler", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_68default_exception_handler, METH_O, __pyx_doc_6uvloop_4loop_4Loop_67default_exception_handler},
  {"get_exception_handler", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_70get_exception_handler, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_69get_exception_handler},
  {"set_exception_handler", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_72set_exception_handler, METH_O, __pyx_doc_6uvloop_4loop_4Loop_71set_exception_handler},
  {"call_exception_handler", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_74call_exception_handler, METH_O, __pyx_doc_6uvloop_4loop_4Loop_73call_exception_handler},
  {"add_reader", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_76add_reader, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_75add_reader},
  {"remove_reader", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_78remove_reader, METH_O, __pyx_doc_6uvloop_4loop_4Loop_77remove_reader},
  {"add_writer", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_80add_writer, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_79add_writer},
  {"remove_writer", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_82remove_writer, METH_O, __pyx_doc_6uvloop_4loop_4Loop_81remove_writer},
  {"sock_recv", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_84sock_recv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_83sock_recv},
  {"sock_recv_into", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_87sock_recv_into, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_86sock_recv_into},
  {"sock_sendall", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_90sock_sendall, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_89sock_sendall},
  {"sock_accept", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_93sock_accept, METH_O, __pyx_doc_6uvloop_4loop_4Loop_92sock_accept},
  {"sock_connect", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_96sock_connect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_95sock_connect},
  {"connect_accepted_socket", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_99connect_accepted_socket, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_98connect_accepted_socket},
  {"run_in_executor", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_102run_in_executor, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_101run_in_executor},
  {"set_default_executor", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_104set_default_executor, METH_O, __pyx_doc_6uvloop_4loop_4Loop_103set_default_executor},
  {"__subprocess_run", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_106__subprocess_run, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_105__subprocess_run},
  {"subprocess_shell", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_109subprocess_shell, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_108subprocess_shell},
  {"subprocess_exec", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_112subprocess_exec, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_111subprocess_exec},
  {"connect_read_pipe", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_115connect_read_pipe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_114connect_read_pipe},
  {"connect_write_pipe", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_118connect_write_pipe, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_117connect_write_pipe},
  {"add_signal_handler", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_121add_signal_handler, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_120add_signal_handler},
  {"remove_signal_handler", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_123remove_signal_handler, METH_O, __pyx_doc_6uvloop_4loop_4Loop_122remove_signal_handler},
  {"create_datagram_endpoint", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_125create_datagram_endpoint, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_4Loop_124create_datagram_endpoint},
  {"_asyncgen_finalizer_hook", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_128_asyncgen_finalizer_hook, METH_O, __pyx_doc_6uvloop_4loop_4Loop_127_asyncgen_finalizer_hook},
  {"_asyncgen_firstiter_hook", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_130_asyncgen_firstiter_hook, METH_O, __pyx_doc_6uvloop_4loop_4Loop_129_asyncgen_firstiter_hook},
  {"shutdown_asyncgens", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_132shutdown_asyncgens, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_131shutdown_asyncgens},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_135__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_4Loop_134__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_4Loop_137__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_4Loop_136__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6uvloop_4loop_Loop[] = {
  {(char *)"print_debug_info", __pyx_getprop_6uvloop_4loop_4Loop_print_debug_info, 0, (char *)0, 0},
  {(char *)"slow_callback_duration", __pyx_getprop_6uvloop_4loop_4Loop_slow_callback_duration, __pyx_setprop_6uvloop_4loop_4Loop_slow_callback_duration, (char *)"slow_callback_duration: object", 0},
  {(char *)"_closed", __pyx_getprop_6uvloop_4loop_4Loop__closed, 0, (char *)0, 0},
  {(char *)"_debug_cc", __pyx_getprop_6uvloop_4loop_4Loop__debug_cc, 0, (char *)0, 0},
  {(char *)"_debug_handles_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_handles_total, 0, (char *)0, 0},
  {(char *)"_debug_handles_closed", __pyx_getprop_6uvloop_4loop_4Loop__debug_handles_closed, 0, (char *)0, 0},
  {(char *)"_debug_handles_current", __pyx_getprop_6uvloop_4loop_4Loop__debug_handles_current, 0, (char *)0, 0},
  {(char *)"_debug_uv_handles_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_uv_handles_total, 0, (char *)0, 0},
  {(char *)"_debug_uv_handles_freed", __pyx_getprop_6uvloop_4loop_4Loop__debug_uv_handles_freed, 0, (char *)0, 0},
  {(char *)"_debug_cb_handles_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_cb_handles_total, 0, (char *)0, 0},
  {(char *)"_debug_cb_handles_count", __pyx_getprop_6uvloop_4loop_4Loop__debug_cb_handles_count, 0, (char *)0, 0},
  {(char *)"_debug_cb_timer_handles_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_cb_timer_handles_total, 0, (char *)0, 0},
  {(char *)"_debug_cb_timer_handles_count", __pyx_getprop_6uvloop_4loop_4Loop__debug_cb_timer_handles_count, 0, (char *)0, 0},
  {(char *)"_debug_stream_shutdown_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_shutdown_errors_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_listen_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_listen_errors_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_read_cb_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_cb_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_read_cb_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_cb_errors_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_read_eof_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_eof_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_read_eof_cb_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_eof_cb_errors_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_read_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_read_errors_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_write_tries", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_tries, 0, (char *)0, 0},
  {(char *)"_debug_stream_write_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_errors_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_write_ctx_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_ctx_total, 0, (char *)0, 0},
  {(char *)"_debug_stream_write_ctx_cnt", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_ctx_cnt, 0, (char *)0, 0},
  {(char *)"_debug_stream_write_cb_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__debug_stream_write_cb_errors_total, 0, (char *)0, 0},
  {(char *)"_poll_read_events_total", __pyx_getprop_6uvloop_4loop_4Loop__poll_read_events_total, 0, (char *)0, 0},
  {(char *)"_poll_read_cb_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__poll_read_cb_errors_total, 0, (char *)0, 0},
  {(char *)"_poll_write_events_total", __pyx_getprop_6uvloop_4loop_4Loop__poll_write_events_total, 0, (char *)0, 0},
  {(char *)"_poll_write_cb_errors_total", __pyx_getprop_6uvloop_4loop_4Loop__poll_write_cb_errors_total, 0, (char *)0, 0},
  {(char *)"_sock_try_write_total", __pyx_getprop_6uvloop_4loop_4Loop__sock_try_write_total, 0, (char *)0, 0},
  {(char *)"_debug_exception_handler_cnt", __pyx_getprop_6uvloop_4loop_4Loop__debug_exception_handler_cnt, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_Loop = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.Loop", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_Loop), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_Loop, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6uvloop_4loop_4Loop_11__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Loop()", /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_Loop, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_Loop, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6uvloop_4loop_Loop, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_6uvloop_4loop_4Loop_3__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_Loop, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_Handle __pyx_vtable_6uvloop_4loop_Handle;

static struct __pyx_obj_6uvloop_4loop_Handle *__pyx_freelist_6uvloop_4loop_Handle[250];
static int __pyx_freecount_6uvloop_4loop_Handle = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop_Handle(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_Handle *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop_Handle > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop_Handle)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop_Handle[--__pyx_freecount_6uvloop_4loop_Handle];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop_Handle));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_6uvloop_4loop_Handle *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_Handle;
  p->loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  p->context = Py_None; Py_INCREF(Py_None);
  p->meth_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->arg1 = Py_None; Py_INCREF(Py_None);
  p->arg2 = Py_None; Py_INCREF(Py_None);
  p->arg3 = Py_None; Py_INCREF(Py_None);
  p->arg4 = Py_None; Py_INCREF(Py_None);
  p->_source_traceback = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_6Handle_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_Handle(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_Handle *p = (struct __pyx_obj_6uvloop_4loop_Handle *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_6uvloop_4loop_6Handle_3__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  if (p->__weakref__) PyObject_ClearWeakRefs(o);
  Py_CLEAR(p->loop);
  Py_CLEAR(p->context);
  Py_CLEAR(p->meth_name);
  Py_CLEAR(p->arg1);
  Py_CLEAR(p->arg2);
  Py_CLEAR(p->arg3);
  Py_CLEAR(p->arg4);
  Py_CLEAR(p->_source_traceback);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop_Handle < 250) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop_Handle)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_6uvloop_4loop_Handle[__pyx_freecount_6uvloop_4loop_Handle++] = ((struct __pyx_obj_6uvloop_4loop_Handle *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop_Handle(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_Handle *p = (struct __pyx_obj_6uvloop_4loop_Handle *)o;
  if (p->loop) {
    e = (*v)(((PyObject *)p->loop), a); if (e) return e;
  }
  if (p->context) {
    e = (*v)(p->context, a); if (e) return e;
  }
  if (p->arg1) {
    e = (*v)(p->arg1, a); if (e) return e;
  }
  if (p->arg2) {
    e = (*v)(p->arg2, a); if (e) return e;
  }
  if (p->arg3) {
    e = (*v)(p->arg3, a); if (e) return e;
  }
  if (p->arg4) {
    e = (*v)(p->arg4, a); if (e) return e;
  }
  if (p->_source_traceback) {
    e = (*v)(p->_source_traceback, a); if (e) return e;
  }
  return 0;
}

static PyObject *__pyx_getprop_6uvloop_4loop_6Handle__source_traceback(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_6Handle_17_source_traceback_1__get__(o);
}

static PyMethodDef __pyx_methods_6uvloop_4loop_Handle[] = {
  {"cancel", (PyCFunction)__pyx_pw_6uvloop_4loop_6Handle_9cancel, METH_NOARGS, __pyx_doc_6uvloop_4loop_6Handle_8cancel},
  {"cancelled", (PyCFunction)__pyx_pw_6uvloop_4loop_6Handle_11cancelled, METH_NOARGS, __pyx_doc_6uvloop_4loop_6Handle_10cancelled},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6Handle_13__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_6Handle_12__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6Handle_15__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_6Handle_14__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6uvloop_4loop_Handle[] = {
  {(char *)"_source_traceback", __pyx_getprop_6uvloop_4loop_6Handle__source_traceback, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_Handle = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.Handle", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_Handle), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_Handle, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6uvloop_4loop_6Handle_7__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Handle()", /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_Handle, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_Handle, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6uvloop_4loop_Handle, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_6uvloop_4loop_6Handle_5__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_Handle, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_TimerHandle __pyx_vtable_6uvloop_4loop_TimerHandle;

static struct __pyx_obj_6uvloop_4loop_TimerHandle *__pyx_freelist_6uvloop_4loop_TimerHandle[250];
static int __pyx_freecount_6uvloop_4loop_TimerHandle = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop_TimerHandle(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_TimerHandle *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop_TimerHandle > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop_TimerHandle)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop_TimerHandle[--__pyx_freecount_6uvloop_4loop_TimerHandle];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop_TimerHandle));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_6uvloop_4loop_TimerHandle *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_TimerHandle;
  p->callback = Py_None; Py_INCREF(Py_None);
  p->args = Py_None; Py_INCREF(Py_None);
  p->timer = ((struct __pyx_obj_6uvloop_4loop_UVTimer *)Py_None); Py_INCREF(Py_None);
  p->loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  p->context = Py_None; Py_INCREF(Py_None);
  p->_source_traceback = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_11TimerHandle_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_TimerHandle(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_TimerHandle *p = (struct __pyx_obj_6uvloop_4loop_TimerHandle *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_6uvloop_4loop_11TimerHandle_3__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  if (p->__weakref__) PyObject_ClearWeakRefs(o);
  Py_CLEAR(p->callback);
  Py_CLEAR(p->args);
  Py_CLEAR(p->timer);
  Py_CLEAR(p->loop);
  Py_CLEAR(p->context);
  Py_CLEAR(p->_source_traceback);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop_TimerHandle < 250) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop_TimerHandle)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_6uvloop_4loop_TimerHandle[__pyx_freecount_6uvloop_4loop_TimerHandle++] = ((struct __pyx_obj_6uvloop_4loop_TimerHandle *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop_TimerHandle(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_TimerHandle *p = (struct __pyx_obj_6uvloop_4loop_TimerHandle *)o;
  if (p->callback) {
    e = (*v)(p->callback, a); if (e) return e;
  }
  if (p->args) {
    e = (*v)(p->args, a); if (e) return e;
  }
  if (p->timer) {
    e = (*v)(((PyObject *)p->timer), a); if (e) return e;
  }
  if (p->loop) {
    e = (*v)(((PyObject *)p->loop), a); if (e) return e;
  }
  if (p->context) {
    e = (*v)(p->context, a); if (e) return e;
  }
  if (p->_source_traceback) {
    e = (*v)(p->_source_traceback, a); if (e) return e;
  }
  return 0;
}

static PyObject *__pyx_getprop_6uvloop_4loop_11TimerHandle__source_traceback(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_11TimerHandle_17_source_traceback_1__get__(o);
}

static PyMethodDef __pyx_methods_6uvloop_4loop_TimerHandle[] = {
  {"cancelled", (PyCFunction)__pyx_pw_6uvloop_4loop_11TimerHandle_7cancelled, METH_NOARGS, __pyx_doc_6uvloop_4loop_11TimerHandle_6cancelled},
  {"cancel", (PyCFunction)__pyx_pw_6uvloop_4loop_11TimerHandle_9cancel, METH_NOARGS, __pyx_doc_6uvloop_4loop_11TimerHandle_8cancel},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_11TimerHandle_11__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_11TimerHandle_10__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_11TimerHandle_13__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_11TimerHandle_12__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6uvloop_4loop_TimerHandle[] = {
  {(char *)"_source_traceback", __pyx_getprop_6uvloop_4loop_11TimerHandle__source_traceback, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_TimerHandle = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.TimerHandle", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_TimerHandle), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_TimerHandle, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6uvloop_4loop_11TimerHandle_5__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_TimerHandle, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_TimerHandle, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6uvloop_4loop_TimerHandle, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_TimerHandle, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVCheck __pyx_vtable_6uvloop_4loop_UVCheck;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVCheck(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVCheck *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVCheck *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVCheck;
  p->h = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVCheck(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVCheck *p = (struct __pyx_obj_6uvloop_4loop_UVCheck *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->h);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVCheck(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVCheck *p = (struct __pyx_obj_6uvloop_4loop_UVCheck *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVHandle(o, v, a); if (e) return e;
  if (p->h) {
    e = (*v)(((PyObject *)p->h), a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVCheck[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_7UVCheck_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_7UVCheck___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_7UVCheck_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_7UVCheck_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVCheck = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVCheck", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVCheck), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVCheck, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVCheck, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVCheck, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVCheck, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVPoll __pyx_vtable_6uvloop_4loop_UVPoll;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVPoll(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVPoll;
  p->reading_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None); Py_INCREF(Py_None);
  p->writing_handle = ((struct __pyx_obj_6uvloop_4loop_Handle *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVPoll(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVPoll *p = (struct __pyx_obj_6uvloop_4loop_UVPoll *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->reading_handle);
  Py_CLEAR(p->writing_handle);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVPoll(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVPoll *p = (struct __pyx_obj_6uvloop_4loop_UVPoll *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVHandle(o, v, a); if (e) return e;
  if (p->reading_handle) {
    e = (*v)(((PyObject *)p->reading_handle), a); if (e) return e;
  }
  if (p->writing_handle) {
    e = (*v)(((PyObject *)p->writing_handle), a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVPoll[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6UVPoll_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_6UVPoll___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6UVPoll_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_6UVPoll_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVPoll = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVPoll", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVPoll), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVPoll, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVPoll, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVPoll, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVPoll, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVStream __pyx_vtable_6uvloop_4loop_UVStream;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVStream(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVStream *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVBaseTransport(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVStream *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVStream;
  p->_protocol_get_buffer = Py_None; Py_INCREF(Py_None);
  p->_protocol_buffer_updated = Py_None; Py_INCREF(Py_None);
  p->_buffer = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_read_pybuf.obj = NULL;
  if (unlikely(__pyx_pw_6uvloop_4loop_8UVStream_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVStream(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVStream *p = (struct __pyx_obj_6uvloop_4loop_UVStream *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_protocol_get_buffer);
  Py_CLEAR(p->_protocol_buffer_updated);
  Py_CLEAR(p->_buffer);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVBaseTransport(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVStream(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVStream *p = (struct __pyx_obj_6uvloop_4loop_UVStream *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVBaseTransport(o, v, a); if (e) return e;
  if (p->_protocol_get_buffer) {
    e = (*v)(p->_protocol_get_buffer, a); if (e) return e;
  }
  if (p->_protocol_buffer_updated) {
    e = (*v)(p->_protocol_buffer_updated, a); if (e) return e;
  }
  if (p->_buffer) {
    e = (*v)(p->_buffer, a); if (e) return e;
  }
  if (p->_read_pybuf.obj) {
    e = (*v)(p->_read_pybuf.obj, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVStream[] = {
  {"write", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_5write, METH_O, __pyx_doc_6uvloop_4loop_8UVStream_4write},
  {"writelines", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_7writelines, METH_O, __pyx_doc_6uvloop_4loop_8UVStream_6writelines},
  {"write_eof", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_9write_eof, METH_NOARGS, __pyx_doc_6uvloop_4loop_8UVStream_8write_eof},
  {"can_write_eof", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_11can_write_eof, METH_NOARGS, __pyx_doc_6uvloop_4loop_8UVStream_10can_write_eof},
  {"is_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_13is_reading, METH_NOARGS, __pyx_doc_6uvloop_4loop_8UVStream_12is_reading},
  {"pause_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_15pause_reading, METH_NOARGS, __pyx_doc_6uvloop_4loop_8UVStream_14pause_reading},
  {"resume_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_17resume_reading, METH_NOARGS, __pyx_doc_6uvloop_4loop_8UVStream_16resume_reading},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_19__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_8UVStream_18__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8UVStream_21__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_8UVStream_20__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVStream = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVStream", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVStream), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStream, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6uvloop_4loop_8UVStream_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStream, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVStream, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVStream, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVStreamServer __pyx_vtable_6uvloop_4loop_UVStreamServer;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVStreamServer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVStreamServer *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVSocketHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVStreamServer *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVStreamServer;
  p->ssl = Py_None; Py_INCREF(Py_None);
  p->ssl_handshake_timeout = Py_None; Py_INCREF(Py_None);
  p->protocol_factory = Py_None; Py_INCREF(Py_None);
  p->_server = ((struct __pyx_obj_6uvloop_4loop_Server *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_14UVStreamServer_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVStreamServer(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVStreamServer *p = (struct __pyx_obj_6uvloop_4loop_UVStreamServer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->ssl);
  Py_CLEAR(p->ssl_handshake_timeout);
  Py_CLEAR(p->protocol_factory);
  Py_CLEAR(p->_server);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVSocketHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVStreamServer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVStreamServer *p = (struct __pyx_obj_6uvloop_4loop_UVStreamServer *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVSocketHandle(o, v, a); if (e) return e;
  if (p->ssl) {
    e = (*v)(p->ssl, a); if (e) return e;
  }
  if (p->ssl_handshake_timeout) {
    e = (*v)(p->ssl_handshake_timeout, a); if (e) return e;
  }
  if (p->protocol_factory) {
    e = (*v)(p->protocol_factory, a); if (e) return e;
  }
  if (p->_server) {
    e = (*v)(((PyObject *)p->_server), a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVStreamServer[] = {
  {"__on_ssl_connected", (PyCFunction)__pyx_pw_6uvloop_4loop_14UVStreamServer_3__on_ssl_connected, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_14UVStreamServer_2__on_ssl_connected},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_14UVStreamServer_5__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_14UVStreamServer_4__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_14UVStreamServer_7__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_14UVStreamServer_6__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVStreamServer = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVStreamServer", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVStreamServer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStreamServer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStreamServer, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVStreamServer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVStreamServer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_TCPServer __pyx_vtable_6uvloop_4loop_TCPServer;

static PyObject *__pyx_tp_new_6uvloop_4loop_TCPServer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_TCPServer *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVStreamServer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_TCPServer *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_TCPServer;
  return o;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_TCPServer[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_9TCPServer_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_9TCPServer___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_9TCPServer_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_9TCPServer_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_TCPServer = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.TCPServer", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_TCPServer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStreamServer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStreamServer, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_TCPServer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_TCPServer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_TCPTransport __pyx_vtable_6uvloop_4loop_TCPTransport;

static PyObject *__pyx_tp_new_6uvloop_4loop_TCPTransport(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_TCPTransport *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVStream(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_TCPTransport;
  return o;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_TCPTransport[] = {
  {"get_extra_info", (PyCFunction)__pyx_pw_6uvloop_4loop_12TCPTransport_1get_extra_info, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12TCPTransport_get_extra_info},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_12TCPTransport_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_12TCPTransport_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_12TCPTransport_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_12TCPTransport_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_TCPTransport = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.TCPTransport", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_TCPTransport), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStream, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVStream_3__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStream, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_TCPTransport, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_TCPTransport, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UnixServer __pyx_vtable_6uvloop_4loop_UnixServer;

static PyObject *__pyx_tp_new_6uvloop_4loop_UnixServer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UnixServer *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVStreamServer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UnixServer *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UnixServer;
  return o;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UnixServer[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_10UnixServer_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_10UnixServer___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_10UnixServer_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_10UnixServer_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UnixServer = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UnixServer", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UnixServer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStreamServer, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStreamServer, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UnixServer, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UnixServer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UnixTransport __pyx_vtable_6uvloop_4loop_UnixTransport;

static PyObject *__pyx_tp_new_6uvloop_4loop_UnixTransport(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UnixTransport *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVStream(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UnixTransport;
  return o;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UnixTransport[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_13UnixTransport_1__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_13UnixTransport___reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_13UnixTransport_3__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_13UnixTransport_2__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UnixTransport = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UnixTransport", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UnixTransport), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStream, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVStream_3__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStream, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UnixTransport, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UnixTransport, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_ReadUnixTransport __pyx_vtable_6uvloop_4loop_ReadUnixTransport;

static PyObject *__pyx_tp_new_6uvloop_4loop_ReadUnixTransport(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVStream(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_ReadUnixTransport;
  return o;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_ReadUnixTransport[] = {
  {"get_write_buffer_limits", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_1get_write_buffer_limits, METH_NOARGS, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_get_write_buffer_limits},
  {"set_write_buffer_limits", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_3set_write_buffer_limits, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_2set_write_buffer_limits},
  {"get_write_buffer_size", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_5get_write_buffer_size, METH_NOARGS, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_4get_write_buffer_size},
  {"write", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_7write, METH_O, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_6write},
  {"writelines", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_9writelines, METH_O, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_8writelines},
  {"write_eof", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_11write_eof, METH_NOARGS, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_10write_eof},
  {"can_write_eof", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_13can_write_eof, METH_NOARGS, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_12can_write_eof},
  {"abort", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_15abort, METH_NOARGS, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_14abort},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_17__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_16__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_17ReadUnixTransport_19__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_17ReadUnixTransport_18__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_ReadUnixTransport = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.ReadUnixTransport", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_ReadUnixTransport), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStream, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVStream_3__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStream, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_ReadUnixTransport, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_ReadUnixTransport, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_WriteUnixTransport __pyx_vtable_6uvloop_4loop_WriteUnixTransport;

static PyObject *__pyx_tp_new_6uvloop_4loop_WriteUnixTransport(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVStream(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_WriteUnixTransport;
  return o;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_WriteUnixTransport[] = {
  {"pause_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_18WriteUnixTransport_1pause_reading, METH_NOARGS, __pyx_doc_6uvloop_4loop_18WriteUnixTransport_pause_reading},
  {"resume_reading", (PyCFunction)__pyx_pw_6uvloop_4loop_18WriteUnixTransport_3resume_reading, METH_NOARGS, __pyx_doc_6uvloop_4loop_18WriteUnixTransport_2resume_reading},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_18WriteUnixTransport_5__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_18WriteUnixTransport_4__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_18WriteUnixTransport_7__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_18WriteUnixTransport_6__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_WriteUnixTransport = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.WriteUnixTransport", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_WriteUnixTransport), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVStream, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVStream_3__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVStream, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_WriteUnixTransport, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_WriteUnixTransport, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVProcess __pyx_vtable_6uvloop_4loop_UVProcess;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVProcess(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVProcess *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVHandle(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVProcess *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVProcess;
  p->_returncode = Py_None; Py_INCREF(Py_None);
  p->_pid = Py_None; Py_INCREF(Py_None);
  p->_errpipe_read = Py_None; Py_INCREF(Py_None);
  p->_errpipe_write = Py_None; Py_INCREF(Py_None);
  p->_preexec_fn = Py_None; Py_INCREF(Py_None);
  p->_fds_to_close = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___env = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___args = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->__pyx___cwd = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_9UVProcess_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVProcess(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVProcess *p = (struct __pyx_obj_6uvloop_4loop_UVProcess *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_returncode);
  Py_CLEAR(p->_pid);
  Py_CLEAR(p->_errpipe_read);
  Py_CLEAR(p->_errpipe_write);
  Py_CLEAR(p->_preexec_fn);
  Py_CLEAR(p->_fds_to_close);
  Py_CLEAR(p->__pyx___env);
  Py_CLEAR(p->__pyx___args);
  Py_CLEAR(p->__pyx___cwd);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVHandle(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVProcess(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVProcess *p = (struct __pyx_obj_6uvloop_4loop_UVProcess *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVHandle(o, v, a); if (e) return e;
  if (p->_returncode) {
    e = (*v)(p->_returncode, a); if (e) return e;
  }
  if (p->_pid) {
    e = (*v)(p->_pid, a); if (e) return e;
  }
  if (p->_errpipe_read) {
    e = (*v)(p->_errpipe_read, a); if (e) return e;
  }
  if (p->_errpipe_write) {
    e = (*v)(p->_errpipe_write, a); if (e) return e;
  }
  if (p->_preexec_fn) {
    e = (*v)(p->_preexec_fn, a); if (e) return e;
  }
  if (p->_fds_to_close) {
    e = (*v)(p->_fds_to_close, a); if (e) return e;
  }
  if (p->__pyx___env) {
    e = (*v)(p->__pyx___env, a); if (e) return e;
  }
  if (p->__pyx___args) {
    e = (*v)(p->__pyx___args, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVProcess[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_9UVProcess_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_9UVProcess_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_9UVProcess_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_9UVProcess_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVProcess = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVProcess", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVProcess), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVProcess, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "Abstract class; wrapper over uv_process_t handle.", /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVProcess, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVProcess, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVProcess, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVProcessTransport __pyx_vtable_6uvloop_4loop_UVProcessTransport;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVProcessTransport(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVProcessTransport *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVProcess(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UVProcessTransport;
  p->_exit_waiters = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_init_futs = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_pending_calls = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_protocol = Py_None; Py_INCREF(Py_None);
  p->_stdin = ((struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *)Py_None); Py_INCREF(Py_None);
  p->_stdout = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)Py_None); Py_INCREF(Py_None);
  p->_stderr = ((struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *)Py_None); Py_INCREF(Py_None);
  p->stdin_proto = Py_None; Py_INCREF(Py_None);
  p->stdout_proto = Py_None; Py_INCREF(Py_None);
  p->stderr_proto = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_18UVProcessTransport_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVProcessTransport(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVProcessTransport *p = (struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_exit_waiters);
  Py_CLEAR(p->_init_futs);
  Py_CLEAR(p->_pending_calls);
  Py_CLEAR(p->_protocol);
  Py_CLEAR(p->_stdin);
  Py_CLEAR(p->_stdout);
  Py_CLEAR(p->_stderr);
  Py_CLEAR(p->stdin_proto);
  Py_CLEAR(p->stdout_proto);
  Py_CLEAR(p->stderr_proto);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVProcess(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVProcessTransport(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVProcessTransport *p = (struct __pyx_obj_6uvloop_4loop_UVProcessTransport *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVProcess(o, v, a); if (e) return e;
  if (p->_exit_waiters) {
    e = (*v)(p->_exit_waiters, a); if (e) return e;
  }
  if (p->_init_futs) {
    e = (*v)(p->_init_futs, a); if (e) return e;
  }
  if (p->_pending_calls) {
    e = (*v)(p->_pending_calls, a); if (e) return e;
  }
  if (p->_protocol) {
    e = (*v)(p->_protocol, a); if (e) return e;
  }
  if (p->_stdin) {
    e = (*v)(((PyObject *)p->_stdin), a); if (e) return e;
  }
  if (p->_stdout) {
    e = (*v)(((PyObject *)p->_stdout), a); if (e) return e;
  }
  if (p->_stderr) {
    e = (*v)(((PyObject *)p->_stderr), a); if (e) return e;
  }
  if (p->stdin_proto) {
    e = (*v)(p->stdin_proto, a); if (e) return e;
  }
  if (p->stdout_proto) {
    e = (*v)(p->stdout_proto, a); if (e) return e;
  }
  if (p->stderr_proto) {
    e = (*v)(p->stderr_proto, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVProcessTransport[] = {
  {"__stdio_inited", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_3__stdio_inited, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_2__stdio_inited},
  {"get_protocol", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_5get_protocol, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_4get_protocol},
  {"set_protocol", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_7set_protocol, METH_O, __pyx_doc_6uvloop_4loop_18UVProcessTransport_6set_protocol},
  {"get_pid", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_9get_pid, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_8get_pid},
  {"get_returncode", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_11get_returncode, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_10get_returncode},
  {"get_pipe_transport", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_13get_pipe_transport, METH_O, __pyx_doc_6uvloop_4loop_18UVProcessTransport_12get_pipe_transport},
  {"terminate", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_15terminate, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_14terminate},
  {"kill", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_17kill, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_16kill},
  {"send_signal", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_19send_signal, METH_O, __pyx_doc_6uvloop_4loop_18UVProcessTransport_18send_signal},
  {"is_closing", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_21is_closing, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_20is_closing},
  {"close", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_23close, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_22close},
  {"get_extra_info", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_25get_extra_info, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_24get_extra_info},
  {"_wait", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_27_wait, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_26_wait},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_29__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_18UVProcessTransport_28__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_18UVProcessTransport_31__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_18UVProcessTransport_30__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVProcessTransport = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVProcessTransport", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVProcessTransport), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVProcessTransport, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVProcessTransport, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVProcessTransport, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVProcessTransport, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UVRequest __pyx_vtable_6uvloop_4loop_UVRequest;

static PyObject *__pyx_tp_new_6uvloop_4loop_UVRequest(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UVRequest *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UVRequest *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_UVRequest;
  p->loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_9UVRequest_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UVRequest(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UVRequest *p = (struct __pyx_obj_6uvloop_4loop_UVRequest *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->loop);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UVRequest(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UVRequest *p = (struct __pyx_obj_6uvloop_4loop_UVRequest *)o;
  if (p->loop) {
    e = (*v)(((PyObject *)p->loop), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop_UVRequest(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop_UVRequest *p = (struct __pyx_obj_6uvloop_4loop_UVRequest *)o;
  tmp = ((PyObject*)p->loop);
  p->loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UVRequest[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_9UVRequest_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_9UVRequest_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_9UVRequest_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_9UVRequest_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UVRequest = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UVRequest", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UVRequest), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UVRequest, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "A base class for all libuv requests (uv_getaddrinfo_t, etc).\n\n    Important: it's a responsibility of the subclass to call the\n    \"on_done\" method in the request's callback.\n\n    If \"on_done\" isn't called, the request object will never die.\n    ", /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UVRequest, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop_UVRequest, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UVRequest, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UVRequest, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_UDPTransport __pyx_vtable_6uvloop_4loop_UDPTransport;

static PyObject *__pyx_tp_new_6uvloop_4loop_UDPTransport(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_UDPTransport *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVBaseTransport(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_UDPTransport *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVHandle*)__pyx_vtabptr_6uvloop_4loop_UDPTransport;
  p->sock = Py_None; Py_INCREF(Py_None);
  p->poll = ((struct __pyx_obj_6uvloop_4loop_UVPoll *)Py_None); Py_INCREF(Py_None);
  p->address = Py_None; Py_INCREF(Py_None);
  p->buffer = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_12UDPTransport_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_UDPTransport(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_UDPTransport *p = (struct __pyx_obj_6uvloop_4loop_UDPTransport *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->sock);
  Py_CLEAR(p->poll);
  Py_CLEAR(p->address);
  Py_CLEAR(p->buffer);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVBaseTransport(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_UDPTransport(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_UDPTransport *p = (struct __pyx_obj_6uvloop_4loop_UDPTransport *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVBaseTransport(o, v, a); if (e) return e;
  if (p->sock) {
    e = (*v)(p->sock, a); if (e) return e;
  }
  if (p->poll) {
    e = (*v)(((PyObject *)p->poll), a); if (e) return e;
  }
  if (p->address) {
    e = (*v)(p->address, a); if (e) return e;
  }
  if (p->buffer) {
    e = (*v)(p->buffer, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_UDPTransport[] = {
  {"sendto", (PyCFunction)__pyx_pw_6uvloop_4loop_12UDPTransport_3sendto, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12UDPTransport_2sendto},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_12UDPTransport_5__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_12UDPTransport_4__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_12UDPTransport_7__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_12UDPTransport_6__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_UDPTransport = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.UDPTransport", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_UDPTransport), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_UDPTransport, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_7__repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_UDPTransport, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_UDPTransport, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_6uvloop_4loop_8UVHandle_3__init__, /*tp_init*/
  #else
  0, /*tp_init*/
  #endif
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_UDPTransport, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_Server __pyx_vtable_6uvloop_4loop_Server;

static PyObject *__pyx_tp_new_6uvloop_4loop_Server(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_Server *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_Server *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_Server;
  p->_servers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_waiters = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_6Server_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_Server(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_Server *p = (struct __pyx_obj_6uvloop_4loop_Server *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  if (p->__weakref__) PyObject_ClearWeakRefs(o);
  Py_CLEAR(p->_servers);
  Py_CLEAR(p->_waiters);
  Py_CLEAR(p->_loop);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_Server(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_Server *p = (struct __pyx_obj_6uvloop_4loop_Server *)o;
  if (p->_servers) {
    e = (*v)(p->_servers, a); if (e) return e;
  }
  if (p->_waiters) {
    e = (*v)(p->_waiters, a); if (e) return e;
  }
  if (p->_loop) {
    e = (*v)(((PyObject *)p->_loop), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop_Server(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop_Server *p = (struct __pyx_obj_6uvloop_4loop_Server *)o;
  tmp = ((PyObject*)p->_servers);
  p->_servers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_waiters);
  p->_waiters = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_loop);
  p->_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6uvloop_4loop_6Server_sockets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_6Server_7sockets_1__get__(o);
}

static PyMethodDef __pyx_methods_6uvloop_4loop_Server[] = {
  {"get_loop", (PyCFunction)__pyx_pw_6uvloop_4loop_6Server_5get_loop, METH_NOARGS, __pyx_doc_6uvloop_4loop_6Server_4get_loop},
  {"wait_closed", (PyCFunction)__pyx_pw_6uvloop_4loop_6Server_7wait_closed, METH_NOARGS, __pyx_doc_6uvloop_4loop_6Server_6wait_closed},
  {"close", (PyCFunction)__pyx_pw_6uvloop_4loop_6Server_10close, METH_NOARGS, __pyx_doc_6uvloop_4loop_6Server_9close},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6Server_12__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_6Server_11__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_6Server_14__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_6Server_13__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6uvloop_4loop_Server[] = {
  {(char *)"sockets", __pyx_getprop_6uvloop_4loop_6Server_sockets, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_Server = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.Server", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_Server), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_Server, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6uvloop_4loop_6Server_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_Server, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop_Server, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_Server, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6uvloop_4loop_Server, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_Server, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_PseudoSocket __pyx_vtable_6uvloop_4loop_PseudoSocket;

static PyObject *__pyx_tp_new_6uvloop_4loop_PseudoSocket(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_PseudoSocket *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_PseudoSocket *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_PseudoSocket;
  p->_peername = Py_None; Py_INCREF(Py_None);
  p->_sockname = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop_PseudoSocket(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_PseudoSocket *p = (struct __pyx_obj_6uvloop_4loop_PseudoSocket *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_peername);
  Py_CLEAR(p->_sockname);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_PseudoSocket(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_PseudoSocket *p = (struct __pyx_obj_6uvloop_4loop_PseudoSocket *)o;
  if (p->_peername) {
    e = (*v)(p->_peername, a); if (e) return e;
  }
  if (p->_sockname) {
    e = (*v)(p->_sockname, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop_PseudoSocket(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop_PseudoSocket *p = (struct __pyx_obj_6uvloop_4loop_PseudoSocket *)o;
  tmp = ((PyObject*)p->_peername);
  p->_peername = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_sockname);
  p->_sockname = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6uvloop_4loop_12PseudoSocket_family(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_12PseudoSocket_6family_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_12PseudoSocket_type(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_12PseudoSocket_4type_1__get__(o);
}

static PyObject *__pyx_getprop_6uvloop_4loop_12PseudoSocket_proto(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6uvloop_4loop_12PseudoSocket_5proto_1__get__(o);
}

static PyMethodDef __pyx_methods_6uvloop_4loop_PseudoSocket[] = {
  {"__getstate__", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_5__getstate__, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_4__getstate__},
  {"fileno", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_7fileno, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_6fileno},
  {"dup", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_9dup, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_8dup},
  {"get_inheritable", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_11get_inheritable, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_10get_inheritable},
  {"set_inheritable", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_13set_inheritable, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_12set_inheritable},
  {"ioctl", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_15ioctl, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_14ioctl},
  {"getsockopt", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_17getsockopt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_16getsockopt},
  {"setsockopt", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_19setsockopt, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_18setsockopt},
  {"getpeername", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_21getpeername, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_20getpeername},
  {"getsockname", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_23getsockname, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_22getsockname},
  {"share", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_25share, METH_O, __pyx_doc_6uvloop_4loop_12PseudoSocket_24share},
  {"accept", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_27accept, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_26accept},
  {"connect", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_29connect, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_28connect},
  {"connect_ex", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_31connect_ex, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_30connect_ex},
  {"bind", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_33bind, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_32bind},
  {"listen", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_35listen, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_34listen},
  {"makefile", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_37makefile, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_36makefile},
  {"sendfile", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_39sendfile, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_38sendfile},
  {"close", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_41close, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_40close},
  {"detach", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_43detach, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_42detach},
  {"shutdown", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_45shutdown, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_44shutdown},
  {"sendmsg_afalg", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_47sendmsg_afalg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_46sendmsg_afalg},
  {"sendmsg", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_49sendmsg, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_48sendmsg},
  {"sendto", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_51sendto, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_50sendto},
  {"send", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_53send, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_52send},
  {"sendall", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_55sendall, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_54sendall},
  {"recv_into", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_57recv_into, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_56recv_into},
  {"recvfrom_into", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_59recvfrom_into, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_58recvfrom_into},
  {"recvmsg_into", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_61recvmsg_into, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_60recvmsg_into},
  {"recvmsg", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_63recvmsg, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_62recvmsg},
  {"recvfrom", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_65recvfrom, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_64recvfrom},
  {"recv", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_67recv, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_66recv},
  {"settimeout", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_69settimeout, METH_O, __pyx_doc_6uvloop_4loop_12PseudoSocket_68settimeout},
  {"gettimeout", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_71gettimeout, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_70gettimeout},
  {"setblocking", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_73setblocking, METH_O, __pyx_doc_6uvloop_4loop_12PseudoSocket_72setblocking},
  {"__enter__", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_75__enter__, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_74__enter__},
  {"__exit__", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_77__exit__, METH_VARARGS|METH_KEYWORDS, __pyx_doc_6uvloop_4loop_12PseudoSocket_76__exit__},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_79__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_12PseudoSocket_78__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_12PseudoSocket_81__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_12PseudoSocket_80__setstate_cython__},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6uvloop_4loop_PseudoSocket[] = {
  {(char *)"family", __pyx_getprop_6uvloop_4loop_12PseudoSocket_family, 0, (char *)0, 0},
  {(char *)"type", __pyx_getprop_6uvloop_4loop_12PseudoSocket_type, 0, (char *)0, 0},
  {(char *)"proto", __pyx_getprop_6uvloop_4loop_12PseudoSocket_proto, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_PseudoSocket = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.PseudoSocket", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_PseudoSocket), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_PseudoSocket, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_pw_6uvloop_4loop_12PseudoSocket_3__repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "PseudoSocket(int family, int type, int proto, int fd)", /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_PseudoSocket, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop_PseudoSocket, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_PseudoSocket, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6uvloop_4loop_PseudoSocket, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_6uvloop_4loop_12PseudoSocket_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_PseudoSocket, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop__StreamWriteContext __pyx_vtable_6uvloop_4loop__StreamWriteContext;

static struct __pyx_obj_6uvloop_4loop__StreamWriteContext *__pyx_freelist_6uvloop_4loop__StreamWriteContext[250];
static int __pyx_freecount_6uvloop_4loop__StreamWriteContext = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop__StreamWriteContext(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop__StreamWriteContext > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop__StreamWriteContext)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop__StreamWriteContext[--__pyx_freecount_6uvloop_4loop__StreamWriteContext];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop__StreamWriteContext));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop__StreamWriteContext;
  p->buffers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->stream = ((struct __pyx_obj_6uvloop_4loop_UVStream *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop__StreamWriteContext(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *p = (struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_6uvloop_4loop_19_StreamWriteContext_1__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->buffers);
  Py_CLEAR(p->stream);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop__StreamWriteContext < 250) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop__StreamWriteContext)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_6uvloop_4loop__StreamWriteContext[__pyx_freecount_6uvloop_4loop__StreamWriteContext++] = ((struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop__StreamWriteContext(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop__StreamWriteContext *p = (struct __pyx_obj_6uvloop_4loop__StreamWriteContext *)o;
  if (p->buffers) {
    e = (*v)(p->buffers, a); if (e) return e;
  }
  if (p->stream) {
    e = (*v)(((PyObject *)p->stream), a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop__StreamWriteContext[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_19_StreamWriteContext_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_19_StreamWriteContext_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_19_StreamWriteContext_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_19_StreamWriteContext_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop__StreamWriteContext = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop._StreamWriteContext", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop__StreamWriteContext), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop__StreamWriteContext, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop__StreamWriteContext, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop__StreamWriteContext, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop__StreamWriteContext, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop__TCPConnectRequest __pyx_vtable_6uvloop_4loop__TCPConnectRequest;

static PyObject *__pyx_tp_new_6uvloop_4loop__TCPConnectRequest(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVRequest(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVRequest*)__pyx_vtabptr_6uvloop_4loop__TCPConnectRequest;
  p->transport = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_18_TCPConnectRequest_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop__TCPConnectRequest(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *p = (struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->transport);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVRequest(o);
}

static int __pyx_tp_traverse_6uvloop_4loop__TCPConnectRequest(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *p = (struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVRequest(o, v, a); if (e) return e;
  if (p->transport) {
    e = (*v)(((PyObject *)p->transport), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop__TCPConnectRequest(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *p = (struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *)o;
  __pyx_tp_clear_6uvloop_4loop_UVRequest(o);
  tmp = ((PyObject*)p->transport);
  p->transport = ((struct __pyx_obj_6uvloop_4loop_TCPTransport *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop__TCPConnectRequest[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_18_TCPConnectRequest_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_18_TCPConnectRequest_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_18_TCPConnectRequest_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_18_TCPConnectRequest_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop__TCPConnectRequest = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop._TCPConnectRequest", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop__TCPConnectRequest), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop__TCPConnectRequest, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop__TCPConnectRequest, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop__TCPConnectRequest, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop__TCPConnectRequest, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop__TCPConnectRequest, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop__PipeConnectRequest __pyx_vtable_6uvloop_4loop__PipeConnectRequest;

static PyObject *__pyx_tp_new_6uvloop_4loop__PipeConnectRequest(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVRequest(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVRequest*)__pyx_vtabptr_6uvloop_4loop__PipeConnectRequest;
  p->transport = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_19_PipeConnectRequest_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop__PipeConnectRequest(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *p = (struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->transport);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVRequest(o);
}

static int __pyx_tp_traverse_6uvloop_4loop__PipeConnectRequest(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *p = (struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVRequest(o, v, a); if (e) return e;
  if (p->transport) {
    e = (*v)(((PyObject *)p->transport), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop__PipeConnectRequest(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *p = (struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *)o;
  __pyx_tp_clear_6uvloop_4loop_UVRequest(o);
  tmp = ((PyObject*)p->transport);
  p->transport = ((struct __pyx_obj_6uvloop_4loop_UnixTransport *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop__PipeConnectRequest[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_19_PipeConnectRequest_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_19_PipeConnectRequest_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_19_PipeConnectRequest_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_19_PipeConnectRequest_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop__PipeConnectRequest = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop._PipeConnectRequest", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop__PipeConnectRequest), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop__PipeConnectRequest, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop__PipeConnectRequest, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop__PipeConnectRequest, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop__PipeConnectRequest, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop__PipeConnectRequest, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_AddrInfo __pyx_vtable_6uvloop_4loop_AddrInfo;

static struct __pyx_obj_6uvloop_4loop_AddrInfo *__pyx_freelist_6uvloop_4loop_AddrInfo[250];
static int __pyx_freecount_6uvloop_4loop_AddrInfo = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop_AddrInfo(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_AddrInfo *p;
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop_AddrInfo > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop_AddrInfo)) & ((t->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop_AddrInfo[--__pyx_freecount_6uvloop_4loop_AddrInfo];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop_AddrInfo));
    (void) PyObject_INIT(o, t);
  } else {
    if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
      o = (*t->tp_alloc)(t, 0);
    } else {
      o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
    }
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop_AddrInfo;
  if (unlikely(__pyx_pw_6uvloop_4loop_8AddrInfo_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_AddrInfo(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_6uvloop_4loop_8AddrInfo_3__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop_AddrInfo < 250) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop_AddrInfo)) & ((Py_TYPE(o)->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)) == 0))) {
    __pyx_freelist_6uvloop_4loop_AddrInfo[__pyx_freecount_6uvloop_4loop_AddrInfo++] = ((struct __pyx_obj_6uvloop_4loop_AddrInfo *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyMethodDef __pyx_methods_6uvloop_4loop_AddrInfo[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8AddrInfo_5__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_8AddrInfo_4__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8AddrInfo_7__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_8AddrInfo_6__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_AddrInfo = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.AddrInfo", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_AddrInfo), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_AddrInfo, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_AddrInfo, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_AddrInfo, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_AddrInfoRequest __pyx_vtable_6uvloop_4loop_AddrInfoRequest;

static PyObject *__pyx_tp_new_6uvloop_4loop_AddrInfoRequest(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVRequest(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVRequest*)__pyx_vtabptr_6uvloop_4loop_AddrInfoRequest;
  p->callback = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_15AddrInfoRequest_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_AddrInfoRequest(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *p = (struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->callback);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVRequest(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_AddrInfoRequest(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *p = (struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVRequest(o, v, a); if (e) return e;
  if (p->callback) {
    e = (*v)(p->callback, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop_AddrInfoRequest(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *p = (struct __pyx_obj_6uvloop_4loop_AddrInfoRequest *)o;
  __pyx_tp_clear_6uvloop_4loop_UVRequest(o);
  tmp = ((PyObject*)p->callback);
  p->callback = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_AddrInfoRequest[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_15AddrInfoRequest_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_15AddrInfoRequest_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_15AddrInfoRequest_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_15AddrInfoRequest_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_AddrInfoRequest = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.AddrInfoRequest", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_AddrInfoRequest), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_AddrInfoRequest, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_AddrInfoRequest, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop_AddrInfoRequest, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_AddrInfoRequest, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_AddrInfoRequest, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop_NameInfoRequest __pyx_vtable_6uvloop_4loop_NameInfoRequest;

static PyObject *__pyx_tp_new_6uvloop_4loop_NameInfoRequest(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6uvloop_4loop_NameInfoRequest *p;
  PyObject *o = __pyx_tp_new_6uvloop_4loop_UVRequest(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_6uvloop_4loop_UVRequest*)__pyx_vtabptr_6uvloop_4loop_NameInfoRequest;
  p->callback = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6uvloop_4loop_15NameInfoRequest_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6uvloop_4loop_NameInfoRequest(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop_NameInfoRequest *p = (struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->callback);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_6uvloop_4loop_UVRequest(o);
}

static int __pyx_tp_traverse_6uvloop_4loop_NameInfoRequest(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop_NameInfoRequest *p = (struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)o;
  e = __pyx_tp_traverse_6uvloop_4loop_UVRequest(o, v, a); if (e) return e;
  if (p->callback) {
    e = (*v)(p->callback, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop_NameInfoRequest(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop_NameInfoRequest *p = (struct __pyx_obj_6uvloop_4loop_NameInfoRequest *)o;
  __pyx_tp_clear_6uvloop_4loop_UVRequest(o);
  tmp = ((PyObject*)p->callback);
  p->callback = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop_NameInfoRequest[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_15NameInfoRequest_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_15NameInfoRequest_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_15NameInfoRequest_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_15NameInfoRequest_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop_NameInfoRequest = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.NameInfoRequest", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop_NameInfoRequest), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop_NameInfoRequest, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop_NameInfoRequest, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop_NameInfoRequest, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop_NameInfoRequest, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop_NameInfoRequest, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_6uvloop_4loop__SSLPipe __pyx_vtable_6uvloop_4loop__SSLPipe;

static PyObject *__pyx_tp_new_6uvloop_4loop__SSLPipe(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_6uvloop_4loop__SSLPipe *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6uvloop_4loop__SSLPipe *)o);
  p->__pyx_vtab = __pyx_vtabptr_6uvloop_4loop__SSLPipe;
  p->_context = Py_None; Py_INCREF(Py_None);
  p->_server_side = Py_None; Py_INCREF(Py_None);
  p->_server_hostname = Py_None; Py_INCREF(Py_None);
  p->_state = Py_None; Py_INCREF(Py_None);
  p->_incoming = Py_None; Py_INCREF(Py_None);
  p->_outgoing = Py_None; Py_INCREF(Py_None);
  p->_sslobj = Py_None; Py_INCREF(Py_None);
  p->_handshake_cb = Py_None; Py_INCREF(Py_None);
  p->_shutdown_cb = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop__SSLPipe(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop__SSLPipe *p = (struct __pyx_obj_6uvloop_4loop__SSLPipe *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_context);
  Py_CLEAR(p->_server_side);
  Py_CLEAR(p->_server_hostname);
  Py_CLEAR(p->_state);
  Py_CLEAR(p->_incoming);
  Py_CLEAR(p->_outgoing);
  Py_CLEAR(p->_sslobj);
  Py_CLEAR(p->_handshake_cb);
  Py_CLEAR(p->_shutdown_cb);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_6uvloop_4loop__SSLPipe(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop__SSLPipe *p = (struct __pyx_obj_6uvloop_4loop__SSLPipe *)o;
  if (p->_context) {
    e = (*v)(p->_context, a); if (e) return e;
  }
  if (p->_server_side) {
    e = (*v)(p->_server_side, a); if (e) return e;
  }
  if (p->_server_hostname) {
    e = (*v)(p->_server_hostname, a); if (e) return e;
  }
  if (p->_state) {
    e = (*v)(p->_state, a); if (e) return e;
  }
  if (p->_incoming) {
    e = (*v)(p->_incoming, a); if (e) return e;
  }
  if (p->_outgoing) {
    e = (*v)(p->_outgoing, a); if (e) return e;
  }
  if (p->_sslobj) {
    e = (*v)(p->_sslobj, a); if (e) return e;
  }
  if (p->_handshake_cb) {
    e = (*v)(p->_handshake_cb, a); if (e) return e;
  }
  if (p->_shutdown_cb) {
    e = (*v)(p->_shutdown_cb, a); if (e) return e;
  }
  return 0;
}

static PyMethodDef __pyx_methods_6uvloop_4loop__SSLPipe[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8_SSLPipe_3__reduce_cython__, METH_NOARGS, __pyx_doc_6uvloop_4loop_8_SSLPipe_2__reduce_cython__},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_6uvloop_4loop_8_SSLPipe_5__setstate_cython__, METH_O, __pyx_doc_6uvloop_4loop_8_SSLPipe_4__setstate_cython__},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_6uvloop_4loop__SSLPipe = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop._SSLPipe", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop__SSLPipe), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop__SSLPipe, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  "_SSLPipe(context, server_side, server_hostname=None)\nAn SSL \"Pipe\".\n\n    An SSL pipe allows you to communicate with an SSL/TLS protocol instance\n    through memory buffers. It can be used to implement a security layer for an\n    existing connection where you don't have access to the connection's file\n    descriptor, or for some reason you don't want to use it.\n\n    An SSL pipe can be in \"wrapped\" and \"unwrapped\" mode. In unwrapped mode,\n    data is passed through untransformed. In wrapped mode, application level\n    data is encrypted to SSL record level data and vice versa. The SSL record\n    level is the lowest level in the SSL protocol suite and is what travels\n    as-is over the wire.\n\n    An SslPipe initially is in \"unwrapped\" mode. To start SSL, call\n    do_handshake(). To shutdown SSL again, call unwrap().\n    ", /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop__SSLPipe, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6uvloop_4loop__SSLPipe, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_6uvloop_4loop_8_SSLPipe_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop__SSLPipe, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *__pyx_freelist_6uvloop_4loop___pyx_scope_struct___getaddrinfo[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct___getaddrinfo = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct___getaddrinfo(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct___getaddrinfo > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct___getaddrinfo[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct___getaddrinfo];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct___getaddrinfo(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fut);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct___getaddrinfo < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct___getaddrinfo[__pyx_freecount_6uvloop_4loop___pyx_scope_struct___getaddrinfo++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct___getaddrinfo(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *)o;
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct___getaddrinfo(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo *)o;
  tmp = ((PyObject*)p->__pyx_v_fut);
  p->__pyx_v_fut = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct___getaddrinfo = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct___getaddrinfo", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct___getaddrinfo), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct___getaddrinfo, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct___getaddrinfo, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct___getaddrinfo, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct___getaddrinfo, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_1__getnameinfo[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_1__getnameinfo = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_1__getnameinfo(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_1__getnameinfo > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_1__getnameinfo[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_1__getnameinfo];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_1__getnameinfo(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fut);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_1__getnameinfo < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_1__getnameinfo[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_1__getnameinfo++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_1__getnameinfo(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *)o;
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_1__getnameinfo(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo *)o;
  tmp = ((PyObject*)p->__pyx_v_fut);
  p->__pyx_v_fut = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_1__getnameinfo = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_1__getnameinfo", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_1__getnameinfo), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_1__getnameinfo, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_1__getnameinfo, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_1__getnameinfo, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_1__getnameinfo, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_2__sock_connect[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_2__sock_connect = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_2__sock_connect(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_2__sock_connect > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_2__sock_connect[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_2__sock_connect];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_2__sock_connect(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_2__sock_connect < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_2__sock_connect[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_2__sock_connect++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_2__sock_connect(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_2__sock_connect(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_sock);
  p->__pyx_v_sock = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_2__sock_connect = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_2__sock_connect", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_2__sock_connect), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_2__sock_connect, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_2__sock_connect, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_2__sock_connect, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_2__sock_connect, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_3___get__[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_3___get__ = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_3___get__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_3___get__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_3___get__[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_3___get__];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_3___get__(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_3___get__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_3___get__[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_3___get__++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_3___get__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_3___get__(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__ *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_3___get__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_3___get__", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_3___get__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_3___get__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_3___get__, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_3___get__, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_3___get__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_4_run_until_complete[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_4_run_until_complete = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_4_run_until_complete(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_4_run_until_complete > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_4_run_until_complete[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_4_run_until_complete];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_4_run_until_complete(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_4_run_until_complete < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_4_run_until_complete[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_4_run_until_complete++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_4_run_until_complete(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_4_run_until_complete(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete *)o;
  tmp = ((PyObject*)p->__pyx_v_self);
  p->__pyx_v_self = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_4_run_until_complete = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_4_run_until_complete", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_4_run_until_complete), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_4_run_until_complete, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_4_run_until_complete, /*tp_traverse*/
  __pyx_tp_clear_6uvloop_4loop___pyx_scope_struct_4_run_until_complete, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_4_run_until_complete, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_addr);
  Py_CLEAR(p->__pyx_v_fut);
  Py_CLEAR(p->__pyx_v_host);
  Py_CLEAR(p->__pyx_v_port);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo *)o;
  if (p->__pyx_v_addr) {
    e = (*v)(p->__pyx_v_addr, a); if (e) return e;
  }
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  if (p->__pyx_v_host) {
    e = (*v)(p->__pyx_v_host, a); if (e) return e;
  }
  if (p->__pyx_v_port) {
    e = (*v)(p->__pyx_v_port, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_5_getaddrinfo", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_6_getnameinfo[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_6_getnameinfo = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_6_getnameinfo(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_6_getnameinfo > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_6_getnameinfo[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_6_getnameinfo];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_6_getnameinfo(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_ai_cnt);
  Py_CLEAR(p->__pyx_v_flowinfo);
  Py_CLEAR(p->__pyx_v_msg);
  Py_CLEAR(p->__pyx_v_scope_id);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sockaddr);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_6_getnameinfo < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_6_getnameinfo[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_6_getnameinfo++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_6_getnameinfo(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo *)o;
  if (p->__pyx_v_ai_cnt) {
    e = (*v)(((PyObject *)p->__pyx_v_ai_cnt), a); if (e) return e;
  }
  if (p->__pyx_v_flowinfo) {
    e = (*v)(p->__pyx_v_flowinfo, a); if (e) return e;
  }
  if (p->__pyx_v_scope_id) {
    e = (*v)(p->__pyx_v_scope_id, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sockaddr) {
    e = (*v)(p->__pyx_v_sockaddr, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_6_getnameinfo = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_6_getnameinfo", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_6_getnameinfo), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_6_getnameinfo, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_6_getnameinfo, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_6_getnameinfo, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_7_start_tls[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_7_start_tls = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_7_start_tls(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_7_start_tls > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_7_start_tls[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_7_start_tls];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_7_start_tls(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_conmade_cb);
  Py_CLEAR(p->__pyx_v_protocol);
  Py_CLEAR(p->__pyx_v_resume_cb);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_server_hostname);
  Py_CLEAR(p->__pyx_v_server_side);
  Py_CLEAR(p->__pyx_v_ssl_handshake_timeout);
  Py_CLEAR(p->__pyx_v_ssl_protocol);
  Py_CLEAR(p->__pyx_v_sslcontext);
  Py_CLEAR(p->__pyx_v_transport);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_7_start_tls < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_7_start_tls[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_7_start_tls++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_7_start_tls(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls *)o;
  if (p->__pyx_v_conmade_cb) {
    e = (*v)(p->__pyx_v_conmade_cb, a); if (e) return e;
  }
  if (p->__pyx_v_protocol) {
    e = (*v)(p->__pyx_v_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_resume_cb) {
    e = (*v)(p->__pyx_v_resume_cb, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_server_hostname) {
    e = (*v)(p->__pyx_v_server_hostname, a); if (e) return e;
  }
  if (p->__pyx_v_server_side) {
    e = (*v)(p->__pyx_v_server_side, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_handshake_timeout) {
    e = (*v)(p->__pyx_v_ssl_handshake_timeout, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_protocol) {
    e = (*v)(p->__pyx_v_ssl_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_sslcontext) {
    e = (*v)(p->__pyx_v_sslcontext, a); if (e) return e;
  }
  if (p->__pyx_v_transport) {
    e = (*v)(p->__pyx_v_transport, a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_7_start_tls = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_7_start_tls", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_7_start_tls), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_7_start_tls, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_7_start_tls, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_7_start_tls, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_8_create_server[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_8_create_server = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_8_create_server(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_8_create_server > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_8_create_server[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_8_create_server];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_8_create_server(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_backlog);
  Py_CLEAR(p->__pyx_v_fs);
  Py_CLEAR(p->__pyx_7genexpr__pyx_v_host);
  Py_CLEAR(p->__pyx_v_host);
  Py_CLEAR(p->__pyx_v_hosts);
  Py_CLEAR(p->__pyx_v_info);
  Py_CLEAR(p->__pyx_v_infos);
  Py_CLEAR(p->__pyx_v_port);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_reuse_address);
  Py_CLEAR(p->__pyx_v_reuse_port);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_server);
  Py_CLEAR(p->__pyx_v_sock);
  Py_CLEAR(p->__pyx_v_ssl);
  Py_CLEAR(p->__pyx_v_ssl_handshake_timeout);
  Py_CLEAR(p->__pyx_v_tcp);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_8_create_server < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_8_create_server[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_8_create_server++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_8_create_server(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server *)o;
  if (p->__pyx_v_backlog) {
    e = (*v)(p->__pyx_v_backlog, a); if (e) return e;
  }
  if (p->__pyx_v_fs) {
    e = (*v)(p->__pyx_v_fs, a); if (e) return e;
  }
  if (p->__pyx_7genexpr__pyx_v_host) {
    e = (*v)(p->__pyx_7genexpr__pyx_v_host, a); if (e) return e;
  }
  if (p->__pyx_v_host) {
    e = (*v)(p->__pyx_v_host, a); if (e) return e;
  }
  if (p->__pyx_v_hosts) {
    e = (*v)(p->__pyx_v_hosts, a); if (e) return e;
  }
  if (p->__pyx_v_info) {
    e = (*v)(p->__pyx_v_info, a); if (e) return e;
  }
  if (p->__pyx_v_infos) {
    e = (*v)(p->__pyx_v_infos, a); if (e) return e;
  }
  if (p->__pyx_v_port) {
    e = (*v)(p->__pyx_v_port, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_reuse_address) {
    e = (*v)(p->__pyx_v_reuse_address, a); if (e) return e;
  }
  if (p->__pyx_v_reuse_port) {
    e = (*v)(p->__pyx_v_reuse_port, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_server) {
    e = (*v)(((PyObject *)p->__pyx_v_server), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  if (p->__pyx_v_ssl) {
    e = (*v)(p->__pyx_v_ssl, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_handshake_timeout) {
    e = (*v)(p->__pyx_v_ssl_handshake_timeout, a); if (e) return e;
  }
  if (p->__pyx_v_tcp) {
    e = (*v)(((PyObject *)p->__pyx_v_tcp), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_8_create_server = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_8_create_server", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_8_create_server), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_8_create_server, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_8_create_server, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_8_create_server, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_9_create_connection[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_9_create_connection = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_9_create_connection(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_9_create_connection > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_9_create_connection[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_9_create_connection];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_9_create_connection(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_addr);
  Py_CLEAR(p->__pyx_v_ai_local);
  Py_CLEAR(p->__pyx_v_ai_remote);
  Py_CLEAR(p->__pyx_v_app_protocol);
  Py_CLEAR(p->__pyx_v_exc);
  Py_CLEAR(p->__pyx_v_exceptions);
  Py_CLEAR(p->__pyx_v_f1);
  Py_CLEAR(p->__pyx_v_f2);
  Py_CLEAR(p->__pyx_v_family);
  Py_CLEAR(p->__pyx_v_flags);
  Py_CLEAR(p->__pyx_v_fs);
  Py_CLEAR(p->__pyx_v_genexpr);
  Py_CLEAR(p->__pyx_v_host);
  Py_CLEAR(p->__pyx_v_local_addr);
  Py_CLEAR(p->__pyx_v_model);
  Py_CLEAR(p->__pyx_v_port);
  Py_CLEAR(p->__pyx_v_proto);
  Py_CLEAR(p->__pyx_v_protocol);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_server_hostname);
  Py_CLEAR(p->__pyx_v_sock);
  Py_CLEAR(p->__pyx_v_ssl);
  Py_CLEAR(p->__pyx_v_ssl_handshake_timeout);
  Py_CLEAR(p->__pyx_v_ssl_waiter);
  Py_CLEAR(p->__pyx_v_sslcontext);
  Py_CLEAR(p->__pyx_v_tr);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_9_create_connection < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_9_create_connection[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_9_create_connection++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_9_create_connection(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection *)o;
  if (p->__pyx_v_addr) {
    e = (*v)(p->__pyx_v_addr, a); if (e) return e;
  }
  if (p->__pyx_v_ai_local) {
    e = (*v)(((PyObject *)p->__pyx_v_ai_local), a); if (e) return e;
  }
  if (p->__pyx_v_ai_remote) {
    e = (*v)(((PyObject *)p->__pyx_v_ai_remote), a); if (e) return e;
  }
  if (p->__pyx_v_app_protocol) {
    e = (*v)(p->__pyx_v_app_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_exc) {
    e = (*v)(p->__pyx_v_exc, a); if (e) return e;
  }
  if (p->__pyx_v_exceptions) {
    e = (*v)(p->__pyx_v_exceptions, a); if (e) return e;
  }
  if (p->__pyx_v_f1) {
    e = (*v)(p->__pyx_v_f1, a); if (e) return e;
  }
  if (p->__pyx_v_f2) {
    e = (*v)(p->__pyx_v_f2, a); if (e) return e;
  }
  if (p->__pyx_v_family) {
    e = (*v)(p->__pyx_v_family, a); if (e) return e;
  }
  if (p->__pyx_v_flags) {
    e = (*v)(p->__pyx_v_flags, a); if (e) return e;
  }
  if (p->__pyx_v_fs) {
    e = (*v)(p->__pyx_v_fs, a); if (e) return e;
  }
  if (p->__pyx_v_genexpr) {
    e = (*v)(p->__pyx_v_genexpr, a); if (e) return e;
  }
  if (p->__pyx_v_host) {
    e = (*v)(p->__pyx_v_host, a); if (e) return e;
  }
  if (p->__pyx_v_local_addr) {
    e = (*v)(p->__pyx_v_local_addr, a); if (e) return e;
  }
  if (p->__pyx_v_model) {
    e = (*v)(p->__pyx_v_model, a); if (e) return e;
  }
  if (p->__pyx_v_port) {
    e = (*v)(p->__pyx_v_port, a); if (e) return e;
  }
  if (p->__pyx_v_proto) {
    e = (*v)(p->__pyx_v_proto, a); if (e) return e;
  }
  if (p->__pyx_v_protocol) {
    e = (*v)(p->__pyx_v_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_server_hostname) {
    e = (*v)(p->__pyx_v_server_hostname, a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  if (p->__pyx_v_ssl) {
    e = (*v)(p->__pyx_v_ssl, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_handshake_timeout) {
    e = (*v)(p->__pyx_v_ssl_handshake_timeout, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_waiter) {
    e = (*v)(p->__pyx_v_ssl_waiter, a); if (e) return e;
  }
  if (p->__pyx_v_sslcontext) {
    e = (*v)(p->__pyx_v_sslcontext, a); if (e) return e;
  }
  if (p->__pyx_v_tr) {
    e = (*v)(((PyObject *)p->__pyx_v_tr), a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_9_create_connection = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_9_create_connection", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_9_create_connection), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_9_create_connection, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_9_create_connection, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_9_create_connection, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_10_genexpr[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_10_genexpr = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_10_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_10_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_10_genexpr[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_10_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_10_genexpr(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_exc);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_10_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_10_genexpr[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_10_genexpr++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_10_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_exc) {
    e = (*v)(p->__pyx_v_exc, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_10_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_10_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_10_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_10_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_10_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_10_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_11_genexpr[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_11_genexpr = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_11_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_11_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_11_genexpr[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_11_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_11_genexpr(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_exc);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_11_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_11_genexpr[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_11_genexpr++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_11_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_exc) {
    e = (*v)(p->__pyx_v_exc, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_11_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_11_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_11_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_11_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_11_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_11_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_12_create_unix_server[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_12_create_unix_server = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_12_create_unix_server(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_12_create_unix_server > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_12_create_unix_server[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_12_create_unix_server];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_12_create_unix_server(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_backlog);
  Py_CLEAR(p->__pyx_v_err);
  Py_CLEAR(p->__pyx_v_exc);
  Py_CLEAR(p->__pyx_v_fspath);
  Py_CLEAR(p->__pyx_v_msg);
  Py_CLEAR(p->__pyx_v_orig_path);
  Py_CLEAR(p->__pyx_v_path);
  Py_CLEAR(p->__pyx_v_pipe);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_server);
  Py_CLEAR(p->__pyx_v_sock);
  Py_CLEAR(p->__pyx_v_ssl);
  Py_CLEAR(p->__pyx_v_ssl_handshake_timeout);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_12_create_unix_server < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_12_create_unix_server[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_12_create_unix_server++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_12_create_unix_server(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server *)o;
  if (p->__pyx_v_backlog) {
    e = (*v)(p->__pyx_v_backlog, a); if (e) return e;
  }
  if (p->__pyx_v_err) {
    e = (*v)(p->__pyx_v_err, a); if (e) return e;
  }
  if (p->__pyx_v_exc) {
    e = (*v)(p->__pyx_v_exc, a); if (e) return e;
  }
  if (p->__pyx_v_fspath) {
    e = (*v)(p->__pyx_v_fspath, a); if (e) return e;
  }
  if (p->__pyx_v_msg) {
    e = (*v)(p->__pyx_v_msg, a); if (e) return e;
  }
  if (p->__pyx_v_orig_path) {
    e = (*v)(p->__pyx_v_orig_path, a); if (e) return e;
  }
  if (p->__pyx_v_path) {
    e = (*v)(p->__pyx_v_path, a); if (e) return e;
  }
  if (p->__pyx_v_pipe) {
    e = (*v)(((PyObject *)p->__pyx_v_pipe), a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_server) {
    e = (*v)(((PyObject *)p->__pyx_v_server), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  if (p->__pyx_v_ssl) {
    e = (*v)(p->__pyx_v_ssl, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_handshake_timeout) {
    e = (*v)(p->__pyx_v_ssl_handshake_timeout, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_12_create_unix_server = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_12_create_unix_server", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_12_create_unix_server), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_12_create_unix_server, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_12_create_unix_server, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_12_create_unix_server, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_app_protocol);
  Py_CLEAR(p->__pyx_v_fspath);
  Py_CLEAR(p->__pyx_v_path);
  Py_CLEAR(p->__pyx_v_protocol);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_server_hostname);
  Py_CLEAR(p->__pyx_v_sock);
  Py_CLEAR(p->__pyx_v_ssl);
  Py_CLEAR(p->__pyx_v_ssl_handshake_timeout);
  Py_CLEAR(p->__pyx_v_ssl_waiter);
  Py_CLEAR(p->__pyx_v_sslcontext);
  Py_CLEAR(p->__pyx_v_tr);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection *)o;
  if (p->__pyx_v_app_protocol) {
    e = (*v)(p->__pyx_v_app_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_fspath) {
    e = (*v)(p->__pyx_v_fspath, a); if (e) return e;
  }
  if (p->__pyx_v_path) {
    e = (*v)(p->__pyx_v_path, a); if (e) return e;
  }
  if (p->__pyx_v_protocol) {
    e = (*v)(p->__pyx_v_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_server_hostname) {
    e = (*v)(p->__pyx_v_server_hostname, a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  if (p->__pyx_v_ssl) {
    e = (*v)(p->__pyx_v_ssl, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_handshake_timeout) {
    e = (*v)(p->__pyx_v_ssl_handshake_timeout, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_waiter) {
    e = (*v)(p->__pyx_v_ssl_waiter, a); if (e) return e;
  }
  if (p->__pyx_v_sslcontext) {
    e = (*v)(p->__pyx_v_sslcontext, a); if (e) return e;
  }
  if (p->__pyx_v_tr) {
    e = (*v)(((PyObject *)p->__pyx_v_tr), a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_13_create_unix_connection", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_14_sock_recv[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_14_sock_recv = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_14_sock_recv(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_14_sock_recv > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_14_sock_recv[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_14_sock_recv];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_14_sock_recv(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fut);
  Py_CLEAR(p->__pyx_v_handle);
  Py_CLEAR(p->__pyx_v_n);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_14_sock_recv < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_14_sock_recv[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_14_sock_recv++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_14_sock_recv(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv *)o;
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  if (p->__pyx_v_handle) {
    e = (*v)(((PyObject *)p->__pyx_v_handle), a); if (e) return e;
  }
  if (p->__pyx_v_n) {
    e = (*v)(p->__pyx_v_n, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_14_sock_recv = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_14_sock_recv", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_14_sock_recv), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_14_sock_recv, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_14_sock_recv, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_14_sock_recv, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_buf);
  Py_CLEAR(p->__pyx_v_fut);
  Py_CLEAR(p->__pyx_v_handle);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into *)o;
  if (p->__pyx_v_buf) {
    e = (*v)(p->__pyx_v_buf, a); if (e) return e;
  }
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  if (p->__pyx_v_handle) {
    e = (*v)(((PyObject *)p->__pyx_v_handle), a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_15_sock_recv_into", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_16_sock_sendall[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_16_sock_sendall = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_16_sock_sendall(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_16_sock_sendall > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_16_sock_sendall[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_16_sock_sendall];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_16_sock_sendall(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_data);
  Py_CLEAR(p->__pyx_v_fut);
  Py_CLEAR(p->__pyx_v_handle);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_16_sock_sendall < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_16_sock_sendall[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_16_sock_sendall++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_16_sock_sendall(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall *)o;
  if (p->__pyx_v_data) {
    e = (*v)(p->__pyx_v_data, a); if (e) return e;
  }
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  if (p->__pyx_v_handle) {
    e = (*v)(((PyObject *)p->__pyx_v_handle), a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_16_sock_sendall = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_16_sock_sendall", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_16_sock_sendall), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_16_sock_sendall, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_16_sock_sendall, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_16_sock_sendall, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_17_sock_accept[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_17_sock_accept = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_17_sock_accept(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_17_sock_accept > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_17_sock_accept[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_17_sock_accept];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_17_sock_accept(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_fut);
  Py_CLEAR(p->__pyx_v_handle);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_17_sock_accept < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_17_sock_accept[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_17_sock_accept++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_17_sock_accept(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept *)o;
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  if (p->__pyx_v_handle) {
    e = (*v)(((PyObject *)p->__pyx_v_handle), a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_17_sock_accept = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_17_sock_accept", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_17_sock_accept), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_17_sock_accept, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_17_sock_accept, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_17_sock_accept, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_18_sock_connect[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_18_sock_connect = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_18_sock_connect(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_18_sock_connect > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_18_sock_connect[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_18_sock_connect];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_18_sock_connect(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__);
  Py_CLEAR(p->__pyx_v_address);
  Py_CLEAR(p->__pyx_v_addrs);
  Py_CLEAR(p->__pyx_v_fut);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_18_sock_connect < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_18_sock_connect[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_18_sock_connect++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_18_sock_connect(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect *)o;
  if (p->__pyx_v__) {
    e = (*v)(p->__pyx_v__, a); if (e) return e;
  }
  if (p->__pyx_v_address) {
    e = (*v)(p->__pyx_v_address, a); if (e) return e;
  }
  if (p->__pyx_v_addrs) {
    e = (*v)(p->__pyx_v_addrs, a); if (e) return e;
  }
  if (p->__pyx_v_fut) {
    e = (*v)(p->__pyx_v_fut, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_18_sock_connect = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_18_sock_connect", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_18_sock_connect), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_18_sock_connect, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_18_sock_connect, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_18_sock_connect, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_app_protocol);
  Py_CLEAR(p->__pyx_v_protocol);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  Py_CLEAR(p->__pyx_v_ssl);
  Py_CLEAR(p->__pyx_v_ssl_handshake_timeout);
  Py_CLEAR(p->__pyx_v_transport);
  Py_CLEAR(p->__pyx_v_transport_waiter);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket *)o;
  if (p->__pyx_v_app_protocol) {
    e = (*v)(p->__pyx_v_app_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_protocol) {
    e = (*v)(p->__pyx_v_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  if (p->__pyx_v_ssl) {
    e = (*v)(p->__pyx_v_ssl, a); if (e) return e;
  }
  if (p->__pyx_v_ssl_handshake_timeout) {
    e = (*v)(p->__pyx_v_ssl_handshake_timeout, a); if (e) return e;
  }
  if (p->__pyx_v_transport) {
    e = (*v)(((PyObject *)p->__pyx_v_transport), a); if (e) return e;
  }
  if (p->__pyx_v_transport_waiter) {
    e = (*v)(p->__pyx_v_transport_waiter, a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_19_connect_accepted_socket", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_20___subprocess_run[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_20___subprocess_run = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_20___subprocess_run(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_20___subprocess_run > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_20___subprocess_run[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_20___subprocess_run];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_20___subprocess_run(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v___uvloop_sleep_after_fork);
  Py_CLEAR(p->__pyx_v_args);
  Py_CLEAR(p->__pyx_v_bufsize);
  Py_CLEAR(p->__pyx_v_close_fds);
  Py_CLEAR(p->__pyx_v_creationflags);
  Py_CLEAR(p->__pyx_v_cwd);
  Py_CLEAR(p->__pyx_v_env);
  Py_CLEAR(p->__pyx_v_executable);
  Py_CLEAR(p->__pyx_v_pass_fds);
  Py_CLEAR(p->__pyx_v_preexec_fn);
  Py_CLEAR(p->__pyx_v_proc);
  Py_CLEAR(p->__pyx_v_protocol);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_restore_signals);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_shell);
  Py_CLEAR(p->__pyx_v_start_new_session);
  Py_CLEAR(p->__pyx_v_startupinfo);
  Py_CLEAR(p->__pyx_v_stderr);
  Py_CLEAR(p->__pyx_v_stdin);
  Py_CLEAR(p->__pyx_v_stdout);
  Py_CLEAR(p->__pyx_v_universal_newlines);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_20___subprocess_run < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_20___subprocess_run[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_20___subprocess_run++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_20___subprocess_run(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run *)o;
  if (p->__pyx_v___uvloop_sleep_after_fork) {
    e = (*v)(p->__pyx_v___uvloop_sleep_after_fork, a); if (e) return e;
  }
  if (p->__pyx_v_args) {
    e = (*v)(p->__pyx_v_args, a); if (e) return e;
  }
  if (p->__pyx_v_bufsize) {
    e = (*v)(p->__pyx_v_bufsize, a); if (e) return e;
  }
  if (p->__pyx_v_close_fds) {
    e = (*v)(p->__pyx_v_close_fds, a); if (e) return e;
  }
  if (p->__pyx_v_creationflags) {
    e = (*v)(p->__pyx_v_creationflags, a); if (e) return e;
  }
  if (p->__pyx_v_cwd) {
    e = (*v)(p->__pyx_v_cwd, a); if (e) return e;
  }
  if (p->__pyx_v_env) {
    e = (*v)(p->__pyx_v_env, a); if (e) return e;
  }
  if (p->__pyx_v_executable) {
    e = (*v)(p->__pyx_v_executable, a); if (e) return e;
  }
  if (p->__pyx_v_pass_fds) {
    e = (*v)(p->__pyx_v_pass_fds, a); if (e) return e;
  }
  if (p->__pyx_v_preexec_fn) {
    e = (*v)(p->__pyx_v_preexec_fn, a); if (e) return e;
  }
  if (p->__pyx_v_proc) {
    e = (*v)(((PyObject *)p->__pyx_v_proc), a); if (e) return e;
  }
  if (p->__pyx_v_protocol) {
    e = (*v)(p->__pyx_v_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_restore_signals) {
    e = (*v)(p->__pyx_v_restore_signals, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_shell) {
    e = (*v)(p->__pyx_v_shell, a); if (e) return e;
  }
  if (p->__pyx_v_start_new_session) {
    e = (*v)(p->__pyx_v_start_new_session, a); if (e) return e;
  }
  if (p->__pyx_v_startupinfo) {
    e = (*v)(p->__pyx_v_startupinfo, a); if (e) return e;
  }
  if (p->__pyx_v_stderr) {
    e = (*v)(p->__pyx_v_stderr, a); if (e) return e;
  }
  if (p->__pyx_v_stdin) {
    e = (*v)(p->__pyx_v_stdin, a); if (e) return e;
  }
  if (p->__pyx_v_stdout) {
    e = (*v)(p->__pyx_v_stdout, a); if (e) return e;
  }
  if (p->__pyx_v_universal_newlines) {
    e = (*v)(p->__pyx_v_universal_newlines, a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_20___subprocess_run = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_20___subprocess_run", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_20___subprocess_run), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_20___subprocess_run, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_20___subprocess_run, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_20___subprocess_run, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_args);
  Py_CLEAR(p->__pyx_v_cmd);
  Py_CLEAR(p->__pyx_v_kwargs);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_shell);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell *)o;
  if (p->__pyx_v_args) {
    e = (*v)(p->__pyx_v_args, a); if (e) return e;
  }
  if (p->__pyx_v_cmd) {
    e = (*v)(p->__pyx_v_cmd, a); if (e) return e;
  }
  if (p->__pyx_v_kwargs) {
    e = (*v)(p->__pyx_v_kwargs, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_shell) {
    e = (*v)(p->__pyx_v_shell, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_21_subprocess_shell", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_args);
  Py_CLEAR(p->__pyx_v_kwargs);
  Py_CLEAR(p->__pyx_v_program);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_shell);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec *)o;
  if (p->__pyx_v_args) {
    e = (*v)(p->__pyx_v_args, a); if (e) return e;
  }
  if (p->__pyx_v_kwargs) {
    e = (*v)(p->__pyx_v_kwargs, a); if (e) return e;
  }
  if (p->__pyx_v_program) {
    e = (*v)(p->__pyx_v_program, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_shell) {
    e = (*v)(p->__pyx_v_shell, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_22_subprocess_exec", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_pipe);
  Py_CLEAR(p->__pyx_v_proto);
  Py_CLEAR(p->__pyx_v_proto_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_transp);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe *)o;
  if (p->__pyx_v_pipe) {
    e = (*v)(p->__pyx_v_pipe, a); if (e) return e;
  }
  if (p->__pyx_v_proto) {
    e = (*v)(p->__pyx_v_proto, a); if (e) return e;
  }
  if (p->__pyx_v_proto_factory) {
    e = (*v)(p->__pyx_v_proto_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_transp) {
    e = (*v)(((PyObject *)p->__pyx_v_transp), a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_23_connect_read_pipe", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_pipe);
  Py_CLEAR(p->__pyx_v_proto);
  Py_CLEAR(p->__pyx_v_proto_factory);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_transp);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe *)o;
  if (p->__pyx_v_pipe) {
    e = (*v)(p->__pyx_v_pipe, a); if (e) return e;
  }
  if (p->__pyx_v_proto) {
    e = (*v)(p->__pyx_v_proto, a); if (e) return e;
  }
  if (p->__pyx_v_proto_factory) {
    e = (*v)(p->__pyx_v_proto_factory, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_transp) {
    e = (*v)(((PyObject *)p->__pyx_v_transp), a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_24_connect_write_pipe", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v__);
  Py_CLEAR(p->__pyx_v_addr);
  Py_CLEAR(p->__pyx_v_addr_infos);
  Py_CLEAR(p->__pyx_8genexpr4__pyx_v_addr_pair);
  Py_CLEAR(p->__pyx_v_addr_pairs_info);
  Py_CLEAR(p->__pyx_v_address);
  Py_CLEAR(p->__pyx_v_allow_broadcast);
  Py_CLEAR(p->__pyx_v_exc);
  Py_CLEAR(p->__pyx_v_exceptions);
  Py_CLEAR(p->__pyx_v_fam);
  Py_CLEAR(p->__pyx_v_family);
  Py_CLEAR(p->__pyx_v_flags);
  Py_CLEAR(p->__pyx_v_genexpr);
  Py_CLEAR(p->__pyx_v_idx);
  Py_CLEAR(p->__pyx_v_infos);
  Py_CLEAR(p->__pyx_8genexpr4__pyx_v_key);
  Py_CLEAR(p->__pyx_v_key);
  Py_CLEAR(p->__pyx_v_local_addr);
  Py_CLEAR(p->__pyx_v_local_address);
  Py_CLEAR(p->__pyx_v_opts);
  Py_CLEAR(p->__pyx_v_pro);
  Py_CLEAR(p->__pyx_v_problems);
  Py_CLEAR(p->__pyx_v_proto);
  Py_CLEAR(p->__pyx_v_protocol);
  Py_CLEAR(p->__pyx_v_protocol_factory);
  Py_CLEAR(p->__pyx_v_r_addr);
  Py_CLEAR(p->__pyx_v_remote_addr);
  Py_CLEAR(p->__pyx_v_remote_address);
  Py_CLEAR(p->__pyx_v_reuse_address);
  Py_CLEAR(p->__pyx_v_reuse_port);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_sock);
  Py_CLEAR(p->__pyx_v_udp);
  Py_CLEAR(p->__pyx_v_waiter);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_3);
  Py_CLEAR(p->__pyx_t_4);
  Py_CLEAR(p->__pyx_t_5);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint *)o;
  if (p->__pyx_v__) {
    e = (*v)(p->__pyx_v__, a); if (e) return e;
  }
  if (p->__pyx_v_addr) {
    e = (*v)(p->__pyx_v_addr, a); if (e) return e;
  }
  if (p->__pyx_v_addr_infos) {
    e = (*v)(p->__pyx_v_addr_infos, a); if (e) return e;
  }
  if (p->__pyx_8genexpr4__pyx_v_addr_pair) {
    e = (*v)(p->__pyx_8genexpr4__pyx_v_addr_pair, a); if (e) return e;
  }
  if (p->__pyx_v_addr_pairs_info) {
    e = (*v)(p->__pyx_v_addr_pairs_info, a); if (e) return e;
  }
  if (p->__pyx_v_address) {
    e = (*v)(p->__pyx_v_address, a); if (e) return e;
  }
  if (p->__pyx_v_allow_broadcast) {
    e = (*v)(p->__pyx_v_allow_broadcast, a); if (e) return e;
  }
  if (p->__pyx_v_exc) {
    e = (*v)(p->__pyx_v_exc, a); if (e) return e;
  }
  if (p->__pyx_v_exceptions) {
    e = (*v)(p->__pyx_v_exceptions, a); if (e) return e;
  }
  if (p->__pyx_v_fam) {
    e = (*v)(p->__pyx_v_fam, a); if (e) return e;
  }
  if (p->__pyx_v_family) {
    e = (*v)(p->__pyx_v_family, a); if (e) return e;
  }
  if (p->__pyx_v_flags) {
    e = (*v)(p->__pyx_v_flags, a); if (e) return e;
  }
  if (p->__pyx_v_genexpr) {
    e = (*v)(p->__pyx_v_genexpr, a); if (e) return e;
  }
  if (p->__pyx_v_idx) {
    e = (*v)(p->__pyx_v_idx, a); if (e) return e;
  }
  if (p->__pyx_v_infos) {
    e = (*v)(p->__pyx_v_infos, a); if (e) return e;
  }
  if (p->__pyx_8genexpr4__pyx_v_key) {
    e = (*v)(p->__pyx_8genexpr4__pyx_v_key, a); if (e) return e;
  }
  if (p->__pyx_v_key) {
    e = (*v)(p->__pyx_v_key, a); if (e) return e;
  }
  if (p->__pyx_v_local_addr) {
    e = (*v)(p->__pyx_v_local_addr, a); if (e) return e;
  }
  if (p->__pyx_v_local_address) {
    e = (*v)(p->__pyx_v_local_address, a); if (e) return e;
  }
  if (p->__pyx_v_opts) {
    e = (*v)(p->__pyx_v_opts, a); if (e) return e;
  }
  if (p->__pyx_v_pro) {
    e = (*v)(p->__pyx_v_pro, a); if (e) return e;
  }
  if (p->__pyx_v_proto) {
    e = (*v)(p->__pyx_v_proto, a); if (e) return e;
  }
  if (p->__pyx_v_protocol) {
    e = (*v)(p->__pyx_v_protocol, a); if (e) return e;
  }
  if (p->__pyx_v_protocol_factory) {
    e = (*v)(p->__pyx_v_protocol_factory, a); if (e) return e;
  }
  if (p->__pyx_v_r_addr) {
    e = (*v)(p->__pyx_v_r_addr, a); if (e) return e;
  }
  if (p->__pyx_v_remote_addr) {
    e = (*v)(p->__pyx_v_remote_addr, a); if (e) return e;
  }
  if (p->__pyx_v_remote_address) {
    e = (*v)(p->__pyx_v_remote_address, a); if (e) return e;
  }
  if (p->__pyx_v_reuse_address) {
    e = (*v)(p->__pyx_v_reuse_address, a); if (e) return e;
  }
  if (p->__pyx_v_reuse_port) {
    e = (*v)(p->__pyx_v_reuse_port, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_sock) {
    e = (*v)(p->__pyx_v_sock, a); if (e) return e;
  }
  if (p->__pyx_v_udp) {
    e = (*v)(((PyObject *)p->__pyx_v_udp), a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_3) {
    e = (*v)(p->__pyx_t_3, a); if (e) return e;
  }
  if (p->__pyx_t_4) {
    e = (*v)(p->__pyx_t_4, a); if (e) return e;
  }
  if (p->__pyx_t_5) {
    e = (*v)(p->__pyx_t_5, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_25_create_datagram_endpoint", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_26_genexpr[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_26_genexpr = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_26_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_26_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_26_genexpr[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_26_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_26_genexpr(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_k);
  Py_CLEAR(p->__pyx_v_v);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_26_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_26_genexpr[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_26_genexpr++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_26_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_k) {
    e = (*v)(p->__pyx_v_k, a); if (e) return e;
  }
  if (p->__pyx_v_v) {
    e = (*v)(p->__pyx_v_v, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_26_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_26_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_26_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_26_genexpr, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_26_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_26_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_8genexpr5__pyx_v_ag);
  Py_CLEAR(p->__pyx_v_agen);
  Py_CLEAR(p->__pyx_v_closing_agens);
  Py_CLEAR(p->__pyx_v_result);
  Py_CLEAR(p->__pyx_v_results);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_shutdown_coro);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens *)o;
  if (p->__pyx_8genexpr5__pyx_v_ag) {
    e = (*v)(p->__pyx_8genexpr5__pyx_v_ag, a); if (e) return e;
  }
  if (p->__pyx_v_agen) {
    e = (*v)(p->__pyx_v_agen, a); if (e) return e;
  }
  if (p->__pyx_v_closing_agens) {
    e = (*v)(p->__pyx_v_closing_agens, a); if (e) return e;
  }
  if (p->__pyx_v_result) {
    e = (*v)(p->__pyx_v_result, a); if (e) return e;
  }
  if (p->__pyx_v_results) {
    e = (*v)(p->__pyx_v_results, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_shutdown_coro) {
    e = (*v)(p->__pyx_v_shutdown_coro, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_27_shutdown_asyncgens", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_28_wait_closed[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_28_wait_closed = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_28_wait_closed(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_28_wait_closed > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_28_wait_closed[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_28_wait_closed];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_28_wait_closed(PyObject *o) {
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_v_waiter);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_28_wait_closed < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_28_wait_closed[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_28_wait_closed++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_28_wait_closed(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *p = (struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_v_waiter) {
    e = (*v)(p->__pyx_v_waiter, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_28_wait_closed = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_28_wait_closed", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_28_wait_closed), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_28_wait_closed, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6uvloop_4loop___pyx_scope_struct_28_wait_closed, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_28_wait_closed, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 *__pyx_freelist_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1[8];
static int __pyx_freecount_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 = 0;

static PyObject *__pyx_tp_new_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1)))) {
    o = (PyObject*)__pyx_freelist_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1[--__pyx_freecount_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1];
    memset(o, 0, sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1));
    (void) PyObject_INIT(o, t);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1(PyObject *o) {
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1)))) {
    __pyx_freelist_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1[__pyx_freecount_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1++] = ((struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyTypeObject __pyx_type_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct_29__test_coroutine_1", /*tp_name*/
  sizeof(struct __pyx_obj_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *__pyx_freelist___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py[8];
static int __pyx_freecount___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py = 0;

static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py)))) {
    o = (PyObject*)__pyx_freelist___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py[--__pyx_freecount___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py];
    memset(o, 0, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py));
    (void) PyObject_INIT(o, t);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py(PyObject *o) {
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py)))) {
    __pyx_freelist___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py[__pyx_freecount___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py++] = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyTypeObject __pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py = {
  PyVarObject_HEAD_INIT(0, 0)
  "uvloop.loop.__pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py", /*tp_name*/
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_loop(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_loop},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "loop",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_18_7_7_7, __pyx_k_18_7_7_7, sizeof(__pyx_k_18_7_7_7), 0, 1, 0, 0},
  {&__pyx_kp_u_2_tuple_is_expected, __pyx_k_2_tuple_is_expected, sizeof(__pyx_k_2_tuple_is_expected), 0, 1, 0, 0},
  {&__pyx_kp_u_AF_INET6_address_must_be_tuple, __pyx_k_AF_INET6_address_must_be_tuple, sizeof(__pyx_k_AF_INET6_address_must_be_tuple), 0, 1, 0, 0},
  {&__pyx_kp_u_AF_INET6_must_be_a_tuple_of_2_4, __pyx_k_AF_INET6_must_be_a_tuple_of_2_4, sizeof(__pyx_k_AF_INET6_must_be_a_tuple_of_2_4), 0, 1, 0, 0},
  {&__pyx_kp_u_AF_INET_address_must_be_tuple, __pyx_k_AF_INET_address_must_be_tuple, sizeof(__pyx_k_AF_INET_address_must_be_tuple), 0, 1, 0, 0},
  {&__pyx_kp_u_AF_INET_address_must_be_tuple_of, __pyx_k_AF_INET_address_must_be_tuple_of, sizeof(__pyx_k_AF_INET_address_must_be_tuple_of), 0, 1, 0, 0},
  {&__pyx_kp_u_AF_UNSPEC_in_DNS_results, __pyx_k_AF_UNSPEC_in_DNS_results, sizeof(__pyx_k_AF_UNSPEC_in_DNS_results), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Stream_Socket_was_expected_got, __pyx_k_A_Stream_Socket_was_expected_got, sizeof(__pyx_k_A_Stream_Socket_was_expected_got), 0, 1, 0, 0},
  {&__pyx_kp_u_A_UDP_Socket_was_expected_got_r, __pyx_k_A_UDP_Socket_was_expected_got_r, sizeof(__pyx_k_A_UDP_Socket_was_expected_got_r), 0, 1, 0, 0},
  {&__pyx_kp_u_A_UNIX_Domain_Stream_Socket_was, __pyx_k_A_UNIX_Domain_Stream_Socket_was, sizeof(__pyx_k_A_UNIX_Domain_Stream_Socket_was), 0, 1, 0, 0},
  {&__pyx_kp_u_A_callable_object_or_None_is_exp, __pyx_k_A_callable_object_or_None_is_exp, sizeof(__pyx_k_A_callable_object_or_None_is_exp), 0, 1, 0, 0},
  {&__pyx_n_s_AbstractChildWatcher, __pyx_k_AbstractChildWatcher, sizeof(__pyx_k_AbstractChildWatcher), 0, 0, 1, 1},
  {&__pyx_kp_u_AddrInfoRequest_callback_called, __pyx_k_AddrInfoRequest_callback_called, sizeof(__pyx_k_AddrInfoRequest_callback_called), 0, 1, 0, 0},
  {&__pyx_kp_u_AddrInfo_data_is_NULL, __pyx_k_AddrInfo_data_is_NULL, sizeof(__pyx_k_AddrInfo_data_is_NULL), 0, 1, 0, 0},
  {&__pyx_n_s_AddressFamily, __pyx_k_AddressFamily, sizeof(__pyx_k_AddressFamily), 0, 0, 1, 1},
  {&__pyx_kp_u_Address_r_is_already_in_use, __pyx_k_Address_r_is_already_in_use, sizeof(__pyx_k_Address_r_is_already_in_use), 0, 1, 0, 0},
  {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
  {&__pyx_kp_u_Bad_exception_data_from_child_r, __pyx_k_Bad_exception_data_from_child_r, sizeof(__pyx_k_Bad_exception_data_from_child_r), 0, 1, 0, 0},
  {&__pyx_n_s_BaseException, __pyx_k_BaseException, sizeof(__pyx_k_BaseException), 0, 0, 1, 1},
  {&__pyx_n_s_BaseProtocol, __pyx_k_BaseProtocol, sizeof(__pyx_k_BaseProtocol), 0, 0, 1, 1},
  {&__pyx_n_s_BlockingIOError, __pyx_k_BlockingIOError, sizeof(__pyx_k_BlockingIOError), 0, 0, 1, 1},
  {&__pyx_n_s_BrokenPipeError, __pyx_k_BrokenPipeError, sizeof(__pyx_k_BrokenPipeError), 0, 0, 1, 1},
  {&__pyx_kp_u_Callback_handles_8, __pyx_k_Callback_handles_8, sizeof(__pyx_k_Callback_handles_8), 0, 1, 0, 0},
  {&__pyx_n_s_CancelledError, __pyx_k_CancelledError, sizeof(__pyx_k_CancelledError), 0, 0, 1, 1},
  {&__pyx_kp_u_Cannot_call_write_after_write_eo, __pyx_k_Cannot_call_write_after_write_eo, sizeof(__pyx_k_Cannot_call_write_after_write_eo), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_call_writelines_after_wri, __pyx_k_Cannot_call_writelines_after_wri, sizeof(__pyx_k_Cannot_call_writelines_after_wri), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_close_a_running_event_loo, __pyx_k_Cannot_close_a_running_event_loo, sizeof(__pyx_k_Cannot_close_a_running_event_loo), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_run_the_event_loop_while, __pyx_k_Cannot_run_the_event_loop_while, sizeof(__pyx_k_Cannot_run_the_event_loop_while), 0, 1, 0, 0},
  {&__pyx_kp_u_Cannot_serialize_socket_object, __pyx_k_Cannot_serialize_socket_object, sizeof(__pyx_k_Cannot_serialize_socket_object), 0, 1, 0, 0},
  {&__pyx_n_s_CertificateError, __pyx_k_CertificateError, sizeof(__pyx_k_CertificateError), 0, 0, 1, 1},
  {&__pyx_kp_u_Connect_call_failed, __pyx_k_Connect_call_failed, sizeof(__pyx_k_Connect_call_failed), 0, 1, 0, 0},
  {&__pyx_n_s_ConnectionAbortedError, __pyx_k_ConnectionAbortedError, sizeof(__pyx_k_ConnectionAbortedError), 0, 0, 1, 1},
  {&__pyx_n_s_ConnectionRefusedError, __pyx_k_ConnectionRefusedError, sizeof(__pyx_k_ConnectionRefusedError), 0, 0, 1, 1},
  {&__pyx_n_s_ConnectionResetError, __pyx_k_ConnectionResetError, sizeof(__pyx_k_ConnectionResetError), 0, 0, 1, 1},
  {&__pyx_n_s_Counter, __pyx_k_Counter, sizeof(__pyx_k_Counter), 0, 0, 1, 1},
  {&__pyx_n_s_DEVNULL, __pyx_k_DEVNULL, sizeof(__pyx_k_DEVNULL), 0, 0, 1, 1},
  {&__pyx_n_u_DO_HANDSHAKE, __pyx_k_DO_HANDSHAKE, sizeof(__pyx_k_DO_HANDSHAKE), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_ADDRFAMILY, __pyx_k_EAI_ADDRFAMILY, sizeof(__pyx_k_EAI_ADDRFAMILY), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_AGAIN, __pyx_k_EAI_AGAIN, sizeof(__pyx_k_EAI_AGAIN), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_BADFLAGS, __pyx_k_EAI_BADFLAGS, sizeof(__pyx_k_EAI_BADFLAGS), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_BADHINTS, __pyx_k_EAI_BADHINTS, sizeof(__pyx_k_EAI_BADHINTS), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_CANCELED, __pyx_k_EAI_CANCELED, sizeof(__pyx_k_EAI_CANCELED), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_FAIL, __pyx_k_EAI_FAIL, sizeof(__pyx_k_EAI_FAIL), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_FAMILY, __pyx_k_EAI_FAMILY, sizeof(__pyx_k_EAI_FAMILY), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_MEMORY, __pyx_k_EAI_MEMORY, sizeof(__pyx_k_EAI_MEMORY), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_NODATA, __pyx_k_EAI_NODATA, sizeof(__pyx_k_EAI_NODATA), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_NONAME, __pyx_k_EAI_NONAME, sizeof(__pyx_k_EAI_NONAME), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_OVERFLOW, __pyx_k_EAI_OVERFLOW, sizeof(__pyx_k_EAI_OVERFLOW), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_PROTOCOL, __pyx_k_EAI_PROTOCOL, sizeof(__pyx_k_EAI_PROTOCOL), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_SERVICE, __pyx_k_EAI_SERVICE, sizeof(__pyx_k_EAI_SERVICE), 0, 1, 0, 1},
  {&__pyx_n_u_EAI_SOCKTYPE, __pyx_k_EAI_SOCKTYPE, sizeof(__pyx_k_EAI_SOCKTYPE), 0, 1, 0, 1},
  {&__pyx_kp_u_Errors_logged, __pyx_k_Errors_logged, sizeof(__pyx_k_Errors_logged), 0, 1, 0, 0},
  {&__pyx_kp_u_Event_loop_is_closed, __pyx_k_Event_loop_is_closed, sizeof(__pyx_k_Event_loop_is_closed), 0, 1, 0, 0},
  {&__pyx_kp_u_Event_loop_stopped_before_Future, __pyx_k_Event_loop_stopped_before_Future, sizeof(__pyx_k_Event_loop_stopped_before_Future), 0, 1, 0, 0},
  {&__pyx_kp_u_Exception_in___repr___r_value_ty, __pyx_k_Exception_in___repr___r_value_ty, sizeof(__pyx_k_Exception_in___repr___r_value_ty), 0, 1, 0, 0},
  {&__pyx_kp_u_Exception_in_callback, __pyx_k_Exception_in_callback, sizeof(__pyx_k_Exception_in_callback), 0, 1, 0, 0},
  {&__pyx_kp_u_Exception_in_default_exception_h, __pyx_k_Exception_in_default_exception_h, sizeof(__pyx_k_Exception_in_default_exception_h), 0, 1, 0, 0},
  {&__pyx_kp_u_Exception_in_default_exception_h_2, __pyx_k_Exception_in_default_exception_h_2, sizeof(__pyx_k_Exception_in_default_exception_h_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Exception_occurred_in_preexec_fn, __pyx_k_Exception_occurred_in_preexec_fn, sizeof(__pyx_k_Exception_occurred_in_preexec_fn), 0, 1, 0, 0},
  {&__pyx_kp_u_Executing_r_took_3f_seconds, __pyx_k_Executing_r_took_3f_seconds, sizeof(__pyx_k_Executing_r_took_3f_seconds), 0, 1, 0, 0},
  {&__pyx_kp_u_Executing_s_took_3f_seconds, __pyx_k_Executing_s_took_3f_seconds, sizeof(__pyx_k_Executing_s_took_3f_seconds), 0, 1, 0, 0},
  {&__pyx_kp_u_Fatal_error_on_SSL_transport, __pyx_k_Fatal_error_on_SSL_transport, sizeof(__pyx_k_Fatal_error_on_SSL_transport), 0, 1, 0, 0},
  {&__pyx_kp_u_Fatal_error_on_server, __pyx_k_Fatal_error_on_server, sizeof(__pyx_k_Fatal_error_on_server), 0, 1, 0, 0},
  {&__pyx_kp_u_Fatal_error_on_transport, __pyx_k_Fatal_error_on_transport, sizeof(__pyx_k_Fatal_error_on_transport), 0, 1, 0, 0},
  {&__pyx_kp_u_Fatal_error_on_transport_2, __pyx_k_Fatal_error_on_transport_2, sizeof(__pyx_k_Fatal_error_on_transport_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Fatal_read_error_on_datagram_tra, __pyx_k_Fatal_read_error_on_datagram_tra, sizeof(__pyx_k_Fatal_read_error_on_datagram_tra), 0, 1, 0, 0},
  {&__pyx_kp_u_Fatal_write_error_on_datagram_tr, __pyx_k_Fatal_write_error_on_datagram_tr, sizeof(__pyx_k_Fatal_write_error_on_datagram_tr), 0, 1, 0, 0},
  {&__pyx_n_s_FileExistsError, __pyx_k_FileExistsError, sizeof(__pyx_k_FileExistsError), 0, 0, 1, 1},
  {&__pyx_n_s_FileNotFoundError, __pyx_k_FileNotFoundError, sizeof(__pyx_k_FileNotFoundError), 0, 0, 1, 1},
  {&__pyx_kp_u_File_descriptor_r_is_used_by_tra, __pyx_k_File_descriptor_r_is_used_by_tra, sizeof(__pyx_k_File_descriptor_r_is_used_by_tra), 0, 1, 0, 0},
  {&__pyx_n_s_FlowControlMixin, __pyx_k_FlowControlMixin, sizeof(__pyx_k_FlowControlMixin), 0, 0, 1, 1},
  {&__pyx_n_s_Future, __pyx_k_Future, sizeof(__pyx_k_Future), 0, 0, 1, 1},
  {&__pyx_kp_u_Handle_loop_is_None_in_Handle, __pyx_k_Handle_loop_is_None_in_Handle, sizeof(__pyx_k_Handle_loop_is_None_in_Handle), 0, 1, 0, 0},
  {&__pyx_kp_u_IPv4_sockaddr_must_be_2_tuple, __pyx_k_IPv4_sockaddr_must_be_2_tuple, sizeof(__pyx_k_IPv4_sockaddr_must_be_2_tuple), 0, 1, 0, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x38, __pyx_k_Incompatible_checksums_s_vs_0x38, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x38), 0, 0, 1, 0},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0x88, __pyx_k_Incompatible_checksums_s_vs_0x88, sizeof(__pyx_k_Incompatible_checksums_s_vs_0x88), 0, 0, 1, 0},
  {&__pyx_n_s_InterruptedError, __pyx_k_InterruptedError, sizeof(__pyx_k_InterruptedError), 0, 0, 1, 1},
  {&__pyx_n_s_InvalidStateError, __pyx_k_InvalidStateError, sizeof(__pyx_k_InvalidStateError), 0, 0, 1, 1},
  {&__pyx_kp_u_Invalid_address_must_be_None_or, __pyx_k_Invalid_address_must_be_None_or, sizeof(__pyx_k_Invalid_address_must_be_None_or), 0, 1, 0, 0},
  {&__pyx_kp_u_Invalid_file_descriptor, __pyx_k_Invalid_file_descriptor, sizeof(__pyx_k_Invalid_file_descriptor), 0, 1, 0, 0},
  {&__pyx_kp_u_Invalid_file_object_r, __pyx_k_Invalid_file_object_r, sizeof(__pyx_k_Invalid_file_object_r), 0, 1, 0, 0},
  {&__pyx_n_s_IsADirectoryError, __pyx_k_IsADirectoryError, sizeof(__pyx_k_IsADirectoryError), 0, 0, 1, 1},
  {&__pyx_n_s_Iterable, __pyx_k_Iterable, sizeof(__pyx_k_Iterable), 0, 0, 1, 1},
  {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
  {&__pyx_kp_u_Listen_errors, __pyx_k_Listen_errors, sizeof(__pyx_k_Listen_errors), 0, 1, 0, 0},
  {&__pyx_n_s_Loop___get___locals_lambda, __pyx_k_Loop___get___locals_lambda, sizeof(__pyx_k_Loop___get___locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_Loop___subprocess_run, __pyx_k_Loop___subprocess_run, sizeof(__pyx_k_Loop___subprocess_run), 0, 0, 1, 1},
  {&__pyx_n_s_Loop__getaddrinfo_locals_callbac, __pyx_k_Loop__getaddrinfo_locals_callbac, sizeof(__pyx_k_Loop__getaddrinfo_locals_callbac), 0, 0, 1, 1},
  {&__pyx_n_s_Loop__getnameinfo_locals_callbac, __pyx_k_Loop__getnameinfo_locals_callbac, sizeof(__pyx_k_Loop__getnameinfo_locals_callbac), 0, 0, 1, 1},
  {&__pyx_kp_u_Loop__read_from_self, __pyx_k_Loop__read_from_self, sizeof(__pyx_k_Loop__read_from_self), 0, 1, 0, 0},
  {&__pyx_kp_u_Loop__sock_accept, __pyx_k_Loop__sock_accept, sizeof(__pyx_k_Loop__sock_accept), 0, 1, 0, 0},
  {&__pyx_kp_u_Loop__sock_connect, __pyx_k_Loop__sock_connect, sizeof(__pyx_k_Loop__sock_connect), 0, 1, 0, 0},
  {&__pyx_n_s_Loop__sock_connect_locals_lambda, __pyx_k_Loop__sock_connect_locals_lambda, sizeof(__pyx_k_Loop__sock_connect_locals_lambda), 0, 0, 1, 1},
  {&__pyx_kp_u_Loop__sock_recv, __pyx_k_Loop__sock_recv, sizeof(__pyx_k_Loop__sock_recv), 0, 1, 0, 0},
  {&__pyx_kp_u_Loop__sock_recv_into, __pyx_k_Loop__sock_recv_into, sizeof(__pyx_k_Loop__sock_recv_into), 0, 1, 0, 0},
  {&__pyx_kp_u_Loop__sock_sendall, __pyx_k_Loop__sock_sendall, sizeof(__pyx_k_Loop__sock_sendall), 0, 1, 0, 0},
  {&__pyx_kp_u_Loop__stop, __pyx_k_Loop__stop, sizeof(__pyx_k_Loop__stop), 0, 1, 0, 0},
  {&__pyx_n_s_Loop_connect_accepted_socket, __pyx_k_Loop_connect_accepted_socket, sizeof(__pyx_k_Loop_connect_accepted_socket), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_connect_read_pipe, __pyx_k_Loop_connect_read_pipe, sizeof(__pyx_k_Loop_connect_read_pipe), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_connect_write_pipe, __pyx_k_Loop_connect_write_pipe, sizeof(__pyx_k_Loop_connect_write_pipe), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_create_connection, __pyx_k_Loop_create_connection, sizeof(__pyx_k_Loop_create_connection), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_create_datagram_endpoint, __pyx_k_Loop_create_datagram_endpoint, sizeof(__pyx_k_Loop_create_datagram_endpoint), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_create_server, __pyx_k_Loop_create_server, sizeof(__pyx_k_Loop_create_server), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_create_unix_connection, __pyx_k_Loop_create_unix_connection, sizeof(__pyx_k_Loop_create_unix_connection), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_create_unix_server, __pyx_k_Loop_create_unix_server, sizeof(__pyx_k_Loop_create_unix_server), 0, 0, 1, 1},
  {&__pyx_kp_u_Loop_debug_info, __pyx_k_Loop_debug_info, sizeof(__pyx_k_Loop_debug_info), 0, 1, 0, 0},
  {&__pyx_n_s_Loop_getaddrinfo, __pyx_k_Loop_getaddrinfo, sizeof(__pyx_k_Loop_getaddrinfo), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_getnameinfo, __pyx_k_Loop_getnameinfo, sizeof(__pyx_k_Loop_getnameinfo), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_shutdown_asyncgens, __pyx_k_Loop_shutdown_asyncgens, sizeof(__pyx_k_Loop_shutdown_asyncgens), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_sock_accept, __pyx_k_Loop_sock_accept, sizeof(__pyx_k_Loop_sock_accept), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_sock_connect, __pyx_k_Loop_sock_connect, sizeof(__pyx_k_Loop_sock_connect), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_sock_recv, __pyx_k_Loop_sock_recv, sizeof(__pyx_k_Loop_sock_recv), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_sock_recv_into, __pyx_k_Loop_sock_recv_into, sizeof(__pyx_k_Loop_sock_recv_into), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_sock_sendall, __pyx_k_Loop_sock_sendall, sizeof(__pyx_k_Loop_sock_sendall), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_start_tls, __pyx_k_Loop_start_tls, sizeof(__pyx_k_Loop_start_tls), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_subprocess_exec, __pyx_k_Loop_subprocess_exec, sizeof(__pyx_k_Loop_subprocess_exec), 0, 0, 1, 1},
  {&__pyx_n_s_Loop_subprocess_shell, __pyx_k_Loop_subprocess_shell, sizeof(__pyx_k_Loop_subprocess_shell), 0, 0, 1, 1},
  {&__pyx_kp_u_Loop_time, __pyx_k_Loop_time, sizeof(__pyx_k_Loop_time), 0, 1, 0, 0},
  {&__pyx_n_s_MemoryBIO, __pyx_k_MemoryBIO, sizeof(__pyx_k_MemoryBIO), 0, 0, 1, 1},
  {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
  {&__pyx_kp_u_Multiple_exceptions, __pyx_k_Multiple_exceptions, sizeof(__pyx_k_Multiple_exceptions), 0, 1, 0, 0},
  {&__pyx_n_s_NSIG, __pyx_k_NSIG, sizeof(__pyx_k_NSIG), 0, 0, 1, 1},
  {&__pyx_kp_u_Neither_host_port_nor_sock_were, __pyx_k_Neither_host_port_nor_sock_were, sizeof(__pyx_k_Neither_host_port_nor_sock_were), 0, 1, 0, 0},
  {&__pyx_kp_u_Non_thread_safe_operation_invoke, __pyx_k_Non_thread_safe_operation_invoke, sizeof(__pyx_k_Non_thread_safe_operation_invoke), 0, 1, 0, 0},
  {&__pyx_n_s_NotImplementedError, __pyx_k_NotImplementedError, sizeof(__pyx_k_NotImplementedError), 0, 0, 1, 1},
  {&__pyx_kp_u_Number_of_signals, __pyx_k_Number_of_signals, sizeof(__pyx_k_Number_of_signals), 0, 1, 0, 0},
  {&__pyx_n_s_OSError, __pyx_k_OSError, sizeof(__pyx_k_OSError), 0, 0, 1, 1},
  {&__pyx_n_s_O_RDWR, __pyx_k_O_RDWR, sizeof(__pyx_k_O_RDWR), 0, 0, 1, 1},
  {&__pyx_kp_u_Object_created_at_most_recent_ca, __pyx_k_Object_created_at_most_recent_ca, sizeof(__pyx_k_Object_created_at_most_recent_ca), 0, 1, 0, 0},
  {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
  {&__pyx_n_s_OverflowError, __pyx_k_OverflowError, sizeof(__pyx_k_OverflowError), 0, 0, 1, 1},
  {&__pyx_n_s_PIPE, __pyx_k_PIPE, sizeof(__pyx_k_PIPE), 0, 0, 1, 1},
  {&__pyx_n_u_PROTOCOL_IS_SHUTDOWN, __pyx_k_PROTOCOL_IS_SHUTDOWN, sizeof(__pyx_k_PROTOCOL_IS_SHUTDOWN), 0, 1, 0, 1},
  {&__pyx_n_u_PYTHONASYNCIODEBUG, __pyx_k_PYTHONASYNCIODEBUG, sizeof(__pyx_k_PYTHONASYNCIODEBUG), 0, 1, 0, 1},
  {&__pyx_n_s_PermissionError, __pyx_k_PermissionError, sizeof(__pyx_k_PermissionError), 0, 0, 1, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_kp_u_Polls_debug_info, __pyx_k_Polls_debug_info, sizeof(__pyx_k_Polls_debug_info), 0, 1, 0, 0},
  {&__pyx_n_s_ProcessLookupError, __pyx_k_ProcessLookupError, sizeof(__pyx_k_ProcessLookupError), 0, 0, 1, 1},
  {&__pyx_kp_u_Process_info, __pyx_k_Process_info, sizeof(__pyx_k_Process_info), 0, 1, 0, 0},
  {&__pyx_kp_u_Process_memory, __pyx_k_Process_memory, sizeof(__pyx_k_Process_memory), 0, 1, 0, 0},
  {&__pyx_n_s_Protocol, __pyx_k_Protocol, sizeof(__pyx_k_Protocol), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_CFunc_object____Loop____bi, __pyx_k_Pyx_CFunc_object____Loop____bi, sizeof(__pyx_k_Pyx_CFunc_object____Loop____bi), 0, 0, 1, 1},
  {&__pyx_kp_u_Racing_with_another_loop_to_spaw, __pyx_k_Racing_with_another_loop_to_spaw, sizeof(__pyx_k_Racing_with_another_loop_to_spaw), 0, 1, 0, 0},
  {&__pyx_n_s_ReadSubprocessPipeProto, __pyx_k_ReadSubprocessPipeProto, sizeof(__pyx_k_ReadSubprocessPipeProto), 0, 0, 1, 1},
  {&__pyx_n_s_ReadSubprocessPipeProto_data_rec, __pyx_k_ReadSubprocessPipeProto_data_rec, sizeof(__pyx_k_ReadSubprocessPipeProto_data_rec), 0, 0, 1, 1},
  {&__pyx_kp_u_Read_EOF_failed_callbacks, __pyx_k_Read_EOF_failed_callbacks, sizeof(__pyx_k_Read_EOF_failed_callbacks), 0, 1, 0, 0},
  {&__pyx_kp_u_Read_EOFs, __pyx_k_Read_EOFs, sizeof(__pyx_k_Read_EOFs), 0, 1, 0, 0},
  {&__pyx_kp_u_Read_callbacks, __pyx_k_Read_callbacks, sizeof(__pyx_k_Read_callbacks), 0, 1, 0, 0},
  {&__pyx_kp_u_Read_callbacks_failed, __pyx_k_Read_callbacks_failed, sizeof(__pyx_k_Read_callbacks_failed), 0, 1, 0, 0},
  {&__pyx_kp_u_Read_errors, __pyx_k_Read_errors, sizeof(__pyx_k_Read_errors), 0, 1, 0, 0},
  {&__pyx_kp_u_Read_events, __pyx_k_Read_events, sizeof(__pyx_k_Read_events), 0, 1, 0, 0},
  {&__pyx_kp_u_Read_failed_callbacks, __pyx_k_Read_failed_callbacks, sizeof(__pyx_k_Read_failed_callbacks), 0, 1, 0, 0},
  {&__pyx_n_s_ResourceWarning, __pyx_k_ResourceWarning, sizeof(__pyx_k_ResourceWarning), 0, 0, 1, 1},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s_RuntimeWarning, __pyx_k_RuntimeWarning, sizeof(__pyx_k_RuntimeWarning), 0, 0, 1, 1},
  {&__pyx_n_u_SHUTDOWN, __pyx_k_SHUTDOWN, sizeof(__pyx_k_SHUTDOWN), 0, 1, 0, 1},
  {&__pyx_n_s_SIG_DFL, __pyx_k_SIG_DFL, sizeof(__pyx_k_SIG_DFL), 0, 0, 1, 1},
  {&__pyx_n_u_SOCK_NONBLOCK, __pyx_k_SOCK_NONBLOCK, sizeof(__pyx_k_SOCK_NONBLOCK), 0, 1, 0, 1},
  {&__pyx_n_u_SO_BROADCAST, __pyx_k_SO_BROADCAST, sizeof(__pyx_k_SO_BROADCAST), 0, 1, 0, 1},
  {&__pyx_n_u_SO_REUSEPORT, __pyx_k_SO_REUSEPORT, sizeof(__pyx_k_SO_REUSEPORT), 0, 1, 0, 1},
  {&__pyx_n_s_SSLContext, __pyx_k_SSLContext, sizeof(__pyx_k_SSLContext), 0, 0, 1, 1},
  {&__pyx_n_s_SSLError, __pyx_k_SSLError, sizeof(__pyx_k_SSLError), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol, __pyx_k_SSLProtocol, sizeof(__pyx_k_SSLProtocol), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport, __pyx_k_SSLProtocolTransport, sizeof(__pyx_k_SSLProtocolTransport), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport___del, __pyx_k_SSLProtocolTransport___del, sizeof(__pyx_k_SSLProtocolTransport___del), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport___init, __pyx_k_SSLProtocolTransport___init, sizeof(__pyx_k_SSLProtocolTransport___init), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport__protocol, __pyx_k_SSLProtocolTransport__protocol, sizeof(__pyx_k_SSLProtocolTransport__protocol), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_abort, __pyx_k_SSLProtocolTransport_abort, sizeof(__pyx_k_SSLProtocolTransport_abort), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_can_write, __pyx_k_SSLProtocolTransport_can_write, sizeof(__pyx_k_SSLProtocolTransport_can_write), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_close, __pyx_k_SSLProtocolTransport_close, sizeof(__pyx_k_SSLProtocolTransport_close), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_get_extra, __pyx_k_SSLProtocolTransport_get_extra, sizeof(__pyx_k_SSLProtocolTransport_get_extra), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_get_protoc, __pyx_k_SSLProtocolTransport_get_protoc, sizeof(__pyx_k_SSLProtocolTransport_get_protoc), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_get_write, __pyx_k_SSLProtocolTransport_get_write, sizeof(__pyx_k_SSLProtocolTransport_get_write), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_is_closing, __pyx_k_SSLProtocolTransport_is_closing, sizeof(__pyx_k_SSLProtocolTransport_is_closing), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_is_reading, __pyx_k_SSLProtocolTransport_is_reading, sizeof(__pyx_k_SSLProtocolTransport_is_reading), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_pause_read, __pyx_k_SSLProtocolTransport_pause_read, sizeof(__pyx_k_SSLProtocolTransport_pause_read), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_resume_rea, __pyx_k_SSLProtocolTransport_resume_rea, sizeof(__pyx_k_SSLProtocolTransport_resume_rea), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_set_protoc, __pyx_k_SSLProtocolTransport_set_protoc, sizeof(__pyx_k_SSLProtocolTransport_set_protoc), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_set_write, __pyx_k_SSLProtocolTransport_set_write, sizeof(__pyx_k_SSLProtocolTransport_set_write), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocolTransport_write, __pyx_k_SSLProtocolTransport_write, sizeof(__pyx_k_SSLProtocolTransport_write), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol___init, __pyx_k_SSLProtocol___init, sizeof(__pyx_k_SSLProtocol___init), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__abort, __pyx_k_SSLProtocol__abort, sizeof(__pyx_k_SSLProtocol__abort), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__check_handshake_tim, __pyx_k_SSLProtocol__check_handshake_tim, sizeof(__pyx_k_SSLProtocol__check_handshake_tim), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__fatal_error, __pyx_k_SSLProtocol__fatal_error, sizeof(__pyx_k_SSLProtocol__fatal_error), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__finalize, __pyx_k_SSLProtocol__finalize, sizeof(__pyx_k_SSLProtocol__finalize), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__get_extra_info, __pyx_k_SSLProtocol__get_extra_info, sizeof(__pyx_k_SSLProtocol__get_extra_info), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__mark_closed, __pyx_k_SSLProtocol__mark_closed, sizeof(__pyx_k_SSLProtocol__mark_closed), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__on_handshake_comple, __pyx_k_SSLProtocol__on_handshake_comple, sizeof(__pyx_k_SSLProtocol__on_handshake_comple), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__process_write_backl, __pyx_k_SSLProtocol__process_write_backl, sizeof(__pyx_k_SSLProtocol__process_write_backl), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__set_app_protocol, __pyx_k_SSLProtocol__set_app_protocol, sizeof(__pyx_k_SSLProtocol__set_app_protocol), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__start_handshake, __pyx_k_SSLProtocol__start_handshake, sizeof(__pyx_k_SSLProtocol__start_handshake), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__start_shutdown, __pyx_k_SSLProtocol__start_shutdown, sizeof(__pyx_k_SSLProtocol__start_shutdown), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__wakeup_waiter, __pyx_k_SSLProtocol__wakeup_waiter, sizeof(__pyx_k_SSLProtocol__wakeup_waiter), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol__write_appdata, __pyx_k_SSLProtocol__write_appdata, sizeof(__pyx_k_SSLProtocol__write_appdata), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol_connection_lost, __pyx_k_SSLProtocol_connection_lost, sizeof(__pyx_k_SSLProtocol_connection_lost), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol_connection_made, __pyx_k_SSLProtocol_connection_made, sizeof(__pyx_k_SSLProtocol_connection_made), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol_data_received, __pyx_k_SSLProtocol_data_received, sizeof(__pyx_k_SSLProtocol_data_received), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol_eof_received, __pyx_k_SSLProtocol_eof_received, sizeof(__pyx_k_SSLProtocol_eof_received), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol_pause_writing, __pyx_k_SSLProtocol_pause_writing, sizeof(__pyx_k_SSLProtocol_pause_writing), 0, 0, 1, 1},
  {&__pyx_n_s_SSLProtocol_resume_writing, __pyx_k_SSLProtocol_resume_writing, sizeof(__pyx_k_SSLProtocol_resume_writing), 0, 0, 1, 1},
  {&__pyx_n_s_SSL_ERROR_SYSCALL, __pyx_k_SSL_ERROR_SYSCALL, sizeof(__pyx_k_SSL_ERROR_SYSCALL), 0, 0, 1, 1},
  {&__pyx_n_s_SSL_ERROR_WANT_READ, __pyx_k_SSL_ERROR_WANT_READ, sizeof(__pyx_k_SSL_ERROR_WANT_READ), 0, 0, 1, 1},
  {&__pyx_n_s_SSL_ERROR_WANT_WRITE, __pyx_k_SSL_ERROR_WANT_WRITE, sizeof(__pyx_k_SSL_ERROR_WANT_WRITE), 0, 0, 1, 1},
  {&__pyx_kp_u_SSL_error_errno, __pyx_k_SSL_error_errno, sizeof(__pyx_k_SSL_error_errno), 0, 1, 0, 0},
  {&__pyx_kp_u_SSL_handshake_failed, __pyx_k_SSL_handshake_failed, sizeof(__pyx_k_SSL_handshake_failed), 0, 1, 0, 0},
  {&__pyx_kp_u_SSL_handshake_failed_on_verifyin, __pyx_k_SSL_handshake_failed_on_verifyin, sizeof(__pyx_k_SSL_handshake_failed_on_verifyin), 0, 1, 0, 0},
  {&__pyx_kp_u_SSL_handshake_is_taking_longer_t, __pyx_k_SSL_handshake_is_taking_longer_t, sizeof(__pyx_k_SSL_handshake_is_taking_longer_t), 0, 1, 0, 0},
  {&__pyx_kp_s_SSL_protocol_Implementation_of_S, __pyx_k_SSL_protocol_Implementation_of_S, sizeof(__pyx_k_SSL_protocol_Implementation_of_S), 0, 0, 1, 0},
  {&__pyx_kp_u_SSL_transport_has_not_been_initi, __pyx_k_SSL_transport_has_not_been_initi, sizeof(__pyx_k_SSL_transport_has_not_been_initi), 0, 1, 0, 0},
  {&__pyx_n_s_STDOUT, __pyx_k_STDOUT, sizeof(__pyx_k_STDOUT), 0, 0, 1, 1},
  {&__pyx_n_s_S_ISSOCK, __pyx_k_S_ISSOCK, sizeof(__pyx_k_S_ISSOCK), 0, 0, 1, 1},
  {&__pyx_kp_u_Server_side_SSL_needs_a_valid_SS, __pyx_k_Server_side_SSL_needs_a_valid_SS, sizeof(__pyx_k_Server_side_SSL_needs_a_valid_SS), 0, 1, 0, 0},
  {&__pyx_n_s_Server_wait_closed, __pyx_k_Server_wait_closed, sizeof(__pyx_k_Server_wait_closed), 0, 0, 1, 1},
  {&__pyx_kp_u_Shutdown_errors, __pyx_k_Shutdown_errors, sizeof(__pyx_k_Shutdown_errors), 0, 1, 0, 0},
  {&__pyx_kp_u_Sock_ops_successful_on_1st_try, __pyx_k_Sock_ops_successful_on_1st_try, sizeof(__pyx_k_Sock_ops_successful_on_1st_try), 0, 1, 0, 0},
  {&__pyx_n_s_SocketKind, __pyx_k_SocketKind, sizeof(__pyx_k_SocketKind), 0, 0, 1, 1},
  {&__pyx_kp_u_Socket_try_writes, __pyx_k_Socket_try_writes, sizeof(__pyx_k_Socket_try_writes), 0, 1, 0, 0},
  {&__pyx_n_s_StackSummary, __pyx_k_StackSummary, sizeof(__pyx_k_StackSummary), 0, 0, 1, 1},
  {&__pyx_kp_u_StreamWriteContext_close_py_buf, __pyx_k_StreamWriteContext_close_py_buf, sizeof(__pyx_k_StreamWriteContext_close_py_buf), 0, 1, 0, 0},
  {&__pyx_kp_u_StreamWriteContext_close_uv_buf, __pyx_k_StreamWriteContext_close_uv_buf, sizeof(__pyx_k_StreamWriteContext_close_uv_buf), 0, 1, 0, 0},
  {&__pyx_kp_u_Streams_debug_info, __pyx_k_Streams_debug_info, sizeof(__pyx_k_Streams_debug_info), 0, 1, 0, 0},
  {&__pyx_n_s_SubprocessError, __pyx_k_SubprocessError, sizeof(__pyx_k_SubprocessError), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketReaderFuture, __pyx_k_SyncSocketReaderFuture, sizeof(__pyx_k_SyncSocketReaderFuture), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketReaderFuture___init, __pyx_k_SyncSocketReaderFuture___init, sizeof(__pyx_k_SyncSocketReaderFuture___init), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketReaderFuture__loop, __pyx_k_SyncSocketReaderFuture__loop, sizeof(__pyx_k_SyncSocketReaderFuture__loop), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketReaderFuture__sock, __pyx_k_SyncSocketReaderFuture__sock, sizeof(__pyx_k_SyncSocketReaderFuture__sock), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketReaderFuture_cancel, __pyx_k_SyncSocketReaderFuture_cancel, sizeof(__pyx_k_SyncSocketReaderFuture_cancel), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketWriterFuture, __pyx_k_SyncSocketWriterFuture, sizeof(__pyx_k_SyncSocketWriterFuture), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketWriterFuture___init, __pyx_k_SyncSocketWriterFuture___init, sizeof(__pyx_k_SyncSocketWriterFuture___init), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketWriterFuture__loop, __pyx_k_SyncSocketWriterFuture__loop, sizeof(__pyx_k_SyncSocketWriterFuture__loop), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketWriterFuture__sock, __pyx_k_SyncSocketWriterFuture__sock, sizeof(__pyx_k_SyncSocketWriterFuture__sock), 0, 0, 1, 1},
  {&__pyx_n_s_SyncSocketWriterFuture_cancel, __pyx_k_SyncSocketWriterFuture_cancel, sizeof(__pyx_k_SyncSocketWriterFuture_cancel), 0, 0, 1, 1},
  {&__pyx_n_s_Task, __pyx_k_Task, sizeof(__pyx_k_Task), 0, 0, 1, 1},
  {&__pyx_n_s_ThreadPoolExecutor, __pyx_k_ThreadPoolExecutor, sizeof(__pyx_k_ThreadPoolExecutor), 0, 0, 1, 1},
  {&__pyx_n_s_TimeoutError, __pyx_k_TimeoutError, sizeof(__pyx_k_TimeoutError), 0, 0, 1, 1},
  {&__pyx_kp_u_Timer_handles_8, __pyx_k_Timer_handles_8, sizeof(__pyx_k_Timer_handles_8), 0, 1, 0, 0},
  {&__pyx_n_s_Transport, __pyx_k_Transport, sizeof(__pyx_k_Transport), 0, 0, 1, 1},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_kp_u_UDPTransport__on_read_ready, __pyx_k_UDPTransport__on_read_ready, sizeof(__pyx_k_UDPTransport__on_read_ready), 0, 1, 0, 0},
  {&__pyx_kp_u_UDPTransport__on_write_ready, __pyx_k_UDPTransport__on_write_ready, sizeof(__pyx_k_UDPTransport__on_write_ready), 0, 1, 0, 0},
  {&__pyx_kp_u_UDP_sendto_address_r_requires_a, __pyx_k_UDP_sendto_address_r_requires_a, sizeof(__pyx_k_UDP_sendto_address_r_requires_a), 0, 1, 0, 0},
  {&__pyx_kp_u_UDP_sendto_r_socket_family_misma, __pyx_k_UDP_sendto_r_socket_family_misma, sizeof(__pyx_k_UDP_sendto_r_socket_family_misma), 0, 1, 0, 0},
  {&__pyx_n_u_UNWRAPPED, __pyx_k_UNWRAPPED, sizeof(__pyx_k_UNWRAPPED), 0, 1, 0, 1},
  {&__pyx_kp_u_UVHandles_python_libuv_total, __pyx_k_UVHandles_python_libuv_total, sizeof(__pyx_k_UVHandles_python_libuv_total), 0, 1, 0, 0},
  {&__pyx_kp_u_UVProcessTransport__call_connect, __pyx_k_UVProcessTransport__call_connect, sizeof(__pyx_k_UVProcessTransport__call_connect), 0, 1, 0, 0},
  {&__pyx_kp_u_UVProcess__close_after_spawn_cal, __pyx_k_UVProcess__close_after_spawn_cal, sizeof(__pyx_k_UVProcess__close_after_spawn_cal), 0, 1, 0, 0},
  {&__pyx_kp_u_UVStream__try_write_called_with, __pyx_k_UVStream__try_write_called_with, sizeof(__pyx_k_UVStream__try_write_called_with), 0, 1, 0, 0},
  {&__pyx_kp_u_UVStream_shutdown_callback_calle, __pyx_k_UVStream_shutdown_callback_calle, sizeof(__pyx_k_UVStream_shutdown_callback_calle), 0, 1, 0, 0},
  {&__pyx_kp_u_UVStream_write_callback_called_w, __pyx_k_UVStream_write_callback_called_w, sizeof(__pyx_k_UVStream_write_callback_called_w), 0, 1, 0, 0},
  {&__pyx_kp_u_UVTransport__call_connection_los, __pyx_k_UVTransport__call_connection_los, sizeof(__pyx_k_UVTransport__call_connection_los), 0, 1, 0, 0},
  {&__pyx_kp_u_UVTransport__call_connection_mad, __pyx_k_UVTransport__call_connection_mad, sizeof(__pyx_k_UVTransport__call_connection_mad), 0, 1, 0, 0},
  {&__pyx_kp_u_Unable_to_check_or_remove_stale, __pyx_k_Unable_to_check_or_remove_stale, sizeof(__pyx_k_Unable_to_check_or_remove_stale), 0, 1, 0, 0},
  {&__pyx_kp_u_Unhandled_error_in_exception_han, __pyx_k_Unhandled_error_in_exception_han, sizeof(__pyx_k_Unhandled_error_in_exception_han), 0, 1, 0, 0},
  {&__pyx_kp_u_Unhandled_exception_in_event_loo, __pyx_k_Unhandled_exception_in_event_loo, sizeof(__pyx_k_Unhandled_exception_in_event_loo), 0, 1, 0, 0},
  {&__pyx_n_s_UnicodeEncodeError, __pyx_k_UnicodeEncodeError, sizeof(__pyx_k_UnicodeEncodeError), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_u_WRAPPED, __pyx_k_WRAPPED, sizeof(__pyx_k_WRAPPED), 0, 1, 0, 1},
  {&__pyx_n_s_WeakSet, __pyx_k_WeakSet, sizeof(__pyx_k_WeakSet), 0, 0, 1, 1},
  {&__pyx_n_s_WeakValueDictionary, __pyx_k_WeakValueDictionary, sizeof(__pyx_k_WeakValueDictionary), 0, 0, 1, 1},
  {&__pyx_n_s_WriteSubprocessPipeProto, __pyx_k_WriteSubprocessPipeProto, sizeof(__pyx_k_WriteSubprocessPipeProto), 0, 0, 1, 1},
  {&__pyx_n_s_WriteSubprocessPipeProto___init, __pyx_k_WriteSubprocessPipeProto___init, sizeof(__pyx_k_WriteSubprocessPipeProto___init), 0, 0, 1, 1},
  {&__pyx_n_s_WriteSubprocessPipeProto___repr, __pyx_k_WriteSubprocessPipeProto___repr, sizeof(__pyx_k_WriteSubprocessPipeProto___repr), 0, 0, 1, 1},
  {&__pyx_n_s_WriteSubprocessPipeProto_connect, __pyx_k_WriteSubprocessPipeProto_connect, sizeof(__pyx_k_WriteSubprocessPipeProto_connect), 0, 0, 1, 1},
  {&__pyx_n_s_WriteSubprocessPipeProto_connect_2, __pyx_k_WriteSubprocessPipeProto_connect_2, sizeof(__pyx_k_WriteSubprocessPipeProto_connect_2), 0, 0, 1, 1},
  {&__pyx_n_s_WriteSubprocessPipeProto_pause_w, __pyx_k_WriteSubprocessPipeProto_pause_w, sizeof(__pyx_k_WriteSubprocessPipeProto_pause_w), 0, 0, 1, 1},
  {&__pyx_n_s_WriteSubprocessPipeProto_resume, __pyx_k_WriteSubprocessPipeProto_resume, sizeof(__pyx_k_WriteSubprocessPipeProto_resume), 0, 0, 1, 1},
  {&__pyx_kp_u_Write_callbacks_failed, __pyx_k_Write_callbacks_failed, sizeof(__pyx_k_Write_callbacks_failed), 0, 1, 0, 0},
  {&__pyx_kp_u_Write_contexts_8, __pyx_k_Write_contexts_8, sizeof(__pyx_k_Write_contexts_8), 0, 1, 0, 0},
  {&__pyx_kp_u_Write_errors, __pyx_k_Write_errors, sizeof(__pyx_k_Write_errors), 0, 1, 0, 0},
  {&__pyx_kp_u_Write_events, __pyx_k_Write_events, sizeof(__pyx_k_Write_events), 0, 1, 0, 0},
  {&__pyx_kp_u_Write_failed_callbacks, __pyx_k_Write_failed_callbacks, sizeof(__pyx_k_Write_failed_callbacks), 0, 1, 0, 0},
  {&__pyx_kp_u_Write_without_poll, __pyx_k_Write_without_poll, sizeof(__pyx_k_Write_without_poll), 0, 1, 0, 0},
  {&__pyx_kp_u_XXX_an_allocated_buffer_in_trans, __pyx_k_XXX_an_allocated_buffer_in_trans, sizeof(__pyx_k_XXX_an_allocated_buffer_in_trans), 0, 1, 0, 0},
  {&__pyx_kp_u_You_must_set_server_hostname_whe, __pyx_k_You_must_set_server_hostname_whe, sizeof(__pyx_k_You_must_set_server_hostname_whe), 0, 1, 0, 0},
  {&__pyx_kp_u__114, __pyx_k__114, sizeof(__pyx_k__114), 0, 1, 0, 0},
  {&__pyx_kp_u__128, __pyx_k__128, sizeof(__pyx_k__128), 0, 1, 0, 0},
  {&__pyx_kp_u__129, __pyx_k__129, sizeof(__pyx_k__129), 0, 1, 0, 0},
  {&__pyx_kp_u__130, __pyx_k__130, sizeof(__pyx_k__130), 0, 1, 0, 0},
  {&__pyx_kp_u__159, __pyx_k__159, sizeof(__pyx_k__159), 0, 1, 0, 0},
  {&__pyx_kp_b__209, __pyx_k__209, sizeof(__pyx_k__209), 0, 0, 0, 0},
  {&__pyx_kp_b__220, __pyx_k__220, sizeof(__pyx_k__220), 0, 0, 0, 0},
  {&__pyx_kp_u__33, __pyx_k__33, sizeof(__pyx_k__33), 0, 1, 0, 0},
  {&__pyx_kp_u__40, __pyx_k__40, sizeof(__pyx_k__40), 0, 1, 0, 0},
  {&__pyx_n_s__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 0, 1, 1},
  {&__pyx_kp_b__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 0, 0, 0},
  {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
  {&__pyx_kp_u__71, __pyx_k__71, sizeof(__pyx_k__71), 0, 1, 0, 0},
  {&__pyx_kp_u__87, __pyx_k__87, sizeof(__pyx_k__87), 0, 1, 0, 0},
  {&__pyx_kp_u__88, __pyx_k__88, sizeof(__pyx_k__88), 0, 1, 0, 0},
  {&__pyx_n_s_abc, __pyx_k_abc, sizeof(__pyx_k_abc), 0, 0, 1, 1},
  {&__pyx_n_s_abort, __pyx_k_abort, sizeof(__pyx_k_abort), 0, 0, 1, 1},
  {&__pyx_n_s_abort_2, __pyx_k_abort_2, sizeof(__pyx_k_abort_2), 0, 0, 1, 1},
  {&__pyx_kp_u_abort_init__closed_is_set, __pyx_k_abort_init__closed_is_set, sizeof(__pyx_k_abort_init__closed_is_set), 0, 1, 0, 0},
  {&__pyx_kp_u_abort_init__inited_is_set, __pyx_k_abort_init__inited_is_set, sizeof(__pyx_k_abort_init__inited_is_set), 0, 1, 0, 0},
  {&__pyx_n_s_accept, __pyx_k_accept, sizeof(__pyx_k_accept), 0, 0, 1, 1},
  {&__pyx_kp_u_accept_method, __pyx_k_accept_method, sizeof(__pyx_k_accept_method), 0, 1, 0, 0},
  {&__pyx_n_s_aclose, __pyx_k_aclose, sizeof(__pyx_k_aclose), 0, 0, 1, 1},
  {&__pyx_kp_u_active_TimerHandle_is_deallacati, __pyx_k_active_TimerHandle_is_deallacati, sizeof(__pyx_k_active_TimerHandle_is_deallacati), 0, 1, 0, 0},
  {&__pyx_n_s_add, __pyx_k_add, sizeof(__pyx_k_add), 0, 0, 1, 1},
  {&__pyx_n_s_add_done_callback, __pyx_k_add_done_callback, sizeof(__pyx_k_add_done_callback), 0, 0, 1, 1},
  {&__pyx_n_s_addr, __pyx_k_addr, sizeof(__pyx_k_addr), 0, 0, 1, 1},
  {&__pyx_n_s_address, __pyx_k_address, sizeof(__pyx_k_address), 0, 0, 1, 1},
  {&__pyx_n_s_address_2, __pyx_k_address_2, sizeof(__pyx_k_address_2), 0, 0, 1, 1},
  {&__pyx_kp_u_alive_closed, __pyx_k_alive_closed, sizeof(__pyx_k_alive_closed), 0, 1, 0, 0},
  {&__pyx_kp_u_all_args_must_be_str_or_bytes, __pyx_k_all_args_must_be_str_or_bytes, sizeof(__pyx_k_all_args_must_be_str_or_bytes), 0, 1, 0, 0},
  {&__pyx_kp_u_all_environment_values_must_be_b, __pyx_k_all_environment_values_must_be_b, sizeof(__pyx_k_all_environment_values_must_be_b), 0, 1, 0, 0},
  {&__pyx_kp_u_all_environment_vars_must_be_byt, __pyx_k_all_environment_vars_must_be_byt, sizeof(__pyx_k_all_environment_vars_must_be_byt), 0, 1, 0, 0},
  {&__pyx_n_s_allow_broadcast, __pyx_k_allow_broadcast, sizeof(__pyx_k_allow_broadcast), 0, 0, 1, 1},
  {&__pyx_kp_u_an_error_occurred_during_closing, __pyx_k_an_error_occurred_during_closing, sizeof(__pyx_k_an_error_occurred_during_closing), 0, 1, 0, 0},
  {&__pyx_n_s_app_protocol, __pyx_k_app_protocol, sizeof(__pyx_k_app_protocol), 0, 0, 1, 1},
  {&__pyx_n_s_app_protocol_2, __pyx_k_app_protocol_2, sizeof(__pyx_k_app_protocol_2), 0, 0, 1, 1},
  {&__pyx_n_s_app_protocol_is_buffer, __pyx_k_app_protocol_is_buffer, sizeof(__pyx_k_app_protocol_is_buffer), 0, 0, 1, 1},
  {&__pyx_n_s_app_transport, __pyx_k_app_transport, sizeof(__pyx_k_app_transport), 0, 0, 1, 1},
  {&__pyx_n_s_appdata, __pyx_k_appdata, sizeof(__pyx_k_appdata), 0, 0, 1, 1},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_appendleft, __pyx_k_appendleft, sizeof(__pyx_k_appendleft), 0, 0, 1, 1},
  {&__pyx_kp_u_application_protocol_failed_to_r, __pyx_k_application_protocol_failed_to_r, sizeof(__pyx_k_application_protocol_failed_to_r), 0, 1, 0, 0},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_u_ascii, __pyx_k_ascii, sizeof(__pyx_k_ascii), 0, 1, 0, 1},
  {&__pyx_n_u_asyncgen, __pyx_k_asyncgen, sizeof(__pyx_k_asyncgen), 0, 1, 0, 1},
  {&__pyx_n_s_asyncgen_finalizer_hook, __pyx_k_asyncgen_finalizer_hook, sizeof(__pyx_k_asyncgen_finalizer_hook), 0, 0, 1, 1},
  {&__pyx_n_s_asyncgen_firstiter_hook, __pyx_k_asyncgen_firstiter_hook, sizeof(__pyx_k_asyncgen_firstiter_hook), 0, 0, 1, 1},
  {&__pyx_kp_u_asynchronous_generator_r_was_sch, __pyx_k_asynchronous_generator_r_was_sch, sizeof(__pyx_k_asynchronous_generator_r_was_sch), 0, 1, 0, 0},
  {&__pyx_n_s_asyncio, __pyx_k_asyncio, sizeof(__pyx_k_asyncio), 0, 0, 1, 1},
  {&__pyx_n_s_asyncio_base_events, __pyx_k_asyncio_base_events, sizeof(__pyx_k_asyncio_base_events), 0, 0, 1, 1},
  {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
  {&__pyx_n_s_asyncio_futures, __pyx_k_asyncio_futures, sizeof(__pyx_k_asyncio_futures), 0, 0, 1, 1},
  {&__pyx_kp_u_asyncio_is_trying_to_install_it, __pyx_k_asyncio_is_trying_to_install_it, sizeof(__pyx_k_asyncio_is_trying_to_install_it), 0, 1, 0, 0},
  {&__pyx_n_s_asyncio_log, __pyx_k_asyncio_log, sizeof(__pyx_k_asyncio_log), 0, 0, 1, 1},
  {&__pyx_n_s_asyncio_sslproto, __pyx_k_asyncio_sslproto, sizeof(__pyx_k_asyncio_sslproto), 0, 0, 1, 1},
  {&__pyx_n_s_asyncio_tasks, __pyx_k_asyncio_tasks, sizeof(__pyx_k_asyncio_tasks), 0, 0, 1, 1},
  {&__pyx_n_s_asyncio_transports, __pyx_k_asyncio_transports, sizeof(__pyx_k_asyncio_transports), 0, 0, 1, 1},
  {&__pyx_n_s_await, __pyx_k_await, sizeof(__pyx_k_await), 0, 0, 1, 1},
  {&__pyx_n_u_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 1, 0, 1},
  {&__pyx_n_s_backlog, __pyx_k_backlog, sizeof(__pyx_k_backlog), 0, 0, 1, 1},
  {&__pyx_kp_b_bin_sh, __pyx_k_bin_sh, sizeof(__pyx_k_bin_sh), 0, 0, 0, 0},
  {&__pyx_n_s_bind, __pyx_k_bind, sizeof(__pyx_k_bind), 0, 0, 1, 1},
  {&__pyx_kp_u_bind_method, __pyx_k_bind_method, sizeof(__pyx_k_bind_method), 0, 1, 0, 0},
  {&__pyx_n_s_buf, __pyx_k_buf, sizeof(__pyx_k_buf), 0, 0, 1, 1},
  {&__pyx_kp_u_buffer_size_is_not_0_after_a_su, __pyx_k_buffer_size_is_not_0_after_a_su, sizeof(__pyx_k_buffer_size_is_not_0_after_a_su), 0, 1, 0, 0},
  {&__pyx_n_s_buffer_updated, __pyx_k_buffer_updated, sizeof(__pyx_k_buffer_updated), 0, 0, 1, 1},
  {&__pyx_n_s_bufsize, __pyx_k_bufsize, sizeof(__pyx_k_bufsize), 0, 0, 1, 1},
  {&__pyx_kp_u_bufsize_must_be_0, __pyx_k_bufsize_must_be_0, sizeof(__pyx_k_bufsize_must_be_0), 0, 1, 0, 0},
  {&__pyx_n_s_builtins, __pyx_k_builtins, sizeof(__pyx_k_builtins), 0, 0, 1, 1},
  {&__pyx_kp_b_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 0, 0},
  {&__pyx_n_s_call_connection_made, __pyx_k_call_connection_made, sizeof(__pyx_k_call_connection_made), 0, 0, 1, 1},
  {&__pyx_n_s_call_connection_made_2, __pyx_k_call_connection_made_2, sizeof(__pyx_k_call_connection_made_2), 0, 0, 1, 1},
  {&__pyx_n_s_call_exception_handler, __pyx_k_call_exception_handler, sizeof(__pyx_k_call_exception_handler), 0, 0, 1, 1},
  {&__pyx_n_s_call_later, __pyx_k_call_later, sizeof(__pyx_k_call_later), 0, 0, 1, 1},
  {&__pyx_n_s_call_soon, __pyx_k_call_soon, sizeof(__pyx_k_call_soon), 0, 0, 1, 1},
  {&__pyx_n_s_call_soon_threadsafe, __pyx_k_call_soon_threadsafe, sizeof(__pyx_k_call_soon_threadsafe), 0, 0, 1, 1},
  {&__pyx_n_s_callback, __pyx_k_callback, sizeof(__pyx_k_callback), 0, 0, 1, 1},
  {&__pyx_kp_u_called_after_destroying_the_UVH, __pyx_k_called_after_destroying_the_UVH, sizeof(__pyx_k_called_after_destroying_the_UVH), 0, 1, 0, 0},
  {&__pyx_kp_u_called_with_handle_data_NULL, __pyx_k_called_with_handle_data_NULL, sizeof(__pyx_k_called_with_handle_data_NULL), 0, 1, 0, 0},
  {&__pyx_kp_u_can_not_get_address_information, __pyx_k_can_not_get_address_information, sizeof(__pyx_k_can_not_get_address_information), 0, 1, 0, 0},
  {&__pyx_n_s_can_write_eof, __pyx_k_can_write_eof, sizeof(__pyx_k_can_write_eof), 0, 0, 1, 1},
  {&__pyx_n_s_cancel, __pyx_k_cancel, sizeof(__pyx_k_cancel), 0, 0, 1, 1},
  {&__pyx_kp_u_cancel_request_data_is_NULL, __pyx_k_cancel_request_data_is_NULL, sizeof(__pyx_k_cancel_request_data_is_NULL), 0, 1, 0, 0},
  {&__pyx_kp_u_cancel_request_data_is_not_UVRe, __pyx_k_cancel_request_data_is_not_UVRe, sizeof(__pyx_k_cancel_request_data_is_not_UVRe), 0, 1, 0, 0},
  {&__pyx_kp_u_cancel_request_is_NULL, __pyx_k_cancel_request_is_NULL, sizeof(__pyx_k_cancel_request_is_NULL), 0, 1, 0, 0},
  {&__pyx_n_s_cancelled, __pyx_k_cancelled, sizeof(__pyx_k_cancelled), 0, 0, 1, 1},
  {&__pyx_n_u_cancelled, __pyx_k_cancelled, sizeof(__pyx_k_cancelled), 0, 1, 0, 1},
  {&__pyx_kp_u_cannot_add_a_signal_handler_for, __pyx_k_cannot_add_a_signal_handler_for, sizeof(__pyx_k_cannot_add_a_signal_handler_for), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_apply_subprocess_STDOUT, __pyx_k_cannot_apply_subprocess_STDOUT, sizeof(__pyx_k_cannot_apply_subprocess_STDOUT), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_convert_sockaddr_into_Pyt, __pyx_k_cannot_convert_sockaddr_into_Pyt, sizeof(__pyx_k_cannot_convert_sockaddr_into_Pyt), 0, 1, 0, 0},
  {&__pyx_kp_u_cannot_spawn_a_process_args_are, __pyx_k_cannot_spawn_a_process_args_are, sizeof(__pyx_k_cannot_spawn_a_process_args_are), 0, 1, 0, 0},
  {&__pyx_n_s_cast, __pyx_k_cast, sizeof(__pyx_k_cast), 0, 0, 1, 1},
  {&__pyx_n_s_cause, __pyx_k_cause, sizeof(__pyx_k_cause), 0, 0, 1, 1},
  {&__pyx_n_s_cfunc_to_py, __pyx_k_cfunc_to_py, sizeof(__pyx_k_cfunc_to_py), 0, 0, 1, 1},
  {&__pyx_n_s_chain, __pyx_k_chain, sizeof(__pyx_k_chain), 0, 0, 1, 1},
  {&__pyx_n_s_check_handshake_timeout, __pyx_k_check_handshake_timeout, sizeof(__pyx_k_check_handshake_timeout), 0, 0, 1, 1},
  {&__pyx_n_s_check_hostname, __pyx_k_check_hostname, sizeof(__pyx_k_check_hostname), 0, 0, 1, 1},
  {&__pyx_n_s_chunk, __pyx_k_chunk, sizeof(__pyx_k_chunk), 0, 0, 1, 1},
  {&__pyx_n_s_cipher, __pyx_k_cipher, sizeof(__pyx_k_cipher), 0, 0, 1, 1},
  {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
  {&__pyx_n_s_clear, __pyx_k_clear, sizeof(__pyx_k_clear), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_kp_u_close__handle_data_is_NULL, __pyx_k_close__handle_data_is_NULL, sizeof(__pyx_k_close__handle_data_is_NULL), 0, 1, 0, 0},
  {&__pyx_kp_u_close__handle_data_is_not_UVHa, __pyx_k_close__handle_data_is_not_UVHa, sizeof(__pyx_k_close__handle_data_is_not_UVHa), 0, 1, 0, 0},
  {&__pyx_n_s_close_fds, __pyx_k_close_fds, sizeof(__pyx_k_close_fds), 0, 0, 1, 1},
  {&__pyx_kp_u_close_method, __pyx_k_close_method, sizeof(__pyx_k_close_method), 0, 1, 0, 0},
  {&__pyx_kp_u_close_uv_is_closing_is_true, __pyx_k_close_uv_is_closing_is_true, sizeof(__pyx_k_close_uv_is_closing_is_true), 0, 1, 0, 0},
  {&__pyx_n_s_closed, __pyx_k_closed, sizeof(__pyx_k_closed), 0, 0, 1, 1},
  {&__pyx_kp_u_closed_Transport_handle_and_unse, __pyx_k_closed_Transport_handle_and_unse, sizeof(__pyx_k_closed_Transport_handle_and_unse), 0, 1, 0, 0},
  {&__pyx_kp_u_closed_reading_x, __pyx_k_closed_reading_x, sizeof(__pyx_k_closed_reading_x), 0, 1, 0, 0},
  {&__pyx_kp_u_closed_x, __pyx_k_closed_x, sizeof(__pyx_k_closed_x), 0, 1, 0, 0},
  {&__pyx_n_s_cmd, __pyx_k_cmd, sizeof(__pyx_k_cmd), 0, 0, 1, 1},
  {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
  {&__pyx_n_s_collections_abc, __pyx_k_collections_abc, sizeof(__pyx_k_collections_abc), 0, 0, 1, 1},
  {&__pyx_n_s_compression, __pyx_k_compression, sizeof(__pyx_k_compression), 0, 0, 1, 1},
  {&__pyx_n_s_concurrent, __pyx_k_concurrent, sizeof(__pyx_k_concurrent), 0, 0, 1, 1},
  {&__pyx_kp_u_concurrent_allocations, __pyx_k_concurrent_allocations, sizeof(__pyx_k_concurrent_allocations), 0, 1, 0, 0},
  {&__pyx_n_s_concurrent_futures, __pyx_k_concurrent_futures, sizeof(__pyx_k_concurrent_futures), 0, 0, 1, 1},
  {&__pyx_n_s_connect, __pyx_k_connect, sizeof(__pyx_k_connect), 0, 0, 1, 1},
  {&__pyx_n_s_connect_accepted_socket, __pyx_k_connect_accepted_socket, sizeof(__pyx_k_connect_accepted_socket), 0, 0, 1, 1},
  {&__pyx_kp_u_connect_ex_method, __pyx_k_connect_ex_method, sizeof(__pyx_k_connect_ex_method), 0, 1, 0, 0},
  {&__pyx_kp_u_connect_failed, __pyx_k_connect_failed, sizeof(__pyx_k_connect_failed), 0, 1, 0, 0},
  {&__pyx_kp_u_connect_method, __pyx_k_connect_method, sizeof(__pyx_k_connect_method), 0, 1, 0, 0},
  {&__pyx_n_s_connect_read_pipe, __pyx_k_connect_read_pipe, sizeof(__pyx_k_connect_read_pipe), 0, 0, 1, 1},
  {&__pyx_n_s_connect_write_pipe, __pyx_k_connect_write_pipe, sizeof(__pyx_k_connect_write_pipe), 0, 0, 1, 1},
  {&__pyx_n_s_connection_lost, __pyx_k_connection_lost, sizeof(__pyx_k_connection_lost), 0, 0, 1, 1},
  {&__pyx_n_s_connection_made, __pyx_k_connection_made, sizeof(__pyx_k_connection_made), 0, 0, 1, 1},
  {&__pyx_n_s_context, __pyx_k_context, sizeof(__pyx_k_context), 0, 0, 1, 1},
  {&__pyx_n_u_context, __pyx_k_context, sizeof(__pyx_k_context), 0, 1, 0, 1},
  {&__pyx_kp_u_context_argument_requires_Pytho, __pyx_k_context_argument_requires_Pytho, sizeof(__pyx_k_context_argument_requires_Pytho), 0, 1, 0, 0},
  {&__pyx_kp_u_context_manager_protocol, __pyx_k_context_manager_protocol, sizeof(__pyx_k_context_manager_protocol), 0, 1, 0, 0},
  {&__pyx_n_s_copy, __pyx_k_copy, sizeof(__pyx_k_copy), 0, 0, 1, 1},
  {&__pyx_n_s_coroutines, __pyx_k_coroutines, sizeof(__pyx_k_coroutines), 0, 0, 1, 1},
  {&__pyx_kp_u_coroutines_cannot_be_used_with_a, __pyx_k_coroutines_cannot_be_used_with_a, sizeof(__pyx_k_coroutines_cannot_be_used_with_a), 0, 1, 0, 0},
  {&__pyx_kp_u_coroutines_cannot_be_used_with_r, __pyx_k_coroutines_cannot_be_used_with_r, sizeof(__pyx_k_coroutines_cannot_be_used_with_r), 0, 1, 0, 0},
  {&__pyx_kp_u_could_not_close_attached_file_ob, __pyx_k_could_not_close_attached_file_ob, sizeof(__pyx_k_could_not_close_attached_file_ob), 0, 1, 0, 0},
  {&__pyx_n_s_create_connection, __pyx_k_create_connection, sizeof(__pyx_k_create_connection), 0, 0, 1, 1},
  {&__pyx_n_s_create_connection_locals_genexpr, __pyx_k_create_connection_locals_genexpr, sizeof(__pyx_k_create_connection_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_create_datagram_endpoint, __pyx_k_create_datagram_endpoint, sizeof(__pyx_k_create_datagram_endpoint), 0, 0, 1, 1},
  {&__pyx_n_s_create_datagram_endpoint_locals, __pyx_k_create_datagram_endpoint_locals, sizeof(__pyx_k_create_datagram_endpoint_locals), 0, 0, 1, 1},
  {&__pyx_n_s_create_default_context, __pyx_k_create_default_context, sizeof(__pyx_k_create_default_context), 0, 0, 1, 1},
  {&__pyx_n_s_create_server, __pyx_k_create_server, sizeof(__pyx_k_create_server), 0, 0, 1, 1},
  {&__pyx_n_s_create_task, __pyx_k_create_task, sizeof(__pyx_k_create_task), 0, 0, 1, 1},
  {&__pyx_n_s_create_unix_connection, __pyx_k_create_unix_connection, sizeof(__pyx_k_create_unix_connection), 0, 0, 1, 1},
  {&__pyx_n_s_create_unix_server, __pyx_k_create_unix_server, sizeof(__pyx_k_create_unix_server), 0, 0, 1, 1},
  {&__pyx_kp_u_created_at, __pyx_k_created_at, sizeof(__pyx_k_created_at), 0, 1, 0, 0},
  {&__pyx_n_s_creationflags, __pyx_k_creationflags, sizeof(__pyx_k_creationflags), 0, 0, 1, 1},
  {&__pyx_kp_u_creationflags_is_not_supported, __pyx_k_creationflags_is_not_supported, sizeof(__pyx_k_creationflags_is_not_supported), 0, 1, 0, 0},
  {&__pyx_n_s_cwd, __pyx_k_cwd, sizeof(__pyx_k_cwd), 0, 0, 1, 1},
  {&__pyx_kp_u_cwd_must_be_a_str_or_bytes_objec, __pyx_k_cwd_must_be_a_str_or_bytes_objec, sizeof(__pyx_k_cwd_must_be_a_str_or_bytes_objec), 0, 1, 0, 0},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_kp_u_data_argument_must_be_a_bytes_li, __pyx_k_data_argument_must_be_a_bytes_li, sizeof(__pyx_k_data_argument_must_be_a_bytes_li), 0, 1, 0, 0},
  {&__pyx_kp_u_data_expecting_a_bytes_like_inst, __pyx_k_data_expecting_a_bytes_like_inst, sizeof(__pyx_k_data_expecting_a_bytes_like_inst), 0, 1, 0, 0},
  {&__pyx_n_s_data_received, __pyx_k_data_received, sizeof(__pyx_k_data_received), 0, 0, 1, 1},
  {&__pyx_n_u_data_received, __pyx_k_data_received, sizeof(__pyx_k_data_received), 0, 1, 0, 1},
  {&__pyx_n_s_datagram_received, __pyx_k_datagram_received, sizeof(__pyx_k_datagram_received), 0, 0, 1, 1},
  {&__pyx_kp_u_dealloc____handle_is_NULL__cl, __pyx_k_dealloc____handle_is_NULL__cl, sizeof(__pyx_k_dealloc____handle_is_NULL__cl), 0, 1, 0, 0},
  {&__pyx_kp_u_deallocating_a_running_event_loo, __pyx_k_deallocating_a_running_event_loo, sizeof(__pyx_k_deallocating_a_running_event_loo), 0, 1, 0, 0},
  {&__pyx_kp_u_deallocating_an_open_event_loop, __pyx_k_deallocating_an_open_event_loop, sizeof(__pyx_k_deallocating_an_open_event_loop), 0, 1, 0, 0},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_u_debug_wrapper, __pyx_k_debug_wrapper, sizeof(__pyx_k_debug_wrapper), 0, 1, 0, 1},
  {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
  {&__pyx_n_s_decref_socketios, __pyx_k_decref_socketios, sizeof(__pyx_k_decref_socketios), 0, 0, 1, 1},
  {&__pyx_n_s_default, __pyx_k_default, sizeof(__pyx_k_default), 0, 0, 1, 1},
  {&__pyx_n_s_default_exception_handler, __pyx_k_default_exception_handler, sizeof(__pyx_k_default_exception_handler), 0, 0, 1, 1},
  {&__pyx_n_s_default_int_handler, __pyx_k_default_int_handler, sizeof(__pyx_k_default_int_handler), 0, 0, 1, 1},
  {&__pyx_n_s_del, __pyx_k_del, sizeof(__pyx_k_del), 0, 0, 1, 1},
  {&__pyx_n_s_delay, __pyx_k_delay, sizeof(__pyx_k_delay), 0, 0, 1, 1},
  {&__pyx_n_s_deque, __pyx_k_deque, sizeof(__pyx_k_deque), 0, 0, 1, 1},
  {&__pyx_n_s_detach, __pyx_k_detach, sizeof(__pyx_k_detach), 0, 0, 1, 1},
  {&__pyx_kp_u_detach_method, __pyx_k_detach_method, sizeof(__pyx_k_detach_method), 0, 1, 0, 0},
  {&__pyx_n_s_devnull, __pyx_k_devnull, sizeof(__pyx_k_devnull), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_n_s_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 0, 1, 1},
  {&__pyx_n_s_discard, __pyx_k_discard, sizeof(__pyx_k_discard), 0, 0, 1, 1},
  {&__pyx_n_s_disconnected, __pyx_k_disconnected, sizeof(__pyx_k_disconnected), 0, 0, 1, 1},
  {&__pyx_n_s_do_handshake, __pyx_k_do_handshake, sizeof(__pyx_k_do_handshake), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_kp_u_does_not_have_a_reader_in_the, __pyx_k_does_not_have_a_reader_in_the, sizeof(__pyx_k_does_not_have_a_reader_in_the), 0, 1, 0, 0},
  {&__pyx_kp_u_does_not_have_a_reader_in_the_2, __pyx_k_does_not_have_a_reader_in_the_2, sizeof(__pyx_k_does_not_have_a_reader_in_the_2), 0, 1, 0, 0},
  {&__pyx_kp_u_does_not_have_a_writer_in_the, __pyx_k_does_not_have_a_writer_in_the, sizeof(__pyx_k_does_not_have_a_writer_in_the), 0, 1, 0, 0},
  {&__pyx_n_s_done, __pyx_k_done, sizeof(__pyx_k_done), 0, 0, 1, 1},
  {&__pyx_n_s_dt, __pyx_k_dt, sizeof(__pyx_k_dt), 0, 0, 1, 1},
  {&__pyx_n_s_dup, __pyx_k_dup, sizeof(__pyx_k_dup), 0, 0, 1, 1},
  {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
  {&__pyx_n_s_enabled, __pyx_k_enabled, sizeof(__pyx_k_enabled), 0, 0, 1, 1},
  {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
  {&__pyx_n_s_ensure_future, __pyx_k_ensure_future, sizeof(__pyx_k_ensure_future), 0, 0, 1, 1},
  {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
  {&__pyx_n_s_env, __pyx_k_env, sizeof(__pyx_k_env), 0, 0, 1, 1},
  {&__pyx_n_s_environ, __pyx_k_environ, sizeof(__pyx_k_environ), 0, 0, 1, 1},
  {&__pyx_n_s_eof_received, __pyx_k_eof_received, sizeof(__pyx_k_eof_received), 0, 0, 1, 1},
  {&__pyx_kp_u_epected_AF_INET_or_AF_INET6_fami, __pyx_k_epected_AF_INET_or_AF_INET6_fami, sizeof(__pyx_k_epected_AF_INET_or_AF_INET6_fami), 0, 1, 0, 0},
  {&__pyx_n_s_errno, __pyx_k_errno, sizeof(__pyx_k_errno), 0, 0, 1, 1},
  {&__pyx_n_u_errno, __pyx_k_errno, sizeof(__pyx_k_errno), 0, 1, 0, 1},
  {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
  {&__pyx_n_s_error_received, __pyx_k_error_received, sizeof(__pyx_k_error_received), 0, 0, 1, 1},
  {&__pyx_kp_u_error_status_in_uv_stream_t_list, __pyx_k_error_status_in_uv_stream_t_list, sizeof(__pyx_k_error_status_in_uv_stream_t_list), 0, 1, 0, 0},
  {&__pyx_kp_u_error_status_in_uv_stream_t_read, __pyx_k_error_status_in_uv_stream_t_read, sizeof(__pyx_k_error_status_in_uv_stream_t_read), 0, 1, 0, 0},
  {&__pyx_kp_u_error_status_in_uv_stream_t_shut, __pyx_k_error_status_in_uv_stream_t_shut, sizeof(__pyx_k_error_status_in_uv_stream_t_shut), 0, 1, 0, 0},
  {&__pyx_kp_u_error_status_in_uv_stream_t_writ, __pyx_k_error_status_in_uv_stream_t_writ, sizeof(__pyx_k_error_status_in_uv_stream_t_writ), 0, 1, 0, 0},
  {&__pyx_kp_u_error_while_attempting_to_bind_o, __pyx_k_error_while_attempting_to_bind_o, sizeof(__pyx_k_error_while_attempting_to_bind_o), 0, 1, 0, 0},
  {&__pyx_n_s_ex, __pyx_k_ex, sizeof(__pyx_k_ex), 0, 0, 1, 1},
  {&__pyx_n_s_exc, __pyx_k_exc, sizeof(__pyx_k_exc), 0, 0, 1, 1},
  {&__pyx_n_s_exc_info, __pyx_k_exc_info, sizeof(__pyx_k_exc_info), 0, 0, 1, 1},
  {&__pyx_n_s_exception, __pyx_k_exception, sizeof(__pyx_k_exception), 0, 0, 1, 1},
  {&__pyx_n_u_exception, __pyx_k_exception, sizeof(__pyx_k_exception), 0, 1, 0, 1},
  {&__pyx_kp_u_exception_in_Task___repr, __pyx_k_exception_in_Task___repr, sizeof(__pyx_k_exception_in_Task___repr), 0, 1, 0, 0},
  {&__pyx_n_s_executable, __pyx_k_executable, sizeof(__pyx_k_executable), 0, 0, 1, 1},
  {&__pyx_n_s_executor, __pyx_k_executor, sizeof(__pyx_k_executor), 0, 0, 1, 1},
  {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
  {&__pyx_n_s_extra, __pyx_k_extra, sizeof(__pyx_k_extra), 0, 0, 1, 1},
  {&__pyx_n_s_extract, __pyx_k_extract, sizeof(__pyx_k_extract), 0, 0, 1, 1},
  {&__pyx_n_s_family, __pyx_k_family, sizeof(__pyx_k_family), 0, 0, 1, 1},
  {&__pyx_kp_u_fatal_Could_not_advance__StreamW, __pyx_k_fatal_Could_not_advance__StreamW, sizeof(__pyx_k_fatal_Could_not_advance__StreamW), 0, 1, 0, 0},
  {&__pyx_n_s_fatal_error, __pyx_k_fatal_error, sizeof(__pyx_k_fatal_error), 0, 0, 1, 1},
  {&__pyx_kp_u_fatal_sent_0_in_advance_uv_buf, __pyx_k_fatal_sent_0_in_advance_uv_buf, sizeof(__pyx_k_fatal_sent_0_in_advance_uv_buf), 0, 1, 0, 0},
  {&__pyx_n_s_fd, __pyx_k_fd, sizeof(__pyx_k_fd), 0, 0, 1, 1},
  {&__pyx_kp_u_fd_2, __pyx_k_fd_2, sizeof(__pyx_k_fd_2), 0, 1, 0, 0},
  {&__pyx_n_s_fileno, __pyx_k_fileno, sizeof(__pyx_k_fileno), 0, 0, 1, 1},
  {&__pyx_n_s_fileobj, __pyx_k_fileobj, sizeof(__pyx_k_fileobj), 0, 0, 1, 1},
  {&__pyx_n_s_finalize, __pyx_k_finalize, sizeof(__pyx_k_finalize), 0, 0, 1, 1},
  {&__pyx_n_s_finalizer, __pyx_k_finalizer, sizeof(__pyx_k_finalizer), 0, 0, 1, 1},
  {&__pyx_n_s_firstiter, __pyx_k_firstiter, sizeof(__pyx_k_firstiter), 0, 0, 1, 1},
  {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
  {&__pyx_n_s_flush, __pyx_k_flush, sizeof(__pyx_k_flush), 0, 0, 1, 1},
  {&__pyx_n_s_force_close, __pyx_k_force_close, sizeof(__pyx_k_force_close), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_format_list, __pyx_k_format_list, sizeof(__pyx_k_format_list), 0, 0, 1, 1},
  {&__pyx_n_s_frame, __pyx_k_frame, sizeof(__pyx_k_frame), 0, 0, 1, 1},
  {&__pyx_n_s_fspath, __pyx_k_fspath, sizeof(__pyx_k_fspath), 0, 0, 1, 1},
  {&__pyx_n_s_func, __pyx_k_func, sizeof(__pyx_k_func), 0, 0, 1, 1},
  {&__pyx_n_s_functools, __pyx_k_functools, sizeof(__pyx_k_functools), 0, 0, 1, 1},
  {&__pyx_n_s_fut, __pyx_k_fut, sizeof(__pyx_k_fut), 0, 0, 1, 1},
  {&__pyx_n_s_futures, __pyx_k_futures, sizeof(__pyx_k_futures), 0, 0, 1, 1},
  {&__pyx_n_s_gaierror, __pyx_k_gaierror, sizeof(__pyx_k_gaierror), 0, 0, 1, 1},
  {&__pyx_n_s_gather, __pyx_k_gather, sizeof(__pyx_k_gather), 0, 0, 1, 1},
  {&__pyx_n_s_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 0, 1, 1},
  {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_get_asyncgen_hooks, __pyx_k_get_asyncgen_hooks, sizeof(__pyx_k_get_asyncgen_hooks), 0, 0, 1, 1},
  {&__pyx_n_u_get_asyncgen_hooks, __pyx_k_get_asyncgen_hooks, sizeof(__pyx_k_get_asyncgen_hooks), 0, 1, 0, 1},
  {&__pyx_n_s_get_buffer, __pyx_k_get_buffer, sizeof(__pyx_k_get_buffer), 0, 0, 1, 1},
  {&__pyx_n_u_get_buffer, __pyx_k_get_buffer, sizeof(__pyx_k_get_buffer), 0, 1, 0, 1},
  {&__pyx_kp_u_get_buffer_returned_an_empty_buf, __pyx_k_get_buffer_returned_an_empty_buf, sizeof(__pyx_k_get_buffer_returned_an_empty_buf), 0, 1, 0, 0},
  {&__pyx_n_s_get_coroutine_origin_tracking_de, __pyx_k_get_coroutine_origin_tracking_de, sizeof(__pyx_k_get_coroutine_origin_tracking_de), 0, 0, 1, 1},
  {&__pyx_n_s_get_coroutine_wrapper, __pyx_k_get_coroutine_wrapper, sizeof(__pyx_k_get_coroutine_wrapper), 0, 0, 1, 1},
  {&__pyx_n_s_get_debug, __pyx_k_get_debug, sizeof(__pyx_k_get_debug), 0, 0, 1, 1},
  {&__pyx_n_s_get_event_loop, __pyx_k_get_event_loop, sizeof(__pyx_k_get_event_loop), 0, 0, 1, 1},
  {&__pyx_n_s_get_extra_info, __pyx_k_get_extra_info, sizeof(__pyx_k_get_extra_info), 0, 0, 1, 1},
  {&__pyx_n_s_get_extra_info_2, __pyx_k_get_extra_info_2, sizeof(__pyx_k_get_extra_info_2), 0, 0, 1, 1},
  {&__pyx_n_s_get_inheritable, __pyx_k_get_inheritable, sizeof(__pyx_k_get_inheritable), 0, 0, 1, 1},
  {&__pyx_n_s_get_protocol, __pyx_k_get_protocol, sizeof(__pyx_k_get_protocol), 0, 0, 1, 1},
  {&__pyx_n_u_get_running_loop, __pyx_k_get_running_loop, sizeof(__pyx_k_get_running_loop), 0, 1, 0, 1},
  {&__pyx_n_s_get_write_buffer_size, __pyx_k_get_write_buffer_size, sizeof(__pyx_k_get_write_buffer_size), 0, 0, 1, 1},
  {&__pyx_n_s_getaddrinfo, __pyx_k_getaddrinfo, sizeof(__pyx_k_getaddrinfo), 0, 0, 1, 1},
  {&__pyx_kp_u_getaddrinfo_returned_empty_list, __pyx_k_getaddrinfo_returned_empty_list, sizeof(__pyx_k_getaddrinfo_returned_empty_list), 0, 1, 0, 0},
  {&__pyx_kp_u_getaddrinfo_returned_empty_list_2, __pyx_k_getaddrinfo_returned_empty_list_2, sizeof(__pyx_k_getaddrinfo_returned_empty_list_2), 0, 1, 0, 0},
  {&__pyx_n_s_getframe, __pyx_k_getframe, sizeof(__pyx_k_getframe), 0, 0, 1, 1},
  {&__pyx_n_s_getnameinfo, __pyx_k_getnameinfo, sizeof(__pyx_k_getnameinfo), 0, 0, 1, 1},
  {&__pyx_kp_u_getnameinfo_argument_1_must_be_a, __pyx_k_getnameinfo_argument_1_must_be_a, sizeof(__pyx_k_getnameinfo_argument_1_must_be_a), 0, 1, 0, 0},
  {&__pyx_kp_u_getnameinfo_flowinfo_must_be_0_1, __pyx_k_getnameinfo_flowinfo_must_be_0_1, sizeof(__pyx_k_getnameinfo_flowinfo_must_be_0_1), 0, 1, 0, 0},
  {&__pyx_n_s_getpeercert, __pyx_k_getpeercert, sizeof(__pyx_k_getpeercert), 0, 0, 1, 1},
  {&__pyx_n_s_getpeername, __pyx_k_getpeername, sizeof(__pyx_k_getpeername), 0, 0, 1, 1},
  {&__pyx_n_s_getservbyname, __pyx_k_getservbyname, sizeof(__pyx_k_getservbyname), 0, 0, 1, 1},
  {&__pyx_kp_u_getsockaddrarg_flowinfo_must_be, __pyx_k_getsockaddrarg_flowinfo_must_be, sizeof(__pyx_k_getsockaddrarg_flowinfo_must_be), 0, 1, 0, 0},
  {&__pyx_kp_u_getsockaddrarg_scope_id_must_be, __pyx_k_getsockaddrarg_scope_id_must_be, sizeof(__pyx_k_getsockaddrarg_scope_id_must_be), 0, 1, 0, 0},
  {&__pyx_n_s_getsockname, __pyx_k_getsockname, sizeof(__pyx_k_getsockname), 0, 0, 1, 1},
  {&__pyx_n_s_getsockopt, __pyx_k_getsockopt, sizeof(__pyx_k_getsockopt), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_gettimeout, __pyx_k_gettimeout, sizeof(__pyx_k_gettimeout), 0, 0, 1, 1},
  {&__pyx_n_u_handle, __pyx_k_handle, sizeof(__pyx_k_handle), 0, 1, 0, 1},
  {&__pyx_kp_u_handle_data_is_NULL_in___close_a, __pyx_k_handle_data_is_NULL_in___close_a, sizeof(__pyx_k_handle_data_is_NULL_in___close_a), 0, 1, 0, 0},
  {&__pyx_kp_u_handle_loop_data_is_NULL_in___en, __pyx_k_handle_loop_data_is_NULL_in___en, sizeof(__pyx_k_handle_loop_data_is_NULL_in___en), 0, 1, 0, 0},
  {&__pyx_kp_u_handle_loop_is_NULL_in___ensure, __pyx_k_handle_loop_is_NULL_in___ensure, sizeof(__pyx_k_handle_loop_is_NULL_in___ensure), 0, 1, 0, 0},
  {&__pyx_n_s_handshake_exc, __pyx_k_handshake_exc, sizeof(__pyx_k_handshake_exc), 0, 0, 1, 1},
  {&__pyx_kp_u_handshake_in_progress_or_complet, __pyx_k_handshake_in_progress_or_complet, sizeof(__pyx_k_handshake_in_progress_or_complet), 0, 1, 0, 0},
  {&__pyx_n_s_handshake_start_time, __pyx_k_handshake_start_time, sizeof(__pyx_k_handshake_start_time), 0, 0, 1, 1},
  {&__pyx_n_s_handshake_timeout_handle, __pyx_k_handshake_timeout_handle, sizeof(__pyx_k_handshake_timeout_handle), 0, 0, 1, 1},
  {&__pyx_kp_u_has_handle_0_in___uv_close_handl, __pyx_k_has_handle_0_in___uv_close_handl, sizeof(__pyx_k_has_handle_0_in___uv_close_handl), 0, 1, 0, 0},
  {&__pyx_kp_u_high, __pyx_k_high, sizeof(__pyx_k_high), 0, 1, 0, 0},
  {&__pyx_n_s_high_2, __pyx_k_high_2, sizeof(__pyx_k_high_2), 0, 0, 1, 1},
  {&__pyx_n_s_host, __pyx_k_host, sizeof(__pyx_k_host), 0, 0, 1, 1},
  {&__pyx_kp_u_host_and_port_was_not_specified, __pyx_k_host_and_port_was_not_specified, sizeof(__pyx_k_host_and_port_was_not_specified), 0, 1, 0, 0},
  {&__pyx_kp_u_host_must_be_a_str_or_bytes, __pyx_k_host_must_be_a_str_or_bytes, sizeof(__pyx_k_host_must_be_a_str_or_bytes), 0, 1, 0, 0},
  {&__pyx_kp_u_host_must_be_a_string_or_bytes_o, __pyx_k_host_must_be_a_string_or_bytes_o, sizeof(__pyx_k_host_must_be_a_string_or_bytes_o), 0, 1, 0, 0},
  {&__pyx_kp_u_host_port_and_sock_can_not_be_sp, __pyx_k_host_port_and_sock_can_not_be_sp, sizeof(__pyx_k_host_port_and_sock_can_not_be_sp), 0, 1, 0, 0},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_ident, __pyx_k_ident, sizeof(__pyx_k_ident), 0, 0, 1, 1},
  {&__pyx_n_u_idna, __pyx_k_idna, sizeof(__pyx_k_idna), 0, 1, 0, 1},
  {&__pyx_n_s_ignore_environment, __pyx_k_ignore_environment, sizeof(__pyx_k_ignore_environment), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_in_handshake, __pyx_k_in_handshake, sizeof(__pyx_k_in_handshake), 0, 0, 1, 1},
  {&__pyx_n_s_in_shutdown, __pyx_k_in_shutdown, sizeof(__pyx_k_in_shutdown), 0, 0, 1, 1},
  {&__pyx_n_u_inf, __pyx_k_inf, sizeof(__pyx_k_inf), 0, 1, 0, 1},
  {&__pyx_n_s_info, __pyx_k_info, sizeof(__pyx_k_info), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_inspect, __pyx_k_inspect, sizeof(__pyx_k_inspect), 0, 0, 1, 1},
  {&__pyx_kp_u_integer_argument_expected_got, __pyx_k_integer_argument_expected_got, sizeof(__pyx_k_integer_argument_expected_got), 0, 1, 0, 0},
  {&__pyx_kp_u_invalid_Handle_cb_type, __pyx_k_invalid_Handle_cb_type, sizeof(__pyx_k_invalid_Handle_cb_type), 0, 1, 0, 0},
  {&__pyx_kp_u_invalid__init_protocol_call, __pyx_k_invalid__init_protocol_call, sizeof(__pyx_k_invalid__init_protocol_call), 0, 1, 0, 0},
  {&__pyx_kp_u_invalid_data_in_writebuf_an_inst, __pyx_k_invalid_data_in_writebuf_an_inst, sizeof(__pyx_k_invalid_data_in_writebuf_an_inst), 0, 1, 0, 0},
  {&__pyx_kp_u_invalid_socket_family_expected_A, __pyx_k_invalid_socket_family_expected_A, sizeof(__pyx_k_invalid_socket_family_expected_A), 0, 1, 0, 0},
  {&__pyx_kp_u_invalid_waiter_object_r_expected, __pyx_k_invalid_waiter_object_r_expected, sizeof(__pyx_k_invalid_waiter_object_r_expected), 0, 1, 0, 0},
  {&__pyx_n_s_io_refs, __pyx_k_io_refs, sizeof(__pyx_k_io_refs), 0, 0, 1, 1},
  {&__pyx_kp_u_is_alive_but__handle_data_is_no, __pyx_k_is_alive_but__handle_data_is_no, sizeof(__pyx_k_is_alive_but__handle_data_is_no), 0, 1, 0, 0},
  {&__pyx_kp_u_is_alive_but__handle_is_NULL, __pyx_k_is_alive_but__handle_is_NULL, sizeof(__pyx_k_is_alive_but__handle_is_NULL), 0, 1, 0, 0},
  {&__pyx_kp_u_is_alive_but__handle_loop_is_no, __pyx_k_is_alive_but__handle_loop_is_no, sizeof(__pyx_k_is_alive_but__handle_loop_is_no), 0, 1, 0, 0},
  {&__pyx_kp_u_is_alive_but__loop_is_None, __pyx_k_is_alive_but__loop_is_None, sizeof(__pyx_k_is_alive_but__loop_is_None), 0, 1, 0, 0},
  {&__pyx_n_s_is_closed, __pyx_k_is_closed, sizeof(__pyx_k_is_closed), 0, 0, 1, 1},
  {&__pyx_n_s_is_closing, __pyx_k_is_closing, sizeof(__pyx_k_is_closing), 0, 0, 1, 1},
  {&__pyx_kp_u_is_not_supported_by_start_tls, __pyx_k_is_not_supported_by_start_tls, sizeof(__pyx_k_is_not_supported_by_start_tls), 0, 1, 0, 0},
  {&__pyx_kp_u_is_not_supposed_to_be_instantia, __pyx_k_is_not_supposed_to_be_instantia, sizeof(__pyx_k_is_not_supposed_to_be_instantia), 0, 1, 0, 0},
  {&__pyx_kp_u_is_open_in___dealloc___with_loo, __pyx_k_is_open_in___dealloc___with_loo, sizeof(__pyx_k_is_open_in___dealloc___with_loo), 0, 1, 0, 0},
  {&__pyx_n_s_is_reading, __pyx_k_is_reading, sizeof(__pyx_k_is_reading), 0, 0, 1, 1},
  {&__pyx_n_s_is_running, __pyx_k_is_running, sizeof(__pyx_k_is_running), 0, 0, 1, 1},
  {&__pyx_n_s_iscoroutine, __pyx_k_iscoroutine, sizeof(__pyx_k_iscoroutine), 0, 0, 1, 1},
  {&__pyx_n_s_iscoroutinefunction, __pyx_k_iscoroutinefunction, sizeof(__pyx_k_iscoroutinefunction), 0, 0, 1, 1},
  {&__pyx_n_u_isfuture, __pyx_k_isfuture, sizeof(__pyx_k_isfuture), 0, 1, 0, 1},
  {&__pyx_n_s_isgenerator, __pyx_k_isgenerator, sizeof(__pyx_k_isgenerator), 0, 0, 1, 1},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_itertools, __pyx_k_itertools, sizeof(__pyx_k_itertools), 0, 0, 1, 1},
  {&__pyx_n_s_keep_open, __pyx_k_keep_open, sizeof(__pyx_k_keep_open), 0, 0, 1, 1},
  {&__pyx_kp_u_laddr_s, __pyx_k_laddr_s, sizeof(__pyx_k_laddr_s), 0, 1, 0, 0},
  {&__pyx_n_s_limit, __pyx_k_limit, sizeof(__pyx_k_limit), 0, 0, 1, 1},
  {&__pyx_kp_u_listen_method, __pyx_k_listen_method, sizeof(__pyx_k_listen_method), 0, 1, 0, 0},
  {&__pyx_n_s_local_addr, __pyx_k_local_addr, sizeof(__pyx_k_local_addr), 0, 0, 1, 1},
  {&__pyx_kp_u_local_addr_must_be_a_tuple_of_ho, __pyx_k_local_addr_must_be_a_tuple_of_ho, sizeof(__pyx_k_local_addr_must_be_a_tuple_of_ho), 0, 1, 0, 0},
  {&__pyx_n_s_log, __pyx_k_log, sizeof(__pyx_k_log), 0, 0, 1, 1},
  {&__pyx_n_s_log_destroy_pending, __pyx_k_log_destroy_pending, sizeof(__pyx_k_log_destroy_pending), 0, 0, 1, 1},
  {&__pyx_n_s_logger, __pyx_k_logger, sizeof(__pyx_k_logger), 0, 0, 1, 1},
  {&__pyx_n_s_lookup_lines, __pyx_k_lookup_lines, sizeof(__pyx_k_lookup_lines), 0, 0, 1, 1},
  {&__pyx_n_s_loop, __pyx_k_loop, sizeof(__pyx_k_loop), 0, 0, 1, 1},
  {&__pyx_n_s_loop_2, __pyx_k_loop_2, sizeof(__pyx_k_loop_2), 0, 0, 1, 1},
  {&__pyx_kp_u_loop__exec_queued_writes, __pyx_k_loop__exec_queued_writes, sizeof(__pyx_k_loop__exec_queued_writes), 0, 1, 0, 0},
  {&__pyx_kp_u_loop__on_idle, __pyx_k_loop__on_idle, sizeof(__pyx_k_loop__on_idle), 0, 1, 0, 0},
  {&__pyx_kp_u_loop__queued_streams_are_not_emp, __pyx_k_loop__queued_streams_are_not_emp, sizeof(__pyx_k_loop__queued_streams_are_not_emp), 0, 1, 0, 0},
  {&__pyx_kp_u_loop_set_debug_False_cannot_unse, __pyx_k_loop_set_debug_False_cannot_unse, sizeof(__pyx_k_loop_set_debug_False_cannot_unse), 0, 1, 0, 0},
  {&__pyx_kp_u_loop_set_debug_True_cannot_set_d, __pyx_k_loop_set_debug_True_cannot_set_d, sizeof(__pyx_k_loop_set_debug_True_cannot_set_d), 0, 1, 0, 0},
  {&__pyx_n_s_low, __pyx_k_low, sizeof(__pyx_k_low), 0, 0, 1, 1},
  {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_main_thread, __pyx_k_main_thread, sizeof(__pyx_k_main_thread), 0, 0, 1, 1},
  {&__pyx_kp_u_makefile_method, __pyx_k_makefile_method, sizeof(__pyx_k_makefile_method), 0, 1, 0, 0},
  {&__pyx_n_s_mark_closed, __pyx_k_mark_closed, sizeof(__pyx_k_mark_closed), 0, 0, 1, 1},
  {&__pyx_n_s_memoryview, __pyx_k_memoryview, sizeof(__pyx_k_memoryview), 0, 0, 1, 1},
  {&__pyx_n_s_message, __pyx_k_message, sizeof(__pyx_k_message), 0, 0, 1, 1},
  {&__pyx_n_u_message, __pyx_k_message, sizeof(__pyx_k_message), 0, 1, 0, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_u_missing, __pyx_k_missing, sizeof(__pyx_k_missing), 0, 1, 0, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_monotonic, __pyx_k_monotonic, sizeof(__pyx_k_monotonic), 0, 0, 1, 1},
  {&__pyx_n_s_msg, __pyx_k_msg, sizeof(__pyx_k_msg), 0, 0, 1, 1},
  {&__pyx_kp_u_must_be_0, __pyx_k_must_be_0, sizeof(__pyx_k_must_be_0), 0, 1, 0, 0},
  {&__pyx_kp_u_must_be_low, __pyx_k_must_be_low, sizeof(__pyx_k_must_be_low), 0, 1, 0, 0},
  {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_u_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 1, 0, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_kp_u_new_callbacks_were_queued_during, __pyx_k_new_callbacks_were_queued_during, sizeof(__pyx_k_new_callbacks_were_queued_during), 0, 1, 0, 0},
  {&__pyx_kp_u_new_poll_handles_were_queued_dur, __pyx_k_new_poll_handles_were_queued_dur, sizeof(__pyx_k_new_poll_handles_were_queued_dur), 0, 1, 0, 0},
  {&__pyx_kp_u_new_timers_were_queued_during_lo, __pyx_k_new_timers_were_queued_during_lo, sizeof(__pyx_k_new_timers_were_queued_during_lo), 0, 1, 0, 0},
  {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
  {&__pyx_kp_u_no_path_and_sock_were_specified, __pyx_k_no_path_and_sock_were_specified, sizeof(__pyx_k_no_path_and_sock_were_specified), 0, 1, 0, 0},
  {&__pyx_kp_u_no_python_buffer_is_allocated_in, __pyx_k_no_python_buffer_is_allocated_in, sizeof(__pyx_k_no_python_buffer_is_allocated_in), 0, 1, 0, 0},
  {&__pyx_kp_u_no_security_layer_present, __pyx_k_no_security_layer_present, sizeof(__pyx_k_no_security_layer_present), 0, 1, 0, 0},
  {&__pyx_n_s_noop, __pyx_k_noop, sizeof(__pyx_k_noop), 0, 0, 1, 1},
  {&__pyx_n_s_noop_2, __pyx_k_noop_2, sizeof(__pyx_k_noop_2), 0, 0, 1, 1},
  {&__pyx_kp_u_not_holding_the_import_lock, __pyx_k_not_holding_the_import_lock, sizeof(__pyx_k_not_holding_the_import_lock), 0, 1, 0, 0},
  {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
  {&__pyx_kp_u_object_created_at_most_recent_ca, __pyx_k_object_created_at_most_recent_ca, sizeof(__pyx_k_object_created_at_most_recent_ca), 0, 1, 0, 0},
  {&__pyx_kp_u_objs_handles, __pyx_k_objs_handles, sizeof(__pyx_k_objs_handles), 0, 1, 0, 0},
  {&__pyx_n_s_offset, __pyx_k_offset, sizeof(__pyx_k_offset), 0, 0, 1, 1},
  {&__pyx_n_s_on_handshake_complete, __pyx_k_on_handshake_complete, sizeof(__pyx_k_on_handshake_complete), 0, 0, 1, 1},
  {&__pyx_n_s_on_ssl_connected, __pyx_k_on_ssl_connected, sizeof(__pyx_k_on_ssl_connected), 0, 0, 1, 1},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_kp_u_open__StreamWriteContext_is_bein, __pyx_k_open__StreamWriteContext_is_bein, sizeof(__pyx_k_open__StreamWriteContext_is_bein), 0, 1, 0, 0},
  {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
  {&__pyx_n_s_partial, __pyx_k_partial, sizeof(__pyx_k_partial), 0, 0, 1, 1},
  {&__pyx_n_s_pass_fds, __pyx_k_pass_fds, sizeof(__pyx_k_pass_fds), 0, 0, 1, 1},
  {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
  {&__pyx_kp_u_path_and_sock_can_not_be_specifi, __pyx_k_path_and_sock_can_not_be_specifi, sizeof(__pyx_k_path_and_sock_can_not_be_specifi), 0, 1, 0, 0},
  {&__pyx_kp_u_path_was_not_specified_and_no_so, __pyx_k_path_was_not_specified_and_no_so, sizeof(__pyx_k_path_was_not_specified_and_no_so), 0, 1, 0, 0},
  {&__pyx_n_s_pause_reading, __pyx_k_pause_reading, sizeof(__pyx_k_pause_reading), 0, 0, 1, 1},
  {&__pyx_n_s_pause_writing, __pyx_k_pause_writing, sizeof(__pyx_k_pause_writing), 0, 0, 1, 1},
  {&__pyx_n_s_paused, __pyx_k_paused, sizeof(__pyx_k_paused), 0, 0, 1, 1},
  {&__pyx_n_s_peercert, __pyx_k_peercert, sizeof(__pyx_k_peercert), 0, 0, 1, 1},
  {&__pyx_n_u_peername, __pyx_k_peername, sizeof(__pyx_k_peername), 0, 1, 0, 1},
  {&__pyx_n_s_pending, __pyx_k_pending, sizeof(__pyx_k_pending), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pipe, __pyx_k_pipe, sizeof(__pyx_k_pipe), 0, 0, 1, 1},
  {&__pyx_n_u_pipe, __pyx_k_pipe, sizeof(__pyx_k_pipe), 0, 1, 0, 1},
  {&__pyx_kp_u_pipe_2, __pyx_k_pipe_2, sizeof(__pyx_k_pipe_2), 0, 1, 0, 0},
  {&__pyx_n_s_pipe_connection_lost, __pyx_k_pipe_connection_lost, sizeof(__pyx_k_pipe_connection_lost), 0, 0, 1, 1},
  {&__pyx_n_s_pipe_data_received, __pyx_k_pipe_data_received, sizeof(__pyx_k_pipe_data_received), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_popleft, __pyx_k_popleft, sizeof(__pyx_k_popleft), 0, 0, 1, 1},
  {&__pyx_n_s_port, __pyx_k_port, sizeof(__pyx_k_port), 0, 0, 1, 1},
  {&__pyx_kp_u_port_must_be_a_str_bytes_or_int, __pyx_k_port_must_be_a_str_bytes_or_int, sizeof(__pyx_k_port_must_be_a_str_bytes_or_int), 0, 1, 0, 0},
  {&__pyx_n_s_preexec_fn, __pyx_k_preexec_fn, sizeof(__pyx_k_preexec_fn), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_u_print_debug_info, __pyx_k_print_debug_info, sizeof(__pyx_k_print_debug_info), 0, 1, 0, 1},
  {&__pyx_n_s_proc, __pyx_k_proc, sizeof(__pyx_k_proc), 0, 0, 1, 1},
  {&__pyx_n_s_process_exited, __pyx_k_process_exited, sizeof(__pyx_k_process_exited), 0, 0, 1, 1},
  {&__pyx_n_s_process_write_backlog, __pyx_k_process_write_backlog, sizeof(__pyx_k_process_write_backlog), 0, 0, 1, 1},
  {&__pyx_n_s_program, __pyx_k_program, sizeof(__pyx_k_program), 0, 0, 1, 1},
  {&__pyx_n_s_property, __pyx_k_property, sizeof(__pyx_k_property), 0, 0, 1, 1},
  {&__pyx_n_s_proto, __pyx_k_proto, sizeof(__pyx_k_proto), 0, 0, 1, 1},
  {&__pyx_n_s_proto_factory, __pyx_k_proto_factory, sizeof(__pyx_k_proto_factory), 0, 0, 1, 1},
  {&__pyx_n_s_protocol, __pyx_k_protocol, sizeof(__pyx_k_protocol), 0, 0, 1, 1},
  {&__pyx_n_u_protocol, __pyx_k_protocol, sizeof(__pyx_k_protocol), 0, 1, 0, 1},
  {&__pyx_n_s_protocol_factory, __pyx_k_protocol_factory, sizeof(__pyx_k_protocol_factory), 0, 0, 1, 1},
  {&__pyx_kp_u_protocol_is_not_set_cannot_call, __pyx_k_protocol_is_not_set_cannot_call, sizeof(__pyx_k_protocol_is_not_set_cannot_call), 0, 1, 0, 0},
  {&__pyx_kp_u_protocol_is_required, __pyx_k_protocol_is_required, sizeof(__pyx_k_protocol_is_required), 0, 1, 0, 0},
  {&__pyx_kp_u_protocol_pause_writing_failed, __pyx_k_protocol_pause_writing_failed, sizeof(__pyx_k_protocol_pause_writing_failed), 0, 1, 0, 0},
  {&__pyx_n_s_protocol_paused, __pyx_k_protocol_paused, sizeof(__pyx_k_protocol_paused), 0, 0, 1, 1},
  {&__pyx_kp_u_protocol_resume_writing_failed, __pyx_k_protocol_resume_writing_failed, sizeof(__pyx_k_protocol_resume_writing_failed), 0, 1, 0, 0},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_PseudoSocket, __pyx_k_pyx_unpickle_PseudoSocket, sizeof(__pyx_k_pyx_unpickle_PseudoSocket), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle__SSLPipe, __pyx_k_pyx_unpickle__SSLPipe, sizeof(__pyx_k_pyx_unpickle__SSLPipe), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_u_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 1, 0, 1},
  {&__pyx_kp_u_r_SSL_handshake_took_1f_ms, __pyx_k_r_SSL_handshake_took_1f_ms, sizeof(__pyx_k_r_SSL_handshake_took_1f_ms), 0, 1, 0, 0},
  {&__pyx_kp_u_r_fileno_returned_non_integer, __pyx_k_r_fileno_returned_non_integer, sizeof(__pyx_k_r_fileno_returned_non_integer), 0, 1, 0, 0},
  {&__pyx_kp_u_r_received_EOF, __pyx_k_r_received_EOF, sizeof(__pyx_k_r_received_EOF), 0, 1, 0, 0},
  {&__pyx_kp_u_r_s, __pyx_k_r_s, sizeof(__pyx_k_r_s), 0, 1, 0, 0},
  {&__pyx_kp_u_r_starts_SSL_handshake, __pyx_k_r_starts_SSL_handshake, sizeof(__pyx_k_r_starts_SSL_handshake), 0, 1, 0, 0},
  {&__pyx_kp_u_raddr_s, __pyx_k_raddr_s, sizeof(__pyx_k_raddr_s), 0, 1, 0, 0},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
  {&__pyx_n_s_reason, __pyx_k_reason, sizeof(__pyx_k_reason), 0, 0, 1, 1},
  {&__pyx_n_u_reason, __pyx_k_reason, sizeof(__pyx_k_reason), 0, 1, 0, 1},
  {&__pyx_kp_u_reason_2, __pyx_k_reason_2, sizeof(__pyx_k_reason_2), 0, 1, 0, 0},
  {&__pyx_n_s_recv, __pyx_k_recv, sizeof(__pyx_k_recv), 0, 0, 1, 1},
  {&__pyx_n_s_recv_into, __pyx_k_recv_into, sizeof(__pyx_k_recv_into), 0, 0, 1, 1},
  {&__pyx_kp_u_recv_into_method, __pyx_k_recv_into_method, sizeof(__pyx_k_recv_into_method), 0, 1, 0, 0},
  {&__pyx_kp_u_recv_method, __pyx_k_recv_method, sizeof(__pyx_k_recv_method), 0, 1, 0, 0},
  {&__pyx_n_s_recvfrom, __pyx_k_recvfrom, sizeof(__pyx_k_recvfrom), 0, 0, 1, 1},
  {&__pyx_kp_u_recvfrom_into_method, __pyx_k_recvfrom_into_method, sizeof(__pyx_k_recvfrom_into_method), 0, 1, 0, 0},
  {&__pyx_kp_u_recvfrom_method, __pyx_k_recvfrom_method, sizeof(__pyx_k_recvfrom_method), 0, 1, 0, 0},
  {&__pyx_kp_u_recvmsg_into_method, __pyx_k_recvmsg_into_method, sizeof(__pyx_k_recvmsg_into_method), 0, 1, 0, 0},
  {&__pyx_kp_u_recvmsg_method, __pyx_k_recvmsg_method, sizeof(__pyx_k_recvmsg_method), 0, 1, 0, 0},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_remote_addr, __pyx_k_remote_addr, sizeof(__pyx_k_remote_addr), 0, 0, 1, 1},
  {&__pyx_n_s_remove, __pyx_k_remove, sizeof(__pyx_k_remove), 0, 0, 1, 1},
  {&__pyx_n_s_remove_done_callback, __pyx_k_remove_done_callback, sizeof(__pyx_k_remove_done_callback), 0, 0, 1, 1},
  {&__pyx_n_s_remove_reader, __pyx_k_remove_reader, sizeof(__pyx_k_remove_reader), 0, 0, 1, 1},
  {&__pyx_n_s_remove_signal_handler, __pyx_k_remove_signal_handler, sizeof(__pyx_k_remove_signal_handler), 0, 0, 1, 1},
  {&__pyx_n_s_remove_writer, __pyx_k_remove_writer, sizeof(__pyx_k_remove_writer), 0, 0, 1, 1},
  {&__pyx_n_s_repr, __pyx_k_repr, sizeof(__pyx_k_repr), 0, 0, 1, 1},
  {&__pyx_n_s_restore_signals, __pyx_k_restore_signals, sizeof(__pyx_k_restore_signals), 0, 0, 1, 1},
  {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
  {&__pyx_n_s_resume_reading, __pyx_k_resume_reading, sizeof(__pyx_k_resume_reading), 0, 0, 1, 1},
  {&__pyx_n_s_resume_writing, __pyx_k_resume_writing, sizeof(__pyx_k_resume_writing), 0, 0, 1, 1},
  {&__pyx_n_s_return_exceptions, __pyx_k_return_exceptions, sizeof(__pyx_k_return_exceptions), 0, 0, 1, 1},
  {&__pyx_kp_u_returning_true_from_eof_received, __pyx_k_returning_true_from_eof_received, sizeof(__pyx_k_returning_true_from_eof_received), 0, 1, 0, 0},
  {&__pyx_n_s_reuse_address, __pyx_k_reuse_address, sizeof(__pyx_k_reuse_address), 0, 0, 1, 1},
  {&__pyx_n_s_reuse_port, __pyx_k_reuse_port, sizeof(__pyx_k_reuse_port), 0, 0, 1, 1},
  {&__pyx_kp_u_reuse_port_not_supported_by_sock, __pyx_k_reuse_port_not_supported_by_sock, sizeof(__pyx_k_reuse_port_not_supported_by_sock), 0, 1, 0, 0},
  {&__pyx_n_s_reverse, __pyx_k_reverse, sizeof(__pyx_k_reverse), 0, 0, 1, 1},
  {&__pyx_n_s_rstrip, __pyx_k_rstrip, sizeof(__pyx_k_rstrip), 0, 0, 1, 1},
  {&__pyx_n_s_run_forever, __pyx_k_run_forever, sizeof(__pyx_k_run_forever), 0, 0, 1, 1},
  {&__pyx_n_s_run_until_complete_locals_lambda, __pyx_k_run_until_complete_locals_lambda, sizeof(__pyx_k_run_until_complete_locals_lambda), 0, 0, 1, 1},
  {&__pyx_kp_u_running_closed_debug, __pyx_k_running_closed_debug, sizeof(__pyx_k_running_closed_debug), 0, 1, 0, 0},
  {&__pyx_kp_u_seconds_aborting_the_connection, __pyx_k_seconds_aborting_the_connection, sizeof(__pyx_k_seconds_aborting_the_connection), 0, 1, 0, 0},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_u_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 1, 0, 1},
  {&__pyx_n_s_self_2, __pyx_k_self_2, sizeof(__pyx_k_self_2), 0, 0, 1, 1},
  {&__pyx_kp_s_self_py_bufs_self_py_bufs_sml_se, __pyx_k_self_py_bufs_self_py_bufs_sml_se, sizeof(__pyx_k_self_py_bufs_self_py_bufs_sml_se), 0, 0, 1, 0},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_kp_u_send_method, __pyx_k_send_method, sizeof(__pyx_k_send_method), 0, 1, 0, 0},
  {&__pyx_kp_u_sendall_method, __pyx_k_sendall_method, sizeof(__pyx_k_sendall_method), 0, 1, 0, 0},
  {&__pyx_kp_u_sendfile_method, __pyx_k_sendfile_method, sizeof(__pyx_k_sendfile_method), 0, 1, 0, 0},
  {&__pyx_kp_u_sendmsg_afalg_method, __pyx_k_sendmsg_afalg_method, sizeof(__pyx_k_sendmsg_afalg_method), 0, 1, 0, 0},
  {&__pyx_kp_u_sendmsg_method, __pyx_k_sendmsg_method, sizeof(__pyx_k_sendmsg_method), 0, 1, 0, 0},
  {&__pyx_n_s_sendto, __pyx_k_sendto, sizeof(__pyx_k_sendto), 0, 0, 1, 1},
  {&__pyx_kp_u_sendto_method, __pyx_k_sendto_method, sizeof(__pyx_k_sendto_method), 0, 1, 0, 0},
  {&__pyx_n_s_server_hostname, __pyx_k_server_hostname, sizeof(__pyx_k_server_hostname), 0, 0, 1, 1},
  {&__pyx_n_s_server_hostname_2, __pyx_k_server_hostname_2, sizeof(__pyx_k_server_hostname_2), 0, 0, 1, 1},
  {&__pyx_kp_u_server_hostname_is_only_meaningf, __pyx_k_server_hostname_is_only_meaningf, sizeof(__pyx_k_server_hostname_is_only_meaningf), 0, 1, 0, 0},
  {&__pyx_n_s_server_side, __pyx_k_server_side, sizeof(__pyx_k_server_side), 0, 0, 1, 1},
  {&__pyx_n_s_server_side_2, __pyx_k_server_side_2, sizeof(__pyx_k_server_side_2), 0, 0, 1, 1},
  {&__pyx_kp_u_service_proto_not_found, __pyx_k_service_proto_not_found, sizeof(__pyx_k_service_proto_not_found), 0, 1, 0, 0},
  {&__pyx_n_s_session_established, __pyx_k_session_established, sizeof(__pyx_k_session_established), 0, 0, 1, 1},
  {&__pyx_n_s_set_app_protocol, __pyx_k_set_app_protocol, sizeof(__pyx_k_set_app_protocol), 0, 0, 1, 1},
  {&__pyx_n_s_set_asyncgen_hooks, __pyx_k_set_asyncgen_hooks, sizeof(__pyx_k_set_asyncgen_hooks), 0, 0, 1, 1},
  {&__pyx_n_s_set_coroutine_origin_tracking_de, __pyx_k_set_coroutine_origin_tracking_de, sizeof(__pyx_k_set_coroutine_origin_tracking_de), 0, 0, 1, 1},
  {&__pyx_n_s_set_coroutine_wrapper, __pyx_k_set_coroutine_wrapper, sizeof(__pyx_k_set_coroutine_wrapper), 0, 0, 1, 1},
  {&__pyx_n_s_set_debug, __pyx_k_set_debug, sizeof(__pyx_k_set_debug), 0, 0, 1, 1},
  {&__pyx_n_s_set_exception, __pyx_k_set_exception, sizeof(__pyx_k_set_exception), 0, 0, 1, 1},
  {&__pyx_n_s_set_inheritable, __pyx_k_set_inheritable, sizeof(__pyx_k_set_inheritable), 0, 0, 1, 1},
  {&__pyx_n_s_set_protocol, __pyx_k_set_protocol, sizeof(__pyx_k_set_protocol), 0, 0, 1, 1},
  {&__pyx_n_s_set_result, __pyx_k_set_result, sizeof(__pyx_k_set_result), 0, 0, 1, 1},
  {&__pyx_n_u_set_running_loop, __pyx_k_set_running_loop, sizeof(__pyx_k_set_running_loop), 0, 1, 0, 1},
  {&__pyx_n_s_set_wakeup_fd, __pyx_k_set_wakeup_fd, sizeof(__pyx_k_set_wakeup_fd), 0, 0, 1, 1},
  {&__pyx_kp_u_set_wakeup_fd_1_failed_s, __pyx_k_set_wakeup_fd_1_failed_s, sizeof(__pyx_k_set_wakeup_fd_1_failed_s), 0, 1, 0, 0},
  {&__pyx_kp_u_set_wakeup_fd_only_works_in_main, __pyx_k_set_wakeup_fd_only_works_in_main, sizeof(__pyx_k_set_wakeup_fd_only_works_in_main), 0, 1, 0, 0},
  {&__pyx_n_s_set_write_buffer_limits, __pyx_k_set_write_buffer_limits, sizeof(__pyx_k_set_write_buffer_limits), 0, 0, 1, 1},
  {&__pyx_n_s_setblocking, __pyx_k_setblocking, sizeof(__pyx_k_setblocking), 0, 0, 1, 1},
  {&__pyx_kp_u_setblocking_transport_sockets_ca, __pyx_k_setblocking_transport_sockets_ca, sizeof(__pyx_k_setblocking_transport_sockets_ca), 0, 1, 0, 0},
  {&__pyx_n_s_setsockopt, __pyx_k_setsockopt, sizeof(__pyx_k_setsockopt), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_settimeout, __pyx_k_settimeout, sizeof(__pyx_k_settimeout), 0, 0, 1, 1},
  {&__pyx_kp_u_settimeout_only_0_timeout_is_all, __pyx_k_settimeout_only_0_timeout_is_all, sizeof(__pyx_k_settimeout_only_0_timeout_is_all), 0, 1, 0, 0},
  {&__pyx_n_s_share, __pyx_k_share, sizeof(__pyx_k_share), 0, 0, 1, 1},
  {&__pyx_n_s_shell, __pyx_k_shell, sizeof(__pyx_k_shell), 0, 0, 1, 1},
  {&__pyx_kp_u_shell_must_be_False, __pyx_k_shell_must_be_False, sizeof(__pyx_k_shell_must_be_False), 0, 1, 0, 0},
  {&__pyx_kp_u_shell_must_be_True, __pyx_k_shell_must_be_True, sizeof(__pyx_k_shell_must_be_True), 0, 1, 0, 0},
  {&__pyx_n_s_shutdown, __pyx_k_shutdown, sizeof(__pyx_k_shutdown), 0, 0, 1, 1},
  {&__pyx_n_s_shutdown_asyncgens, __pyx_k_shutdown_asyncgens, sizeof(__pyx_k_shutdown_asyncgens), 0, 0, 1, 1},
  {&__pyx_kp_u_shutdown_in_progress, __pyx_k_shutdown_in_progress, sizeof(__pyx_k_shutdown_in_progress), 0, 1, 0, 0},
  {&__pyx_kp_u_shutdown_method, __pyx_k_shutdown_method, sizeof(__pyx_k_shutdown_method), 0, 1, 0, 0},
  {&__pyx_n_s_sig, __pyx_k_sig, sizeof(__pyx_k_sig), 0, 0, 1, 1},
  {&__pyx_kp_u_sig_cannot_be_caught, __pyx_k_sig_cannot_be_caught, sizeof(__pyx_k_sig_cannot_be_caught), 0, 1, 0, 0},
  {&__pyx_kp_u_sig_must_be_an_int_not_r, __pyx_k_sig_must_be_an_int_not_r, sizeof(__pyx_k_sig_must_be_an_int_not_r), 0, 1, 0, 0},
  {&__pyx_kp_u_sig_out_of_range_1, __pyx_k_sig_out_of_range_1, sizeof(__pyx_k_sig_out_of_range_1), 0, 1, 0, 0},
  {&__pyx_n_s_sighandler, __pyx_k_sighandler, sizeof(__pyx_k_sighandler), 0, 0, 1, 1},
  {&__pyx_n_s_siginterrupt, __pyx_k_siginterrupt, sizeof(__pyx_k_siginterrupt), 0, 0, 1, 1},
  {&__pyx_n_s_signal, __pyx_k_signal, sizeof(__pyx_k_signal), 0, 0, 1, 1},
  {&__pyx_n_s_signum, __pyx_k_signum, sizeof(__pyx_k_signum), 0, 0, 1, 1},
  {&__pyx_n_s_sleep, __pyx_k_sleep, sizeof(__pyx_k_sleep), 0, 0, 1, 1},
  {&__pyx_n_s_sock, __pyx_k_sock, sizeof(__pyx_k_sock), 0, 0, 1, 1},
  {&__pyx_n_s_sock_accept, __pyx_k_sock_accept, sizeof(__pyx_k_sock_accept), 0, 0, 1, 1},
  {&__pyx_n_s_sock_connect, __pyx_k_sock_connect, sizeof(__pyx_k_sock_connect), 0, 0, 1, 1},
  {&__pyx_n_s_sock_recv, __pyx_k_sock_recv, sizeof(__pyx_k_sock_recv), 0, 0, 1, 1},
  {&__pyx_n_s_sock_recv_into, __pyx_k_sock_recv_into, sizeof(__pyx_k_sock_recv_into), 0, 0, 1, 1},
  {&__pyx_kp_u_sock_recv_into_is_called_on_a_c, __pyx_k_sock_recv_into_is_called_on_a_c, sizeof(__pyx_k_sock_recv_into_is_called_on_a_c), 0, 1, 0, 0},
  {&__pyx_kp_u_sock_recv_is_called_on_a_cancel, __pyx_k_sock_recv_is_called_on_a_cancel, sizeof(__pyx_k_sock_recv_is_called_on_a_cancel), 0, 1, 0, 0},
  {&__pyx_n_s_sock_sendall, __pyx_k_sock_sendall, sizeof(__pyx_k_sock_sendall), 0, 0, 1, 1},
  {&__pyx_kp_u_sock_sendall_is_called_on_a_can, __pyx_k_sock_sendall_is_called_on_a_can, sizeof(__pyx_k_sock_sendall_is_called_on_a_can), 0, 1, 0, 0},
  {&__pyx_n_s_sockaddr, __pyx_k_sockaddr, sizeof(__pyx_k_sockaddr), 0, 0, 1, 1},
  {&__pyx_kp_u_sockaddr_must_be_a_tuple_of_2_3, __pyx_k_sockaddr_must_be_a_tuple_of_2_3, sizeof(__pyx_k_sockaddr_must_be_a_tuple_of_2_3), 0, 1, 0, 0},
  {&__pyx_kp_u_sockaddr_resolved_to_multiple_ad, __pyx_k_sockaddr_resolved_to_multiple_ad, sizeof(__pyx_k_sockaddr_resolved_to_multiple_ad), 0, 1, 0, 0},
  {&__pyx_kp_u_socket, __pyx_k_socket, sizeof(__pyx_k_socket), 0, 1, 0, 0},
  {&__pyx_n_s_socket_2, __pyx_k_socket_2, sizeof(__pyx_k_socket_2), 0, 0, 1, 1},
  {&__pyx_n_u_socket_2, __pyx_k_socket_2, sizeof(__pyx_k_socket_2), 0, 1, 0, 1},
  {&__pyx_kp_u_socket_modifier_keyword_argument, __pyx_k_socket_modifier_keyword_argument, sizeof(__pyx_k_socket_modifier_keyword_argument), 0, 1, 0, 0},
  {&__pyx_kp_u_socket_send_raised_exception, __pyx_k_socket_send_raised_exception, sizeof(__pyx_k_socket_send_raised_exception), 0, 1, 0, 0},
  {&__pyx_n_s_socketpair, __pyx_k_socketpair, sizeof(__pyx_k_socketpair), 0, 0, 1, 1},
  {&__pyx_kp_u_sockets, __pyx_k_sockets, sizeof(__pyx_k_sockets), 0, 1, 0, 0},
  {&__pyx_n_s_sockets_2, __pyx_k_sockets_2, sizeof(__pyx_k_sockets_2), 0, 0, 1, 1},
  {&__pyx_n_u_sockname, __pyx_k_sockname, sizeof(__pyx_k_sockname), 0, 1, 0, 1},
  {&__pyx_n_s_source, __pyx_k_source, sizeof(__pyx_k_source), 0, 0, 1, 1},
  {&__pyx_n_u_source_traceback, __pyx_k_source_traceback, sizeof(__pyx_k_source_traceback), 0, 1, 0, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_ssl, __pyx_k_ssl, sizeof(__pyx_k_ssl), 0, 0, 1, 1},
  {&__pyx_kp_u_ssl_argument_must_be_an_SSLConte, __pyx_k_ssl_argument_must_be_an_SSLConte, sizeof(__pyx_k_ssl_argument_must_be_an_SSLConte), 0, 1, 0, 0},
  {&__pyx_n_s_ssl_handshake_timeout, __pyx_k_ssl_handshake_timeout, sizeof(__pyx_k_ssl_handshake_timeout), 0, 0, 1, 1},
  {&__pyx_n_s_ssl_handshake_timeout_2, __pyx_k_ssl_handshake_timeout_2, sizeof(__pyx_k_ssl_handshake_timeout_2), 0, 0, 1, 1},
  {&__pyx_kp_u_ssl_handshake_timeout_is_only_me, __pyx_k_ssl_handshake_timeout_is_only_me, sizeof(__pyx_k_ssl_handshake_timeout_is_only_me), 0, 1, 0, 0},
  {&__pyx_kp_u_ssl_handshake_timeout_should_be, __pyx_k_ssl_handshake_timeout_should_be, sizeof(__pyx_k_ssl_handshake_timeout_should_be), 0, 1, 0, 0},
  {&__pyx_kp_u_ssl_is_expected_to_be_None_or_an, __pyx_k_ssl_is_expected_to_be_None_or_an, sizeof(__pyx_k_ssl_is_expected_to_be_None_or_an), 0, 1, 0, 0},
  {&__pyx_n_s_ssl_object, __pyx_k_ssl_object, sizeof(__pyx_k_ssl_object), 0, 0, 1, 1},
  {&__pyx_n_s_ssl_protocol, __pyx_k_ssl_protocol, sizeof(__pyx_k_ssl_protocol), 0, 0, 1, 1},
  {&__pyx_n_s_ssl_protocol_2, __pyx_k_ssl_protocol_2, sizeof(__pyx_k_ssl_protocol_2), 0, 0, 1, 1},
  {&__pyx_n_s_sslcontext, __pyx_k_sslcontext, sizeof(__pyx_k_sslcontext), 0, 0, 1, 1},
  {&__pyx_n_s_sslcontext_2, __pyx_k_sslcontext_2, sizeof(__pyx_k_sslcontext_2), 0, 0, 1, 1},
  {&__pyx_kp_u_sslcontext_is_expected_to_be_an, __pyx_k_sslcontext_is_expected_to_be_an, sizeof(__pyx_k_sslcontext_is_expected_to_be_an), 0, 1, 0, 0},
  {&__pyx_n_s_ssldata, __pyx_k_ssldata, sizeof(__pyx_k_ssldata), 0, 0, 1, 1},
  {&__pyx_n_s_sslobj, __pyx_k_sslobj, sizeof(__pyx_k_sslobj), 0, 0, 1, 1},
  {&__pyx_n_s_sslpipe, __pyx_k_sslpipe, sizeof(__pyx_k_sslpipe), 0, 0, 1, 1},
  {&__pyx_n_s_sslpipe_2, __pyx_k_sslpipe_2, sizeof(__pyx_k_sslpipe_2), 0, 0, 1, 1},
  {&__pyx_n_s_st_mode, __pyx_k_st_mode, sizeof(__pyx_k_st_mode), 0, 0, 1, 1},
  {&__pyx_n_s_start_handshake, __pyx_k_start_handshake, sizeof(__pyx_k_start_handshake), 0, 0, 1, 1},
  {&__pyx_kp_u_start_init_can_only_be_called, __pyx_k_start_init_can_only_be_called, sizeof(__pyx_k_start_init_can_only_be_called), 0, 1, 0, 0},
  {&__pyx_n_s_start_new_session, __pyx_k_start_new_session, sizeof(__pyx_k_start_new_session), 0, 0, 1, 1},
  {&__pyx_n_s_start_shutdown, __pyx_k_start_shutdown, sizeof(__pyx_k_start_shutdown), 0, 0, 1, 1},
  {&__pyx_n_s_start_tls, __pyx_k_start_tls, sizeof(__pyx_k_start_tls), 0, 0, 1, 1},
  {&__pyx_n_s_startupinfo, __pyx_k_startupinfo, sizeof(__pyx_k_startupinfo), 0, 0, 1, 1},
  {&__pyx_kp_u_startupinfo_is_not_supported, __pyx_k_startupinfo_is_not_supported, sizeof(__pyx_k_startupinfo_is_not_supported), 0, 1, 0, 0},
  {&__pyx_n_s_stat, __pyx_k_stat, sizeof(__pyx_k_stat), 0, 0, 1, 1},
  {&__pyx_n_s_stderr, __pyx_k_stderr, sizeof(__pyx_k_stderr), 0, 0, 1, 1},
  {&__pyx_n_s_stdin, __pyx_k_stdin, sizeof(__pyx_k_stdin), 0, 0, 1, 1},
  {&__pyx_n_s_stdio_fut, __pyx_k_stdio_fut, sizeof(__pyx_k_stdio_fut), 0, 0, 1, 1},
  {&__pyx_n_s_stdio_inited, __pyx_k_stdio_inited, sizeof(__pyx_k_stdio_inited), 0, 0, 1, 1},
  {&__pyx_n_s_stdout, __pyx_k_stdout, sizeof(__pyx_k_stdout), 0, 0, 1, 1},
  {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
  {&__pyx_kp_u_stream_is_open_after_UVStream__t, __pyx_k_stream_is_open_after_UVStream__t, sizeof(__pyx_k_stream_is_open_after_UVStream__t), 0, 1, 0, 0},
  {&__pyx_n_s_strerror, __pyx_k_strerror, sizeof(__pyx_k_strerror), 0, 0, 1, 1},
  {&__pyx_kp_u_string_is_expected, __pyx_k_string_is_expected, sizeof(__pyx_k_string_is_expected), 0, 1, 0, 0},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_submit, __pyx_k_submit, sizeof(__pyx_k_submit), 0, 0, 1, 1},
  {&__pyx_n_s_subprocess, __pyx_k_subprocess, sizeof(__pyx_k_subprocess), 0, 0, 1, 1},
  {&__pyx_kp_u_subprocess_STDOUT_is_supported_o, __pyx_k_subprocess_STDOUT_is_supported_o, sizeof(__pyx_k_subprocess_STDOUT_is_supported_o), 0, 1, 0, 0},
  {&__pyx_n_s_subprocess_exec, __pyx_k_subprocess_exec, sizeof(__pyx_k_subprocess_exec), 0, 0, 1, 1},
  {&__pyx_n_s_subprocess_run, __pyx_k_subprocess_run, sizeof(__pyx_k_subprocess_run), 0, 0, 1, 1},
  {&__pyx_n_s_subprocess_shell, __pyx_k_subprocess_shell, sizeof(__pyx_k_subprocess_shell), 0, 0, 1, 1},
  {&__pyx_n_s_subtract, __pyx_k_subtract, sizeof(__pyx_k_subtract), 0, 0, 1, 1},
  {&__pyx_n_s_super, __pyx_k_super, sizeof(__pyx_k_super), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_u_task, __pyx_k_task, sizeof(__pyx_k_task), 0, 1, 0, 1},
  {&__pyx_kp_u_task_factory_must_be_a_callable, __pyx_k_task_factory_must_be_a_callable, sizeof(__pyx_k_task_factory_must_be_a_callable), 0, 1, 0, 0},
  {&__pyx_n_u_tcp, __pyx_k_tcp, sizeof(__pyx_k_tcp), 0, 1, 0, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_test_coroutine_1, __pyx_k_test_coroutine_1, sizeof(__pyx_k_test_coroutine_1), 0, 0, 1, 1},
  {&__pyx_kp_u_the_socket_must_be_non_blocking, __pyx_k_the_socket_must_be_non_blocking, sizeof(__pyx_k_the_socket_must_be_non_blocking), 0, 1, 0, 0},
  {&__pyx_kp_u_this_event_loop_is_already_runni, __pyx_k_this_event_loop_is_already_runni, sizeof(__pyx_k_this_event_loop_is_already_runni), 0, 1, 0, 0},
  {&__pyx_n_s_threading, __pyx_k_threading, sizeof(__pyx_k_threading), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
  {&__pyx_n_s_timeout, __pyx_k_timeout, sizeof(__pyx_k_timeout), 0, 0, 1, 1},
  {&__pyx_n_s_tr, __pyx_k_tr, sizeof(__pyx_k_tr), 0, 0, 1, 1},
  {&__pyx_n_s_traceback, __pyx_k_traceback, sizeof(__pyx_k_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_traceback_2, __pyx_k_traceback_2, sizeof(__pyx_k_traceback_2), 0, 0, 1, 1},
  {&__pyx_n_s_transport, __pyx_k_transport, sizeof(__pyx_k_transport), 0, 0, 1, 1},
  {&__pyx_n_u_transport, __pyx_k_transport, sizeof(__pyx_k_transport), 0, 1, 0, 1},
  {&__pyx_kp_u_transport_2, __pyx_k_transport_2, sizeof(__pyx_k_transport_2), 0, 1, 0, 0},
  {&__pyx_n_s_transport_3, __pyx_k_transport_3, sizeof(__pyx_k_transport_3), 0, 0, 1, 1},
  {&__pyx_kp_u_transport_sockets_do_not_support, __pyx_k_transport_sockets_do_not_support, sizeof(__pyx_k_transport_sockets_do_not_support), 0, 1, 0, 0},
  {&__pyx_n_s_transports, __pyx_k_transports, sizeof(__pyx_k_transports), 0, 0, 1, 1},
  {&__pyx_kp_u_try_write_sent_all_data_and_ret, __pyx_k_try_write_sent_all_data_and_ret, sizeof(__pyx_k_try_write_sent_all_data_and_ret), 0, 1, 0, 0},
  {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
  {&__pyx_n_u_udp, __pyx_k_udp, sizeof(__pyx_k_udp), 0, 1, 0, 1},
  {&__pyx_kp_u_unable_to_listen_no_protocol_fac, __pyx_k_unable_to_listen_no_protocol_fac, sizeof(__pyx_k_unable_to_listen_no_protocol_fac), 0, 1, 0, 0},
  {&__pyx_kp_u_unable_to_perform_operation_on_r, __pyx_k_unable_to_perform_operation_on_r, sizeof(__pyx_k_unable_to_perform_operation_on_r), 0, 1, 0, 0},
  {&__pyx_kp_u_unable_to_start_the_loop_it_was, __pyx_k_unable_to_start_the_loop_it_was, sizeof(__pyx_k_unable_to_start_the_loop_it_was), 0, 1, 0, 0},
  {&__pyx_kp_u_unclosed_resource_r, __pyx_k_unclosed_resource_r, sizeof(__pyx_k_unclosed_resource_r), 0, 1, 0, 0},
  {&__pyx_kp_u_unclosed_resource_r_2, __pyx_k_unclosed_resource_r_2, sizeof(__pyx_k_unclosed_resource_r_2), 0, 1, 0, 0},
  {&__pyx_kp_u_unclosed_resource_r_could_not_se, __pyx_k_unclosed_resource_r_could_not_se, sizeof(__pyx_k_unclosed_resource_r_could_not_se), 0, 1, 0, 0},
  {&__pyx_kp_u_unclosed_transport_r, __pyx_k_unclosed_transport_r, sizeof(__pyx_k_unclosed_transport_r), 0, 1, 0, 0},
  {&__pyx_kp_u_unexpected_address_family, __pyx_k_unexpected_address_family, sizeof(__pyx_k_unexpected_address_family), 0, 1, 0, 0},
  {&__pyx_kp_u_unhandled_error_or_an_empty_buff, __pyx_k_unhandled_error_or_an_empty_buff, sizeof(__pyx_k_unhandled_error_or_an_empty_buff), 0, 1, 0, 0},
  {&__pyx_n_s_universal_newlines, __pyx_k_universal_newlines, sizeof(__pyx_k_universal_newlines), 0, 0, 1, 1},
  {&__pyx_kp_u_universal_newlines_must_be_False, __pyx_k_universal_newlines_must_be_False, sizeof(__pyx_k_universal_newlines_must_be_False), 0, 1, 0, 0},
  {&__pyx_kp_u_unopened_TCPServer, __pyx_k_unopened_TCPServer, sizeof(__pyx_k_unopened_TCPServer), 0, 1, 0, 0},
  {&__pyx_n_s_unwrap, __pyx_k_unwrap, sizeof(__pyx_k_unwrap), 0, 0, 1, 1},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {&__pyx_kp_u_uv_close_handle_cb_handle_loop, __pyx_k_uv_close_handle_cb_handle_loop, sizeof(__pyx_k_uv_close_handle_cb_handle_loop), 0, 1, 0, 0},
  {&__pyx_kp_u_uv_handle_t_current_freed_total, __pyx_k_uv_handle_t_current_freed_total, sizeof(__pyx_k_uv_handle_t_current_freed_total), 0, 1, 0, 0},
  {&__pyx_kp_u_uvloop_PseudoSocket_fd_family_s, __pyx_k_uvloop_PseudoSocket_fd_family_s, sizeof(__pyx_k_uvloop_PseudoSocket_fd_family_s), 0, 1, 0, 0},
  {&__pyx_kp_s_uvloop_handles_process_pyx, __pyx_k_uvloop_handles_process_pyx, sizeof(__pyx_k_uvloop_handles_process_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_uvloop_loop, __pyx_k_uvloop_loop, sizeof(__pyx_k_uvloop_loop), 0, 0, 1, 1},
  {&__pyx_kp_s_uvloop_loop_pyx, __pyx_k_uvloop_loop_pyx, sizeof(__pyx_k_uvloop_loop_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_uvloop_sleep_after_fork, __pyx_k_uvloop_sleep_after_fork, sizeof(__pyx_k_uvloop_sleep_after_fork), 0, 0, 1, 1},
  {&__pyx_kp_s_uvloop_sslproto_pyx, __pyx_k_uvloop_sslproto_pyx, sizeof(__pyx_k_uvloop_sslproto_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
  {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
  {&__pyx_n_s_wait, __pyx_k_wait, sizeof(__pyx_k_wait), 0, 0, 1, 1},
  {&__pyx_n_s_wait_closed, __pyx_k_wait_closed, sizeof(__pyx_k_wait_closed), 0, 0, 1, 1},
  {&__pyx_n_s_waiter, __pyx_k_waiter, sizeof(__pyx_k_waiter), 0, 0, 1, 1},
  {&__pyx_n_s_waiter_2, __pyx_k_waiter_2, sizeof(__pyx_k_waiter_2), 0, 0, 1, 1},
  {&__pyx_kp_u_waiter_is_not_None_in__call_conn, __pyx_k_waiter_is_not_None_in__call_conn, sizeof(__pyx_k_waiter_is_not_None_in__call_conn), 0, 1, 0, 0},
  {&__pyx_n_s_wakeup_waiter, __pyx_k_wakeup_waiter, sizeof(__pyx_k_wakeup_waiter), 0, 0, 1, 1},
  {&__pyx_n_s_walk_stack, __pyx_k_walk_stack, sizeof(__pyx_k_walk_stack), 0, 0, 1, 1},
  {&__pyx_n_s_warn, __pyx_k_warn, sizeof(__pyx_k_warn), 0, 0, 1, 1},
  {&__pyx_n_s_warn_on_full_buffer, __pyx_k_warn_on_full_buffer, sizeof(__pyx_k_warn_on_full_buffer), 0, 0, 1, 1},
  {&__pyx_n_s_warning, __pyx_k_warning, sizeof(__pyx_k_warning), 0, 0, 1, 1},
  {&__pyx_n_s_warnings, __pyx_k_warnings, sizeof(__pyx_k_warnings), 0, 0, 1, 1},
  {&__pyx_n_u_wb, __pyx_k_wb, sizeof(__pyx_k_wb), 0, 1, 0, 1},
  {&__pyx_n_s_weakref, __pyx_k_weakref, sizeof(__pyx_k_weakref), 0, 0, 1, 1},
  {&__pyx_n_s_when, __pyx_k_when, sizeof(__pyx_k_when), 0, 0, 1, 1},
  {&__pyx_kp_u_without_no_gc_clear_loop_was_se, __pyx_k_without_no_gc_clear_loop_was_se, sizeof(__pyx_k_without_no_gc_clear_loop_was_se), 0, 1, 0, 0},
  {&__pyx_n_s_wrap, __pyx_k_wrap, sizeof(__pyx_k_wrap), 0, 0, 1, 1},
  {&__pyx_n_s_wrap_bio, __pyx_k_wrap_bio, sizeof(__pyx_k_wrap_bio), 0, 0, 1, 1},
  {&__pyx_n_s_wrap_future, __pyx_k_wrap_future, sizeof(__pyx_k_wrap_future), 0, 0, 1, 1},
  {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {&__pyx_n_s_write_appdata, __pyx_k_write_appdata, sizeof(__pyx_k_write_appdata), 0, 0, 1, 1},
  {&__pyx_n_s_write_backlog, __pyx_k_write_backlog, sizeof(__pyx_k_write_backlog), 0, 0, 1, 1},
  {&__pyx_n_s_write_buffer_size, __pyx_k_write_buffer_size, sizeof(__pyx_k_write_buffer_size), 0, 0, 1, 1},
  {&__pyx_n_s_write_eof, __pyx_k_write_eof, sizeof(__pyx_k_write_eof), 0, 0, 1, 1},
  {&__pyx_n_s_writelines, __pyx_k_writelines, sizeof(__pyx_k_writelines), 0, 0, 1, 1},
  {&__pyx_n_s_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_property = __Pyx_GetBuiltinName(__pyx_n_s_property); if (!__pyx_builtin_property) __PYX_ERR(0, 356, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(0, 389, __pyx_L1_error)
  __pyx_builtin_OSError = __Pyx_GetBuiltinName(__pyx_n_s_OSError); if (!__pyx_builtin_OSError) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(2, 99, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(2, 185, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(2, 246, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(2, 356, __pyx_L1_error)
  __pyx_builtin_BaseException = __Pyx_GetBuiltinName(__pyx_n_s_BaseException); if (!__pyx_builtin_BaseException) __PYX_ERR(2, 388, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(2, 628, __pyx_L1_error)
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(2, 677, __pyx_L1_error)
  __pyx_builtin_RuntimeWarning = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeWarning); if (!__pyx_builtin_RuntimeWarning) __PYX_ERR(2, 1067, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(2, 1137, __pyx_L1_error)
  __pyx_builtin_OverflowError = __Pyx_GetBuiltinName(__pyx_n_s_OverflowError); if (!__pyx_builtin_OverflowError) __PYX_ERR(2, 1486, __pyx_L1_error)
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_n_s_zip); if (!__pyx_builtin_zip) __PYX_ERR(2, 2950, __pyx_L1_error)
  __pyx_builtin_NotImplementedError = __Pyx_GetBuiltinName(__pyx_n_s_NotImplementedError); if (!__pyx_builtin_NotImplementedError) __PYX_ERR(3, 24, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(4, 224, __pyx_L1_error)
  __pyx_builtin_super = __Pyx_GetBuiltinName(__pyx_n_s_super); if (!__pyx_builtin_super) __PYX_ERR(5, 162, __pyx_L1_error)
  __pyx_builtin_open = __Pyx_GetBuiltinName(__pyx_n_s_open); if (!__pyx_builtin_open) __PYX_ERR(6, 176, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(6, 219, __pyx_L1_error)
  __pyx_builtin_UnicodeEncodeError = __Pyx_GetBuiltinName(__pyx_n_s_UnicodeEncodeError); if (!__pyx_builtin_UnicodeEncodeError) __PYX_ERR(7, 84, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "uvloop/loop.pyx":181
 *     def __init__(self):
 *         self.set_debug((not sys_ignore_environment
 *                         and bool(os_environ.get('PYTHONASYNCIODEBUG'))))             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_n_u_PYTHONASYNCIODEBUG); if (unlikely(!__pyx_tuple_)) __PYX_ERR(2, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "uvloop/loop.pyx":185
 *     def __dealloc__(self):
 *         if self._running == 1:
 *             raise RuntimeError('deallocating a running event loop!')             # <<<<<<<<<<<<<<
 *         if self._closed == 0:
 *             aio_logger.error("deallocating an open event loop")
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_u_deallocating_a_running_event_loo); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(2, 185, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "uvloop/loop.pyx":187
 *             raise RuntimeError('deallocating a running event loop!')
 *         if self._closed == 0:
 *             aio_logger.error("deallocating an open event loop")             # <<<<<<<<<<<<<<
 *             return
 *         PyMem_RawFree(self.uvloop)
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_deallocating_an_open_event_loop); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(2, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "uvloop/loop.pyx":242
 * 
 *         self._ssock, self._csock = socket_socketpair()
 *         self._ssock.setblocking(False)             # <<<<<<<<<<<<<<
 *         self._csock.setblocking(False)
 *         try:
 */
  __pyx_tuple__4 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(2, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "uvloop/loop.pyx":243
 *         self._ssock, self._csock = socket_socketpair()
 *         self._ssock.setblocking(False)
 *         self._csock.setblocking(False)             # <<<<<<<<<<<<<<
 *         try:
 *             _set_signal_wakeup_fd(self._csock.fileno())
 */
  __pyx_tuple__5 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(2, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "uvloop/loop.pyx":289
 * 
 *         try:
 *             signal_set_wakeup_fd(-1)             # <<<<<<<<<<<<<<
 *         except (ValueError, OSError) as exc:
 *             aio_logger.info('set_wakeup_fd(-1) failed: %s', exc)
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_int_neg_1); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(2, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "uvloop/loop.pyx":317
 *         while True:
 *             try:
 *                 data = self._ssock.recv(65536)             # <<<<<<<<<<<<<<
 *                 if not data:
 *                     break
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_int_65536); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(2, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "uvloop/loop.pyx":444
 * 
 *         if self._closed == 1:
 *             raise RuntimeError('unable to start the loop; it was closed')             # <<<<<<<<<<<<<<
 * 
 *         if self._running == 1:
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_unable_to_start_the_loop_it_was); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(2, 444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "uvloop/loop.pyx":447
 * 
 *         if self._running == 1:
 *             raise RuntimeError('this event loop is already running.')             # <<<<<<<<<<<<<<
 * 
 *         if (aio_get_running_loop is not None and
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_this_event_loop_is_already_runni); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(2, 447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "uvloop/loop.pyx":451
 *         if (aio_get_running_loop is not None and
 *                 aio_get_running_loop() is not None):
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'Cannot run the event loop while another loop is running')
 * 
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Cannot_run_the_event_loop_while); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(2, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "uvloop/loop.pyx":472
 *         finally:
 *             if aio_set_running_loop is not None:
 *                 aio_set_running_loop(None)             # <<<<<<<<<<<<<<
 * 
 *             self._recv_signals_stop()
 */
  __pyx_tuple__12 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(2, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);
  __pyx_tuple__13 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(2, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "uvloop/loop.pyx":492
 * 
 *         if self._running == 1:
 *             raise RuntimeError("Cannot close a running event loop")             # <<<<<<<<<<<<<<
 * 
 *         if self._closed == 1:
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Cannot_close_a_running_event_loo); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(2, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "uvloop/loop.pyx":591
 *         if UVLOOP_DEBUG:
 *             if len(self._queued_streams) != queued_len:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     'loop._queued_streams are not empty after '
 *                     '_exec_queued_writes')
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_u_loop__queued_streams_are_not_emp); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(2, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "uvloop/loop.pyx":636
 *     cdef inline _check_closed(self):
 *         if self._closed == 1:
 *             raise RuntimeError('Event loop is closed')             # <<<<<<<<<<<<<<
 * 
 *     cdef inline _check_thread(self):
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_u_Event_loop_is_closed); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(2, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "uvloop/loop.pyx":643
 *         cdef uint64_t thread_id = <uint64_t><int64_t>PyThread_get_thread_ident()
 *         if thread_id != self._thread_id:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 "Non-thread-safe operation invoked on an event loop other "
 *                 "than the current one")
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_Non_thread_safe_operation_invoke); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(2, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "uvloop/loop.pyx":832
 *             port = str(port).encode()
 *         if port is not None and not isinstance(port, bytes):
 *             raise TypeError('port must be a str, bytes or int')             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(host, str):
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_u_port_must_be_a_str_bytes_or_int); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(2, 832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "uvloop/loop.pyx":835
 * 
 *         if isinstance(host, str):
 *             host = host.encode('idna')             # <<<<<<<<<<<<<<
 *         if host is not None:
 *             if not isinstance(host, bytes):
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_n_u_idna); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(2, 835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "uvloop/loop.pyx":838
 *         if host is not None:
 *             if not isinstance(host, bytes):
 *                 raise TypeError('host must be a str or bytes')             # <<<<<<<<<<<<<<
 * 
 *         fut = self._new_future()
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_u_host_must_be_a_str_or_bytes); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(2, 838, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "uvloop/loop.pyx":842
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if AddrInfo.isinstance(result):
 *                 try:
 */
  __pyx_tuple__21 = PyTuple_Pack(3, __pyx_n_s_result, __pyx_n_s_data, __pyx_n_s_ex); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(2, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);
  __pyx_codeobj__22 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__21, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_loop_pyx, __pyx_n_s_callback, 842, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__22)) __PYX_ERR(2, 842, __pyx_L1_error)

  /* "uvloop/loop.pyx":866
 *         fut = self._new_future()
 * 
 *         def callback(result):             # <<<<<<<<<<<<<<
 *             if isinstance(result, tuple):
 *                 fut.set_result(result)
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_n_s_result); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(2, 866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);
  __pyx_codeobj__24 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__23, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_loop_pyx, __pyx_n_s_callback, 866, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__24)) __PYX_ERR(2, 866, __pyx_L1_error)

  /* "uvloop/loop.pyx":880
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'_sock_recv is called on a cancelled Future')
 * 
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_kp_u_sock_recv_is_called_on_a_cancel); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(2, 880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "uvloop/loop.pyx":905
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'_sock_recv_into is called on a cancelled Future')
 * 
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_u_sock_recv_into_is_called_on_a_c); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(2, 905, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "uvloop/loop.pyx":934
 *             if fut.cancelled():
 *                 # Shouldn't happen with _SyncSocketReaderFuture.
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     f'_sock_sendall is called on a cancelled Future')
 * 
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_u_sock_sendall_is_called_on_a_can); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(2, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "uvloop/loop.pyx":955
 * 
 *         if n == len(data):
 *             fut.set_result(None)             # <<<<<<<<<<<<<<
 *         else:
 *             if n:
 */
  __pyx_tuple__28 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(2, 955, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "uvloop/loop.pyx":974
 *         try:
 *             conn, address = sock.accept()
 *             conn.setblocking(False)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             # There is an active reader for _sock_accept, so
 */
  __pyx_tuple__29 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(2, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "uvloop/loop.pyx":1025
 *             fut.set_exception(exc)
 *         else:
 *             fut.set_result(None)             # <<<<<<<<<<<<<<
 * 
 *     cdef _sock_set_reuseport(self, int fd):
 */
  __pyx_tuple__30 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(2, 1025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "uvloop/loop.pyx":1051
 *                 self._coroutine_origin_tracking_saved_depth = (
 *                     sys.get_coroutine_origin_tracking_depth())
 *                 sys.set_coroutine_origin_tracking_depth(             # <<<<<<<<<<<<<<
 *                     DEBUG_STACK_DEPTH)
 *             else:
 */
  __pyx_tuple__31 = PyTuple_Pack(1, __pyx_int_10); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(2, 1051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "uvloop/loop.pyx":1078
 *                         current_wrapper, RuntimeWarning, self)
 *                 else:
 *                     sys_set_coroutine_wrapper(None)             # <<<<<<<<<<<<<<
 *                     self._coroutine_debug_set = False
 * 
 */
  __pyx_tuple__32 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(2, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "uvloop/loop.pyx":1137
 *         ################### OS
 * 
 *         print('---- Process info: -----')             # <<<<<<<<<<<<<<
 *         print('Process memory:            {}'.format(rusage.ru_maxrss))
 *         print('Number of signals:         {}'.format(rusage.ru_nsignals))
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_kp_u_Process_info); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(2, 1137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "uvloop/loop.pyx":1140
 *         print('Process memory:            {}'.format(rusage.ru_maxrss))
 *         print('Number of signals:         {}'.format(rusage.ru_nsignals))
 *         print('')             # <<<<<<<<<<<<<<
 * 
 *         ################### Loop
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_kp_u__7); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(2, 1140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "uvloop/loop.pyx":1144
 *         ################### Loop
 * 
 *         print('--- Loop debug info: ---')             # <<<<<<<<<<<<<<
 *         print('Loop time:                 {}'.format(self.time()))
 *         print('Errors logged:             {}'.format(
 */
  __pyx_tuple__36 = PyTuple_Pack(1, __pyx_kp_u_Loop_debug_info); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(2, 1144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "uvloop/loop.pyx":1157
 *         print()
 * 
 *         print('                        alive  | closed  |')             # <<<<<<<<<<<<<<
 *         print('UVHandles               python | libuv   | total')
 *         print('                        objs   | handles |')
 */
  __pyx_tuple__37 = PyTuple_Pack(1, __pyx_kp_u_alive_closed); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(2, 1157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "uvloop/loop.pyx":1158
 * 
 *         print('                        alive  | closed  |')
 *         print('UVHandles               python | libuv   | total')             # <<<<<<<<<<<<<<
 *         print('                        objs   | handles |')
 *         print('-------------------------------+---------+---------')
 */
  __pyx_tuple__38 = PyTuple_Pack(1, __pyx_kp_u_UVHandles_python_libuv_total); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(2, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "uvloop/loop.pyx":1159
 *         print('                        alive  | closed  |')
 *         print('UVHandles               python | libuv   | total')
 *         print('                        objs   | handles |')             # <<<<<<<<<<<<<<
 *         print('-------------------------------+---------+---------')
 *         for name in sorted(self._debug_handles_total):
 */
  __pyx_tuple__39 = PyTuple_Pack(1, __pyx_kp_u_objs_handles); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(2, 1159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "uvloop/loop.pyx":1160
 *         print('UVHandles               python | libuv   | total')
 *         print('                        objs   | handles |')
 *         print('-------------------------------+---------+---------')             # <<<<<<<<<<<<<<
 *         for name in sorted(self._debug_handles_total):
 *             print('    {: <18} {: >7} | {: >7} | {: >7}'.format(
 */
  __pyx_tuple__41 = PyTuple_Pack(1, __pyx_kp_u__40); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(2, 1160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "uvloop/loop.pyx":1175
 *         print()
 * 
 *         print('--- Streams debug info: ---')             # <<<<<<<<<<<<<<
 *         print('Write errors:              {}'.format(
 *             self._debug_stream_write_errors_total))
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_kp_u_Streams_debug_info); if (unlikely(!__pyx_tuple__42)) __PYX_ERR(2, 1175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "uvloop/loop.pyx":1203
 *         print()
 * 
 *         print('--- Polls debug info: ---')             # <<<<<<<<<<<<<<
 *         print('Read events:               {}'.format(
 *             self._poll_read_events_total))
 */
  __pyx_tuple__43 = PyTuple_Pack(1, __pyx_kp_u_Polls_debug_info); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(2, 1203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "uvloop/loop.pyx":1214
 *         print()
 * 
 *         print('--- Sock ops successful on 1st try: ---')             # <<<<<<<<<<<<<<
 *         print('Socket try-writes:         {}'.format(
 *             self._sock_try_write_total))
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_kp_u_Sock_ops_successful_on_1st_try); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(2, 1214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "uvloop/loop.pyx":1225
 *                 return lambda: self._print_debug_info()
 *             else:
 *                 raise AttributeError('print_debug_info')             # <<<<<<<<<<<<<<
 * 
 *     # Public API
 */
  __pyx_tuple__45 = PyTuple_Pack(1, __pyx_n_u_print_debug_info); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(2, 1225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "uvloop/loop.pyx":1404
 *         """
 *         if factory is not None and not callable(factory):
 *             raise TypeError('task factory must be a callable or None')             # <<<<<<<<<<<<<<
 *         self._task_factory = factory
 * 
 */
  __pyx_tuple__46 = PyTuple_Pack(1, __pyx_kp_u_task_factory_must_be_a_callable); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(2, 1404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "uvloop/loop.pyx":1446
 *             future.remove_done_callback(done_cb)
 *         if not future.done():
 *             raise RuntimeError('Event loop stopped before Future completed.')             # <<<<<<<<<<<<<<
 * 
 *         return future.result()
 */
  __pyx_tuple__47 = PyTuple_Pack(1, __pyx_kp_u_Event_loop_stopped_before_Future); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(2, 1446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "uvloop/loop.pyx":1472
 * 
 *         if not isinstance(sockaddr, tuple):
 *             raise TypeError('getnameinfo() argument 1 must be a tuple')             # <<<<<<<<<<<<<<
 * 
 *         sl = len(sockaddr)
 */
  __pyx_tuple__48 = PyTuple_Pack(1, __pyx_kp_u_getnameinfo_argument_1_must_be_a); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(2, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "uvloop/loop.pyx":1477
 * 
 *         if sl < 2 or sl > 4:
 *             raise ValueError('sockaddr must be a tuple of 2, 3 or 4 values')             # <<<<<<<<<<<<<<
 * 
 *         if sl > 2:
 */
  __pyx_tuple__49 = PyTuple_Pack(1, __pyx_kp_u_sockaddr_must_be_a_tuple_of_2_3); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(2, 1477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "uvloop/loop.pyx":1493
 *             scope_id = sockaddr[3]
 *             if scope_id < 0 or scope_id > 2 ** 32:
 *                 raise OverflowError(             # <<<<<<<<<<<<<<
 *                     'getsockaddrarg: scope_id must be unsigned 32 bit integer')
 *         else:
 */
  __pyx_tuple__50 = PyTuple_Pack(1, __pyx_kp_u_getsockaddrarg_scope_id_must_be); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(2, 1493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "uvloop/loop.pyx":1509
 * 
 *         if ai.ai_next:
 *             raise OSError("sockaddr resolved to multiple addresses")             # <<<<<<<<<<<<<<
 * 
 *         if ai.ai_family == uv.AF_INET:
 */
  __pyx_tuple__51 = PyTuple_Pack(1, __pyx_kp_u_sockaddr_resolved_to_multiple_ad); if (unlikely(!__pyx_tuple__51)) __PYX_ERR(2, 1509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "uvloop/loop.pyx":1513
 *         if ai.ai_family == uv.AF_INET:
 *             if sl > 2:
 *                 raise OSError("IPv4 sockaddr must be 2 tuple")             # <<<<<<<<<<<<<<
 *         elif ai.ai_family == uv.AF_INET6:
 *             # Modify some fields in `ai`
 */
  __pyx_tuple__52 = PyTuple_Pack(1, __pyx_kp_u_IPv4_sockaddr_must_be_2_tuple); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(2, 1513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "uvloop/loop.pyx":1623
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_server(
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_kp_u_host_port_and_sock_can_not_be_sp); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(2, 1623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "uvloop/loop.pyx":1632
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')             # <<<<<<<<<<<<<<
 *         else:
 *             if ssl_handshake_timeout is not None:
 */
  __pyx_tuple__56 = PyTuple_Pack(1, __pyx_kp_u_ssl_argument_must_be_an_SSLConte); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(2, 1632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "uvloop/loop.pyx":1635
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
  __pyx_tuple__57 = PyTuple_Pack(1, __pyx_kp_u_ssl_handshake_timeout_is_only_me); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(2, 1635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "uvloop/loop.pyx":1640
 *         if host is not None or port is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 * 
 */
  __pyx_tuple__58 = PyTuple_Pack(1, __pyx_kp_u_host_port_and_sock_can_not_be_sp); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(2, 1640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "uvloop/loop.pyx":1645
 *             reuse_port = bool(reuse_port)
 *             if reuse_port and not has_SO_REUSEPORT:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'reuse_port not supported by socket module')
 * 
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_kp_u_reuse_port_not_supported_by_sock); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(2, 1645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "uvloop/loop.pyx":1667
 *                     while addrinfo != NULL:
 *                         if addrinfo.ai_family == uv.AF_UNSPEC:
 *                             raise RuntimeError('AF_UNSPEC in DNS results')             # <<<<<<<<<<<<<<
 * 
 *                         tcp = self._create_server(
 */
  __pyx_tuple__60 = PyTuple_Pack(1, __pyx_kp_u_AF_UNSPEC_in_DNS_results); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(2, 1667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "uvloop/loop.pyx":1683
 *         else:
 *             if sock is None:
 *                 raise ValueError('Neither host/port nor sock were specified')             # <<<<<<<<<<<<<<
 *             if not _is_sock_stream(sock.type):
 *                 raise ValueError(
 */
  __pyx_tuple__61 = PyTuple_Pack(1, __pyx_kp_u_Neither_host_port_nor_sock_were); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(2, 1683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "uvloop/loop.pyx":1690
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *             tcp = TCPServer.new(self, protocol_factory, server, ssl,
 */
  __pyx_tuple__62 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(2, 1690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "uvloop/loop.pyx":1746
 *         if sock is not None and sock.family == uv.AF_UNIX:
 *             if host is not None or port is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 *             return await self.create_unix_connection(
 */
  __pyx_tuple__63 = PyTuple_Pack(1, __pyx_kp_u_host_port_and_sock_can_not_be_sp); if (unlikely(!__pyx_tuple__63)) __PYX_ERR(2, 1746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__63);
  __Pyx_GIVEREF(__pyx_tuple__63);

  /* "uvloop/loop.pyx":1757
 *             if server_hostname is None:
 *                 if not host:
 *                     raise ValueError('You must set server_hostname '             # <<<<<<<<<<<<<<
 *                                      'when using ssl without a host')
 *                 server_hostname = host
 */
  __pyx_tuple__64 = PyTuple_Pack(1, __pyx_kp_u_You_must_set_server_hostname_whe); if (unlikely(!__pyx_tuple__64)) __PYX_ERR(2, 1757, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "uvloop/loop.pyx":1769
 *         else:
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')             # <<<<<<<<<<<<<<
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(
 */
  __pyx_tuple__65 = PyTuple_Pack(1, __pyx_kp_u_server_hostname_is_only_meaningf); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(2, 1769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "uvloop/loop.pyx":1771
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
  __pyx_tuple__66 = PyTuple_Pack(1, __pyx_kp_u_ssl_handshake_timeout_is_only_me); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(2, 1771, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "uvloop/loop.pyx":1776
 *         if host is not None or port is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host/port and sock can not be specified at the same time')
 * 
 */
  __pyx_tuple__67 = PyTuple_Pack(1, __pyx_kp_u_host_port_and_sock_can_not_be_sp); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(2, 1776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "uvloop/loop.pyx":1800
 *                 if not isinstance(local_addr, (tuple, list)) or \
 *                         len(local_addr) != 2:
 *                     raise ValueError(             # <<<<<<<<<<<<<<
 *                         'local_addr must be a tuple of host and port')
 * 
 */
  __pyx_tuple__68 = PyTuple_Pack(1, __pyx_kp_u_local_addr_must_be_a_tuple_of_ho); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(2, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "uvloop/loop.pyx":1825
 *                 ai_remote = f1.result()
 *                 if ai_remote.data is NULL:
 *                     raise OSError('getaddrinfo() returned empty list')             # <<<<<<<<<<<<<<
 *                 rai = ai_remote.data
 * 
 */
  __pyx_tuple__69 = PyTuple_Pack(1, __pyx_kp_u_getaddrinfo_returned_empty_list); if (unlikely(!__pyx_tuple__69)) __PYX_ERR(2, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "uvloop/loop.pyx":1831
 *                 ai_local = f2.result()
 *                 if ai_local.data is NULL:
 *                     raise OSError(             # <<<<<<<<<<<<<<
 *                         'getaddrinfo() returned empty list for local_addr')
 *                 lai = ai_local.data
 */
  __pyx_tuple__70 = PyTuple_Pack(1, __pyx_kp_u_getaddrinfo_returned_empty_list_2); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(2, 1831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "uvloop/loop.pyx":1888
 *         else:
 *             if sock is None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'host and port was not specified and no sock specified')
 *             if not _is_sock_stream(sock.type):
 */
  __pyx_tuple__72 = PyTuple_Pack(1, __pyx_kp_u_host_and_port_was_not_specified); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(2, 1888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "uvloop/loop.pyx":1896
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *             waiter = self._new_future()
 */
  __pyx_tuple__73 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(2, 1896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "uvloop/loop.pyx":1957
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')             # <<<<<<<<<<<<<<
 *         else:
 *             if ssl_handshake_timeout is not None:
 */
  __pyx_tuple__74 = PyTuple_Pack(1, __pyx_kp_u_ssl_argument_must_be_an_SSLConte); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(2, 1957, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "uvloop/loop.pyx":1960
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
  __pyx_tuple__75 = PyTuple_Pack(1, __pyx_kp_u_ssl_handshake_timeout_is_only_me); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(2, 1960, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "uvloop/loop.pyx":1965
 *         if path is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'path and sock can not be specified at the same time')
 *             orig_path = path
 */
  __pyx_tuple__76 = PyTuple_Pack(1, __pyx_kp_u_path_and_sock_can_not_be_specifi); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(2, 1965, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "uvloop/loop.pyx":2017
 *         else:
 *             if sock is None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'path was not specified, and no sock specified')
 * 
 */
  __pyx_tuple__77 = PyTuple_Pack(1, __pyx_kp_u_path_was_not_specified_and_no_so); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(2, 2017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "uvloop/loop.pyx":2027
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *         pipe = UnixServer.new(
 */
  __pyx_tuple__78 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(2, 2027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);

  /* "uvloop/loop.pyx":2065
 *         if ssl:
 *             if server_hostname is None:
 *                 raise ValueError('You must set server_hostname '             # <<<<<<<<<<<<<<
 *                                  'when using ssl without a host')
 * 
 */
  __pyx_tuple__79 = PyTuple_Pack(1, __pyx_kp_u_You_must_set_server_hostname_whe); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(2, 2065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);

  /* "uvloop/loop.pyx":2076
 *         else:
 *             if server_hostname is not None:
 *                 raise ValueError('server_hostname is only meaningful with ssl')             # <<<<<<<<<<<<<<
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(
 */
  __pyx_tuple__80 = PyTuple_Pack(1, __pyx_kp_u_server_hostname_is_only_meaningf); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(2, 2076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);

  /* "uvloop/loop.pyx":2078
 *                 raise ValueError('server_hostname is only meaningful with ssl')
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
  __pyx_tuple__81 = PyTuple_Pack(1, __pyx_kp_u_ssl_handshake_timeout_is_only_me); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(2, 2078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "uvloop/loop.pyx":2083
 *         if path is not None:
 *             if sock is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'path and sock can not be specified at the same time')
 * 
 */
  __pyx_tuple__82 = PyTuple_Pack(1, __pyx_kp_u_path_and_sock_can_not_be_specifi); if (unlikely(!__pyx_tuple__82)) __PYX_ERR(2, 2083, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__82);
  __Pyx_GIVEREF(__pyx_tuple__82);

  /* "uvloop/loop.pyx":2109
 *         else:
 *             if sock is None:
 *                 raise ValueError('no path and sock were specified')             # <<<<<<<<<<<<<<
 * 
 *             if sock.family != uv.AF_UNIX or not _is_sock_stream(sock.type):
 */
  __pyx_tuple__83 = PyTuple_Pack(1, __pyx_kp_u_no_path_and_sock_were_specified); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(2, 2109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "uvloop/loop.pyx":2118
 *             # libuv will set the socket to non-blocking mode, but
 *             # we want Python socket object to notice that.
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 * 
 *             waiter = self._new_future()
 */
  __pyx_tuple__84 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(2, 2118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);

  /* "uvloop/loop.pyx":2152
 *         `call_exception_handler()`.
 *         """
 *         message = context.get('message')             # <<<<<<<<<<<<<<
 *         if not message:
 *             message = 'Unhandled exception in event loop'
 */
  __pyx_tuple__85 = PyTuple_Pack(1, __pyx_n_u_message); if (unlikely(!__pyx_tuple__85)) __PYX_ERR(2, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);

  /* "uvloop/loop.pyx":2156
 *             message = 'Unhandled exception in event loop'
 * 
 *         exception = context.get('exception')             # <<<<<<<<<<<<<<
 *         if exception is not None:
 *             exc_info = (type(exception), exception, exception.__traceback__)
 */
  __pyx_tuple__86 = PyTuple_Pack(1, __pyx_n_u_exception); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(2, 2156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "uvloop/loop.pyx":2232
 *                 # in the default implementation, as well as for subclassed
 *                 # event loops with overloaded "default_exception_handler".
 *                 aio_logger.error('Exception in default exception handler',             # <<<<<<<<<<<<<<
 *                                  exc_info=True)
 *         else:
 */
  __pyx_tuple__89 = PyTuple_Pack(1, __pyx_kp_u_Exception_in_default_exception_h); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(2, 2232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);

  /* "uvloop/loop.pyx":2249
 *                     # Guard 'default_exception_handler' in case it is
 *                     # overloaded.
 *                     aio_logger.error('Exception in default exception handler '             # <<<<<<<<<<<<<<
 *                                      'while handling an unexpected error '
 *                                      'in custom exception handler',
 */
  __pyx_tuple__90 = PyTuple_Pack(1, __pyx_kp_u_Exception_in_default_exception_h_2); if (unlikely(!__pyx_tuple__90)) __PYX_ERR(2, 2249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__90);
  __Pyx_GIVEREF(__pyx_tuple__90);

  /* "uvloop/loop.pyx":2288
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 */
  __pyx_tuple__91 = PyTuple_Pack(1, __pyx_kp_u_the_socket_must_be_non_blocking); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(2, 2288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);

  /* "uvloop/loop.pyx":2314
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 */
  __pyx_tuple__92 = PyTuple_Pack(1, __pyx_kp_u_the_socket_must_be_non_blocking); if (unlikely(!__pyx_tuple__92)) __PYX_ERR(2, 2314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__92);
  __Pyx_GIVEREF(__pyx_tuple__92);

  /* "uvloop/loop.pyx":2344
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         if not data:
 */
  __pyx_tuple__93 = PyTuple_Pack(1, __pyx_kp_u_the_socket_must_be_non_blocking); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(2, 2344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "uvloop/loop.pyx":2395
 * 
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         fut = _SyncSocketReaderFuture(sock, self)
 */
  __pyx_tuple__94 = PyTuple_Pack(1, __pyx_kp_u_the_socket_must_be_non_blocking); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(2, 2395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);

  /* "uvloop/loop.pyx":2415
 *         """
 *         if self._debug and sock.gettimeout() != 0:
 *             raise ValueError("the socket must be non-blocking")             # <<<<<<<<<<<<<<
 * 
 *         socket_inc_io_ref(sock)
 */
  __pyx_tuple__95 = PyTuple_Pack(1, __pyx_kp_u_the_socket_must_be_non_blocking); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(2, 2415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);

  /* "uvloop/loop.pyx":2423
 *             else:
 *                 addrs = await self.getaddrinfo(
 *                     *address[:2], family=sock.family)             # <<<<<<<<<<<<<<
 * 
 *                 _, _, _, _, address = addrs[0]
 */
  __pyx_slice__96 = PySlice_New(Py_None, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__96)) __PYX_ERR(2, 2423, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__96);
  __Pyx_GIVEREF(__pyx_slice__96);

  /* "uvloop/loop.pyx":2449
 *         if ssl is not None:
 *             if not isinstance(ssl, ssl_SSLContext):
 *                 raise TypeError('ssl argument must be an SSLContext or None')             # <<<<<<<<<<<<<<
 *         else:
 *             if ssl_handshake_timeout is not None:
 */
  __pyx_tuple__97 = PyTuple_Pack(1, __pyx_kp_u_ssl_argument_must_be_an_SSLConte); if (unlikely(!__pyx_tuple__97)) __PYX_ERR(2, 2449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);

  /* "uvloop/loop.pyx":2452
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
  __pyx_tuple__98 = PyTuple_Pack(1, __pyx_kp_u_ssl_handshake_timeout_is_only_me); if (unlikely(!__pyx_tuple__98)) __PYX_ERR(2, 2452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__98);
  __Pyx_GIVEREF(__pyx_tuple__98);

  /* "uvloop/loop.pyx":2482
 * 
 *         if transport is None:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'invalid socket family, expected AF_UNIX, AF_INET or AF_INET6')
 * 
 */
  __pyx_tuple__99 = PyTuple_Pack(1, __pyx_kp_u_invalid_socket_family_expected_A); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(2, 2482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);

  /* "uvloop/loop.pyx":2502
 *     def run_in_executor(self, executor, func, *args):
 *         if aio_iscoroutine(func) or aio_iscoroutinefunction(func):
 *             raise TypeError("coroutines cannot be used with run_in_executor()")             # <<<<<<<<<<<<<<
 * 
 *         self._check_closed()
 */
  __pyx_tuple__100 = PyTuple_Pack(1, __pyx_kp_u_coroutines_cannot_be_used_with_r); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(2, 2502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);

  /* "uvloop/loop.pyx":2547
 * 
 *         if universal_newlines:
 *             raise ValueError("universal_newlines must be False")             # <<<<<<<<<<<<<<
 *         if bufsize != 0:
 *             raise ValueError("bufsize must be 0")
 */
  __pyx_tuple__104 = PyTuple_Pack(1, __pyx_kp_u_universal_newlines_must_be_False); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(2, 2547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);

  /* "uvloop/loop.pyx":2549
 *             raise ValueError("universal_newlines must be False")
 *         if bufsize != 0:
 *             raise ValueError("bufsize must be 0")             # <<<<<<<<<<<<<<
 *         if startupinfo is not None:
 *             raise ValueError('startupinfo is not supported')
 */
  __pyx_tuple__105 = PyTuple_Pack(1, __pyx_kp_u_bufsize_must_be_0); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(2, 2549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);

  /* "uvloop/loop.pyx":2551
 *             raise ValueError("bufsize must be 0")
 *         if startupinfo is not None:
 *             raise ValueError('startupinfo is not supported')             # <<<<<<<<<<<<<<
 *         if creationflags != 0:
 *             raise ValueError('creationflags is not supported')
 */
  __pyx_tuple__106 = PyTuple_Pack(1, __pyx_kp_u_startupinfo_is_not_supported); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(2, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "uvloop/loop.pyx":2553
 *             raise ValueError('startupinfo is not supported')
 *         if creationflags != 0:
 *             raise ValueError('creationflags is not supported')             # <<<<<<<<<<<<<<
 * 
 *         if executable is not None:
 */
  __pyx_tuple__107 = PyTuple_Pack(1, __pyx_kp_u_creationflags_is_not_supported); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(2, 2553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);

  /* "uvloop/loop.pyx":2585
 * 
 *         if not shell:
 *             raise ValueError("shell must be True")             # <<<<<<<<<<<<<<
 * 
 *         args = [cmd]
 */
  __pyx_tuple__108 = PyTuple_Pack(1, __pyx_kp_u_shell_must_be_True); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(2, 2585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);

  /* "uvloop/loop.pyx":2599
 * 
 *         if shell:
 *             raise ValueError("shell must be False")             # <<<<<<<<<<<<<<
 * 
 *         args = list((program,) + args)
 */
  __pyx_tuple__109 = PyTuple_Pack(1, __pyx_kp_u_shell_must_be_False); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(2, 2599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "uvloop/loop.pyx":2668
 *             self._setup_signals()
 *             if not self._listening_signals:
 *                 raise ValueError('set_wakeup_fd only works in main thread')             # <<<<<<<<<<<<<<
 * 
 *         if (aio_iscoroutine(callback)
 */
  __pyx_tuple__110 = PyTuple_Pack(1, __pyx_kp_u_set_wakeup_fd_only_works_in_main); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(2, 2668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);

  /* "uvloop/loop.pyx":2672
 *         if (aio_iscoroutine(callback)
 *                 or aio_iscoroutinefunction(callback)):
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 "coroutines cannot be used with add_signal_handler()")
 * 
 */
  __pyx_tuple__111 = PyTuple_Pack(1, __pyx_kp_u_coroutines_cannot_be_used_with_a); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(2, 2672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);

  /* "uvloop/loop.pyx":2694
 *                 return
 * 
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'cannot add a signal handler for SIGCHLD: it is used '
 *                 'by the event loop to track subprocesses')
 */
  __pyx_tuple__112 = PyTuple_Pack(1, __pyx_kp_u_cannot_add_a_signal_handler_for); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(2, 2694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);

  /* "uvloop/loop.pyx":2723
 *             if not self._signal_handlers:
 *                 try:
 *                     signal_set_wakeup_fd(-1)             # <<<<<<<<<<<<<<
 *                 except (ValueError, OSError) as nexc:
 *                     aio_logger.info('set_wakeup_fd(-1) failed: %s', nexc)
 */
  __pyx_tuple__113 = PyTuple_Pack(1, __pyx_int_neg_1); if (unlikely(!__pyx_tuple__113)) __PYX_ERR(2, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__113);
  __Pyx_GIVEREF(__pyx_tuple__113);

  /* "uvloop/loop.pyx":2820
 *                     'socket modifier keyword arguments can not be used '
 *                     'when sock is specified. ({})'.format(problems))
 *             sock.setblocking(False)             # <<<<<<<<<<<<<<
 *             udp = UDPTransport.new(self, sock, None)
 *         else:
 */
  __pyx_tuple__115 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(2, 2820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);

  /* "uvloop/loop.pyx":2825
 *             if not (local_addr or remote_addr):
 *                 if family == 0:
 *                     raise ValueError('unexpected address family')             # <<<<<<<<<<<<<<
 *                 addr_pairs_info = (((family, proto), (None, None)),)
 *             elif family == uv.AF_UNIX:
 */
  __pyx_tuple__116 = PyTuple_Pack(1, __pyx_kp_u_unexpected_address_family); if (unlikely(!__pyx_tuple__116)) __PYX_ERR(2, 2825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__116);
  __Pyx_GIVEREF(__pyx_tuple__116);

  /* "uvloop/loop.pyx":2826
 *                 if family == 0:
 *                     raise ValueError('unexpected address family')
 *                 addr_pairs_info = (((family, proto), (None, None)),)             # <<<<<<<<<<<<<<
 *             elif family == uv.AF_UNIX:
 *                 for addr in (local_addr, remote_addr):
 */
  __pyx_tuple__117 = PyTuple_Pack(2, Py_None, Py_None); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(2, 2826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);

  /* "uvloop/loop.pyx":2830
 *                 for addr in (local_addr, remote_addr):
 *                     if addr is not None and not isinstance(addr, str):
 *                         raise TypeError('string is expected')             # <<<<<<<<<<<<<<
 *                 addr_pairs_info = (((family, proto),
 *                                     (local_addr, remote_addr)), )
 */
  __pyx_tuple__118 = PyTuple_Pack(1, __pyx_kp_u_string_is_expected); if (unlikely(!__pyx_tuple__118)) __PYX_ERR(2, 2830, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__118);
  __Pyx_GIVEREF(__pyx_tuple__118);

  /* "uvloop/loop.pyx":2842
 * 
 *                         infos = await self.getaddrinfo(
 *                             *addr[:2], family=family, type=uv.SOCK_DGRAM,             # <<<<<<<<<<<<<<
 *                             proto=proto, flags=flags)
 * 
 */
  __pyx_slice__119 = PySlice_New(Py_None, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__119)) __PYX_ERR(2, 2842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__119);
  __Pyx_GIVEREF(__pyx_slice__119);

  /* "uvloop/loop.pyx":2846
 * 
 *                         if not infos:
 *                             raise OSError('getaddrinfo() returned empty list')             # <<<<<<<<<<<<<<
 * 
 *                         for fam, _, pro, _, address in infos:
 */
  __pyx_tuple__120 = PyTuple_Pack(1, __pyx_kp_u_getaddrinfo_returned_empty_list); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(2, 2846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "uvloop/loop.pyx":2861
 * 
 *                 if not addr_pairs_info:
 *                     raise ValueError('can not get address information')             # <<<<<<<<<<<<<<
 * 
 *             exceptions = []
 */
  __pyx_tuple__121 = PyTuple_Pack(1, __pyx_kp_u_can_not_get_address_information); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(2, 2861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);

  /* "uvloop/loop.pyx":2878
 *                     if allow_broadcast:
 *                         sock.setsockopt(uv.SOL_SOCKET, SO_BROADCAST, 1)
 *                     sock.setblocking(False)             # <<<<<<<<<<<<<<
 *                     if local_addr:
 *                         sock.bind(local_address)
 */
  __pyx_tuple__122 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__122)) __PYX_ERR(2, 2878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__122);
  __Pyx_GIVEREF(__pyx_tuple__122);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__123 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__124 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__124)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__124);
  __Pyx_GIVEREF(__pyx_tuple__124);

  /* "uvloop/loop.pyx":2968
 *     if loop._recv_buffer_in_use == 1:
 *         buf.len = 0
 *         exc = RuntimeError('concurrent allocations')             # <<<<<<<<<<<<<<
 *         loop._handle_exception(exc)
 *         return
 */
  __pyx_tuple__125 = PyTuple_Pack(1, __pyx_kp_u_concurrent_allocations); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(2, 2968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);

  /* "uvloop/cbhandles.pyx":24
 *         else:
 *             if context is not None:
 *                 raise NotImplementedError(             # <<<<<<<<<<<<<<
 *                     '"context" argument requires Python 3.7')
 *             self.context = None
 */
  __pyx_tuple__126 = PyTuple_Pack(1, __pyx_kp_u_context_argument_requires_Pytho); if (unlikely(!__pyx_tuple__126)) __PYX_ERR(3, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__126);
  __Pyx_GIVEREF(__pyx_tuple__126);

  /* "uvloop/cbhandles.pyx":32
 *             self.loop._debug_cb_handles_count -= 1
 *         if self.loop is None:
 *             raise RuntimeError('Handle.loop is None in Handle.__dealloc__')             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self):
 */
  __pyx_tuple__127 = PyTuple_Pack(1, __pyx_kp_u_Handle_loop_is_None_in_Handle); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(3, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__131 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__131)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__131);
  __Pyx_GIVEREF(__pyx_tuple__131);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__132 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__132)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__132);
  __Pyx_GIVEREF(__pyx_tuple__132);

  /* "uvloop/cbhandles.pyx":186
 *         else:
 *             if context is not None:
 *                 raise NotImplementedError(             # <<<<<<<<<<<<<<
 *                     '"context" argument requires Python 3.7')
 *             self.context = None
 */
  __pyx_tuple__133 = PyTuple_Pack(1, __pyx_kp_u_context_argument_requires_Pytho); if (unlikely(!__pyx_tuple__133)) __PYX_ERR(3, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__133);
  __Pyx_GIVEREF(__pyx_tuple__133);

  /* "uvloop/cbhandles.pyx":205
 *             self.loop._debug_cb_timer_handles_count -= 1
 *         if self.timer is not None:
 *             raise RuntimeError('active TimerHandle is deallacating')             # <<<<<<<<<<<<<<
 * 
 *     cdef _cancel(self):
 */
  __pyx_tuple__134 = PyTuple_Pack(1, __pyx_kp_u_active_TimerHandle_is_deallacati); if (unlikely(!__pyx_tuple__134)) __PYX_ERR(3, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__134);
  __Pyx_GIVEREF(__pyx_tuple__134);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__135 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__136 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__136)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__136);
  __Pyx_GIVEREF(__pyx_tuple__136);

  /* "uvloop/pseudosock.pyx":64
 * 
 *     def __getstate__(self):
 *         raise TypeError("Cannot serialize socket object")             # <<<<<<<<<<<<<<
 * 
 *     def fileno(self):
 */
  __pyx_tuple__137 = PyTuple_Pack(1, __pyx_kp_u_Cannot_serialize_socket_object); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(10, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);

  /* "uvloop/pseudosock.pyx":72
 *         fd = os_dup(self._fd)
 *         sock = socket_socket(self._family, self._type, self._proto, fileno=fd)
 *         sock.settimeout(0)             # <<<<<<<<<<<<<<
 *         return sock
 * 
 */
  __pyx_tuple__138 = PyTuple_Pack(1, __pyx_int_0); if (unlikely(!__pyx_tuple__138)) __PYX_ERR(10, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__138);
  __Pyx_GIVEREF(__pyx_tuple__138);

  /* "uvloop/pseudosock.pyx":193
 *         if value == 0:
 *             return
 *         raise ValueError(             # <<<<<<<<<<<<<<
 *             'settimeout(): only 0 timeout is allowed on transport sockets')
 * 
 */
  __pyx_tuple__139 = PyTuple_Pack(1, __pyx_kp_u_settimeout_only_0_timeout_is_all); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(10, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);

  /* "uvloop/pseudosock.pyx":202
 *         if not flag:
 *             return
 *         raise ValueError(             # <<<<<<<<<<<<<<
 *             'setblocking(): transport sockets cannot be blocking')
 * 
 */
  __pyx_tuple__140 = PyTuple_Pack(1, __pyx_kp_u_setblocking_transport_sockets_ca); if (unlikely(!__pyx_tuple__140)) __PYX_ERR(10, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__140);
  __Pyx_GIVEREF(__pyx_tuple__140);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__141 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__142 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__142)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__142);
  __Pyx_GIVEREF(__pyx_tuple__142);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__143 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__143)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__143);
  __Pyx_GIVEREF(__pyx_tuple__143);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__144 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__144)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__144);
  __Pyx_GIVEREF(__pyx_tuple__144);

  /* "uvloop/handles/handle.pyx":318
 *     if UVLOOP_DEBUG:
 *         if handle.loop is NULL:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'handle.loop is NULL in __ensure_handle_data')
 * 
 */
  __pyx_tuple__145 = PyTuple_Pack(1, __pyx_kp_u_handle_loop_is_NULL_in___ensure); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(4, 318, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);

  /* "uvloop/handles/handle.pyx":322
 * 
 *         if handle.loop.data is NULL:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'handle.loop.data is NULL in __ensure_handle_data')
 * 
 */
  __pyx_tuple__146 = PyTuple_Pack(1, __pyx_kp_u_handle_loop_data_is_NULL_in___en); if (unlikely(!__pyx_tuple__146)) __PYX_ERR(4, 322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__146);
  __Pyx_GIVEREF(__pyx_tuple__146);

  /* "uvloop/handles/handle.pyx":354
 *         if UVLOOP_DEBUG:
 *             if handle.loop == NULL or handle.loop.data == NULL:
 *                 raise RuntimeError(             # <<<<<<<<<<<<<<
 *                     '__uv_close_handle_cb: handle.loop is invalid')
 *             (<Loop>handle.loop.data)._debug_uv_handles_freed += 1
 */
  __pyx_tuple__147 = PyTuple_Pack(1, __pyx_kp_u_uv_close_handle_cb_handle_loop); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(4, 354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);

  /* "uvloop/handles/handle.pyx":364
 *             if UVLOOP_DEBUG:
 *                 if not h._has_handle:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         'has_handle=0 in __uv_close_handle_cb')
 *                 h._loop._debug_handles_closed.update([
 */
  __pyx_tuple__148 = PyTuple_Pack(1, __pyx_kp_u_has_handle_0_in___uv_close_handl); if (unlikely(!__pyx_tuple__148)) __PYX_ERR(4, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__148);
  __Pyx_GIVEREF(__pyx_tuple__148);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__149 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__150 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__150)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__150);
  __Pyx_GIVEREF(__pyx_tuple__150);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__151 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__152 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__152)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__152);
  __Pyx_GIVEREF(__pyx_tuple__152);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__153 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__154 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__154)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__154);
  __Pyx_GIVEREF(__pyx_tuple__154);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__155 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__155)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__155);
  __Pyx_GIVEREF(__pyx_tuple__155);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__156 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__156)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__156);
  __Pyx_GIVEREF(__pyx_tuple__156);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__157 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__158 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__158)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__158);
  __Pyx_GIVEREF(__pyx_tuple__158);

  /* "uvloop/handles/basetransport.pyx":122
 *                 if not self._is_alive():
 *                     self._waiter.set_exception(
 *                         RuntimeError(             # <<<<<<<<<<<<<<
 *                             'closed Transport handle and unset waiter'))
 *                 else:
 */
  __pyx_tuple__160 = PyTuple_Pack(1, __pyx_kp_u_closed_Transport_handle_and_unse); if (unlikely(!__pyx_tuple__160)) __PYX_ERR(16, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__160);
  __Pyx_GIVEREF(__pyx_tuple__160);

  /* "uvloop/handles/basetransport.pyx":125
 *                             'closed Transport handle and unset waiter'))
 *                 else:
 *                     self._waiter.set_result(True)             # <<<<<<<<<<<<<<
 *             self._waiter = None
 * 
 */
  __pyx_tuple__161 = PyTuple_Pack(1, Py_True); if (unlikely(!__pyx_tuple__161)) __PYX_ERR(16, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__161);
  __Pyx_GIVEREF(__pyx_tuple__161);

  /* "uvloop/handles/basetransport.pyx":130
 *     cdef _call_connection_made(self):
 *         if self._protocol is None:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'protocol is not set, cannot call connection_made()')
 * 
 */
  __pyx_tuple__162 = PyTuple_Pack(1, __pyx_kp_u_protocol_is_not_set_cannot_call); if (unlikely(!__pyx_tuple__162)) __PYX_ERR(16, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__162);
  __Pyx_GIVEREF(__pyx_tuple__162);

  /* "uvloop/handles/basetransport.pyx":220
 *         self._loop._track_transport(self)
 *         if self._protocol is None:
 *             raise RuntimeError('invalid _init_protocol call')             # <<<<<<<<<<<<<<
 *         self._schedule_call_connection_made()
 * 
 */
  __pyx_tuple__163 = PyTuple_Pack(1, __pyx_kp_u_invalid__init_protocol_call); if (unlikely(!__pyx_tuple__163)) __PYX_ERR(16, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__163);
  __Pyx_GIVEREF(__pyx_tuple__163);

  /* "uvloop/handles/basetransport.pyx":264
 * 
 *     def abort(self):
 *         self._force_close(None)             # <<<<<<<<<<<<<<
 * 
 *     def close(self):
 */
  __pyx_tuple__164 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__164)) __PYX_ERR(16, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__164);
  __Pyx_GIVEREF(__pyx_tuple__164);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__165 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__165)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__165);
  __Pyx_GIVEREF(__pyx_tuple__165);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__166 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__166)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__166);
  __Pyx_GIVEREF(__pyx_tuple__166);

  /* "uvloop/handles/stream.pyx":36
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '_StreamWriteContext.close: uv_bufs != NULL and '
 *                         'py_bufs_sml_inuse is True')
 */
  __pyx_tuple__167 = PyTuple_Pack(1, __pyx_kp_u_StreamWriteContext_close_uv_buf); if (unlikely(!__pyx_tuple__167)) __PYX_ERR(18, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__167);
  __Pyx_GIVEREF(__pyx_tuple__167);

  /* "uvloop/handles/stream.pyx":47
 *             if UVLOOP_DEBUG:
 *                 if self.py_bufs_sml_inuse:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '_StreamWriteContext.close: py_bufs != NULL and '
 *                         'py_bufs_sml_inuse is True')
 */
  __pyx_tuple__168 = PyTuple_Pack(1, __pyx_kp_u_StreamWriteContext_close_py_buf); if (unlikely(!__pyx_tuple__168)) __PYX_ERR(18, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__168);
  __Pyx_GIVEREF(__pyx_tuple__168);

  /* "uvloop/handles/stream.pyx":92
 *             if UVLOOP_DEBUG:
 *                 if sent < 0:
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')             # <<<<<<<<<<<<<<
 * 
 *         raise RuntimeError('fatal: Could not advance _StreamWriteContext')
 */
  __pyx_tuple__169 = PyTuple_Pack(1, __pyx_kp_u_fatal_sent_0_in_advance_uv_buf); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(18, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);

  /* "uvloop/handles/stream.pyx":94
 *                     raise RuntimeError('fatal: sent < 0 in advance_uv_buf')
 * 
 *         raise RuntimeError('fatal: Could not advance _StreamWriteContext')             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
 */
  __pyx_tuple__170 = PyTuple_Pack(1, __pyx_kp_u_fatal_Could_not_advance__StreamW); if (unlikely(!__pyx_tuple__170)) __PYX_ERR(18, 94, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__170);
  __Pyx_GIVEREF(__pyx_tuple__170);

  /* "uvloop/handles/stream.pyx":198
 *             # Because we do an INCREF in _StreamWriteContext.new,
 *             # __dealloc__ shouldn't ever happen with `self.closed == 1`
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'open _StreamWriteContext is being deallocated')
 * 
 */
  __pyx_tuple__171 = PyTuple_Pack(1, __pyx_kp_u_open__StreamWriteContext_is_bein); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(18, 198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 */
  __pyx_tuple__172 = PyTuple_Pack(1, __pyx_kp_s_self_py_bufs_self_py_bufs_sml_se); if (unlikely(!__pyx_tuple__172)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__172);
  __Pyx_GIVEREF(__pyx_tuple__172);

  /* "(tree fragment)":4
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.py_bufs,self.py_bufs_sml,self.req,self.uv_bufs,self.uv_bufs_start cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__173 = PyTuple_Pack(1, __pyx_kp_s_self_py_bufs_self_py_bufs_sml_se); if (unlikely(!__pyx_tuple__173)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__173);
  __Pyx_GIVEREF(__pyx_tuple__173);

  /* "uvloop/handles/stream.pyx":226
 *     cdef _set_protocol(self, object protocol):
 *         if protocol is None:
 *             raise TypeError('protocol is required')             # <<<<<<<<<<<<<<
 * 
 *         UVBaseTransport._set_protocol(self, protocol)
 */
  __pyx_tuple__174 = PyTuple_Pack(1, __pyx_kp_u_protocol_is_required); if (unlikely(!__pyx_tuple__174)) __PYX_ERR(18, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__174);
  __Pyx_GIVEREF(__pyx_tuple__174);

  /* "uvloop/handles/stream.pyx":353
 * 
 *         if (<uv.uv_stream_t*>self._handle).write_queue_size != 0:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'UVStream._try_write called with data in uv buffers')
 * 
 */
  __pyx_tuple__175 = PyTuple_Pack(1, __pyx_kp_u_UVStream__try_write_called_with); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(18, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);

  /* "uvloop/handles/stream.pyx":412
 * 
 *         if not PyBytes_CheckExact(data):
 *             data = memoryview(data).cast('b')             # <<<<<<<<<<<<<<
 * 
 *         dlen = len(data)
 */
  __pyx_tuple__176 = PyTuple_Pack(1, __pyx_n_u_b); if (unlikely(!__pyx_tuple__176)) __PYX_ERR(18, 412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__176);
  __Pyx_GIVEREF(__pyx_tuple__176);

  /* "uvloop/handles/stream.pyx":434
 *             if UVLOOP_DEBUG:
 *                 if self._buffer_size != 0 or self._buffer != []:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         '_buffer_size is not 0 after a successful _exec_write')
 * 
 */
  __pyx_tuple__177 = PyTuple_Pack(1, __pyx_kp_u_buffer_size_is_not_0_after_a_su); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(18, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);

  /* "uvloop/handles/stream.pyx":480
 *                     if not self._closing:
 *                         # This should never happen.
 *                         raise RuntimeError(             # <<<<<<<<<<<<<<
 *                             'stream is open after UVStream._try_write '
 *                             'returned None')
 */
  __pyx_tuple__178 = PyTuple_Pack(1, __pyx_kp_u_stream_is_open_after_UVStream__t); if (unlikely(!__pyx_tuple__178)) __PYX_ERR(18, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__178);
  __Pyx_GIVEREF(__pyx_tuple__178);

  /* "uvloop/handles/stream.pyx":496
 *                     if UVLOOP_DEBUG:
 *                         if sent == len(data):
 *                             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                                 '_try_write sent all data and returned '
 *                                 'non-zero')
 */
  __pyx_tuple__179 = PyTuple_Pack(1, __pyx_kp_u_try_write_sent_all_data_and_ret); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(18, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);

  /* "uvloop/handles/stream.pyx":674
 * 
 *         if self._eof:
 *             raise RuntimeError('Cannot call write() after write_eof()')             # <<<<<<<<<<<<<<
 *         if not buf:
 *             return
 */
  __pyx_tuple__180 = PyTuple_Pack(1, __pyx_kp_u_Cannot_call_write_after_write_eo); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(18, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);

  /* "uvloop/handles/stream.pyx":686
 * 
 *         if self._eof:
 *             raise RuntimeError('Cannot call writelines() after write_eof()')             # <<<<<<<<<<<<<<
 *         if self._conn_lost:
 *             self._conn_lost += 1
 */
  __pyx_tuple__181 = PyTuple_Pack(1, __pyx_kp_u_Cannot_call_writelines_after_wri); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(18, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__182 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__182)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__182);
  __Pyx_GIVEREF(__pyx_tuple__182);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__183 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);

  /* "uvloop/handles/stream.pyx":950
 *     if nread == uv.UV_ENOBUFS:
 *         sc._fatal_error(
 *             RuntimeError(             # <<<<<<<<<<<<<<
 *                 'unhandled error (or an empty buffer) in get_buffer()'),
 *             False)
 */
  __pyx_tuple__184 = PyTuple_Pack(1, __pyx_kp_u_unhandled_error_or_an_empty_buff); if (unlikely(!__pyx_tuple__184)) __PYX_ERR(18, 950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__184);
  __Pyx_GIVEREF(__pyx_tuple__184);

  /* "uvloop/handles/streamserver.pyx":21
 *         else:
 *             if ssl_handshake_timeout is not None:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'ssl_handshake_timeout is only meaningful with ssl')
 * 
 */
  __pyx_tuple__185 = PyTuple_Pack(1, __pyx_kp_u_ssl_handshake_timeout_is_only_me); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(19, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);

  /* "uvloop/handles/streamserver.pyx":41
 * 
 *         if self.protocol_factory is None:
 *             raise RuntimeError('unable to listen(); no protocol_factory')             # <<<<<<<<<<<<<<
 * 
 *         if self.opened != 1:
 */
  __pyx_tuple__186 = PyTuple_Pack(1, __pyx_kp_u_unable_to_listen_no_protocol_fac); if (unlikely(!__pyx_tuple__186)) __PYX_ERR(19, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__186);
  __Pyx_GIVEREF(__pyx_tuple__186);

  /* "uvloop/handles/streamserver.pyx":44
 * 
 *         if self.opened != 1:
 *             raise RuntimeError('unopened TCPServer')             # <<<<<<<<<<<<<<
 * 
 *         err = uv.uv_listen(<uv.uv_stream_t*> self._handle,
 */
  __pyx_tuple__187 = PyTuple_Pack(1, __pyx_kp_u_unopened_TCPServer); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(19, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__188 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__188)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__188);
  __Pyx_GIVEREF(__pyx_tuple__188);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__189 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__189)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__189);
  __Pyx_GIVEREF(__pyx_tuple__189);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__190 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__190)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__190);
  __Pyx_GIVEREF(__pyx_tuple__190);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__191 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__191)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__191);
  __Pyx_GIVEREF(__pyx_tuple__191);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__192 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__193 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__193)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__193);
  __Pyx_GIVEREF(__pyx_tuple__193);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__194 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__194)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__194);
  __Pyx_GIVEREF(__pyx_tuple__194);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__195 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__195)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__195);
  __Pyx_GIVEREF(__pyx_tuple__195);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__196 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__196)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__196);
  __Pyx_GIVEREF(__pyx_tuple__196);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__197 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__197)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__197);
  __Pyx_GIVEREF(__pyx_tuple__197);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__198 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__198)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__198);
  __Pyx_GIVEREF(__pyx_tuple__198);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__199 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__200 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__200)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__200);
  __Pyx_GIVEREF(__pyx_tuple__200);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__201 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__201)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__201);
  __Pyx_GIVEREF(__pyx_tuple__201);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__202 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__202)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__202);
  __Pyx_GIVEREF(__pyx_tuple__202);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__203 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__203)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__203);
  __Pyx_GIVEREF(__pyx_tuple__203);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__204 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__204)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__204);
  __Pyx_GIVEREF(__pyx_tuple__204);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__205 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__205)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__205);
  __Pyx_GIVEREF(__pyx_tuple__205);

  /* "uvloop/handles/process.pyx":56
 *             # GIL should help us to avoid that.)
 *             self._abort_init()
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'Racing with another loop to spawn a process.')
 * 
 */
  __pyx_tuple__206 = PyTuple_Pack(1, __pyx_kp_u_Racing_with_another_loop_to_spaw); if (unlikely(!__pyx_tuple__206)) __PYX_ERR(6, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__206);
  __Pyx_GIVEREF(__pyx_tuple__206);

  /* "uvloop/handles/process.pyx":83
 *                 # See CPython/posixmodule.c for details
 *                 self._abort_init()
 *                 raise RuntimeError('not holding the import lock')             # <<<<<<<<<<<<<<
 * 
 *             if err < 0:
 */
  __pyx_tuple__207 = PyTuple_Pack(1, __pyx_kp_u_not_holding_the_import_lock); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(6, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);

  /* "uvloop/handles/process.pyx":134
 * 
 *         if debug_flags & __PROCESS_DEBUG_SLEEP_AFTER_FORK:
 *             time_sleep(1)             # <<<<<<<<<<<<<<
 * 
 *         if preexec_fn is not None and errpipe_data:
 */
  __pyx_tuple__208 = PyTuple_Pack(1, __pyx_int_1); if (unlikely(!__pyx_tuple__208)) __PYX_ERR(6, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__208);
  __Pyx_GIVEREF(__pyx_tuple__208);

  /* "uvloop/handles/process.pyx":140
 *             # process must be dead now.
 *             try:
 *                 exc_name, exc_msg = errpipe_data.split(b':', 1)             # <<<<<<<<<<<<<<
 *                 exc_name = exc_name.decode()
 *                 exc_msg = exc_msg.decode()
 */
  __pyx_tuple__210 = PyTuple_Pack(2, __pyx_kp_b__209, __pyx_int_1); if (unlikely(!__pyx_tuple__210)) __PYX_ERR(6, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__210);
  __Pyx_GIVEREF(__pyx_tuple__210);

  /* "uvloop/handles/process.pyx":151
 *                               subprocess_SubprocessError)
 * 
 *             exc = subprocess_SubprocessError(             # <<<<<<<<<<<<<<
 *                 'Exception occurred in preexec_fn.')
 *             exc.__cause__ = exc_cls(exc_msg)
 */
  __pyx_tuple__211 = PyTuple_Pack(1, __pyx_kp_u_Exception_occurred_in_preexec_fn); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(6, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);

  /* "uvloop/handles/process.pyx":178
 *                     with open(self._errpipe_write, 'wb') as f:
 *                         f.write(str(ex.__class__.__name__).encode())
 *                         f.write(b':')             # <<<<<<<<<<<<<<
 *                         f.write(str(ex.args[0]).encode())
 *                 finally:
 */
  __pyx_tuple__212 = PyTuple_Pack(1, __pyx_kp_b__209); if (unlikely(!__pyx_tuple__212)) __PYX_ERR(6, 178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__212);
  __Pyx_GIVEREF(__pyx_tuple__212);

  /* "uvloop/handles/process.pyx":176
 *             except BaseException as ex:
 *                 try:
 *                     with open(self._errpipe_write, 'wb') as f:             # <<<<<<<<<<<<<<
 *                         f.write(str(ex.__class__.__name__).encode())
 *                         f.write(b':')
 */
  __pyx_tuple__213 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__213)) __PYX_ERR(6, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__213);
  __Pyx_GIVEREF(__pyx_tuple__213);

  /* "uvloop/handles/process.pyx":189
 *     cdef _close_after_spawn(self, int fd):
 *         if self._fds_to_close is None:
 *             raise RuntimeError(             # <<<<<<<<<<<<<<
 *                 'UVProcess._close_after_spawn called after uv_spawn')
 *         self._fds_to_close.add(fd)
 */
  __pyx_tuple__214 = PyTuple_Pack(1, __pyx_kp_u_UVProcess__close_after_spawn_cal); if (unlikely(!__pyx_tuple__214)) __PYX_ERR(6, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__214);
  __Pyx_GIVEREF(__pyx_tuple__214);

  /* "uvloop/handles/process.pyx":257
 *                 cwd = PyUnicode_EncodeFSDefault(cwd)
 *             if not isinstance(cwd, bytes):
 *                 raise ValueError('cwd must be a str or bytes object')             # <<<<<<<<<<<<<<
 * 
 *             self.__cwd = cwd
 */
  __pyx_tuple__215 = PyTuple_Pack(1, __pyx_kp_u_cwd_must_be_a_str_or_bytes_objec); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(6, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);

  /* "uvloop/handles/process.pyx":272
 * 
 *         if an < 1:
 *             raise ValueError('cannot spawn a process: args are empty')             # <<<<<<<<<<<<<<
 * 
 *         self.__args = args.copy()
 */
  __pyx_tuple__216 = PyTuple_Pack(1, __pyx_kp_u_cannot_spawn_a_process_args_are); if (unlikely(!__pyx_tuple__216)) __PYX_ERR(6, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__216);
  __Pyx_GIVEREF(__pyx_tuple__216);

  /* "uvloop/handles/process.pyx":280
 *                 self.__args[i] = PyUnicode_EncodeFSDefault(arg)
 *             elif not isinstance(arg, bytes):
 *                 raise TypeError('all args must be str or bytes')             # <<<<<<<<<<<<<<
 * 
 *         path = self.__args[0]
 */
  __pyx_tuple__217 = PyTuple_Pack(1, __pyx_kp_u_all_args_must_be_str_or_bytes); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(6, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);

  /* "uvloop/handles/process.pyx":295
 *                     key = PyUnicode_EncodeFSDefault(key)
 *                 elif not isinstance(key, bytes):
 *                     raise TypeError(             # <<<<<<<<<<<<<<
 *                         'all environment vars must be bytes or str')
 * 
 */
  __pyx_tuple__218 = PyTuple_Pack(1, __pyx_kp_u_all_environment_vars_must_be_byt); if (unlikely(!__pyx_tuple__218)) __PYX_ERR(6, 295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__218);
  __Pyx_GIVEREF(__pyx_tuple__218);

  /* "uvloop/handles/process.pyx":301
 *                     val = PyUnicode_EncodeFSDefault(val)
 *                 elif not isinstance(val, bytes):
 *                     raise TypeError(             # <<<<<<<<<<<<<<
 *                         'all environment values must be bytes or str')
 * 
 */
  __pyx_tuple__219 = PyTuple_Pack(1, __pyx_kp_u_all_environment_values_must_be_b); if (unlikely(!__pyx_tuple__219)) __PYX_ERR(6, 301, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__219);
  __Pyx_GIVEREF(__pyx_tuple__219);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__221 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__221)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__221);
  __Pyx_GIVEREF(__pyx_tuple__221);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__222 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__222)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__222);
  __Pyx_GIVEREF(__pyx_tuple__222);

  /* "uvloop/handles/process.pyx":366
 *             self._loop.call_soon(self._protocol.process_exited)
 *         else:
 *             self._pending_calls.append((_CALL_PROCESS_EXITED, None, None))             # <<<<<<<<<<<<<<
 * 
 *         self._try_finish()
 */
  __pyx_tuple__223 = PyTuple_Pack(3, __pyx_int_2, Py_None, Py_None); if (unlikely(!__pyx_tuple__223)) __PYX_ERR(6, 366, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__223);
  __Pyx_GIVEREF(__pyx_tuple__223);

  /* "uvloop/handles/process.pyx":443
 *                 io[0] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 *             else:
 */
  __pyx_tuple__224 = PyTuple_Pack(1, __pyx_kp_u_subprocess_STDOUT_is_supported_o); if (unlikely(!__pyx_tuple__224)) __PYX_ERR(6, 443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__224);
  __Pyx_GIVEREF(__pyx_tuple__224);

  /* "uvloop/handles/process.pyx":471
 *                 io[1] = self._file_devnull()
 *             elif _stdout == subprocess_STDOUT:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     'subprocess.STDOUT is supported only by stderr parameter')
 *             else:
 */
  __pyx_tuple__225 = PyTuple_Pack(1, __pyx_kp_u_subprocess_STDOUT_is_supported_o); if (unlikely(!__pyx_tuple__225)) __PYX_ERR(6, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__225);
  __Pyx_GIVEREF(__pyx_tuple__225);

  /* "uvloop/handles/process.pyx":493
 *                 if io[1] is None:
 *                     # shouldn't ever happen
 *                     raise RuntimeError('cannot apply subprocess.STDOUT')             # <<<<<<<<<<<<<<
 * 
 *                 newfd = os_dup(io[1])
 */
  __pyx_tuple__226 = PyTuple_Pack(1, __pyx_kp_u_cannot_apply_subprocess_STDOUT); if (unlikely(!__pyx_tuple__226)) __PYX_ERR(6, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__226);
  __Pyx_GIVEREF(__pyx_tuple__226);

  /* "uvloop/handles/process.pyx":523
 *         else:
 *             if waiter is not None and not waiter.cancelled():
 *                 waiter.set_result(True)             # <<<<<<<<<<<<<<
 * 
 *         self._stdio_ready = 1
 */
  __pyx_tuple__227 = PyTuple_Pack(1, Py_True); if (unlikely(!__pyx_tuple__227)) __PYX_ERR(6, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__227);
  __Pyx_GIVEREF(__pyx_tuple__227);

  /* "uvloop/handles/process.pyx":552
 *                 self._loop.call_soon(self._protocol.connection_lost, None)
 *             else:
 *                 self._pending_calls.append((_CALL_CONNECTION_LOST, None, None))             # <<<<<<<<<<<<<<
 * 
 *     def __stdio_inited(self, waiter, stdio_fut):
 */
  __pyx_tuple__228 = PyTuple_Pack(3, __pyx_int_3, Py_None, Py_None); if (unlikely(!__pyx_tuple__228)) __PYX_ERR(6, 552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__228);
  __Pyx_GIVEREF(__pyx_tuple__228);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__229 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__229)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__229);
  __Pyx_GIVEREF(__pyx_tuple__229);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__230 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__230)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__230);
  __Pyx_GIVEREF(__pyx_tuple__230);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__231 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__231)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__231);
  __Pyx_GIVEREF(__pyx_tuple__231);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__232 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__232)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__232);
  __Pyx_GIVEREF(__pyx_tuple__232);

  /* "uvloop/dns.pyx":22
 *             return socket_getservbyname(port, 'udp')
 * 
 *     raise OSError('service/proto not found')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__233 = PyTuple_Pack(1, __pyx_kp_u_service_proto_not_found); if (unlikely(!__pyx_tuple__233)) __PYX_ERR(7, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__233);
  __Pyx_GIVEREF(__pyx_tuple__233);

  /* "uvloop/dns.pyx":63
 *         )
 * 
 *     raise RuntimeError("cannot convert sockaddr into Python object")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__234 = PyTuple_Pack(1, __pyx_kp_u_cannot_convert_sockaddr_into_Pyt); if (unlikely(!__pyx_tuple__234)) __PYX_ERR(7, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__234);
  __Pyx_GIVEREF(__pyx_tuple__234);

  /* "uvloop/dns.pyx":76
 *     if family == uv.AF_INET:
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET address must be tuple')             # <<<<<<<<<<<<<<
 *         if len(addr) != 2:
 *             raise ValueError('AF_INET address must be tuple of (host, port)')
 */
  __pyx_tuple__235 = PyTuple_Pack(1, __pyx_kp_u_AF_INET_address_must_be_tuple); if (unlikely(!__pyx_tuple__235)) __PYX_ERR(7, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__235);
  __Pyx_GIVEREF(__pyx_tuple__235);

  /* "uvloop/dns.pyx":78
 *             raise TypeError('AF_INET address must be tuple')
 *         if len(addr) != 2:
 *             raise ValueError('AF_INET address must be tuple of (host, port)')             # <<<<<<<<<<<<<<
 *         host, port = addr
 *         if isinstance(host, str):
 */
  __pyx_tuple__236 = PyTuple_Pack(1, __pyx_kp_u_AF_INET_address_must_be_tuple_of); if (unlikely(!__pyx_tuple__236)) __PYX_ERR(7, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__236);
  __Pyx_GIVEREF(__pyx_tuple__236);

  /* "uvloop/dns.pyx":83
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')             # <<<<<<<<<<<<<<
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 */
  __pyx_tuple__237 = PyTuple_Pack(1, __pyx_n_u_ascii); if (unlikely(!__pyx_tuple__237)) __PYX_ERR(7, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__237);
  __Pyx_GIVEREF(__pyx_tuple__237);

  /* "uvloop/dns.pyx":85
 *                 host = host.encode('ascii')
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')             # <<<<<<<<<<<<<<
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')
 */
  __pyx_tuple__238 = PyTuple_Pack(1, __pyx_n_u_idna); if (unlikely(!__pyx_tuple__238)) __PYX_ERR(7, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__238);
  __Pyx_GIVEREF(__pyx_tuple__238);

  /* "uvloop/dns.pyx":87
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')             # <<<<<<<<<<<<<<
 * 
 *         port = __port_to_int(port, None)
 */
  __pyx_tuple__239 = PyTuple_Pack(1, __pyx_kp_u_host_must_be_a_string_or_bytes_o); if (unlikely(!__pyx_tuple__239)) __PYX_ERR(7, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__239);
  __Pyx_GIVEREF(__pyx_tuple__239);

  /* "uvloop/dns.pyx":97
 *     elif family == uv.AF_INET6:
 *         if not isinstance(addr, tuple):
 *             raise TypeError('AF_INET6 address must be tuple')             # <<<<<<<<<<<<<<
 * 
 *         addr_len = len(addr)
 */
  __pyx_tuple__240 = PyTuple_Pack(1, __pyx_kp_u_AF_INET6_address_must_be_tuple); if (unlikely(!__pyx_tuple__240)) __PYX_ERR(7, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__240);
  __Pyx_GIVEREF(__pyx_tuple__240);

  /* "uvloop/dns.pyx":101
 *         addr_len = len(addr)
 *         if addr_len < 2 or addr_len > 4:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 'AF_INET6 must be a tuple of 2-4 parameters: '
 *                 '(host, port, flowinfo?, scope_id?)')
 */
  __pyx_tuple__241 = PyTuple_Pack(1, __pyx_kp_u_AF_INET6_must_be_a_tuple_of_2_4); if (unlikely(!__pyx_tuple__241)) __PYX_ERR(7, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__241);
  __Pyx_GIVEREF(__pyx_tuple__241);

  /* "uvloop/dns.pyx":109
 *             try:
 *                 # idna codec is rather slow, so we try ascii first.
 *                 host = host.encode('ascii')             # <<<<<<<<<<<<<<
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')
 */
  __pyx_tuple__242 = PyTuple_Pack(1, __pyx_n_u_ascii); if (unlikely(!__pyx_tuple__242)) __PYX_ERR(7, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__242);
  __Pyx_GIVEREF(__pyx_tuple__242);

  /* "uvloop/dns.pyx":111
 *                 host = host.encode('ascii')
 *             except UnicodeEncodeError:
 *                 host = host.encode('idna')             # <<<<<<<<<<<<<<
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')
 */
  __pyx_tuple__243 = PyTuple_Pack(1, __pyx_n_u_idna); if (unlikely(!__pyx_tuple__243)) __PYX_ERR(7, 111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__243);
  __Pyx_GIVEREF(__pyx_tuple__243);

  /* "uvloop/dns.pyx":113
 *                 host = host.encode('idna')
 *         if not isinstance(host, (bytes, bytearray)):
 *             raise TypeError('host must be a string or bytes object')             # <<<<<<<<<<<<<<
 * 
 *         port = __port_to_int(addr[1], None)
 */
  __pyx_tuple__244 = PyTuple_Pack(1, __pyx_kp_u_host_must_be_a_string_or_bytes_o); if (unlikely(!__pyx_tuple__244)) __PYX_ERR(7, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__244);
  __Pyx_GIVEREF(__pyx_tuple__244);

  /* "uvloop/dns.pyx":225
 * 
 *         if self.data is NULL:
 *             raise RuntimeError('AddrInfo.data is NULL')             # <<<<<<<<<<<<<<
 * 
 *         ptr = self.data
 */
  __pyx_tuple__245 = PyTuple_Pack(1, __pyx_kp_u_AddrInfo_data_is_NULL); if (unlikely(!__pyx_tuple__245)) __PYX_ERR(7, 225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__245);
  __Pyx_GIVEREF(__pyx_tuple__245);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__246 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__246)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__246);
  __Pyx_GIVEREF(__pyx_tuple__246);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__247 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__247)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__247);
  __Pyx_GIVEREF(__pyx_tuple__247);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__248 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__248)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__248);
  __Pyx_GIVEREF(__pyx_tuple__248);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__249 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__249)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__249);
  __Pyx_GIVEREF(__pyx_tuple__249);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__250 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__250)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__250);
  __Pyx_GIVEREF(__pyx_tuple__250);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__251 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__251)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__251);
  __Pyx_GIVEREF(__pyx_tuple__251);

  /* "uvloop/dns.pyx":329
 * 
 *     if resolver.data is NULL:
 *         aio_logger.error(             # <<<<<<<<<<<<<<
 *             'AddrInfoRequest callback called with NULL resolver.data')
 *         return
 */
  __pyx_tuple__252 = PyTuple_Pack(1, __pyx_kp_u_AddrInfoRequest_callback_called); if (unlikely(!__pyx_tuple__252)) __PYX_ERR(7, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__252);
  __Pyx_GIVEREF(__pyx_tuple__252);

  /* "uvloop/sslproto.pyx":6
 * cdef _create_transport_context(server_side, server_hostname):
 *     if server_side:
 *         raise ValueError('Server side SSL needs a valid SSLContext')             # <<<<<<<<<<<<<<
 * 
 *     # Client side may pass ssl=True to use a default
 */
  __pyx_tuple__253 = PyTuple_Pack(1, __pyx_kp_u_Server_side_SSL_needs_a_valid_SS); if (unlikely(!__pyx_tuple__253)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__253);
  __Pyx_GIVEREF(__pyx_tuple__253);

  /* "uvloop/sslproto.pyx":93
 *         """
 *         if self._state is not _UNWRAPPED:
 *             raise RuntimeError('handshake in progress or completed')             # <<<<<<<<<<<<<<
 *         self._sslobj = self._context.wrap_bio(
 *             self._incoming, self._outgoing,
 */
  __pyx_tuple__254 = PyTuple_Pack(1, __pyx_kp_u_handshake_in_progress_or_complet); if (unlikely(!__pyx_tuple__254)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__254);
  __Pyx_GIVEREF(__pyx_tuple__254);

  /* "uvloop/sslproto.pyx":114
 *         """
 *         if self._state is _UNWRAPPED:
 *             raise RuntimeError('no security layer present')             # <<<<<<<<<<<<<<
 *         if self._state is _SHUTDOWN:
 *             raise RuntimeError('shutdown in progress')
 */
  __pyx_tuple__255 = PyTuple_Pack(1, __pyx_kp_u_no_security_layer_present); if (unlikely(!__pyx_tuple__255)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__255);
  __Pyx_GIVEREF(__pyx_tuple__255);

  /* "uvloop/sslproto.pyx":116
 *             raise RuntimeError('no security layer present')
 *         if self._state is _SHUTDOWN:
 *             raise RuntimeError('shutdown in progress')             # <<<<<<<<<<<<<<
 *         assert self._state in (_WRAPPED, _DO_HANDSHAKE)
 *         self._state = _SHUTDOWN
 */
  __pyx_tuple__256 = PyTuple_Pack(1, __pyx_kp_u_shutdown_in_progress); if (unlikely(!__pyx_tuple__256)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__256);
  __Pyx_GIVEREF(__pyx_tuple__256);

  /* "uvloop/sslproto.pyx":174
 *                 self._state = _WRAPPED
 *                 if self._handshake_cb:
 *                     self._handshake_cb(None)             # <<<<<<<<<<<<<<
 *                 if only_handshake:
 *                     return (ssldata, appdata)
 */
  __pyx_tuple__257 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__257)) __PYX_ERR(0, 174, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__257);
  __Pyx_GIVEREF(__pyx_tuple__257);

  /* "uvloop/sslproto.pyx":312
 *         tr = self._ssl_protocol._transport
 *         if tr is None:
 *             raise RuntimeError('SSL transport has not been initialized yet')             # <<<<<<<<<<<<<<
 *         return tr.is_reading()
 * 
 */
  __pyx_tuple__258 = PyTuple_Pack(1, __pyx_kp_u_SSL_transport_has_not_been_initi); if (unlikely(!__pyx_tuple__258)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__258);
  __Pyx_GIVEREF(__pyx_tuple__258);

  /* "uvloop/sslproto.pyx":453
 *                 self._waiter.set_exception(exc)
 *             else:
 *                 self._waiter.set_result(None)             # <<<<<<<<<<<<<<
 *         self._waiter = None
 * 
 */
  __pyx_tuple__259 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__259)) __PYX_ERR(0, 453, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__259);
  __Pyx_GIVEREF(__pyx_tuple__259);

  /* "uvloop/sslproto.pyx":548
 *                 keep_open = self._app_protocol.eof_received()
 *                 if keep_open:
 *                     aio_logger.warning('returning true from eof_received() '             # <<<<<<<<<<<<<<
 *                                        'has no effect when using ssl')
 *         finally:
 */
  __pyx_tuple__260 = PyTuple_Pack(1, __pyx_kp_u_returning_true_from_eof_received); if (unlikely(!__pyx_tuple__260)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__260);
  __Pyx_GIVEREF(__pyx_tuple__260);

  /* "uvloop/sslproto.pyx":571
 *         else:
 *             self._in_shutdown = True
 *             self._write_appdata(b'')             # <<<<<<<<<<<<<<
 * 
 *     def _write_appdata(self, data):
 */
  __pyx_tuple__261 = PyTuple_Pack(1, __pyx_kp_b__7); if (unlikely(!__pyx_tuple__261)) __PYX_ERR(0, 571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__261);
  __Pyx_GIVEREF(__pyx_tuple__261);

  /* "uvloop/sslproto.pyx":587
 *         # (b'', 1) is a special value in _process_write_backlog() to do
 *         # the SSL handshake
 *         self._write_backlog.append((b'', 1))             # <<<<<<<<<<<<<<
 *         self._handshake_timeout_handle = \
 *             self._loop.call_later(self._ssl_handshake_timeout,
 */
  __pyx_tuple__262 = PyTuple_Pack(2, __pyx_kp_b__7, __pyx_int_1); if (unlikely(!__pyx_tuple__262)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__262);
  __Pyx_GIVEREF(__pyx_tuple__262);

  /* "uvloop/sslproto.pyx":722
 *         buf_len = len(buf)
 *         if not buf_len:
 *             raise RuntimeError('get_buffer() returned an empty buffer')             # <<<<<<<<<<<<<<
 * 
 *         if buf_len >= data_len:
 */
  __pyx_tuple__263 = PyTuple_Pack(1, __pyx_kp_u_get_buffer_returned_an_empty_buf); if (unlikely(!__pyx_tuple__263)) __PYX_ERR(0, 722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__263);
  __Pyx_GIVEREF(__pyx_tuple__263);

  /* "uvloop/handles/udp.pyx":57
 *             return
 *         try:
 *             data, addr = self.sock.recvfrom(UV_STREAM_RECV_BUF_SIZE)             # <<<<<<<<<<<<<<
 *         except (BlockingIOError, InterruptedError):
 *             pass
 */
  __pyx_tuple__264 = PyTuple_Pack(1, __pyx_int_256000); if (unlikely(!__pyx_tuple__264)) __PYX_ERR(22, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__264);
  __Pyx_GIVEREF(__pyx_tuple__264);

  /* "uvloop/handles/udp.pyx":164
 *         if self._conn_lost and self._address:
 *             if self._conn_lost >= LOG_THRESHOLD_FOR_CONNLOST_WRITES:
 *                 aio_logger.warning('socket.send() raised exception.')             # <<<<<<<<<<<<<<
 *             self._conn_lost += 1
 *             return
 */
  __pyx_tuple__265 = PyTuple_Pack(1, __pyx_kp_u_socket_send_raised_exception); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(22, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__266 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__266)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__266);
  __Pyx_GIVEREF(__pyx_tuple__266);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__267 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 */
  __pyx_tuple__268 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__268)) __PYX_ERR(9, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__268);
  __Pyx_GIVEREF(__pyx_tuple__268);

  /* "(tree fragment)":4
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("no default __reduce__ due to non-trivial __cinit__")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__269 = PyTuple_Pack(1, __pyx_kp_s_no_default___reduce___due_to_non); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(9, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):
 *     def wrap(Loop self, bint enabled):             # <<<<<<<<<<<<<<
 *         """wrap(self: 'Loop', enabled: bool)"""
 *         return f(self, enabled)
 */
  __pyx_tuple__271 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_enabled); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(9, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__271, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_wrap, 65, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(9, 65, __pyx_L1_error)

  /* "uvloop/loop.pyx":2983
 * class _SyncSocketReaderFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */
  __pyx_tuple__273 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_sock, __pyx_n_s_loop); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);
  __pyx_codeobj__274 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__273, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_loop_pyx, __pyx_n_s_init, 2983, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__274)) __PYX_ERR(2, 2983, __pyx_L1_error)

  /* "uvloop/loop.pyx":2988
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_reader(self.__sock)
 */
  __pyx_tuple__275 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__275)) __PYX_ERR(2, 2988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__275);
  __Pyx_GIVEREF(__pyx_tuple__275);
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__275, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_loop_pyx, __pyx_n_s_cancel, 2988, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(2, 2988, __pyx_L1_error)

  /* "uvloop/loop.pyx":2998
 * class _SyncSocketWriterFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */
  __pyx_tuple__277 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_sock, __pyx_n_s_loop); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(2, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__277, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_loop_pyx, __pyx_n_s_init, 2998, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(2, 2998, __pyx_L1_error)

  /* "uvloop/loop.pyx":3003
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_writer(self.__sock)
 */
  __pyx_tuple__279 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__279)) __PYX_ERR(2, 3003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__279);
  __Pyx_GIVEREF(__pyx_tuple__279);
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__279, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_loop_pyx, __pyx_n_s_cancel, 3003, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(2, 3003, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":674
 * class WriteSubprocessPipeProto(aio_BaseProtocol):
 * 
 *     def __init__(self, proc, fd):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if type(proc) is not UVProcessTransport:
 */
  __pyx_tuple__281 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_proc, __pyx_n_s_fd); if (unlikely(!__pyx_tuple__281)) __PYX_ERR(6, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__281);
  __Pyx_GIVEREF(__pyx_tuple__281);
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__281, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_handles_process_pyx, __pyx_n_s_init, 674, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(6, 674, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":685
 *         self.disconnected = False
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         self.pipe = transport
 * 
 */
  __pyx_tuple__283 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_transport); if (unlikely(!__pyx_tuple__283)) __PYX_ERR(6, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__283);
  __Pyx_GIVEREF(__pyx_tuple__283);
  __pyx_codeobj__284 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__283, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_handles_process_pyx, __pyx_n_s_connection_made, 685, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__284)) __PYX_ERR(6, 685, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":688
 *         self.pipe = transport
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return ('<%s fd=%s pipe=%r>'
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 */
  __pyx_tuple__285 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__285)) __PYX_ERR(6, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__285);
  __Pyx_GIVEREF(__pyx_tuple__285);
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__285, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_handles_process_pyx, __pyx_n_s_repr, 688, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(6, 688, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":692
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         self.disconnected = True
 *         (<UVProcessTransport>self.proc)._pipe_connection_lost(self.fd, exc)
 */
  __pyx_tuple__287 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__287)) __PYX_ERR(6, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__287);
  __Pyx_GIVEREF(__pyx_tuple__287);
  __pyx_codeobj__288 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__287, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_handles_process_pyx, __pyx_n_s_connection_lost, 692, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__288)) __PYX_ERR(6, 692, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":697
 *         self.proc = None
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 */
  __pyx_tuple__289 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__289)) __PYX_ERR(6, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__289);
  __Pyx_GIVEREF(__pyx_tuple__289);
  __pyx_codeobj__290 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__289, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_handles_process_pyx, __pyx_n_s_pause_writing, 697, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__290)) __PYX_ERR(6, 697, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":700
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.resume_writing()
 * 
 */
  __pyx_tuple__291 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__291)) __PYX_ERR(6, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__291);
  __Pyx_GIVEREF(__pyx_tuple__291);
  __pyx_codeobj__292 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__291, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_handles_process_pyx, __pyx_n_s_resume_writing, 700, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__292)) __PYX_ERR(6, 700, __pyx_L1_error)

  /* "uvloop/handles/process.pyx":707
 *                               aio_Protocol):
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._pipe_data_received(self.fd, data)
 * 
 */
  __pyx_tuple__293 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_data); if (unlikely(!__pyx_tuple__293)) __PYX_ERR(6, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__293);
  __Pyx_GIVEREF(__pyx_tuple__293);
  __pyx_codeobj__294 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__293, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_handles_process_pyx, __pyx_n_s_data_received, 707, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__294)) __PYX_ERR(6, 707, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":272
 *     # _sendfile_compatible = constants._SendfileMode.FALLBACK
 * 
 *     def __init__(self, loop, ssl_protocol):             # <<<<<<<<<<<<<<
 *         self._loop = loop
 *         # SSLProtocol instance
 */
  __pyx_tuple__295 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_loop, __pyx_n_s_ssl_protocol); if (unlikely(!__pyx_tuple__295)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__295);
  __Pyx_GIVEREF(__pyx_tuple__295);
  __pyx_codeobj__296 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__295, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_init, 272, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__296)) __PYX_ERR(0, 272, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":278
 *         self._closed = False
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         """Get optional transport information."""
 *         return self._ssl_protocol._get_extra_info(name, default)
 */
  __pyx_tuple__297 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_name_2, __pyx_n_s_default); if (unlikely(!__pyx_tuple__297)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__297);
  __Pyx_GIVEREF(__pyx_tuple__297);
  __pyx_codeobj__298 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__297, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_get_extra_info, 278, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__298)) __PYX_ERR(0, 278, __pyx_L1_error)
  __pyx_tuple__299 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__299)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__299);
  __Pyx_GIVEREF(__pyx_tuple__299);

  /* "uvloop/sslproto.pyx":282
 *         return self._ssl_protocol._get_extra_info(name, default)
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 */
  __pyx_tuple__300 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_protocol); if (unlikely(!__pyx_tuple__300)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__300);
  __Pyx_GIVEREF(__pyx_tuple__300);
  __pyx_codeobj__301 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__300, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_set_protocol, 282, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__301)) __PYX_ERR(0, 282, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":285
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._ssl_protocol._app_protocol
 * 
 */
  __pyx_tuple__302 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__302)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__302);
  __Pyx_GIVEREF(__pyx_tuple__302);
  __pyx_codeobj__303 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__302, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_get_protocol, 285, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__303)) __PYX_ERR(0, 285, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":288
 *         return self._ssl_protocol._app_protocol
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closed
 * 
 */
  __pyx_tuple__304 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__304)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__304);
  __Pyx_GIVEREF(__pyx_tuple__304);
  __pyx_codeobj__305 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__304, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_is_closing, 288, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__305)) __PYX_ERR(0, 288, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":291
 *         return self._closed
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         """Close the transport.
 * 
 */
  __pyx_tuple__306 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__306)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__306);
  __Pyx_GIVEREF(__pyx_tuple__306);
  __pyx_codeobj__307 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__306, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_close, 291, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__307)) __PYX_ERR(0, 291, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":302
 *         self._ssl_protocol._start_shutdown()
 * 
 *     def __del__(self):             # <<<<<<<<<<<<<<
 *         if not self._closed:
 *             _warn_with_source(
 */
  __pyx_tuple__308 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__308)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__308);
  __Pyx_GIVEREF(__pyx_tuple__308);
  __pyx_codeobj__309 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__308, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_del, 302, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__309)) __PYX_ERR(0, 302, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":309
 *             self.close()
 * 
 *     def is_reading(self):             # <<<<<<<<<<<<<<
 *         tr = self._ssl_protocol._transport
 *         if tr is None:
 */
  __pyx_tuple__310 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_tr); if (unlikely(!__pyx_tuple__310)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__310);
  __Pyx_GIVEREF(__pyx_tuple__310);
  __pyx_codeobj__311 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__310, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_is_reading, 309, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__311)) __PYX_ERR(0, 309, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":315
 *         return tr.is_reading()
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         """Pause the receiving end.
 * 
 */
  __pyx_tuple__312 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__312)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__312);
  __Pyx_GIVEREF(__pyx_tuple__312);
  __pyx_codeobj__313 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__312, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_pause_reading, 315, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__313)) __PYX_ERR(0, 315, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":323
 *         self._ssl_protocol._transport.pause_reading()
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         """Resume the receiving end.
 * 
 */
  __pyx_tuple__314 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__314)) __PYX_ERR(0, 323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__314);
  __Pyx_GIVEREF(__pyx_tuple__314);
  __pyx_codeobj__315 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__314, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_resume_reading, 323, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__315)) __PYX_ERR(0, 323, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":331
 *         self._ssl_protocol._transport.resume_reading()
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         """Set the high- and low-water limits for write flow control.
 * 
 */
  __pyx_tuple__316 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_high_2, __pyx_n_s_low); if (unlikely(!__pyx_tuple__316)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__316);
  __Pyx_GIVEREF(__pyx_tuple__316);
  __pyx_codeobj__317 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__316, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_set_write_buffer_limits, 331, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__317)) __PYX_ERR(0, 331, __pyx_L1_error)
  __pyx_tuple__318 = PyTuple_Pack(2, ((PyObject *)Py_None), ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__318)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__318);
  __Pyx_GIVEREF(__pyx_tuple__318);

  /* "uvloop/sslproto.pyx":352
 *         self._ssl_protocol._transport.set_write_buffer_limits(high, low)
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         """Return the current size of the write buffer."""
 *         return self._ssl_protocol._transport.get_write_buffer_size()
 */
  __pyx_tuple__319 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__319)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__319);
  __Pyx_GIVEREF(__pyx_tuple__319);
  __pyx_codeobj__320 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__319, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_get_write_buffer_size, 352, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__320)) __PYX_ERR(0, 352, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":357
 * 
 *     @property
 *     def _protocol_paused(self):             # <<<<<<<<<<<<<<
 *         # Required for sendfile fallback pause_writing/resume_writing logic
 *         return self._ssl_protocol._transport._protocol_paused
 */
  __pyx_tuple__321 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__321)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__321);
  __Pyx_GIVEREF(__pyx_tuple__321);
  __pyx_codeobj__322 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__321, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_protocol_paused, 357, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__322)) __PYX_ERR(0, 357, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":361
 *         return self._ssl_protocol._transport._protocol_paused
 * 
 *     def write(self, data):             # <<<<<<<<<<<<<<
 *         """Write some data bytes to the transport.
 * 
 */
  __pyx_tuple__323 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_data); if (unlikely(!__pyx_tuple__323)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__323);
  __Pyx_GIVEREF(__pyx_tuple__323);
  __pyx_codeobj__324 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__323, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_write, 361, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__324)) __PYX_ERR(0, 361, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":374
 *         self._ssl_protocol._write_appdata(data)
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         """Return True if this transport supports write_eof(), False if not."""
 *         return False
 */
  __pyx_tuple__325 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__325)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__325);
  __Pyx_GIVEREF(__pyx_tuple__325);
  __pyx_codeobj__326 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__325, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_can_write_eof, 374, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__326)) __PYX_ERR(0, 374, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":378
 *         return False
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         """Close the transport immediately.
 * 
 */
  __pyx_tuple__327 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__327)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__327);
  __Pyx_GIVEREF(__pyx_tuple__327);
  __pyx_codeobj__328 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__327, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_abort_2, 378, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__328)) __PYX_ERR(0, 378, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":389
 * 
 * 
 * class SSLProtocol(object):             # <<<<<<<<<<<<<<
 *     """SSL protocol.
 * 
 */
  __pyx_tuple__329 = PyTuple_Pack(1, __pyx_builtin_object); if (unlikely(!__pyx_tuple__329)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__329);
  __Pyx_GIVEREF(__pyx_tuple__329);

  /* "uvloop/sslproto.pyx":396
 *     """
 * 
 *     def __init__(self, loop, app_protocol, sslcontext, waiter,             # <<<<<<<<<<<<<<
 *                  server_side=False, server_hostname=None,
 *                  call_connection_made=True,
 */
  __pyx_tuple__330 = PyTuple_Pack(9, __pyx_n_s_self_2, __pyx_n_s_loop, __pyx_n_s_app_protocol_2, __pyx_n_s_sslcontext, __pyx_n_s_waiter, __pyx_n_s_server_side, __pyx_n_s_server_hostname, __pyx_n_s_call_connection_made, __pyx_n_s_ssl_handshake_timeout); if (unlikely(!__pyx_tuple__330)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__330);
  __Pyx_GIVEREF(__pyx_tuple__330);
  __pyx_codeobj__331 = (PyObject*)__Pyx_PyCode_New(9, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__330, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_init, 396, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__331)) __PYX_ERR(0, 396, __pyx_L1_error)
  __pyx_tuple__332 = PyTuple_Pack(4, ((PyObject *)Py_False), ((PyObject *)Py_None), ((PyObject *)Py_True), ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__332)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__332);
  __Pyx_GIVEREF(__pyx_tuple__332);

  /* "uvloop/sslproto.pyx":439
 *         self._ssl_handshake_timeout = ssl_handshake_timeout
 * 
 *     def _set_app_protocol(self, app_protocol):             # <<<<<<<<<<<<<<
 *         self._app_protocol = app_protocol
 *         self._app_protocol_is_buffer = (
 */
  __pyx_tuple__333 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_app_protocol_2); if (unlikely(!__pyx_tuple__333)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__333);
  __Pyx_GIVEREF(__pyx_tuple__333);
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__333, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_set_app_protocol, 439, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(0, 439, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":446
 *         )
 * 
 *     def _wakeup_waiter(self, exc=None):             # <<<<<<<<<<<<<<
 *         if self._waiter is None:
 *             return
 */
  __pyx_tuple__335 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__335)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__335);
  __Pyx_GIVEREF(__pyx_tuple__335);
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__335, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_wakeup_waiter, 446, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(0, 446, __pyx_L1_error)
  __pyx_tuple__337 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__337)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__337);
  __Pyx_GIVEREF(__pyx_tuple__337);

  /* "uvloop/sslproto.pyx":456
 *         self._waiter = None
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is made.
 * 
 */
  __pyx_tuple__338 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_transport); if (unlikely(!__pyx_tuple__338)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__338);
  __Pyx_GIVEREF(__pyx_tuple__338);
  __pyx_codeobj__339 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__338, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_connection_made, 456, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__339)) __PYX_ERR(0, 456, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":467
 *         self._start_handshake()
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is lost or closed.
 * 
 */
  __pyx_tuple__340 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__340)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__340);
  __Pyx_GIVEREF(__pyx_tuple__340);
  __pyx_codeobj__341 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__340, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_connection_lost, 467, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__341)) __PYX_ERR(0, 467, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":482
 *         self._wakeup_waiter(exc)
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer goes over
 *         the high-water mark.
 */
  __pyx_tuple__342 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__342)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__342);
  __Pyx_GIVEREF(__pyx_tuple__342);
  __pyx_codeobj__343 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__342, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_pause_writing, 482, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__343)) __PYX_ERR(0, 482, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":488
 *         self._app_protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer drains below
 *         the low-water mark.
 */
  __pyx_tuple__344 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__344)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__344);
  __Pyx_GIVEREF(__pyx_tuple__344);
  __pyx_codeobj__345 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__344, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_resume_writing, 488, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__345)) __PYX_ERR(0, 488, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":494
 *         self._app_protocol.resume_writing()
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         """Called when some SSL data is received.
 * 
 */
  __pyx_tuple__346 = PyTuple_Pack(8, __pyx_n_s_self_2, __pyx_n_s_data, __pyx_n_s_ssldata, __pyx_n_s_appdata, __pyx_n_s_e, __pyx_n_s_msg, __pyx_n_s_chunk, __pyx_n_s_ex); if (unlikely(!__pyx_tuple__346)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__346);
  __Pyx_GIVEREF(__pyx_tuple__346);
  __pyx_codeobj__347 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__346, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_data_received, 494, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__347)) __PYX_ERR(0, 494, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":531
 *                 break
 * 
 *     def eof_received(self):             # <<<<<<<<<<<<<<
 *         """Called when the other end of the low-level stream
 *         is half-closed.
 */
  __pyx_tuple__348 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_keep_open); if (unlikely(!__pyx_tuple__348)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__348);
  __Pyx_GIVEREF(__pyx_tuple__348);
  __pyx_codeobj__349 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__348, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_eof_received, 531, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__349)) __PYX_ERR(0, 531, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":553
 *             self._transport.close()
 * 
 *     def _get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if name in self._extra:
 *             return self._extra[name]
 */
  __pyx_tuple__350 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_name_2, __pyx_n_s_default); if (unlikely(!__pyx_tuple__350)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__350);
  __Pyx_GIVEREF(__pyx_tuple__350);
  __pyx_codeobj__351 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__350, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_get_extra_info_2, 553, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__351)) __PYX_ERR(0, 553, __pyx_L1_error)
  __pyx_tuple__352 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__352)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__352);
  __Pyx_GIVEREF(__pyx_tuple__352);

  /* "uvloop/sslproto.pyx":561
 *             return default
 * 
 *     def _mark_closed(self):             # <<<<<<<<<<<<<<
 *         self._closed = True
 * 
 */
  __pyx_tuple__353 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__353)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__353);
  __Pyx_GIVEREF(__pyx_tuple__353);
  __pyx_codeobj__354 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__353, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_mark_closed, 561, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__354)) __PYX_ERR(0, 561, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":564
 *         self._closed = True
 * 
 *     def _start_shutdown(self):             # <<<<<<<<<<<<<<
 *         if self._in_shutdown:
 *             return
 */
  __pyx_tuple__355 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__355)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__355);
  __Pyx_GIVEREF(__pyx_tuple__355);
  __pyx_codeobj__356 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__355, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_start_shutdown, 564, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__356)) __PYX_ERR(0, 564, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":573
 *             self._write_appdata(b'')
 * 
 *     def _write_appdata(self, data):             # <<<<<<<<<<<<<<
 *         self._write_backlog.append((data, 0))
 *         self._write_buffer_size += len(data)
 */
  __pyx_tuple__357 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_data); if (unlikely(!__pyx_tuple__357)) __PYX_ERR(0, 573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__357);
  __Pyx_GIVEREF(__pyx_tuple__357);
  __pyx_codeobj__358 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__357, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_write_appdata, 573, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__358)) __PYX_ERR(0, 573, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":578
 *         self._process_write_backlog()
 * 
 *     def _start_handshake(self):             # <<<<<<<<<<<<<<
 *         if self._loop.get_debug():
 *             aio_logger.debug("%r starts SSL handshake", self)
 */
  __pyx_tuple__359 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__359)) __PYX_ERR(0, 578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__359);
  __Pyx_GIVEREF(__pyx_tuple__359);
  __pyx_codeobj__360 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__359, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_start_handshake, 578, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__360)) __PYX_ERR(0, 578, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":593
 *         self._process_write_backlog()
 * 
 *     def _check_handshake_timeout(self):             # <<<<<<<<<<<<<<
 *         if self._in_handshake is True:
 *             msg = (
 */
  __pyx_tuple__361 = PyTuple_Pack(2, __pyx_n_s_self_2, __pyx_n_s_msg); if (unlikely(!__pyx_tuple__361)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__361);
  __Pyx_GIVEREF(__pyx_tuple__361);
  __pyx_codeobj__362 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__361, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_check_handshake_timeout, 593, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__362)) __PYX_ERR(0, 593, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":602
 *             self._fatal_error(ConnectionAbortedError(msg))
 * 
 *     def _on_handshake_complete(self, handshake_exc):             # <<<<<<<<<<<<<<
 *         self._in_handshake = False
 *         self._handshake_timeout_handle.cancel()
 */
  __pyx_tuple__363 = PyTuple_Pack(7, __pyx_n_s_self_2, __pyx_n_s_handshake_exc, __pyx_n_s_sslobj, __pyx_n_s_peercert, __pyx_n_s_exc, __pyx_n_s_msg, __pyx_n_s_dt); if (unlikely(!__pyx_tuple__363)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__363);
  __Pyx_GIVEREF(__pyx_tuple__363);
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(2, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__363, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_on_handshake_complete, 602, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(0, 602, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":643
 *         self._loop.call_soon(self._process_write_backlog)
 * 
 *     def _process_write_backlog(self):             # <<<<<<<<<<<<<<
 *         # Try to make progress on the write backlog.
 *         if self._transport is None or self._sslpipe is None:
 */
  __pyx_tuple__365 = PyTuple_Pack(7, __pyx_n_s_self_2, __pyx_n_s_sslpipe_2, __pyx_n_s_i, __pyx_n_s_data, __pyx_n_s_offset, __pyx_n_s_ssldata, __pyx_n_s_exc); if (unlikely(!__pyx_tuple__365)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__365);
  __Pyx_GIVEREF(__pyx_tuple__365);
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(1, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_process_write_backlog, 643, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(0, 643, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":685
 *                 self._fatal_error(exc, 'Fatal error on SSL transport')
 * 
 *     def _fatal_error(self, exc, message='Fatal error on transport'):             # <<<<<<<<<<<<<<
 *         if self._transport:
 *             self._transport._force_close(exc)
 */
  __pyx_tuple__367 = PyTuple_Pack(3, __pyx_n_s_self_2, __pyx_n_s_exc, __pyx_n_s_message); if (unlikely(!__pyx_tuple__367)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__367);
  __Pyx_GIVEREF(__pyx_tuple__367);
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__367, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_fatal_error, 685, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(0, 685, __pyx_L1_error)
  __pyx_tuple__369 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_u_Fatal_error_on_transport_2)); if (unlikely(!__pyx_tuple__369)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__369);
  __Pyx_GIVEREF(__pyx_tuple__369);

  /* "uvloop/sslproto.pyx":702
 *             })
 * 
 *     def _finalize(self):             # <<<<<<<<<<<<<<
 *         self._sslpipe = None
 * 
 */
  __pyx_tuple__370 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__370)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__370);
  __Pyx_GIVEREF(__pyx_tuple__370);
  __pyx_codeobj__371 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__370, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_finalize, 702, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__371)) __PYX_ERR(0, 702, __pyx_L1_error)

  /* "uvloop/sslproto.pyx":708
 *             self._transport.close()
 * 
 *     def _abort(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._transport is not None:
 */
  __pyx_tuple__372 = PyTuple_Pack(1, __pyx_n_s_self_2); if (unlikely(!__pyx_tuple__372)) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__372);
  __Pyx_GIVEREF(__pyx_tuple__372);
  __pyx_codeobj__373 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__372, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_sslproto_pyx, __pyx_n_s_abort, 708, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__373)) __PYX_ERR(0, 708, __pyx_L1_error)

  /* "uvloop/loop.pyx":3103
 * 
 * @cython.iterable_coroutine
 * async def _test_coroutine_1():             # <<<<<<<<<<<<<<
 *     return 42
 */
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_uvloop_loop_pyx, __pyx_n_s_test_coroutine_1, 3103, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(2, 3103, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x88c0b03:
 *         from pickle import PickleError as __pyx_PickleError
 */
  __pyx_tuple__374 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__374)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__374);
  __Pyx_GIVEREF(__pyx_tuple__374);
  __pyx_codeobj__375 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__374, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_PseudoSocket, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__375)) __PYX_ERR(9, 1, __pyx_L1_error)
  __pyx_tuple__376 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__376)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__376);
  __Pyx_GIVEREF(__pyx_tuple__376);
  __pyx_codeobj__377 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__376, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle__SSLPipe, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__377)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  __pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyList_Type_copy.type = (PyObject*)&PyList_Type;
  __pyx_umethod_PyUnicode_Type_rstrip.type = (PyObject*)&PyUnicode_Type;
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(2, 1, __pyx_L1_error);
  __pyx_float_0_1 = PyFloat_FromDouble(0.1); if (unlikely(!__pyx_float_0_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_float_1e3 = PyFloat_FromDouble(1e3); if (unlikely(!__pyx_float_1e3)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_float_60_0 = PyFloat_FromDouble(60.0); if (unlikely(!__pyx_float_60_0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_42 = PyInt_FromLong(42); if (unlikely(!__pyx_int_42)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_100 = PyInt_FromLong(100); if (unlikely(!__pyx_int_100)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_1000 = PyInt_FromLong(1000); if (unlikely(!__pyx_int_1000)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_50000 = PyInt_FromLong(50000L); if (unlikely(!__pyx_int_50000)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_65536 = PyInt_FromLong(65536L); if (unlikely(!__pyx_int_65536)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_256000 = PyInt_FromLong(256000L); if (unlikely(!__pyx_int_256000)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_1048575 = PyInt_FromLong(1048575L); if (unlikely(!__pyx_int_1048575)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_59579947 = PyInt_FromLong(59579947L); if (unlikely(!__pyx_int_59579947)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_143395587 = PyInt_FromLong(143395587L); if (unlikely(!__pyx_int_143395587)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_3153600000 = PyInt_FromString((char *)"3153600000", 0, 0); if (unlikely(!__pyx_int_3153600000)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_4294967296 = PyInt_FromString((char *)"4294967296", 0, 0); if (unlikely(!__pyx_int_4294967296)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_modinit_global_init_code(void); /*proto*/
static int __Pyx_modinit_variable_export_code(void); /*proto*/
static int __Pyx_modinit_function_export_code(void); /*proto*/
static int __Pyx_modinit_type_init_code(void); /*proto*/
static int __Pyx_modinit_type_import_code(void); /*proto*/
static int __Pyx_modinit_variable_import_code(void); /*proto*/
static int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_6uvloop_4loop_aio_get_event_loop = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_CancelledError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_InvalidStateError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_TimeoutError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_Future = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_Task = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_ensure_future = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_gather = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_wait = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_wrap_future = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_logger = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_iscoroutine = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_iscoroutinefunction = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_BaseProtocol = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_Protocol = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_isfuture = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_get_running_loop = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_set_running_loop = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_debug_wrapper = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_AbstractChildWatcher = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_Transport = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_aio_FlowControlMixin = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_col_deque = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_col_Iterable = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_col_Counter = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_col_OrderedDict = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_cc_ThreadPoolExecutor = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_cc_Future = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_errno_EBADF = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_errno_EINVAL = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_ft_partial = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_gc_disable = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_iter_chain = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_inspect_isgenerator = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_gaierror = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_error = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_timeout = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_socket = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_socketpair = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_getservbyname = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_AddressFamily = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_socket_SocketKind = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_name = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_environ = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_dup = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_set_inheritable = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_get_inheritable = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_close = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_open = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_devnull = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_O_RDWR = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_pipe = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_read = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_remove = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_os_stat = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_stat_S_ISSOCK = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_sys_ignore_environment = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_sys_exc_info = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_sys_set_coroutine_wrapper = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_sys_get_coroutine_wrapper = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_sys_getframe = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_sys_version_info = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_ssl_SSLContext = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_ssl_MemoryBIO = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_ssl_create_default_context = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_ssl_SSLError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_ssl_CertificateError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_subprocess_SubprocessError = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_signal_signal = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_signal_siginterrupt = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_signal_set_wakeup_fd = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_signal_default_int_handler = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_signal_SIG_DFL = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_time_sleep = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_time_monotonic = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_tb_StackSummary = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_tb_walk_stack = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_tb_format_list = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_warnings_warn = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_weakref_WeakValueDictionary = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_weakref_WeakSet = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop_py_inf = Py_None; Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop__UNWRAPPED = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop__DO_HANDSHAKE = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop__WRAPPED = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop__SHUTDOWN = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_6uvloop_4loop___forking_loop = ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None); Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_6uvloop_4loop_UVHandle = &__pyx_vtable_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVHandle._start_init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *, struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_8UVHandle__start_init;
  __pyx_vtable_6uvloop_4loop_UVHandle._abort_init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__abort_init;
  __pyx_vtable_6uvloop_4loop_UVHandle._finish_init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__finish_init;
  __pyx_vtable_6uvloop_4loop_UVHandle._is_alive = (int (*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__is_alive;
  __pyx_vtable_6uvloop_4loop_UVHandle._ensure_alive = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__ensure_alive;
  __pyx_vtable_6uvloop_4loop_UVHandle._error = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_8UVHandle__error;
  __pyx_vtable_6uvloop_4loop_UVHandle._fatal_error = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *, PyObject *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error *__pyx_optional_args))__pyx_f_6uvloop_4loop_8UVHandle__fatal_error;
  __pyx_vtable_6uvloop_4loop_UVHandle._warn_unclosed = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__warn_unclosed;
  __pyx_vtable_6uvloop_4loop_UVHandle._dealloc_impl = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__dealloc_impl;
  __pyx_vtable_6uvloop_4loop_UVHandle._free = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__free;
  __pyx_vtable_6uvloop_4loop_UVHandle._close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVHandle__close;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVHandle) < 0) __PYX_ERR(4, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVHandle.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVHandle.tp_dictoffset && __pyx_type_6uvloop_4loop_UVHandle.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVHandle.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVHandle.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVHandle) < 0) __PYX_ERR(4, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVHandle", (PyObject *)&__pyx_type_6uvloop_4loop_UVHandle) < 0) __PYX_ERR(4, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVHandle) < 0) __PYX_ERR(4, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVHandle = &__pyx_type_6uvloop_4loop_UVHandle;
  __pyx_vtabptr_6uvloop_4loop_UVSocketHandle = &__pyx_vtable_6uvloop_4loop_UVSocketHandle;
  __pyx_vtable_6uvloop_4loop_UVSocketHandle.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVSocketHandle.__pyx_base._close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_14UVSocketHandle__close;
  __pyx_vtable_6uvloop_4loop_UVSocketHandle._fileno = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_14UVSocketHandle__fileno;
  __pyx_vtable_6uvloop_4loop_UVSocketHandle._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_14UVSocketHandle__new_socket;
  __pyx_vtable_6uvloop_4loop_UVSocketHandle._get_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_14UVSocketHandle__get_socket;
  __pyx_vtable_6uvloop_4loop_UVSocketHandle._attach_fileobj = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, PyObject *))__pyx_f_6uvloop_4loop_14UVSocketHandle__attach_fileobj;
  __pyx_vtable_6uvloop_4loop_UVSocketHandle._open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int))__pyx_f_6uvloop_4loop_14UVSocketHandle__open;
  __pyx_type_6uvloop_4loop_UVSocketHandle.tp_base = __pyx_ptype_6uvloop_4loop_UVHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVSocketHandle) < 0) __PYX_ERR(4, 228, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVSocketHandle.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVSocketHandle.tp_dictoffset && __pyx_type_6uvloop_4loop_UVSocketHandle.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVSocketHandle.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVSocketHandle.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVSocketHandle) < 0) __PYX_ERR(4, 228, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVSocketHandle", (PyObject *)&__pyx_type_6uvloop_4loop_UVSocketHandle) < 0) __PYX_ERR(4, 228, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVSocketHandle) < 0) __PYX_ERR(4, 228, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVSocketHandle = &__pyx_type_6uvloop_4loop_UVSocketHandle;
  __pyx_vtabptr_6uvloop_4loop_UVAsync = &__pyx_vtable_6uvloop_4loop_UVAsync;
  __pyx_vtable_6uvloop_4loop_UVAsync.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVAsync._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVAsync *, struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *))__pyx_f_6uvloop_4loop_7UVAsync__init;
  __pyx_vtable_6uvloop_4loop_UVAsync.send = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVAsync *))__pyx_f_6uvloop_4loop_7UVAsync_send;
  __pyx_vtable_6uvloop_4loop_UVAsync.new = (struct __pyx_obj_6uvloop_4loop_UVAsync *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *))__pyx_f_6uvloop_4loop_7UVAsync_new;
  __pyx_type_6uvloop_4loop_UVAsync.tp_base = __pyx_ptype_6uvloop_4loop_UVHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVAsync) < 0) __PYX_ERR(11, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVAsync.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVAsync.tp_dictoffset && __pyx_type_6uvloop_4loop_UVAsync.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVAsync.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVAsync.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVAsync) < 0) __PYX_ERR(11, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVAsync", (PyObject *)&__pyx_type_6uvloop_4loop_UVAsync) < 0) __PYX_ERR(11, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVAsync) < 0) __PYX_ERR(11, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVAsync = &__pyx_type_6uvloop_4loop_UVAsync;
  __pyx_vtabptr_6uvloop_4loop_UVTimer = &__pyx_vtable_6uvloop_4loop_UVTimer;
  __pyx_vtable_6uvloop_4loop_UVTimer.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVTimer._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVTimer *, struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *, uint64_t))__pyx_f_6uvloop_4loop_7UVTimer__init;
  __pyx_vtable_6uvloop_4loop_UVTimer.stop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVTimer *))__pyx_f_6uvloop_4loop_7UVTimer_stop;
  __pyx_vtable_6uvloop_4loop_UVTimer.start = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVTimer *))__pyx_f_6uvloop_4loop_7UVTimer_start;
  __pyx_vtable_6uvloop_4loop_UVTimer.new = (struct __pyx_obj_6uvloop_4loop_UVTimer *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, __pyx_t_6uvloop_4loop_method_t, PyObject *, uint64_t))__pyx_f_6uvloop_4loop_7UVTimer_new;
  __pyx_type_6uvloop_4loop_UVTimer.tp_base = __pyx_ptype_6uvloop_4loop_UVHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVTimer) < 0) __PYX_ERR(14, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVTimer.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVTimer.tp_dictoffset && __pyx_type_6uvloop_4loop_UVTimer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVTimer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVTimer.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVTimer) < 0) __PYX_ERR(14, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVTimer", (PyObject *)&__pyx_type_6uvloop_4loop_UVTimer) < 0) __PYX_ERR(14, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVTimer) < 0) __PYX_ERR(14, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVTimer = &__pyx_type_6uvloop_4loop_UVTimer;
  __pyx_vtabptr_6uvloop_4loop_UVIdle = &__pyx_vtable_6uvloop_4loop_UVIdle;
  __pyx_vtable_6uvloop_4loop_UVIdle.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVIdle._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVIdle *, struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_6UVIdle__init;
  __pyx_vtable_6uvloop_4loop_UVIdle.stop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVIdle *))__pyx_f_6uvloop_4loop_6UVIdle_stop;
  __pyx_vtable_6uvloop_4loop_UVIdle.start = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVIdle *))__pyx_f_6uvloop_4loop_6UVIdle_start;
  __pyx_vtable_6uvloop_4loop_UVIdle.new = (struct __pyx_obj_6uvloop_4loop_UVIdle *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_6UVIdle_new;
  __pyx_type_6uvloop_4loop_UVIdle.tp_base = __pyx_ptype_6uvloop_4loop_UVHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVIdle) < 0) __PYX_ERR(12, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVIdle.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVIdle.tp_dictoffset && __pyx_type_6uvloop_4loop_UVIdle.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVIdle.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVIdle.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVIdle) < 0) __PYX_ERR(12, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVIdle", (PyObject *)&__pyx_type_6uvloop_4loop_UVIdle) < 0) __PYX_ERR(12, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVIdle) < 0) __PYX_ERR(12, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVIdle = &__pyx_type_6uvloop_4loop_UVIdle;
  __pyx_vtabptr_6uvloop_4loop_UVBaseTransport = &__pyx_vtable_6uvloop_4loop_UVBaseTransport;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVSocketHandle;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport.__pyx_base.__pyx_base._fatal_error = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *, PyObject *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error *__pyx_optional_args))__pyx_f_6uvloop_4loop_15UVBaseTransport__fatal_error;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._set_write_buffer_limits = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, struct __pyx_opt_args_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits *__pyx_optional_args))__pyx_f_6uvloop_4loop_15UVBaseTransport__set_write_buffer_limits;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._maybe_pause_protocol = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_pause_protocol;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._maybe_resume_protocol = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__maybe_resume_protocol;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._schedule_call_connection_made = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_made;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._schedule_call_connection_lost = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *))__pyx_f_6uvloop_4loop_15UVBaseTransport__schedule_call_connection_lost;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._wakeup_waiter = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__wakeup_waiter;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._call_connection_made = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__call_connection_made;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._call_connection_lost = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *))__pyx_f_6uvloop_4loop_15UVBaseTransport__call_connection_lost;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._set_server = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, struct __pyx_obj_6uvloop_4loop_Server *))__pyx_f_6uvloop_4loop_15UVBaseTransport__set_server;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._set_waiter = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *))__pyx_f_6uvloop_4loop_15UVBaseTransport__set_waiter;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._set_protocol = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *))__pyx_f_6uvloop_4loop_15UVBaseTransport__set_protocol;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._clear_protocol = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__clear_protocol;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._init_protocol = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__init_protocol;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._add_extra_info = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_15UVBaseTransport__add_extra_info;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._get_write_buffer_size = (size_t (*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__get_write_buffer_size;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._is_reading = (int (*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__is_reading;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._start_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__start_reading;
  __pyx_vtable_6uvloop_4loop_UVBaseTransport._stop_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_15UVBaseTransport__stop_reading;
  __pyx_type_6uvloop_4loop_UVBaseTransport.tp_base = __pyx_ptype_6uvloop_4loop_UVSocketHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVBaseTransport) < 0) __PYX_ERR(16, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVBaseTransport.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVBaseTransport.tp_dictoffset && __pyx_type_6uvloop_4loop_UVBaseTransport.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVBaseTransport.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVBaseTransport.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVBaseTransport) < 0) __PYX_ERR(16, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVBaseTransport", (PyObject *)&__pyx_type_6uvloop_4loop_UVBaseTransport) < 0) __PYX_ERR(16, 2, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_UVBaseTransport.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_UVBaseTransport.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_UVBaseTransport, __weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVBaseTransport) < 0) __PYX_ERR(16, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVBaseTransport = &__pyx_type_6uvloop_4loop_UVBaseTransport;
  __pyx_vtabptr_6uvloop_4loop_Loop = &__pyx_vtable_6uvloop_4loop_Loop;
  __pyx_vtable_6uvloop_4loop_Loop._init_debug_fields = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__init_debug_fields;
  __pyx_vtable_6uvloop_4loop_Loop._on_wake = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__on_wake;
  __pyx_vtable_6uvloop_4loop_Loop._on_idle = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__on_idle;
  __pyx_vtable_6uvloop_4loop_Loop.__pyx___run = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, uv_run_mode))__pyx_f_6uvloop_4loop_4Loop___run;
  __pyx_vtable_6uvloop_4loop_Loop._run = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, uv_run_mode))__pyx_f_6uvloop_4loop_4Loop__run;
  __pyx_vtable_6uvloop_4loop_Loop._close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__close;
  __pyx_vtable_6uvloop_4loop_Loop._stop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__stop;
  __pyx_vtable_6uvloop_4loop_Loop._time = (uint64_t (*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__time;
  __pyx_vtable_6uvloop_4loop_Loop._queue_write = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_4Loop__queue_write;
  __pyx_vtable_6uvloop_4loop_Loop._exec_queued_writes = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__exec_queued_writes;
  __pyx_vtable_6uvloop_4loop_Loop._call_soon = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__call_soon;
  __pyx_vtable_6uvloop_4loop_Loop._call_soon_handle = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_4Loop__call_soon_handle;
  __pyx_vtable_6uvloop_4loop_Loop._call_later = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, uint64_t, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__call_later;
  __pyx_vtable_6uvloop_4loop_Loop._handle_exception = (void (*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__handle_exception;
  __pyx_vtable_6uvloop_4loop_Loop._new_future = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__new_future;
  __pyx_vtable_6uvloop_4loop_Loop._check_signal = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__check_signal;
  __pyx_vtable_6uvloop_4loop_Loop._check_closed = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__check_closed;
  __pyx_vtable_6uvloop_4loop_Loop._check_thread = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__check_thread;
  __pyx_vtable_6uvloop_4loop_Loop._getaddrinfo = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, int, int, int, int, int))__pyx_f_6uvloop_4loop_4Loop__getaddrinfo;
  __pyx_vtable_6uvloop_4loop_Loop._getnameinfo = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct sockaddr *, int))__pyx_f_6uvloop_4loop_4Loop__getnameinfo;
  __pyx_vtable_6uvloop_4loop_Loop._create_server = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct sockaddr *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, int, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__create_server;
  __pyx_vtable_6uvloop_4loop_Loop._track_transport = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_4Loop__track_transport;
  __pyx_vtable_6uvloop_4loop_Loop._fileobj_to_fd = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__fileobj_to_fd;
  __pyx_vtable_6uvloop_4loop_Loop._ensure_fd_no_transport = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__ensure_fd_no_transport;
  __pyx_vtable_6uvloop_4loop_Loop._track_process = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVProcess *))__pyx_f_6uvloop_4loop_4Loop__track_process;
  __pyx_vtable_6uvloop_4loop_Loop._untrack_process = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_UVProcess *))__pyx_f_6uvloop_4loop_4Loop__untrack_process;
  __pyx_vtable_6uvloop_4loop_Loop._add_reader = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_4Loop__add_reader;
  __pyx_vtable_6uvloop_4loop_Loop._has_reader = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__has_reader;
  __pyx_vtable_6uvloop_4loop_Loop._remove_reader = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__remove_reader;
  __pyx_vtable_6uvloop_4loop_Loop._add_writer = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_4Loop__add_writer;
  __pyx_vtable_6uvloop_4loop_Loop._has_writer = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__has_writer;
  __pyx_vtable_6uvloop_4loop_Loop._remove_writer = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__remove_writer;
  __pyx_vtable_6uvloop_4loop_Loop._sock_recv = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__sock_recv;
  __pyx_vtable_6uvloop_4loop_Loop._sock_recv_into = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__sock_recv_into;
  __pyx_vtable_6uvloop_4loop_Loop._sock_sendall = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__sock_sendall;
  __pyx_vtable_6uvloop_4loop_Loop._sock_accept = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__sock_accept;
  __pyx_vtable_6uvloop_4loop_Loop._sock_connect = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__sock_connect;
  __pyx_vtable_6uvloop_4loop_Loop._sock_connect_cb = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__sock_connect_cb;
  __pyx_vtable_6uvloop_4loop_Loop._sock_set_reuseport = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, int))__pyx_f_6uvloop_4loop_4Loop__sock_set_reuseport;
  __pyx_vtable_6uvloop_4loop_Loop._setup_signals = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__setup_signals;
  __pyx_vtable_6uvloop_4loop_Loop._shutdown_signals = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__shutdown_signals;
  __pyx_vtable_6uvloop_4loop_Loop._recv_signals_start = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__recv_signals_start;
  __pyx_vtable_6uvloop_4loop_Loop._recv_signals_stop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__recv_signals_stop;
  __pyx_vtable_6uvloop_4loop_Loop._handle_signal = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__handle_signal;
  __pyx_vtable_6uvloop_4loop_Loop._read_from_self = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__read_from_self;
  __pyx_vtable_6uvloop_4loop_Loop._ceval_process_signals = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__ceval_process_signals;
  __pyx_vtable_6uvloop_4loop_Loop._invoke_signals = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *))__pyx_f_6uvloop_4loop_4Loop__invoke_signals;
  __pyx_vtable_6uvloop_4loop_Loop._set_coroutine_debug = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, int))__pyx_f_6uvloop_4loop_4Loop__set_coroutine_debug;
  __pyx_vtable_6uvloop_4loop_Loop._print_debug_info = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_4Loop__print_debug_info;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_Loop) < 0) __PYX_ERR(2, 86, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_Loop.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_Loop.tp_dictoffset && __pyx_type_6uvloop_4loop_Loop.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_Loop.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_Loop.tp_dict, __pyx_vtabptr_6uvloop_4loop_Loop) < 0) __PYX_ERR(2, 86, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "Loop", (PyObject *)&__pyx_type_6uvloop_4loop_Loop) < 0) __PYX_ERR(2, 86, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_Loop.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_Loop.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_Loop, __weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_Loop) < 0) __PYX_ERR(2, 86, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_Loop = &__pyx_type_6uvloop_4loop_Loop;
  __pyx_vtabptr_6uvloop_4loop_Handle = &__pyx_vtable_6uvloop_4loop_Handle;
  __pyx_vtable_6uvloop_4loop_Handle._set_loop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Handle *, struct __pyx_obj_6uvloop_4loop_Loop *))__pyx_f_6uvloop_4loop_6Handle__set_loop;
  __pyx_vtable_6uvloop_4loop_Handle._set_context = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Handle *, PyObject *))__pyx_f_6uvloop_4loop_6Handle__set_context;
  __pyx_vtable_6uvloop_4loop_Handle._run = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_6Handle__run;
  __pyx_vtable_6uvloop_4loop_Handle._cancel = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_6Handle__cancel;
  __pyx_vtable_6uvloop_4loop_Handle._format_handle = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_6Handle__format_handle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_Handle) < 0) __PYX_ERR(3, 3, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_Handle.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_Handle.tp_dictoffset && __pyx_type_6uvloop_4loop_Handle.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_Handle.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_Handle.tp_dict, __pyx_vtabptr_6uvloop_4loop_Handle) < 0) __PYX_ERR(3, 3, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "Handle", (PyObject *)&__pyx_type_6uvloop_4loop_Handle) < 0) __PYX_ERR(3, 3, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_Handle.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_Handle.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_Handle, __weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_Handle) < 0) __PYX_ERR(3, 3, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_Handle = &__pyx_type_6uvloop_4loop_Handle;
  __pyx_vtabptr_6uvloop_4loop_TimerHandle = &__pyx_vtable_6uvloop_4loop_TimerHandle;
  __pyx_vtable_6uvloop_4loop_TimerHandle._run = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_TimerHandle *))__pyx_f_6uvloop_4loop_11TimerHandle__run;
  __pyx_vtable_6uvloop_4loop_TimerHandle._cancel = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_TimerHandle *))__pyx_f_6uvloop_4loop_11TimerHandle__cancel;
  __pyx_vtable_6uvloop_4loop_TimerHandle._clear = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_TimerHandle *))__pyx_f_6uvloop_4loop_11TimerHandle__clear;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_TimerHandle) < 0) __PYX_ERR(3, 167, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_TimerHandle.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_TimerHandle.tp_dictoffset && __pyx_type_6uvloop_4loop_TimerHandle.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_TimerHandle.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_TimerHandle.tp_dict, __pyx_vtabptr_6uvloop_4loop_TimerHandle) < 0) __PYX_ERR(3, 167, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "TimerHandle", (PyObject *)&__pyx_type_6uvloop_4loop_TimerHandle) < 0) __PYX_ERR(3, 167, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_TimerHandle.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_TimerHandle.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_TimerHandle, __weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_TimerHandle) < 0) __PYX_ERR(3, 167, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_TimerHandle = &__pyx_type_6uvloop_4loop_TimerHandle;
  __pyx_vtabptr_6uvloop_4loop_UVCheck = &__pyx_vtable_6uvloop_4loop_UVCheck;
  __pyx_vtable_6uvloop_4loop_UVCheck.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVCheck._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVCheck *, struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_7UVCheck__init;
  __pyx_vtable_6uvloop_4loop_UVCheck.stop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVCheck *))__pyx_f_6uvloop_4loop_7UVCheck_stop;
  __pyx_vtable_6uvloop_4loop_UVCheck.start = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVCheck *))__pyx_f_6uvloop_4loop_7UVCheck_start;
  __pyx_vtable_6uvloop_4loop_UVCheck.new = (struct __pyx_obj_6uvloop_4loop_UVCheck *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_7UVCheck_new;
  __pyx_type_6uvloop_4loop_UVCheck.tp_base = __pyx_ptype_6uvloop_4loop_UVHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVCheck) < 0) __PYX_ERR(13, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVCheck.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVCheck.tp_dictoffset && __pyx_type_6uvloop_4loop_UVCheck.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVCheck.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVCheck.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVCheck) < 0) __PYX_ERR(13, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVCheck", (PyObject *)&__pyx_type_6uvloop_4loop_UVCheck) < 0) __PYX_ERR(13, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVCheck) < 0) __PYX_ERR(13, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVCheck = &__pyx_type_6uvloop_4loop_UVCheck;
  __pyx_vtabptr_6uvloop_4loop_UVPoll = &__pyx_vtable_6uvloop_4loop_UVPoll;
  __pyx_vtable_6uvloop_4loop_UVPoll.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVPoll.__pyx_base._fatal_error = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *, PyObject *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error *__pyx_optional_args))__pyx_f_6uvloop_4loop_6UVPoll__fatal_error;
  __pyx_vtable_6uvloop_4loop_UVPoll.__pyx_base._close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_6UVPoll__close;
  __pyx_vtable_6uvloop_4loop_UVPoll._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *, struct __pyx_obj_6uvloop_4loop_Loop *, int))__pyx_f_6uvloop_4loop_6UVPoll__init;
  __pyx_vtable_6uvloop_4loop_UVPoll._poll_start = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *, int))__pyx_f_6uvloop_4loop_6UVPoll__poll_start;
  __pyx_vtable_6uvloop_4loop_UVPoll._poll_stop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *))__pyx_f_6uvloop_4loop_6UVPoll__poll_stop;
  __pyx_vtable_6uvloop_4loop_UVPoll.is_active = (int (*)(struct __pyx_obj_6uvloop_4loop_UVPoll *))__pyx_f_6uvloop_4loop_6UVPoll_is_active;
  __pyx_vtable_6uvloop_4loop_UVPoll.is_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *))__pyx_f_6uvloop_4loop_6UVPoll_is_reading;
  __pyx_vtable_6uvloop_4loop_UVPoll.is_writing = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *))__pyx_f_6uvloop_4loop_6UVPoll_is_writing;
  __pyx_vtable_6uvloop_4loop_UVPoll.start_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_6UVPoll_start_reading;
  __pyx_vtable_6uvloop_4loop_UVPoll.start_writing = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *, struct __pyx_obj_6uvloop_4loop_Handle *))__pyx_f_6uvloop_4loop_6UVPoll_start_writing;
  __pyx_vtable_6uvloop_4loop_UVPoll.stop_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *))__pyx_f_6uvloop_4loop_6UVPoll_stop_reading;
  __pyx_vtable_6uvloop_4loop_UVPoll.stop_writing = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *))__pyx_f_6uvloop_4loop_6UVPoll_stop_writing;
  __pyx_vtable_6uvloop_4loop_UVPoll.stop = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVPoll *))__pyx_f_6uvloop_4loop_6UVPoll_stop;
  __pyx_vtable_6uvloop_4loop_UVPoll.new = (struct __pyx_obj_6uvloop_4loop_UVPoll *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, int))__pyx_f_6uvloop_4loop_6UVPoll_new;
  __pyx_type_6uvloop_4loop_UVPoll.tp_base = __pyx_ptype_6uvloop_4loop_UVHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVPoll) < 0) __PYX_ERR(15, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVPoll.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVPoll.tp_dictoffset && __pyx_type_6uvloop_4loop_UVPoll.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVPoll.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVPoll.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVPoll) < 0) __PYX_ERR(15, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVPoll", (PyObject *)&__pyx_type_6uvloop_4loop_UVPoll) < 0) __PYX_ERR(15, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVPoll) < 0) __PYX_ERR(15, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVPoll = &__pyx_type_6uvloop_4loop_UVPoll;
  __pyx_vtabptr_6uvloop_4loop_UVStream = &__pyx_vtable_6uvloop_4loop_UVStream;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVBaseTransport;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base.__pyx_base.__pyx_base._close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_8UVStream__close;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base._set_protocol = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *, PyObject *))__pyx_f_6uvloop_4loop_8UVStream__set_protocol;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base._clear_protocol = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_8UVStream__clear_protocol;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base._get_write_buffer_size = (size_t (*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_8UVStream__get_write_buffer_size;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base._is_reading = (int (*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_8UVStream__is_reading;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base._start_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_8UVStream__start_reading;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx_base._stop_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_8UVStream__stop_reading;
  __pyx_vtable_6uvloop_4loop_UVStream._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *))__pyx_f_6uvloop_4loop_8UVStream__init;
  __pyx_vtable_6uvloop_4loop_UVStream._exec_write = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream__exec_write;
  __pyx_vtable_6uvloop_4loop_UVStream._shutdown = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream__shutdown;
  __pyx_vtable_6uvloop_4loop_UVStream._accept = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *, struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream__accept;
  __pyx_vtable_6uvloop_4loop_UVStream._close_on_read_error = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream__close_on_read_error;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx___reading_started = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream___reading_started;
  __pyx_vtable_6uvloop_4loop_UVStream.__pyx___reading_stopped = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream___reading_stopped;
  __pyx_vtable_6uvloop_4loop_UVStream._write = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *))__pyx_f_6uvloop_4loop_8UVStream__write;
  __pyx_vtable_6uvloop_4loop_UVStream._try_write = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *))__pyx_f_6uvloop_4loop_8UVStream__try_write;
  __pyx_vtable_6uvloop_4loop_UVStream._on_accept = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream__on_accept;
  __pyx_vtable_6uvloop_4loop_UVStream._on_eof = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream__on_eof;
  __pyx_vtable_6uvloop_4loop_UVStream._on_write = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *))__pyx_f_6uvloop_4loop_8UVStream__on_write;
  __pyx_vtable_6uvloop_4loop_UVStream._on_connect = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *))__pyx_f_6uvloop_4loop_8UVStream__on_connect;
  __pyx_type_6uvloop_4loop_UVStream.tp_base = __pyx_ptype_6uvloop_4loop_UVBaseTransport;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVStream) < 0) __PYX_ERR(18, 208, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVStream.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVStream.tp_dictoffset && __pyx_type_6uvloop_4loop_UVStream.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVStream.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVStream.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVStream) < 0) __PYX_ERR(18, 208, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVStream", (PyObject *)&__pyx_type_6uvloop_4loop_UVStream) < 0) __PYX_ERR(18, 208, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_UVStream.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_UVStream.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_UVStream, __pyx_base.__weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVStream) < 0) __PYX_ERR(18, 208, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVStream = &__pyx_type_6uvloop_4loop_UVStream;
  __pyx_vtabptr_6uvloop_4loop_UVStreamServer = &__pyx_vtable_6uvloop_4loop_UVStreamServer;
  __pyx_vtable_6uvloop_4loop_UVStreamServer.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVSocketHandle;
  __pyx_vtable_6uvloop_4loop_UVStreamServer.__pyx_base.__pyx_base._fatal_error = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *, PyObject *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8UVHandle__fatal_error *__pyx_optional_args))__pyx_f_6uvloop_4loop_14UVStreamServer__fatal_error;
  __pyx_vtable_6uvloop_4loop_UVStreamServer._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_14UVStreamServer__init;
  __pyx_vtable_6uvloop_4loop_UVStreamServer._mark_as_open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *))__pyx_f_6uvloop_4loop_14UVStreamServer__mark_as_open;
  __pyx_vtable_6uvloop_4loop_UVStreamServer.listen = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, PyObject *))__pyx_f_6uvloop_4loop_14UVStreamServer_listen;
  __pyx_vtable_6uvloop_4loop_UVStreamServer._on_listen = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *))__pyx_f_6uvloop_4loop_14UVStreamServer__on_listen;
  __pyx_vtable_6uvloop_4loop_UVStreamServer._make_new_transport = (struct __pyx_obj_6uvloop_4loop_UVStream *(*)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_14UVStreamServer__make_new_transport;
  __pyx_type_6uvloop_4loop_UVStreamServer.tp_base = __pyx_ptype_6uvloop_4loop_UVSocketHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVStreamServer) < 0) __PYX_ERR(19, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVStreamServer.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVStreamServer.tp_dictoffset && __pyx_type_6uvloop_4loop_UVStreamServer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVStreamServer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVStreamServer.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVStreamServer) < 0) __PYX_ERR(19, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVStreamServer", (PyObject *)&__pyx_type_6uvloop_4loop_UVStreamServer) < 0) __PYX_ERR(19, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVStreamServer) < 0) __PYX_ERR(19, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVStreamServer = &__pyx_type_6uvloop_4loop_UVStreamServer;
  __pyx_vtabptr_6uvloop_4loop_TCPServer = &__pyx_vtable_6uvloop_4loop_TCPServer;
  __pyx_vtable_6uvloop_4loop_TCPServer.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVStreamServer;
  __pyx_vtable_6uvloop_4loop_TCPServer.__pyx_base.__pyx_base._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_9TCPServer__new_socket;
  __pyx_vtable_6uvloop_4loop_TCPServer.__pyx_base.__pyx_base._open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int))__pyx_f_6uvloop_4loop_9TCPServer__open;
  __pyx_vtable_6uvloop_4loop_TCPServer.__pyx_base._make_new_transport = (struct __pyx_obj_6uvloop_4loop_UVStream *(*)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_9TCPServer__make_new_transport;
  __pyx_vtable_6uvloop_4loop_TCPServer.bind = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_TCPServer *, struct sockaddr *, struct __pyx_opt_args_6uvloop_4loop_9TCPServer_bind *__pyx_optional_args))__pyx_f_6uvloop_4loop_9TCPServer_bind;
  __pyx_vtable_6uvloop_4loop_TCPServer.new = (struct __pyx_obj_6uvloop_4loop_TCPServer *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, unsigned int, PyObject *))__pyx_f_6uvloop_4loop_9TCPServer_new;
  __pyx_type_6uvloop_4loop_TCPServer.tp_base = __pyx_ptype_6uvloop_4loop_UVStreamServer;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_TCPServer) < 0) __PYX_ERR(5, 57, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_TCPServer.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_TCPServer.tp_dictoffset && __pyx_type_6uvloop_4loop_TCPServer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_TCPServer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_TCPServer.tp_dict, __pyx_vtabptr_6uvloop_4loop_TCPServer) < 0) __PYX_ERR(5, 57, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "TCPServer", (PyObject *)&__pyx_type_6uvloop_4loop_TCPServer) < 0) __PYX_ERR(5, 57, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_TCPServer) < 0) __PYX_ERR(5, 57, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_TCPServer = &__pyx_type_6uvloop_4loop_TCPServer;
  __pyx_vtabptr_6uvloop_4loop_TCPTransport = &__pyx_vtable_6uvloop_4loop_TCPTransport;
  __pyx_vtable_6uvloop_4loop_TCPTransport.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVStream;
  __pyx_vtable_6uvloop_4loop_TCPTransport.__pyx_base.__pyx_base.__pyx_base._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_12TCPTransport__new_socket;
  __pyx_vtable_6uvloop_4loop_TCPTransport.__pyx_base.__pyx_base.__pyx_base._open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int))__pyx_f_6uvloop_4loop_12TCPTransport__open;
  __pyx_vtable_6uvloop_4loop_TCPTransport.__pyx_base.__pyx_base._call_connection_made = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_12TCPTransport__call_connection_made;
  __pyx_vtable_6uvloop_4loop_TCPTransport.bind = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_TCPTransport *, struct sockaddr *, struct __pyx_opt_args_6uvloop_4loop_12TCPTransport_bind *__pyx_optional_args))__pyx_f_6uvloop_4loop_12TCPTransport_bind;
  __pyx_vtable_6uvloop_4loop_TCPTransport.connect = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_TCPTransport *, struct sockaddr *))__pyx_f_6uvloop_4loop_12TCPTransport_connect;
  __pyx_vtable_6uvloop_4loop_TCPTransport._set_nodelay = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_TCPTransport *))__pyx_f_6uvloop_4loop_12TCPTransport__set_nodelay;
  __pyx_vtable_6uvloop_4loop_TCPTransport.new = (struct __pyx_obj_6uvloop_4loop_TCPTransport *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *))__pyx_f_6uvloop_4loop_12TCPTransport_new;
  __pyx_type_6uvloop_4loop_TCPTransport.tp_base = __pyx_ptype_6uvloop_4loop_UVStream;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_TCPTransport) < 0) __PYX_ERR(5, 99, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_TCPTransport.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_TCPTransport.tp_dictoffset && __pyx_type_6uvloop_4loop_TCPTransport.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_TCPTransport.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_TCPTransport.tp_dict, __pyx_vtabptr_6uvloop_4loop_TCPTransport) < 0) __PYX_ERR(5, 99, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "TCPTransport", (PyObject *)&__pyx_type_6uvloop_4loop_TCPTransport) < 0) __PYX_ERR(5, 99, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_TCPTransport.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_TCPTransport.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_TCPTransport, __pyx_base.__pyx_base.__weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_TCPTransport) < 0) __PYX_ERR(5, 99, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_TCPTransport = &__pyx_type_6uvloop_4loop_TCPTransport;
  __pyx_vtabptr_6uvloop_4loop_UnixServer = &__pyx_vtable_6uvloop_4loop_UnixServer;
  __pyx_vtable_6uvloop_4loop_UnixServer.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVStreamServer;
  __pyx_vtable_6uvloop_4loop_UnixServer.__pyx_base.__pyx_base._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_10UnixServer__new_socket;
  __pyx_vtable_6uvloop_4loop_UnixServer.__pyx_base.__pyx_base._open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int))__pyx_f_6uvloop_4loop_10UnixServer__open;
  __pyx_vtable_6uvloop_4loop_UnixServer.__pyx_base._make_new_transport = (struct __pyx_obj_6uvloop_4loop_UVStream *(*)(struct __pyx_obj_6uvloop_4loop_UVStreamServer *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_10UnixServer__make_new_transport;
  __pyx_vtable_6uvloop_4loop_UnixServer.bind = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UnixServer *, PyObject *))__pyx_f_6uvloop_4loop_10UnixServer_bind;
  __pyx_vtable_6uvloop_4loop_UnixServer.new = (struct __pyx_obj_6uvloop_4loop_UnixServer *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_10UnixServer_new;
  __pyx_type_6uvloop_4loop_UnixServer.tp_base = __pyx_ptype_6uvloop_4loop_UVStreamServer;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UnixServer) < 0) __PYX_ERR(20, 38, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UnixServer.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UnixServer.tp_dictoffset && __pyx_type_6uvloop_4loop_UnixServer.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UnixServer.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UnixServer.tp_dict, __pyx_vtabptr_6uvloop_4loop_UnixServer) < 0) __PYX_ERR(20, 38, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UnixServer", (PyObject *)&__pyx_type_6uvloop_4loop_UnixServer) < 0) __PYX_ERR(20, 38, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UnixServer) < 0) __PYX_ERR(20, 38, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UnixServer = &__pyx_type_6uvloop_4loop_UnixServer;
  __pyx_vtabptr_6uvloop_4loop_UnixTransport = &__pyx_vtable_6uvloop_4loop_UnixTransport;
  __pyx_vtable_6uvloop_4loop_UnixTransport.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVStream;
  __pyx_vtable_6uvloop_4loop_UnixTransport.__pyx_base.__pyx_base.__pyx_base._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_13UnixTransport__new_socket;
  __pyx_vtable_6uvloop_4loop_UnixTransport.__pyx_base.__pyx_base.__pyx_base._open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int))__pyx_f_6uvloop_4loop_13UnixTransport__open;
  __pyx_vtable_6uvloop_4loop_UnixTransport.new = (struct __pyx_obj_6uvloop_4loop_UnixTransport *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *))__pyx_f_6uvloop_4loop_13UnixTransport_new;
  __pyx_vtable_6uvloop_4loop_UnixTransport.connect = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UnixTransport *, char *))__pyx_f_6uvloop_4loop_13UnixTransport_connect;
  __pyx_type_6uvloop_4loop_UnixTransport.tp_base = __pyx_ptype_6uvloop_4loop_UVStream;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UnixTransport) < 0) __PYX_ERR(20, 78, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UnixTransport.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UnixTransport.tp_dictoffset && __pyx_type_6uvloop_4loop_UnixTransport.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UnixTransport.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UnixTransport.tp_dict, __pyx_vtabptr_6uvloop_4loop_UnixTransport) < 0) __PYX_ERR(20, 78, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UnixTransport", (PyObject *)&__pyx_type_6uvloop_4loop_UnixTransport) < 0) __PYX_ERR(20, 78, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_UnixTransport.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_UnixTransport.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_UnixTransport, __pyx_base.__pyx_base.__weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UnixTransport) < 0) __PYX_ERR(20, 78, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UnixTransport = &__pyx_type_6uvloop_4loop_UnixTransport;
  __pyx_vtabptr_6uvloop_4loop_ReadUnixTransport = &__pyx_vtable_6uvloop_4loop_ReadUnixTransport;
  __pyx_vtable_6uvloop_4loop_ReadUnixTransport.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVStream;
  __pyx_vtable_6uvloop_4loop_ReadUnixTransport.__pyx_base.__pyx_base.__pyx_base._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_17ReadUnixTransport__new_socket;
  __pyx_vtable_6uvloop_4loop_ReadUnixTransport.__pyx_base.__pyx_base.__pyx_base._open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int))__pyx_f_6uvloop_4loop_17ReadUnixTransport__open;
  __pyx_vtable_6uvloop_4loop_ReadUnixTransport.new = (struct __pyx_obj_6uvloop_4loop_ReadUnixTransport *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *))__pyx_f_6uvloop_4loop_17ReadUnixTransport_new;
  __pyx_type_6uvloop_4loop_ReadUnixTransport.tp_base = __pyx_ptype_6uvloop_4loop_UVStream;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_ReadUnixTransport) < 0) __PYX_ERR(20, 103, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_ReadUnixTransport.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_ReadUnixTransport.tp_dictoffset && __pyx_type_6uvloop_4loop_ReadUnixTransport.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_ReadUnixTransport.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_ReadUnixTransport.tp_dict, __pyx_vtabptr_6uvloop_4loop_ReadUnixTransport) < 0) __PYX_ERR(20, 103, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "ReadUnixTransport", (PyObject *)&__pyx_type_6uvloop_4loop_ReadUnixTransport) < 0) __PYX_ERR(20, 103, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_ReadUnixTransport.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_ReadUnixTransport.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_ReadUnixTransport, __pyx_base.__pyx_base.__weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_ReadUnixTransport) < 0) __PYX_ERR(20, 103, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_ReadUnixTransport = &__pyx_type_6uvloop_4loop_ReadUnixTransport;
  __pyx_vtabptr_6uvloop_4loop_WriteUnixTransport = &__pyx_vtable_6uvloop_4loop_WriteUnixTransport;
  __pyx_vtable_6uvloop_4loop_WriteUnixTransport.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVStream;
  __pyx_vtable_6uvloop_4loop_WriteUnixTransport.__pyx_base.__pyx_base.__pyx_base._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_18WriteUnixTransport__new_socket;
  __pyx_vtable_6uvloop_4loop_WriteUnixTransport.__pyx_base.__pyx_base.__pyx_base._open = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *, int))__pyx_f_6uvloop_4loop_18WriteUnixTransport__open;
  __pyx_vtable_6uvloop_4loop_WriteUnixTransport.new = (struct __pyx_obj_6uvloop_4loop_WriteUnixTransport *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, struct __pyx_obj_6uvloop_4loop_Server *, PyObject *))__pyx_f_6uvloop_4loop_18WriteUnixTransport_new;
  __pyx_type_6uvloop_4loop_WriteUnixTransport.tp_base = __pyx_ptype_6uvloop_4loop_UVStream;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_WriteUnixTransport) < 0) __PYX_ERR(20, 146, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_WriteUnixTransport.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_WriteUnixTransport.tp_dictoffset && __pyx_type_6uvloop_4loop_WriteUnixTransport.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_WriteUnixTransport.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_WriteUnixTransport.tp_dict, __pyx_vtabptr_6uvloop_4loop_WriteUnixTransport) < 0) __PYX_ERR(20, 146, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "WriteUnixTransport", (PyObject *)&__pyx_type_6uvloop_4loop_WriteUnixTransport) < 0) __PYX_ERR(20, 146, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_WriteUnixTransport.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_WriteUnixTransport.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_WriteUnixTransport, __pyx_base.__pyx_base.__weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_WriteUnixTransport) < 0) __PYX_ERR(20, 146, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_WriteUnixTransport = &__pyx_type_6uvloop_4loop_WriteUnixTransport;
  __pyx_vtabptr_6uvloop_4loop_UVProcess = &__pyx_vtable_6uvloop_4loop_UVProcess;
  __pyx_vtable_6uvloop_4loop_UVProcess.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVHandle;
  __pyx_vtable_6uvloop_4loop_UVProcess.__pyx_base._dealloc_impl = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_9UVProcess__dealloc_impl;
  __pyx_vtable_6uvloop_4loop_UVProcess.__pyx_base._close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_9UVProcess__close;
  __pyx_vtable_6uvloop_4loop_UVProcess._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_9UVProcess__init;
  __pyx_vtable_6uvloop_4loop_UVProcess._after_fork = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *))__pyx_f_6uvloop_4loop_9UVProcess__after_fork;
  __pyx_vtable_6uvloop_4loop_UVProcess.__pyx___to_cstring_array = (char **(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *))__pyx_f_6uvloop_4loop_9UVProcess___to_cstring_array;
  __pyx_vtable_6uvloop_4loop_UVProcess._init_args = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *))__pyx_f_6uvloop_4loop_9UVProcess__init_args;
  __pyx_vtable_6uvloop_4loop_UVProcess._init_env = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *))__pyx_f_6uvloop_4loop_9UVProcess__init_env;
  __pyx_vtable_6uvloop_4loop_UVProcess._init_files = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_9UVProcess__init_files;
  __pyx_vtable_6uvloop_4loop_UVProcess._init_options = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_9UVProcess__init_options;
  __pyx_vtable_6uvloop_4loop_UVProcess._close_after_spawn = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, int))__pyx_f_6uvloop_4loop_9UVProcess__close_after_spawn;
  __pyx_vtable_6uvloop_4loop_UVProcess._on_exit = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, int64_t, int))__pyx_f_6uvloop_4loop_9UVProcess__on_exit;
  __pyx_vtable_6uvloop_4loop_UVProcess._kill = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, int))__pyx_f_6uvloop_4loop_9UVProcess__kill;
  __pyx_type_6uvloop_4loop_UVProcess.tp_base = __pyx_ptype_6uvloop_4loop_UVHandle;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVProcess) < 0) __PYX_ERR(6, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVProcess.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVProcess.tp_dictoffset && __pyx_type_6uvloop_4loop_UVProcess.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVProcess.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVProcess.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVProcess) < 0) __PYX_ERR(6, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVProcess", (PyObject *)&__pyx_type_6uvloop_4loop_UVProcess) < 0) __PYX_ERR(6, 2, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVProcess) < 0) __PYX_ERR(6, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVProcess = &__pyx_type_6uvloop_4loop_UVProcess;
  __pyx_vtabptr_6uvloop_4loop_UVProcessTransport = &__pyx_vtable_6uvloop_4loop_UVProcessTransport;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVProcess;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport.__pyx_base._init_files = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_18UVProcessTransport__init_files;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport.__pyx_base._on_exit = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcess *, int64_t, int))__pyx_f_6uvloop_4loop_18UVProcessTransport__on_exit;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._file_redirect_stdio = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, int))__pyx_f_6uvloop_4loop_18UVProcessTransport__file_redirect_stdio;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._file_devnull = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *))__pyx_f_6uvloop_4loop_18UVProcessTransport__file_devnull;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._file_inpipe = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *))__pyx_f_6uvloop_4loop_18UVProcessTransport__file_inpipe;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._file_outpipe = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *))__pyx_f_6uvloop_4loop_18UVProcessTransport__file_outpipe;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._check_proc = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *))__pyx_f_6uvloop_4loop_18UVProcessTransport__check_proc;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._pipe_connection_lost = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, int, PyObject *))__pyx_f_6uvloop_4loop_18UVProcessTransport__pipe_connection_lost;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._pipe_data_received = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, int, PyObject *))__pyx_f_6uvloop_4loop_18UVProcessTransport__pipe_data_received;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._call_connection_made = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *, PyObject *))__pyx_f_6uvloop_4loop_18UVProcessTransport__call_connection_made;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport._try_finish = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVProcessTransport *))__pyx_f_6uvloop_4loop_18UVProcessTransport__try_finish;
  __pyx_vtable_6uvloop_4loop_UVProcessTransport.new = (struct __pyx_obj_6uvloop_4loop_UVProcessTransport *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_18UVProcessTransport_new;
  __pyx_type_6uvloop_4loop_UVProcessTransport.tp_base = __pyx_ptype_6uvloop_4loop_UVProcess;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVProcessTransport) < 0) __PYX_ERR(6, 346, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVProcessTransport.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVProcessTransport.tp_dictoffset && __pyx_type_6uvloop_4loop_UVProcessTransport.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVProcessTransport.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVProcessTransport.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVProcessTransport) < 0) __PYX_ERR(6, 346, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVProcessTransport", (PyObject *)&__pyx_type_6uvloop_4loop_UVProcessTransport) < 0) __PYX_ERR(6, 346, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVProcessTransport) < 0) __PYX_ERR(6, 346, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVProcessTransport = &__pyx_type_6uvloop_4loop_UVProcessTransport;
  __pyx_vtabptr_6uvloop_4loop_UVRequest = &__pyx_vtable_6uvloop_4loop_UVRequest;
  __pyx_vtable_6uvloop_4loop_UVRequest.on_done = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVRequest *))__pyx_f_6uvloop_4loop_9UVRequest_on_done;
  __pyx_vtable_6uvloop_4loop_UVRequest.cancel = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVRequest *))__pyx_f_6uvloop_4loop_9UVRequest_cancel;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UVRequest) < 0) __PYX_ERR(21, 1, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UVRequest.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UVRequest.tp_dictoffset && __pyx_type_6uvloop_4loop_UVRequest.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UVRequest.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UVRequest.tp_dict, __pyx_vtabptr_6uvloop_4loop_UVRequest) < 0) __PYX_ERR(21, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UVRequest", (PyObject *)&__pyx_type_6uvloop_4loop_UVRequest) < 0) __PYX_ERR(21, 1, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UVRequest) < 0) __PYX_ERR(21, 1, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UVRequest = &__pyx_type_6uvloop_4loop_UVRequest;
  __pyx_vtabptr_6uvloop_4loop_UDPTransport = &__pyx_vtable_6uvloop_4loop_UDPTransport;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVBaseTransport;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base.__pyx_base.__pyx_base._dealloc_impl = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_12UDPTransport__dealloc_impl;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base.__pyx_base.__pyx_base._free = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_12UDPTransport__free;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base.__pyx_base.__pyx_base._close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVHandle *))__pyx_f_6uvloop_4loop_12UDPTransport__close;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base.__pyx_base._fileno = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_12UDPTransport__fileno;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base.__pyx_base._new_socket = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVSocketHandle *))__pyx_f_6uvloop_4loop_12UDPTransport__new_socket;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base._get_write_buffer_size = (size_t (*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_12UDPTransport__get_write_buffer_size;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base._is_reading = (int (*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_12UDPTransport__is_reading;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base._start_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_12UDPTransport__start_reading;
  __pyx_vtable_6uvloop_4loop_UDPTransport.__pyx_base._stop_reading = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UVBaseTransport *))__pyx_f_6uvloop_4loop_12UDPTransport__stop_reading;
  __pyx_vtable_6uvloop_4loop_UDPTransport._init = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UDPTransport *, struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_12UDPTransport__init;
  __pyx_vtable_6uvloop_4loop_UDPTransport._on_read_ready = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UDPTransport *))__pyx_f_6uvloop_4loop_12UDPTransport__on_read_ready;
  __pyx_vtable_6uvloop_4loop_UDPTransport._on_write_ready = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_UDPTransport *))__pyx_f_6uvloop_4loop_12UDPTransport__on_write_ready;
  __pyx_vtable_6uvloop_4loop_UDPTransport.new = (struct __pyx_obj_6uvloop_4loop_UDPTransport *(*)(struct __pyx_obj_6uvloop_4loop_Loop *, PyObject *, PyObject *))__pyx_f_6uvloop_4loop_12UDPTransport_new;
  __pyx_type_6uvloop_4loop_UDPTransport.tp_base = __pyx_ptype_6uvloop_4loop_UVBaseTransport;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_UDPTransport) < 0) __PYX_ERR(22, 2, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_UDPTransport.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_UDPTransport.tp_dictoffset && __pyx_type_6uvloop_4loop_UDPTransport.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_UDPTransport.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_UDPTransport.tp_dict, __pyx_vtabptr_6uvloop_4loop_UDPTransport) < 0) __PYX_ERR(22, 2, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "UDPTransport", (PyObject *)&__pyx_type_6uvloop_4loop_UDPTransport) < 0) __PYX_ERR(22, 2, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_UDPTransport.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_UDPTransport.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_UDPTransport, __pyx_base.__weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_UDPTransport) < 0) __PYX_ERR(22, 2, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_UDPTransport = &__pyx_type_6uvloop_4loop_UDPTransport;
  __pyx_vtabptr_6uvloop_4loop_Server = &__pyx_vtable_6uvloop_4loop_Server;
  __pyx_vtable_6uvloop_4loop_Server._add_server = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Server *, struct __pyx_obj_6uvloop_4loop_UVStreamServer *))__pyx_f_6uvloop_4loop_6Server__add_server;
  __pyx_vtable_6uvloop_4loop_Server._wakeup = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Server *))__pyx_f_6uvloop_4loop_6Server__wakeup;
  __pyx_vtable_6uvloop_4loop_Server._attach = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Server *))__pyx_f_6uvloop_4loop_6Server__attach;
  __pyx_vtable_6uvloop_4loop_Server._detach = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Server *))__pyx_f_6uvloop_4loop_6Server__detach;
  __pyx_vtable_6uvloop_4loop_Server._ref = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Server *))__pyx_f_6uvloop_4loop_6Server__ref;
  __pyx_vtable_6uvloop_4loop_Server._unref = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_Server *))__pyx_f_6uvloop_4loop_6Server__unref;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_Server) < 0) __PYX_ERR(23, 1, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_Server.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_Server.tp_dictoffset && __pyx_type_6uvloop_4loop_Server.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_Server.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_Server.tp_dict, __pyx_vtabptr_6uvloop_4loop_Server) < 0) __PYX_ERR(23, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "Server", (PyObject *)&__pyx_type_6uvloop_4loop_Server) < 0) __PYX_ERR(23, 1, __pyx_L1_error)
  if (__pyx_type_6uvloop_4loop_Server.tp_weaklistoffset == 0) __pyx_type_6uvloop_4loop_Server.tp_weaklistoffset = offsetof(struct __pyx_obj_6uvloop_4loop_Server, __weakref__);
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_Server) < 0) __PYX_ERR(23, 1, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_Server = &__pyx_type_6uvloop_4loop_Server;
  __pyx_vtabptr_6uvloop_4loop_PseudoSocket = &__pyx_vtable_6uvloop_4loop_PseudoSocket;
  __pyx_vtable_6uvloop_4loop_PseudoSocket._na = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_PseudoSocket *, PyObject *))__pyx_f_6uvloop_4loop_12PseudoSocket__na;
  __pyx_vtable_6uvloop_4loop_PseudoSocket._make_sock = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_PseudoSocket *))__pyx_f_6uvloop_4loop_12PseudoSocket__make_sock;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_PseudoSocket) < 0) __PYX_ERR(10, 1, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_PseudoSocket.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_PseudoSocket.tp_dictoffset && __pyx_type_6uvloop_4loop_PseudoSocket.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_PseudoSocket.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_PseudoSocket.tp_dict, __pyx_vtabptr_6uvloop_4loop_PseudoSocket) < 0) __PYX_ERR(10, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "PseudoSocket", (PyObject *)&__pyx_type_6uvloop_4loop_PseudoSocket) < 0) __PYX_ERR(10, 1, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_PseudoSocket) < 0) __PYX_ERR(10, 1, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_PseudoSocket = &__pyx_type_6uvloop_4loop_PseudoSocket;
  __pyx_vtabptr_6uvloop_4loop__StreamWriteContext = &__pyx_vtable_6uvloop_4loop__StreamWriteContext;
  __pyx_vtable_6uvloop_4loop__StreamWriteContext.free_bufs = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *))__pyx_f_6uvloop_4loop_19_StreamWriteContext_free_bufs;
  __pyx_vtable_6uvloop_4loop__StreamWriteContext.close = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *))__pyx_f_6uvloop_4loop_19_StreamWriteContext_close;
  __pyx_vtable_6uvloop_4loop__StreamWriteContext.advance_uv_buf = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__StreamWriteContext *, size_t))__pyx_f_6uvloop_4loop_19_StreamWriteContext_advance_uv_buf;
  __pyx_vtable_6uvloop_4loop__StreamWriteContext.new = (struct __pyx_obj_6uvloop_4loop__StreamWriteContext *(*)(struct __pyx_obj_6uvloop_4loop_UVStream *, PyObject *))__pyx_f_6uvloop_4loop_19_StreamWriteContext_new;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop__StreamWriteContext) < 0) __PYX_ERR(18, 5, __pyx_L1_error)
  __pyx_type_6uvloop_4loop__StreamWriteContext.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop__StreamWriteContext.tp_dictoffset && __pyx_type_6uvloop_4loop__StreamWriteContext.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop__StreamWriteContext.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop__StreamWriteContext.tp_dict, __pyx_vtabptr_6uvloop_4loop__StreamWriteContext) < 0) __PYX_ERR(18, 5, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "_StreamWriteContext", (PyObject *)&__pyx_type_6uvloop_4loop__StreamWriteContext) < 0) __PYX_ERR(18, 5, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop__StreamWriteContext) < 0) __PYX_ERR(18, 5, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop__StreamWriteContext = &__pyx_type_6uvloop_4loop__StreamWriteContext;
  __pyx_vtabptr_6uvloop_4loop__TCPConnectRequest = &__pyx_vtable_6uvloop_4loop__TCPConnectRequest;
  __pyx_vtable_6uvloop_4loop__TCPConnectRequest.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVRequest;
  __pyx_vtable_6uvloop_4loop__TCPConnectRequest.connect = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__TCPConnectRequest *, struct sockaddr *))__pyx_f_6uvloop_4loop_18_TCPConnectRequest_connect;
  __pyx_type_6uvloop_4loop__TCPConnectRequest.tp_base = __pyx_ptype_6uvloop_4loop_UVRequest;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop__TCPConnectRequest) < 0) __PYX_ERR(5, 181, __pyx_L1_error)
  __pyx_type_6uvloop_4loop__TCPConnectRequest.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop__TCPConnectRequest.tp_dictoffset && __pyx_type_6uvloop_4loop__TCPConnectRequest.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop__TCPConnectRequest.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop__TCPConnectRequest.tp_dict, __pyx_vtabptr_6uvloop_4loop__TCPConnectRequest) < 0) __PYX_ERR(5, 181, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "_TCPConnectRequest", (PyObject *)&__pyx_type_6uvloop_4loop__TCPConnectRequest) < 0) __PYX_ERR(5, 181, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop__TCPConnectRequest) < 0) __PYX_ERR(5, 181, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop__TCPConnectRequest = &__pyx_type_6uvloop_4loop__TCPConnectRequest;
  __pyx_vtabptr_6uvloop_4loop__PipeConnectRequest = &__pyx_vtable_6uvloop_4loop__PipeConnectRequest;
  __pyx_vtable_6uvloop_4loop__PipeConnectRequest.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVRequest;
  __pyx_vtable_6uvloop_4loop__PipeConnectRequest.connect = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__PipeConnectRequest *, char *))__pyx_f_6uvloop_4loop_19_PipeConnectRequest_connect;
  __pyx_type_6uvloop_4loop__PipeConnectRequest.tp_base = __pyx_ptype_6uvloop_4loop_UVRequest;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop__PipeConnectRequest) < 0) __PYX_ERR(20, 177, __pyx_L1_error)
  __pyx_type_6uvloop_4loop__PipeConnectRequest.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop__PipeConnectRequest.tp_dictoffset && __pyx_type_6uvloop_4loop__PipeConnectRequest.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop__PipeConnectRequest.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop__PipeConnectRequest.tp_dict, __pyx_vtabptr_6uvloop_4loop__PipeConnectRequest) < 0) __PYX_ERR(20, 177, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "_PipeConnectRequest", (PyObject *)&__pyx_type_6uvloop_4loop__PipeConnectRequest) < 0) __PYX_ERR(20, 177, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop__PipeConnectRequest) < 0) __PYX_ERR(20, 177, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop__PipeConnectRequest = &__pyx_type_6uvloop_4loop__PipeConnectRequest;
  __pyx_vtabptr_6uvloop_4loop_AddrInfo = &__pyx_vtable_6uvloop_4loop_AddrInfo;
  __pyx_vtable_6uvloop_4loop_AddrInfo.set_data = (void (*)(struct __pyx_obj_6uvloop_4loop_AddrInfo *, struct addrinfo *))__pyx_f_6uvloop_4loop_8AddrInfo_set_data;
  __pyx_vtable_6uvloop_4loop_AddrInfo.unpack = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_AddrInfo *))__pyx_f_6uvloop_4loop_8AddrInfo_unpack;
  __pyx_vtable_6uvloop_4loop_AddrInfo.isinstance = (int (*)(PyObject *))__pyx_f_6uvloop_4loop_8AddrInfo_isinstance;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_AddrInfo) < 0) __PYX_ERR(7, 204, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_AddrInfo.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_AddrInfo.tp_dictoffset && __pyx_type_6uvloop_4loop_AddrInfo.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_AddrInfo.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_AddrInfo.tp_dict, __pyx_vtabptr_6uvloop_4loop_AddrInfo) < 0) __PYX_ERR(7, 204, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "AddrInfo", (PyObject *)&__pyx_type_6uvloop_4loop_AddrInfo) < 0) __PYX_ERR(7, 204, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_AddrInfo) < 0) __PYX_ERR(7, 204, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_AddrInfo = &__pyx_type_6uvloop_4loop_AddrInfo;
  __pyx_vtabptr_6uvloop_4loop_AddrInfoRequest = &__pyx_vtable_6uvloop_4loop_AddrInfoRequest;
  __pyx_vtable_6uvloop_4loop_AddrInfoRequest.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVRequest;
  __pyx_type_6uvloop_4loop_AddrInfoRequest.tp_base = __pyx_ptype_6uvloop_4loop_UVRequest;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_AddrInfoRequest) < 0) __PYX_ERR(7, 248, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_AddrInfoRequest.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_AddrInfoRequest.tp_dictoffset && __pyx_type_6uvloop_4loop_AddrInfoRequest.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_AddrInfoRequest.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_AddrInfoRequest.tp_dict, __pyx_vtabptr_6uvloop_4loop_AddrInfoRequest) < 0) __PYX_ERR(7, 248, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "AddrInfoRequest", (PyObject *)&__pyx_type_6uvloop_4loop_AddrInfoRequest) < 0) __PYX_ERR(7, 248, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_AddrInfoRequest) < 0) __PYX_ERR(7, 248, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_AddrInfoRequest = &__pyx_type_6uvloop_4loop_AddrInfoRequest;
  __pyx_vtabptr_6uvloop_4loop_NameInfoRequest = &__pyx_vtable_6uvloop_4loop_NameInfoRequest;
  __pyx_vtable_6uvloop_4loop_NameInfoRequest.__pyx_base = *__pyx_vtabptr_6uvloop_4loop_UVRequest;
  __pyx_vtable_6uvloop_4loop_NameInfoRequest.query = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop_NameInfoRequest *, struct sockaddr *, int))__pyx_f_6uvloop_4loop_15NameInfoRequest_query;
  __pyx_type_6uvloop_4loop_NameInfoRequest.tp_base = __pyx_ptype_6uvloop_4loop_UVRequest;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop_NameInfoRequest) < 0) __PYX_ERR(7, 303, __pyx_L1_error)
  __pyx_type_6uvloop_4loop_NameInfoRequest.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop_NameInfoRequest.tp_dictoffset && __pyx_type_6uvloop_4loop_NameInfoRequest.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop_NameInfoRequest.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop_NameInfoRequest.tp_dict, __pyx_vtabptr_6uvloop_4loop_NameInfoRequest) < 0) __PYX_ERR(7, 303, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "NameInfoRequest", (PyObject *)&__pyx_type_6uvloop_4loop_NameInfoRequest) < 0) __PYX_ERR(7, 303, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop_NameInfoRequest) < 0) __PYX_ERR(7, 303, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop_NameInfoRequest = &__pyx_type_6uvloop_4loop_NameInfoRequest;
  __pyx_vtabptr_6uvloop_4loop__SSLPipe = &__pyx_vtable_6uvloop_4loop__SSLPipe;
  __pyx_vtable_6uvloop_4loop__SSLPipe.do_handshake = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_do_handshake *__pyx_optional_args))__pyx_f_6uvloop_4loop_8_SSLPipe_do_handshake;
  __pyx_vtable_6uvloop_4loop__SSLPipe.shutdown = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_shutdown *__pyx_optional_args))__pyx_f_6uvloop_4loop_8_SSLPipe_shutdown;
  __pyx_vtable_6uvloop_4loop__SSLPipe.feed_eof = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__SSLPipe *))__pyx_f_6uvloop_4loop_8_SSLPipe_feed_eof;
  __pyx_vtable_6uvloop_4loop__SSLPipe.feed_ssldata = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_ssldata *__pyx_optional_args))__pyx_f_6uvloop_4loop_8_SSLPipe_feed_ssldata;
  __pyx_vtable_6uvloop_4loop__SSLPipe.feed_appdata = (PyObject *(*)(struct __pyx_obj_6uvloop_4loop__SSLPipe *, PyObject *, struct __pyx_opt_args_6uvloop_4loop_8_SSLPipe_feed_appdata *__pyx_optional_args))__pyx_f_6uvloop_4loop_8_SSLPipe_feed_appdata;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop__SSLPipe) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  __pyx_type_6uvloop_4loop__SSLPipe.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop__SSLPipe.tp_dictoffset && __pyx_type_6uvloop_4loop__SSLPipe.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop__SSLPipe.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_6uvloop_4loop__SSLPipe, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 30, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_6uvloop_4loop_8_SSLPipe___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_6uvloop_4loop_8_SSLPipe___init__.doc = __pyx_doc_6uvloop_4loop_8_SSLPipe___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_6uvloop_4loop_8_SSLPipe___init__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_6uvloop_4loop__SSLPipe.tp_dict, __pyx_vtabptr_6uvloop_4loop__SSLPipe) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "_SSLPipe", (PyObject *)&__pyx_type_6uvloop_4loop__SSLPipe) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_6uvloop_4loop__SSLPipe) < 0) __PYX_ERR(0, 30, __pyx_L1_error)
  __pyx_ptype_6uvloop_4loop__SSLPipe = &__pyx_type_6uvloop_4loop__SSLPipe;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct___getaddrinfo) < 0) __PYX_ERR(2, 822, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct___getaddrinfo.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct___getaddrinfo.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct___getaddrinfo.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct___getaddrinfo.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct___getaddrinfo = &__pyx_type_6uvloop_4loop___pyx_scope_struct___getaddrinfo;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_1__getnameinfo) < 0) __PYX_ERR(2, 862, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_1__getnameinfo.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_1__getnameinfo.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_1__getnameinfo.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_1__getnameinfo.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_1__getnameinfo = &__pyx_type_6uvloop_4loop___pyx_scope_struct_1__getnameinfo;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_2__sock_connect) < 0) __PYX_ERR(2, 986, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_2__sock_connect.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_2__sock_connect.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_2__sock_connect.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_2__sock_connect.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_2__sock_connect = &__pyx_type_6uvloop_4loop___pyx_scope_struct_2__sock_connect;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_3___get__) < 0) __PYX_ERR(2, 1221, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_3___get__.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_3___get__.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_3___get__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_3___get__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_3___get__ = &__pyx_type_6uvloop_4loop___pyx_scope_struct_3___get__;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_4_run_until_complete) < 0) __PYX_ERR(2, 1411, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_4_run_until_complete.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_4_run_until_complete.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_4_run_until_complete.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_4_run_until_complete.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_4_run_until_complete = &__pyx_type_6uvloop_4loop___pyx_scope_struct_4_run_until_complete;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo) < 0) __PYX_ERR(2, 1451, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo = &__pyx_type_6uvloop_4loop___pyx_scope_struct_5_getaddrinfo;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_6_getnameinfo) < 0) __PYX_ERR(2, 1465, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_6_getnameinfo.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_6_getnameinfo.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_6_getnameinfo.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_6_getnameinfo.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_6_getnameinfo = &__pyx_type_6uvloop_4loop___pyx_scope_struct_6_getnameinfo;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_7_start_tls) < 0) __PYX_ERR(2, 1523, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_7_start_tls.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_7_start_tls.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_7_start_tls.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_7_start_tls.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_7_start_tls = &__pyx_type_6uvloop_4loop___pyx_scope_struct_7_start_tls;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_8_create_server) < 0) __PYX_ERR(2, 1567, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_8_create_server.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_8_create_server.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_8_create_server.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_8_create_server.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_8_create_server = &__pyx_type_6uvloop_4loop___pyx_scope_struct_8_create_server;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_9_create_connection) < 0) __PYX_ERR(2, 1709, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_9_create_connection.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_9_create_connection.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_9_create_connection.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_9_create_connection.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_9_create_connection = &__pyx_type_6uvloop_4loop___pyx_scope_struct_9_create_connection;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_10_genexpr) < 0) __PYX_ERR(2, 1880, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_10_genexpr.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_10_genexpr.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_10_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_10_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_10_genexpr = &__pyx_type_6uvloop_4loop___pyx_scope_struct_10_genexpr;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_11_genexpr) < 0) __PYX_ERR(2, 1885, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_11_genexpr.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_11_genexpr.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_11_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_11_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_11_genexpr = &__pyx_type_6uvloop_4loop___pyx_scope_struct_11_genexpr;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_12_create_unix_server) < 0) __PYX_ERR(2, 1927, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_12_create_unix_server.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_12_create_unix_server.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_12_create_unix_server.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_12_create_unix_server.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_12_create_unix_server = &__pyx_type_6uvloop_4loop___pyx_scope_struct_12_create_unix_server;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection) < 0) __PYX_ERR(2, 2050, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection = &__pyx_type_6uvloop_4loop___pyx_scope_struct_13_create_unix_connection;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_14_sock_recv) < 0) __PYX_ERR(2, 2275, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_14_sock_recv.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_14_sock_recv.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_14_sock_recv.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_14_sock_recv.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_14_sock_recv = &__pyx_type_6uvloop_4loop___pyx_scope_struct_14_sock_recv;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into) < 0) __PYX_ERR(2, 2302, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into = &__pyx_type_6uvloop_4loop___pyx_scope_struct_15_sock_recv_into;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_16_sock_sendall) < 0) __PYX_ERR(2, 2328, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_16_sock_sendall.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_16_sock_sendall.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_16_sock_sendall.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_16_sock_sendall.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_16_sock_sendall = &__pyx_type_6uvloop_4loop___pyx_scope_struct_16_sock_sendall;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_17_sock_accept) < 0) __PYX_ERR(2, 2381, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_17_sock_accept.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_17_sock_accept.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_17_sock_accept.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_17_sock_accept.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_17_sock_accept = &__pyx_type_6uvloop_4loop___pyx_scope_struct_17_sock_accept;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_18_sock_connect) < 0) __PYX_ERR(2, 2409, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_18_sock_connect.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_18_sock_connect.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_18_sock_connect.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_18_sock_connect.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_18_sock_connect = &__pyx_type_6uvloop_4loop___pyx_scope_struct_18_sock_connect;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket) < 0) __PYX_ERR(2, 2433, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket = &__pyx_type_6uvloop_4loop___pyx_scope_struct_19_connect_accepted_socket;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_20___subprocess_run) < 0) __PYX_ERR(2, 2518, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_20___subprocess_run.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_20___subprocess_run.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_20___subprocess_run.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_20___subprocess_run.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_20___subprocess_run = &__pyx_type_6uvloop_4loop___pyx_scope_struct_20___subprocess_run;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell) < 0) __PYX_ERR(2, 2580, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell = &__pyx_type_6uvloop_4loop___pyx_scope_struct_21_subprocess_shell;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec) < 0) __PYX_ERR(2, 2595, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec = &__pyx_type_6uvloop_4loop___pyx_scope_struct_22_subprocess_exec;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe) < 0) __PYX_ERR(2, 2607, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe = &__pyx_type_6uvloop_4loop___pyx_scope_struct_23_connect_read_pipe;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe) < 0) __PYX_ERR(2, 2632, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe = &__pyx_type_6uvloop_4loop___pyx_scope_struct_24_connect_write_pipe;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint) < 0) __PYX_ERR(2, 2766, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint = &__pyx_type_6uvloop_4loop___pyx_scope_struct_25_create_datagram_endpoint;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_26_genexpr) < 0) __PYX_ERR(2, 2816, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_26_genexpr.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_26_genexpr.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_26_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_26_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_26_genexpr = &__pyx_type_6uvloop_4loop___pyx_scope_struct_26_genexpr;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens) < 0) __PYX_ERR(2, 2932, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens = &__pyx_type_6uvloop_4loop___pyx_scope_struct_27_shutdown_asyncgens;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_28_wait_closed) < 0) __PYX_ERR(23, 46, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_28_wait_closed.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_28_wait_closed.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_28_wait_closed.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_28_wait_closed.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_28_wait_closed = &__pyx_type_6uvloop_4loop___pyx_scope_struct_28_wait_closed;
  if (PyType_Ready(&__pyx_type_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1) < 0) __PYX_ERR(2, 3103, __pyx_L1_error)
  __pyx_type_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1.tp_dictoffset && __pyx_type_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1 = &__pyx_type_6uvloop_4loop___pyx_scope_struct_29__test_coroutine_1;
  if (PyType_Ready(&__pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py) < 0) __PYX_ERR(9, 64, __pyx_L1_error)
  __pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py.tp_dictoffset && __pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype___pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py = &__pyx_scope_struct____Pyx_CFunc_object____Loop____bint___to_py;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  0); if (unlikely(!__pyx_ptype_7cpython_4type_type)) __PYX_ERR(24, 9, __pyx_L1_error)
  __pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "bool", sizeof(PyBoolObject), 0); if (unlikely(!__pyx_ptype_7cpython_4bool_bool)) __PYX_ERR(25, 8, __pyx_L1_error)
  __pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "complex", sizeof(PyComplexObject), 0); if (unlikely(!__pyx_ptype_7cpython_7complex_complex)) __PYX_ERR(26, 15, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION < 3
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC void
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#else
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (!(defined(__cplusplus)) || (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 4)))
    #define CYTHON_SMALL_CODE __attribute__((optimize("Os")))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initloop(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initloop(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_loop(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_loop(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        result = PyDict_SetItemString(moddict, to_name, value);
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__") < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__") < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static int __pyx_pymod_exec_loop(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int64_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m && __pyx_m == __pyx_pyinit_module) return 0;
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_loop(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(2, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("loop", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(2, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(2, 1, __pyx_L1_error)
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(2, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_uvloop__loop) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(2, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "uvloop.loop")) {
      if (unlikely(PyDict_SetItemString(modules, "uvloop.loop", __pyx_m) < 0)) __PYX_ERR(2, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() != 0)) goto __pyx_L1_error;
  if (unlikely(__Pyx_modinit_type_import_code() != 0)) goto __pyx_L1_error;
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  #endif

  /* "uvloop/loop.pyx":3
 * # cython: language_level=3, embedsignature=True
 * 
 * import asyncio             # <<<<<<<<<<<<<<
 * cimport cython
 * 
 */
  __pyx_t_1 = __Pyx_patch_asyncio(__Pyx_Import(__pyx_n_s_asyncio, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_1) < 0) __PYX_ERR(2, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":35
 *                      Py_SIZE, PyBytes_AS_STRING, PyBUF_WRITABLE
 * 
 * from . import _noop             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_noop);
  __Pyx_GIVEREF(__pyx_n_s_noop);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_noop);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s__7, __pyx_t_1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_noop); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_noop, __pyx_t_1) < 0) __PYX_ERR(2, 35, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":1
 * import asyncio, asyncio.log, asyncio.base_events, \             # <<<<<<<<<<<<<<
 *        asyncio.sslproto, asyncio.coroutines, \
 *        asyncio.futures, asyncio.transports
 */
  __pyx_t_2 = __Pyx_patch_asyncio(__Pyx_Import(__pyx_n_s_asyncio, 0, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_2) < 0) __PYX_ERR(27, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_asyncio_log, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_2) < 0) __PYX_ERR(27, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_asyncio_base_events, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_2) < 0) __PYX_ERR(27, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":2
 * import asyncio, asyncio.log, asyncio.base_events, \
 *        asyncio.sslproto, asyncio.coroutines, \             # <<<<<<<<<<<<<<
 *        asyncio.futures, asyncio.transports
 * import collections.abc
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_asyncio_sslproto, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_2) < 0) __PYX_ERR(27, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_asyncio_coroutines, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_2) < 0) __PYX_ERR(27, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":3
 * import asyncio, asyncio.log, asyncio.base_events, \
 *        asyncio.sslproto, asyncio.coroutines, \
 *        asyncio.futures, asyncio.transports             # <<<<<<<<<<<<<<
 * import collections.abc
 * import concurrent.futures
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_asyncio_futures, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_2) < 0) __PYX_ERR(27, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_asyncio_transports, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_asyncio, __pyx_t_2) < 0) __PYX_ERR(27, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":4
 *        asyncio.sslproto, asyncio.coroutines, \
 *        asyncio.futures, asyncio.transports
 * import collections.abc             # <<<<<<<<<<<<<<
 * import concurrent.futures
 * import errno
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_collections_abc, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_collections, __pyx_t_2) < 0) __PYX_ERR(27, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":5
 *        asyncio.futures, asyncio.transports
 * import collections.abc
 * import concurrent.futures             # <<<<<<<<<<<<<<
 * import errno
 * import functools
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_concurrent_futures, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_concurrent, __pyx_t_2) < 0) __PYX_ERR(27, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":6
 * import collections.abc
 * import concurrent.futures
 * import errno             # <<<<<<<<<<<<<<
 * import functools
 * import gc
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_errno, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_errno, __pyx_t_2) < 0) __PYX_ERR(27, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":7
 * import concurrent.futures
 * import errno
 * import functools             # <<<<<<<<<<<<<<
 * import gc
 * import inspect
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_functools, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_functools, __pyx_t_2) < 0) __PYX_ERR(27, 7, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":8
 * import errno
 * import functools
 * import gc             # <<<<<<<<<<<<<<
 * import inspect
 * import itertools
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_gc, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_gc, __pyx_t_2) < 0) __PYX_ERR(27, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":9
 * import functools
 * import gc
 * import inspect             # <<<<<<<<<<<<<<
 * import itertools
 * import os
 */
  __pyx_t_2 = __Pyx_patch_inspect(__Pyx_Import(__pyx_n_s_inspect, 0, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_inspect, __pyx_t_2) < 0) __PYX_ERR(27, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":10
 * import gc
 * import inspect
 * import itertools             # <<<<<<<<<<<<<<
 * import os
 * import signal
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_itertools, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_itertools, __pyx_t_2) < 0) __PYX_ERR(27, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":11
 * import inspect
 * import itertools
 * import os             # <<<<<<<<<<<<<<
 * import signal
 * import socket
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_os, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_2) < 0) __PYX_ERR(27, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":12
 * import itertools
 * import os
 * import signal             # <<<<<<<<<<<<<<
 * import socket
 * import subprocess
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_signal, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_signal, __pyx_t_2) < 0) __PYX_ERR(27, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":13
 * import os
 * import signal
 * import socket             # <<<<<<<<<<<<<<
 * import subprocess
 * import ssl
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_socket_2, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_socket_2, __pyx_t_2) < 0) __PYX_ERR(27, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":14
 * import signal
 * import socket
 * import subprocess             # <<<<<<<<<<<<<<
 * import ssl
 * import stat
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_subprocess, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_subprocess, __pyx_t_2) < 0) __PYX_ERR(27, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":15
 * import socket
 * import subprocess
 * import ssl             # <<<<<<<<<<<<<<
 * import stat
 * import sys
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_ssl, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ssl, __pyx_t_2) < 0) __PYX_ERR(27, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":16
 * import subprocess
 * import ssl
 * import stat             # <<<<<<<<<<<<<<
 * import sys
 * import threading
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_stat, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stat, __pyx_t_2) < 0) __PYX_ERR(27, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":17
 * import ssl
 * import stat
 * import sys             # <<<<<<<<<<<<<<
 * import threading
 * import traceback
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_sys, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_2) < 0) __PYX_ERR(27, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":18
 * import stat
 * import sys
 * import threading             # <<<<<<<<<<<<<<
 * import traceback
 * import time
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_threading, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_threading, __pyx_t_2) < 0) __PYX_ERR(27, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":19
 * import sys
 * import threading
 * import traceback             # <<<<<<<<<<<<<<
 * import time
 * import warnings
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_traceback_2, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_traceback_2, __pyx_t_2) < 0) __PYX_ERR(27, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":20
 * import threading
 * import traceback
 * import time             # <<<<<<<<<<<<<<
 * import warnings
 * import weakref
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_time, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_2) < 0) __PYX_ERR(27, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":21
 * import traceback
 * import time
 * import warnings             # <<<<<<<<<<<<<<
 * import weakref
 * 
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_warnings, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_warnings, __pyx_t_2) < 0) __PYX_ERR(27, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":22
 * import time
 * import warnings
 * import weakref             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_weakref, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_weakref, __pyx_t_2) < 0) __PYX_ERR(27, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":25
 * 
 * 
 * cdef aio_get_event_loop = asyncio.get_event_loop             # <<<<<<<<<<<<<<
 * cdef aio_CancelledError = asyncio.CancelledError
 * cdef aio_InvalidStateError = asyncio.InvalidStateError
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_event_loop); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_get_event_loop);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_get_event_loop, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":26
 * 
 * cdef aio_get_event_loop = asyncio.get_event_loop
 * cdef aio_CancelledError = asyncio.CancelledError             # <<<<<<<<<<<<<<
 * cdef aio_InvalidStateError = asyncio.InvalidStateError
 * cdef aio_TimeoutError = asyncio.TimeoutError
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_CancelledError); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_CancelledError);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_CancelledError, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":27
 * cdef aio_get_event_loop = asyncio.get_event_loop
 * cdef aio_CancelledError = asyncio.CancelledError
 * cdef aio_InvalidStateError = asyncio.InvalidStateError             # <<<<<<<<<<<<<<
 * cdef aio_TimeoutError = asyncio.TimeoutError
 * cdef aio_Future = asyncio.Future
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_InvalidStateError); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_InvalidStateError);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_InvalidStateError, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":28
 * cdef aio_CancelledError = asyncio.CancelledError
 * cdef aio_InvalidStateError = asyncio.InvalidStateError
 * cdef aio_TimeoutError = asyncio.TimeoutError             # <<<<<<<<<<<<<<
 * cdef aio_Future = asyncio.Future
 * cdef aio_Task = asyncio.Task
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_TimeoutError); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_TimeoutError);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_TimeoutError, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":29
 * cdef aio_InvalidStateError = asyncio.InvalidStateError
 * cdef aio_TimeoutError = asyncio.TimeoutError
 * cdef aio_Future = asyncio.Future             # <<<<<<<<<<<<<<
 * cdef aio_Task = asyncio.Task
 * cdef aio_ensure_future = asyncio.ensure_future
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Future); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_Future);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_Future, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":30
 * cdef aio_TimeoutError = asyncio.TimeoutError
 * cdef aio_Future = asyncio.Future
 * cdef aio_Task = asyncio.Task             # <<<<<<<<<<<<<<
 * cdef aio_ensure_future = asyncio.ensure_future
 * cdef aio_gather = asyncio.gather
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Task); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_Task);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_Task, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":31
 * cdef aio_Future = asyncio.Future
 * cdef aio_Task = asyncio.Task
 * cdef aio_ensure_future = asyncio.ensure_future             # <<<<<<<<<<<<<<
 * cdef aio_gather = asyncio.gather
 * cdef aio_wait = asyncio.wait
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ensure_future); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_ensure_future);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_ensure_future, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":32
 * cdef aio_Task = asyncio.Task
 * cdef aio_ensure_future = asyncio.ensure_future
 * cdef aio_gather = asyncio.gather             # <<<<<<<<<<<<<<
 * cdef aio_wait = asyncio.wait
 * cdef aio_wrap_future = asyncio.wrap_future
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_gather); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_gather);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_gather, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":33
 * cdef aio_ensure_future = asyncio.ensure_future
 * cdef aio_gather = asyncio.gather
 * cdef aio_wait = asyncio.wait             # <<<<<<<<<<<<<<
 * cdef aio_wrap_future = asyncio.wrap_future
 * cdef aio_logger = asyncio.log.logger
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_wait);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_wait, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":34
 * cdef aio_gather = asyncio.gather
 * cdef aio_wait = asyncio.wait
 * cdef aio_wrap_future = asyncio.wrap_future             # <<<<<<<<<<<<<<
 * cdef aio_logger = asyncio.log.logger
 * cdef aio_iscoroutine = asyncio.iscoroutine
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_wrap_future); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_wrap_future);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_wrap_future, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":35
 * cdef aio_wait = asyncio.wait
 * cdef aio_wrap_future = asyncio.wrap_future
 * cdef aio_logger = asyncio.log.logger             # <<<<<<<<<<<<<<
 * cdef aio_iscoroutine = asyncio.iscoroutine
 * cdef aio_iscoroutinefunction = asyncio.iscoroutinefunction
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_log); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_logger); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_logger);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_logger, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":36
 * cdef aio_wrap_future = asyncio.wrap_future
 * cdef aio_logger = asyncio.log.logger
 * cdef aio_iscoroutine = asyncio.iscoroutine             # <<<<<<<<<<<<<<
 * cdef aio_iscoroutinefunction = asyncio.iscoroutinefunction
 * cdef aio_BaseProtocol = asyncio.BaseProtocol
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_iscoroutine); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_iscoroutine);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_iscoroutine, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":37
 * cdef aio_logger = asyncio.log.logger
 * cdef aio_iscoroutine = asyncio.iscoroutine
 * cdef aio_iscoroutinefunction = asyncio.iscoroutinefunction             # <<<<<<<<<<<<<<
 * cdef aio_BaseProtocol = asyncio.BaseProtocol
 * cdef aio_Protocol = asyncio.Protocol
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_iscoroutinefunction); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_iscoroutinefunction);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_iscoroutinefunction, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":38
 * cdef aio_iscoroutine = asyncio.iscoroutine
 * cdef aio_iscoroutinefunction = asyncio.iscoroutinefunction
 * cdef aio_BaseProtocol = asyncio.BaseProtocol             # <<<<<<<<<<<<<<
 * cdef aio_Protocol = asyncio.Protocol
 * cdef aio_isfuture = getattr(asyncio, 'isfuture', None)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_BaseProtocol); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_BaseProtocol);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_BaseProtocol, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":39
 * cdef aio_iscoroutinefunction = asyncio.iscoroutinefunction
 * cdef aio_BaseProtocol = asyncio.BaseProtocol
 * cdef aio_Protocol = asyncio.Protocol             # <<<<<<<<<<<<<<
 * cdef aio_isfuture = getattr(asyncio, 'isfuture', None)
 * cdef aio_get_running_loop = getattr(asyncio, '_get_running_loop', None)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Protocol); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_Protocol);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_Protocol, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":40
 * cdef aio_BaseProtocol = asyncio.BaseProtocol
 * cdef aio_Protocol = asyncio.Protocol
 * cdef aio_isfuture = getattr(asyncio, 'isfuture', None)             # <<<<<<<<<<<<<<
 * cdef aio_get_running_loop = getattr(asyncio, '_get_running_loop', None)
 * cdef aio_set_running_loop = getattr(asyncio, '_set_running_loop', None)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_isfuture, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_isfuture);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_isfuture, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":41
 * cdef aio_Protocol = asyncio.Protocol
 * cdef aio_isfuture = getattr(asyncio, 'isfuture', None)
 * cdef aio_get_running_loop = getattr(asyncio, '_get_running_loop', None)             # <<<<<<<<<<<<<<
 * cdef aio_set_running_loop = getattr(asyncio, '_set_running_loop', None)
 * cdef aio_debug_wrapper = getattr(asyncio.coroutines, 'debug_wrapper', None)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_get_running_loop, Py_None); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_get_running_loop);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_get_running_loop, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":42
 * cdef aio_isfuture = getattr(asyncio, 'isfuture', None)
 * cdef aio_get_running_loop = getattr(asyncio, '_get_running_loop', None)
 * cdef aio_set_running_loop = getattr(asyncio, '_set_running_loop', None)             # <<<<<<<<<<<<<<
 * cdef aio_debug_wrapper = getattr(asyncio.coroutines, 'debug_wrapper', None)
 * cdef aio_AbstractChildWatcher = asyncio.AbstractChildWatcher
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_set_running_loop, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_set_running_loop);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_set_running_loop, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":43
 * cdef aio_get_running_loop = getattr(asyncio, '_get_running_loop', None)
 * cdef aio_set_running_loop = getattr(asyncio, '_set_running_loop', None)
 * cdef aio_debug_wrapper = getattr(asyncio.coroutines, 'debug_wrapper', None)             # <<<<<<<<<<<<<<
 * cdef aio_AbstractChildWatcher = asyncio.AbstractChildWatcher
 * cdef aio_Transport = asyncio.Transport
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_coroutines); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_debug_wrapper, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_debug_wrapper);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_debug_wrapper, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":44
 * cdef aio_set_running_loop = getattr(asyncio, '_set_running_loop', None)
 * cdef aio_debug_wrapper = getattr(asyncio.coroutines, 'debug_wrapper', None)
 * cdef aio_AbstractChildWatcher = asyncio.AbstractChildWatcher             # <<<<<<<<<<<<<<
 * cdef aio_Transport = asyncio.Transport
 * cdef aio_FlowControlMixin = asyncio.transports._FlowControlMixin
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_AbstractChildWatcher); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_AbstractChildWatcher);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_AbstractChildWatcher, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":45
 * cdef aio_debug_wrapper = getattr(asyncio.coroutines, 'debug_wrapper', None)
 * cdef aio_AbstractChildWatcher = asyncio.AbstractChildWatcher
 * cdef aio_Transport = asyncio.Transport             # <<<<<<<<<<<<<<
 * cdef aio_FlowControlMixin = asyncio.transports._FlowControlMixin
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Transport); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_Transport);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_Transport, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":46
 * cdef aio_AbstractChildWatcher = asyncio.AbstractChildWatcher
 * cdef aio_Transport = asyncio.Transport
 * cdef aio_FlowControlMixin = asyncio.transports._FlowControlMixin             # <<<<<<<<<<<<<<
 * 
 * cdef col_deque = collections.deque
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_asyncio); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_transports); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_FlowControlMixin); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_aio_FlowControlMixin);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_aio_FlowControlMixin, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":48
 * cdef aio_FlowControlMixin = asyncio.transports._FlowControlMixin
 * 
 * cdef col_deque = collections.deque             # <<<<<<<<<<<<<<
 * cdef col_Iterable = collections.abc.Iterable
 * cdef col_Counter = collections.Counter
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_deque); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_col_deque);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_col_deque, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":49
 * 
 * cdef col_deque = collections.deque
 * cdef col_Iterable = collections.abc.Iterable             # <<<<<<<<<<<<<<
 * cdef col_Counter = collections.Counter
 * cdef col_OrderedDict = collections.OrderedDict
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_abc); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Iterable); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_col_Iterable);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_col_Iterable, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":50
 * cdef col_deque = collections.deque
 * cdef col_Iterable = collections.abc.Iterable
 * cdef col_Counter = collections.Counter             # <<<<<<<<<<<<<<
 * cdef col_OrderedDict = collections.OrderedDict
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Counter); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_col_Counter);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_col_Counter, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":51
 * cdef col_Iterable = collections.abc.Iterable
 * cdef col_Counter = collections.Counter
 * cdef col_OrderedDict = collections.OrderedDict             # <<<<<<<<<<<<<<
 * 
 * cdef cc_ThreadPoolExecutor = concurrent.futures.ThreadPoolExecutor
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_collections); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_col_OrderedDict);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_col_OrderedDict, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":53
 * cdef col_OrderedDict = collections.OrderedDict
 * 
 * cdef cc_ThreadPoolExecutor = concurrent.futures.ThreadPoolExecutor             # <<<<<<<<<<<<<<
 * cdef cc_Future = concurrent.futures.Future
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_concurrent); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_futures); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ThreadPoolExecutor); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_cc_ThreadPoolExecutor);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_cc_ThreadPoolExecutor, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":54
 * 
 * cdef cc_ThreadPoolExecutor = concurrent.futures.ThreadPoolExecutor
 * cdef cc_Future = concurrent.futures.Future             # <<<<<<<<<<<<<<
 * 
 * cdef errno_EBADF = errno.EBADF
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_concurrent); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_futures); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Future); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_cc_Future);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_cc_Future, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":56
 * cdef cc_Future = concurrent.futures.Future
 * 
 * cdef errno_EBADF = errno.EBADF             # <<<<<<<<<<<<<<
 * cdef errno_EINVAL = errno.EINVAL
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(EBADF); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_errno_EBADF);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_errno_EBADF, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":57
 * 
 * cdef errno_EBADF = errno.EBADF
 * cdef errno_EINVAL = errno.EINVAL             # <<<<<<<<<<<<<<
 * 
 * cdef ft_partial = functools.partial
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(EINVAL); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_errno_EINVAL);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_errno_EINVAL, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":59
 * cdef errno_EINVAL = errno.EINVAL
 * 
 * cdef ft_partial = functools.partial             # <<<<<<<<<<<<<<
 * 
 * cdef gc_disable = gc.disable
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_functools); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_partial); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_ft_partial);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_ft_partial, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":61
 * cdef ft_partial = functools.partial
 * 
 * cdef gc_disable = gc.disable             # <<<<<<<<<<<<<<
 * 
 * cdef iter_chain = itertools.chain
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_gc); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_disable); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_gc_disable);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_gc_disable, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":63
 * cdef gc_disable = gc.disable
 * 
 * cdef iter_chain = itertools.chain             # <<<<<<<<<<<<<<
 * cdef inspect_isgenerator = inspect.isgenerator
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_itertools); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_chain); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_iter_chain);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_iter_chain, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":64
 * 
 * cdef iter_chain = itertools.chain
 * cdef inspect_isgenerator = inspect.isgenerator             # <<<<<<<<<<<<<<
 * 
 * cdef int has_SO_REUSEPORT = hasattr(socket, 'SO_REUSEPORT')
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_inspect); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_isgenerator); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_inspect_isgenerator);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_inspect_isgenerator, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":66
 * cdef inspect_isgenerator = inspect.isgenerator
 * 
 * cdef int has_SO_REUSEPORT = hasattr(socket, 'SO_REUSEPORT')             # <<<<<<<<<<<<<<
 * cdef int SO_REUSEPORT = getattr(socket, 'SO_REUSEPORT', 0)
 * cdef int SO_BROADCAST = getattr(socket, 'SO_BROADCAST')
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_HasAttr(__pyx_t_2, __pyx_n_u_SO_REUSEPORT); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(27, 66, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_has_SO_REUSEPORT = __pyx_t_3;

  /* "uvloop/includes/stdlib.pxi":67
 * 
 * cdef int has_SO_REUSEPORT = hasattr(socket, 'SO_REUSEPORT')
 * cdef int SO_REUSEPORT = getattr(socket, 'SO_REUSEPORT', 0)             # <<<<<<<<<<<<<<
 * cdef int SO_BROADCAST = getattr(socket, 'SO_BROADCAST')
 * cdef int SOCK_NONBLOCK = getattr(socket, 'SOCK_NONBLOCK', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_SO_REUSEPORT, __pyx_int_0); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 67, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_SO_REUSEPORT = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":68
 * cdef int has_SO_REUSEPORT = hasattr(socket, 'SO_REUSEPORT')
 * cdef int SO_REUSEPORT = getattr(socket, 'SO_REUSEPORT', 0)
 * cdef int SO_BROADCAST = getattr(socket, 'SO_BROADCAST')             # <<<<<<<<<<<<<<
 * cdef int SOCK_NONBLOCK = getattr(socket, 'SOCK_NONBLOCK', -1)
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr(__pyx_t_1, __pyx_n_u_SO_BROADCAST); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 68, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_SO_BROADCAST = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":69
 * cdef int SO_REUSEPORT = getattr(socket, 'SO_REUSEPORT', 0)
 * cdef int SO_BROADCAST = getattr(socket, 'SO_BROADCAST')
 * cdef int SOCK_NONBLOCK = getattr(socket, 'SOCK_NONBLOCK', -1)             # <<<<<<<<<<<<<<
 * 
 * cdef socket_gaierror = socket.gaierror
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_SOCK_NONBLOCK, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 69, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_SOCK_NONBLOCK = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":71
 * cdef int SOCK_NONBLOCK = getattr(socket, 'SOCK_NONBLOCK', -1)
 * 
 * cdef socket_gaierror = socket.gaierror             # <<<<<<<<<<<<<<
 * cdef socket_error = socket.error
 * cdef socket_timeout = socket.timeout
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_gaierror); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_gaierror);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_gaierror, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":72
 * 
 * cdef socket_gaierror = socket.gaierror
 * cdef socket_error = socket.error             # <<<<<<<<<<<<<<
 * cdef socket_timeout = socket.timeout
 * cdef socket_socket = socket.socket
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_error); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_error);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_error, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":73
 * cdef socket_gaierror = socket.gaierror
 * cdef socket_error = socket.error
 * cdef socket_timeout = socket.timeout             # <<<<<<<<<<<<<<
 * cdef socket_socket = socket.socket
 * cdef socket_socketpair = socket.socketpair
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_timeout); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_timeout);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_timeout, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":74
 * cdef socket_error = socket.error
 * cdef socket_timeout = socket.timeout
 * cdef socket_socket = socket.socket             # <<<<<<<<<<<<<<
 * cdef socket_socketpair = socket.socketpair
 * cdef socket_getservbyname = socket.getservbyname
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_socket);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_socket, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":75
 * cdef socket_timeout = socket.timeout
 * cdef socket_socket = socket.socket
 * cdef socket_socketpair = socket.socketpair             # <<<<<<<<<<<<<<
 * cdef socket_getservbyname = socket.getservbyname
 * cdef socket_AddressFamily = socket.AddressFamily
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_socketpair); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_socketpair);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_socketpair, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":76
 * cdef socket_socket = socket.socket
 * cdef socket_socketpair = socket.socketpair
 * cdef socket_getservbyname = socket.getservbyname             # <<<<<<<<<<<<<<
 * cdef socket_AddressFamily = socket.AddressFamily
 * cdef socket_SocketKind = socket.SocketKind
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getservbyname); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_getservbyname);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_getservbyname, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":77
 * cdef socket_socketpair = socket.socketpair
 * cdef socket_getservbyname = socket.getservbyname
 * cdef socket_AddressFamily = socket.AddressFamily             # <<<<<<<<<<<<<<
 * cdef socket_SocketKind = socket.SocketKind
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_AddressFamily); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 77, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_AddressFamily);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_AddressFamily, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":78
 * cdef socket_getservbyname = socket.getservbyname
 * cdef socket_AddressFamily = socket.AddressFamily
 * cdef socket_SocketKind = socket.SocketKind             # <<<<<<<<<<<<<<
 * 
 * cdef int socket_EAI_ADDRFAMILY = getattr(socket, 'EAI_ADDRFAMILY', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_SocketKind); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_socket_SocketKind);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_socket_SocketKind, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":80
 * cdef socket_SocketKind = socket.SocketKind
 * 
 * cdef int socket_EAI_ADDRFAMILY = getattr(socket, 'EAI_ADDRFAMILY', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_AGAIN      = getattr(socket, 'EAI_AGAIN', -1)
 * cdef int socket_EAI_BADFLAGS   = getattr(socket, 'EAI_BADFLAGS', -1)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_EAI_ADDRFAMILY, __pyx_int_neg_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 80, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_ADDRFAMILY = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":81
 * 
 * cdef int socket_EAI_ADDRFAMILY = getattr(socket, 'EAI_ADDRFAMILY', -1)
 * cdef int socket_EAI_AGAIN      = getattr(socket, 'EAI_AGAIN', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_BADFLAGS   = getattr(socket, 'EAI_BADFLAGS', -1)
 * cdef int socket_EAI_BADHINTS   = getattr(socket, 'EAI_BADHINTS', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_EAI_AGAIN, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_AGAIN = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":82
 * cdef int socket_EAI_ADDRFAMILY = getattr(socket, 'EAI_ADDRFAMILY', -1)
 * cdef int socket_EAI_AGAIN      = getattr(socket, 'EAI_AGAIN', -1)
 * cdef int socket_EAI_BADFLAGS   = getattr(socket, 'EAI_BADFLAGS', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_BADHINTS   = getattr(socket, 'EAI_BADHINTS', -1)
 * cdef int socket_EAI_CANCELED   = getattr(socket, 'EAI_CANCELED', -1)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_EAI_BADFLAGS, __pyx_int_neg_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 82, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_BADFLAGS = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":83
 * cdef int socket_EAI_AGAIN      = getattr(socket, 'EAI_AGAIN', -1)
 * cdef int socket_EAI_BADFLAGS   = getattr(socket, 'EAI_BADFLAGS', -1)
 * cdef int socket_EAI_BADHINTS   = getattr(socket, 'EAI_BADHINTS', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_CANCELED   = getattr(socket, 'EAI_CANCELED', -1)
 * cdef int socket_EAI_FAIL       = getattr(socket, 'EAI_FAIL', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_EAI_BADHINTS, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 83, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_BADHINTS = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":84
 * cdef int socket_EAI_BADFLAGS   = getattr(socket, 'EAI_BADFLAGS', -1)
 * cdef int socket_EAI_BADHINTS   = getattr(socket, 'EAI_BADHINTS', -1)
 * cdef int socket_EAI_CANCELED   = getattr(socket, 'EAI_CANCELED', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_FAIL       = getattr(socket, 'EAI_FAIL', -1)
 * cdef int socket_EAI_FAMILY     = getattr(socket, 'EAI_FAMILY', -1)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_EAI_CANCELED, __pyx_int_neg_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 84, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_CANCELED = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":85
 * cdef int socket_EAI_BADHINTS   = getattr(socket, 'EAI_BADHINTS', -1)
 * cdef int socket_EAI_CANCELED   = getattr(socket, 'EAI_CANCELED', -1)
 * cdef int socket_EAI_FAIL       = getattr(socket, 'EAI_FAIL', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_FAMILY     = getattr(socket, 'EAI_FAMILY', -1)
 * cdef int socket_EAI_MEMORY     = getattr(socket, 'EAI_MEMORY', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_EAI_FAIL, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 85, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_FAIL = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":86
 * cdef int socket_EAI_CANCELED   = getattr(socket, 'EAI_CANCELED', -1)
 * cdef int socket_EAI_FAIL       = getattr(socket, 'EAI_FAIL', -1)
 * cdef int socket_EAI_FAMILY     = getattr(socket, 'EAI_FAMILY', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_MEMORY     = getattr(socket, 'EAI_MEMORY', -1)
 * cdef int socket_EAI_NODATA     = getattr(socket, 'EAI_NODATA', -1)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_EAI_FAMILY, __pyx_int_neg_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 86, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_FAMILY = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":87
 * cdef int socket_EAI_FAIL       = getattr(socket, 'EAI_FAIL', -1)
 * cdef int socket_EAI_FAMILY     = getattr(socket, 'EAI_FAMILY', -1)
 * cdef int socket_EAI_MEMORY     = getattr(socket, 'EAI_MEMORY', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_NODATA     = getattr(socket, 'EAI_NODATA', -1)
 * cdef int socket_EAI_NONAME     = getattr(socket, 'EAI_NONAME', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_EAI_MEMORY, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 87, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_MEMORY = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":88
 * cdef int socket_EAI_FAMILY     = getattr(socket, 'EAI_FAMILY', -1)
 * cdef int socket_EAI_MEMORY     = getattr(socket, 'EAI_MEMORY', -1)
 * cdef int socket_EAI_NODATA     = getattr(socket, 'EAI_NODATA', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_NONAME     = getattr(socket, 'EAI_NONAME', -1)
 * cdef int socket_EAI_OVERFLOW   = getattr(socket, 'EAI_OVERFLOW', -1)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_EAI_NODATA, __pyx_int_neg_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 88, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_NODATA = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":89
 * cdef int socket_EAI_MEMORY     = getattr(socket, 'EAI_MEMORY', -1)
 * cdef int socket_EAI_NODATA     = getattr(socket, 'EAI_NODATA', -1)
 * cdef int socket_EAI_NONAME     = getattr(socket, 'EAI_NONAME', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_OVERFLOW   = getattr(socket, 'EAI_OVERFLOW', -1)
 * cdef int socket_EAI_PROTOCOL   = getattr(socket, 'EAI_PROTOCOL', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_EAI_NONAME, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 89, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_NONAME = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":90
 * cdef int socket_EAI_NODATA     = getattr(socket, 'EAI_NODATA', -1)
 * cdef int socket_EAI_NONAME     = getattr(socket, 'EAI_NONAME', -1)
 * cdef int socket_EAI_OVERFLOW   = getattr(socket, 'EAI_OVERFLOW', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_PROTOCOL   = getattr(socket, 'EAI_PROTOCOL', -1)
 * cdef int socket_EAI_SERVICE    = getattr(socket, 'EAI_SERVICE', -1)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_EAI_OVERFLOW, __pyx_int_neg_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 90, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_OVERFLOW = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":91
 * cdef int socket_EAI_NONAME     = getattr(socket, 'EAI_NONAME', -1)
 * cdef int socket_EAI_OVERFLOW   = getattr(socket, 'EAI_OVERFLOW', -1)
 * cdef int socket_EAI_PROTOCOL   = getattr(socket, 'EAI_PROTOCOL', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_SERVICE    = getattr(socket, 'EAI_SERVICE', -1)
 * cdef int socket_EAI_SOCKTYPE   = getattr(socket, 'EAI_SOCKTYPE', -1)
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_EAI_PROTOCOL, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 91, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_PROTOCOL = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":92
 * cdef int socket_EAI_OVERFLOW   = getattr(socket, 'EAI_OVERFLOW', -1)
 * cdef int socket_EAI_PROTOCOL   = getattr(socket, 'EAI_PROTOCOL', -1)
 * cdef int socket_EAI_SERVICE    = getattr(socket, 'EAI_SERVICE', -1)             # <<<<<<<<<<<<<<
 * cdef int socket_EAI_SOCKTYPE   = getattr(socket, 'EAI_SOCKTYPE', -1)
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr3(__pyx_t_1, __pyx_n_u_EAI_SERVICE, __pyx_int_neg_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 92, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_SERVICE = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":93
 * cdef int socket_EAI_PROTOCOL   = getattr(socket, 'EAI_PROTOCOL', -1)
 * cdef int socket_EAI_SERVICE    = getattr(socket, 'EAI_SERVICE', -1)
 * cdef int socket_EAI_SOCKTYPE   = getattr(socket, 'EAI_SOCKTYPE', -1)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_socket_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_2, __pyx_n_u_EAI_SOCKTYPE, __pyx_int_neg_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 93, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_socket_EAI_SOCKTYPE = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":96
 * 
 * 
 * cdef str os_name = os.name             # <<<<<<<<<<<<<<
 * cdef os_environ = os.environ
 * cdef os_dup = os.dup
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_name_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 96, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(27, 96, __pyx_L1_error)
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_name);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_name, ((PyObject*)__pyx_t_2));
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":97
 * 
 * cdef str os_name = os.name
 * cdef os_environ = os.environ             # <<<<<<<<<<<<<<
 * cdef os_dup = os.dup
 * cdef os_set_inheritable = os.set_inheritable
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_environ); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_environ);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_environ, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":98
 * cdef str os_name = os.name
 * cdef os_environ = os.environ
 * cdef os_dup = os.dup             # <<<<<<<<<<<<<<
 * cdef os_set_inheritable = os.set_inheritable
 * cdef os_get_inheritable = os.get_inheritable
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_dup); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 98, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_dup);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_dup, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":99
 * cdef os_environ = os.environ
 * cdef os_dup = os.dup
 * cdef os_set_inheritable = os.set_inheritable             # <<<<<<<<<<<<<<
 * cdef os_get_inheritable = os.get_inheritable
 * cdef os_close = os.close
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_inheritable); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_set_inheritable);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_set_inheritable, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":100
 * cdef os_dup = os.dup
 * cdef os_set_inheritable = os.set_inheritable
 * cdef os_get_inheritable = os.get_inheritable             # <<<<<<<<<<<<<<
 * cdef os_close = os.close
 * cdef os_open = os.open
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_inheritable); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_get_inheritable);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_get_inheritable, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":101
 * cdef os_set_inheritable = os.set_inheritable
 * cdef os_get_inheritable = os.get_inheritable
 * cdef os_close = os.close             # <<<<<<<<<<<<<<
 * cdef os_open = os.open
 * cdef os_devnull = os.devnull
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_close); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_close);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_close, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":102
 * cdef os_get_inheritable = os.get_inheritable
 * cdef os_close = os.close
 * cdef os_open = os.open             # <<<<<<<<<<<<<<
 * cdef os_devnull = os.devnull
 * cdef os_O_RDWR = os.O_RDWR
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_open); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_open);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_open, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":103
 * cdef os_close = os.close
 * cdef os_open = os.open
 * cdef os_devnull = os.devnull             # <<<<<<<<<<<<<<
 * cdef os_O_RDWR = os.O_RDWR
 * cdef os_pipe = os.pipe
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_devnull); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_devnull);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_devnull, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":104
 * cdef os_open = os.open
 * cdef os_devnull = os.devnull
 * cdef os_O_RDWR = os.O_RDWR             # <<<<<<<<<<<<<<
 * cdef os_pipe = os.pipe
 * cdef os_read = os.read
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_O_RDWR); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_O_RDWR);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_O_RDWR, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":105
 * cdef os_devnull = os.devnull
 * cdef os_O_RDWR = os.O_RDWR
 * cdef os_pipe = os.pipe             # <<<<<<<<<<<<<<
 * cdef os_read = os.read
 * cdef os_remove = os.remove
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_pipe); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_pipe);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_pipe, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":106
 * cdef os_O_RDWR = os.O_RDWR
 * cdef os_pipe = os.pipe
 * cdef os_read = os.read             # <<<<<<<<<<<<<<
 * cdef os_remove = os.remove
 * cdef os_stat = os.stat
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_read); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_read);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_read, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":107
 * cdef os_pipe = os.pipe
 * cdef os_read = os.read
 * cdef os_remove = os.remove             # <<<<<<<<<<<<<<
 * cdef os_stat = os.stat
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_remove); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_remove);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_remove, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":108
 * cdef os_read = os.read
 * cdef os_remove = os.remove
 * cdef os_stat = os.stat             # <<<<<<<<<<<<<<
 * 
 * cdef stat_S_ISSOCK = stat.S_ISSOCK
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_stat); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_os_stat);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_os_stat, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":110
 * cdef os_stat = os.stat
 * 
 * cdef stat_S_ISSOCK = stat.S_ISSOCK             # <<<<<<<<<<<<<<
 * 
 * cdef sys_ignore_environment = sys.flags.ignore_environment
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_stat); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_S_ISSOCK); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_stat_S_ISSOCK);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_stat_S_ISSOCK, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":112
 * cdef stat_S_ISSOCK = stat.S_ISSOCK
 * 
 * cdef sys_ignore_environment = sys.flags.ignore_environment             # <<<<<<<<<<<<<<
 * cdef sys_exc_info = sys.exc_info
 * cdef sys_set_coroutine_wrapper = sys.set_coroutine_wrapper
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_flags); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ignore_environment); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_sys_ignore_environment);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_sys_ignore_environment, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":113
 * 
 * cdef sys_ignore_environment = sys.flags.ignore_environment
 * cdef sys_exc_info = sys.exc_info             # <<<<<<<<<<<<<<
 * cdef sys_set_coroutine_wrapper = sys.set_coroutine_wrapper
 * cdef sys_get_coroutine_wrapper = sys.get_coroutine_wrapper
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_exc_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_sys_exc_info);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_sys_exc_info, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":114
 * cdef sys_ignore_environment = sys.flags.ignore_environment
 * cdef sys_exc_info = sys.exc_info
 * cdef sys_set_coroutine_wrapper = sys.set_coroutine_wrapper             # <<<<<<<<<<<<<<
 * cdef sys_get_coroutine_wrapper = sys.get_coroutine_wrapper
 * cdef sys_getframe = sys._getframe
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_coroutine_wrapper); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_sys_set_coroutine_wrapper);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_sys_set_coroutine_wrapper, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":115
 * cdef sys_exc_info = sys.exc_info
 * cdef sys_set_coroutine_wrapper = sys.set_coroutine_wrapper
 * cdef sys_get_coroutine_wrapper = sys.get_coroutine_wrapper             # <<<<<<<<<<<<<<
 * cdef sys_getframe = sys._getframe
 * cdef sys_version_info = sys.version_info
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_coroutine_wrapper); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_sys_get_coroutine_wrapper);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_sys_get_coroutine_wrapper, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":116
 * cdef sys_set_coroutine_wrapper = sys.set_coroutine_wrapper
 * cdef sys_get_coroutine_wrapper = sys.get_coroutine_wrapper
 * cdef sys_getframe = sys._getframe             # <<<<<<<<<<<<<<
 * cdef sys_version_info = sys.version_info
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getframe); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_sys_getframe);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_sys_getframe, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":117
 * cdef sys_get_coroutine_wrapper = sys.get_coroutine_wrapper
 * cdef sys_getframe = sys._getframe
 * cdef sys_version_info = sys.version_info             # <<<<<<<<<<<<<<
 * 
 * cdef ssl_SSLContext = ssl.SSLContext
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_version_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_sys_version_info);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_sys_version_info, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":119
 * cdef sys_version_info = sys.version_info
 * 
 * cdef ssl_SSLContext = ssl.SSLContext             # <<<<<<<<<<<<<<
 * cdef ssl_MemoryBIO = ssl.MemoryBIO
 * cdef ssl_create_default_context = ssl.create_default_context
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_SSLContext); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_ssl_SSLContext);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_ssl_SSLContext, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":120
 * 
 * cdef ssl_SSLContext = ssl.SSLContext
 * cdef ssl_MemoryBIO = ssl.MemoryBIO             # <<<<<<<<<<<<<<
 * cdef ssl_create_default_context = ssl.create_default_context
 * cdef ssl_SSLError = ssl.SSLError
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_MemoryBIO); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_ssl_MemoryBIO);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_ssl_MemoryBIO, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":121
 * cdef ssl_SSLContext = ssl.SSLContext
 * cdef ssl_MemoryBIO = ssl.MemoryBIO
 * cdef ssl_create_default_context = ssl.create_default_context             # <<<<<<<<<<<<<<
 * cdef ssl_SSLError = ssl.SSLError
 * cdef ssl_CertificateError = ssl.CertificateError
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_create_default_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_ssl_create_default_context);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_ssl_create_default_context, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":122
 * cdef ssl_MemoryBIO = ssl.MemoryBIO
 * cdef ssl_create_default_context = ssl.create_default_context
 * cdef ssl_SSLError = ssl.SSLError             # <<<<<<<<<<<<<<
 * cdef ssl_CertificateError = ssl.CertificateError
 * cdef int ssl_SSL_ERROR_WANT_READ = ssl.SSL_ERROR_WANT_READ
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SSLError); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_ssl_SSLError);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_ssl_SSLError, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":123
 * cdef ssl_create_default_context = ssl.create_default_context
 * cdef ssl_SSLError = ssl.SSLError
 * cdef ssl_CertificateError = ssl.CertificateError             # <<<<<<<<<<<<<<
 * cdef int ssl_SSL_ERROR_WANT_READ = ssl.SSL_ERROR_WANT_READ
 * cdef int ssl_SSL_ERROR_WANT_WRITE = ssl.SSL_ERROR_WANT_WRITE
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_CertificateError); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_ssl_CertificateError);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_ssl_CertificateError, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":124
 * cdef ssl_SSLError = ssl.SSLError
 * cdef ssl_CertificateError = ssl.CertificateError
 * cdef int ssl_SSL_ERROR_WANT_READ = ssl.SSL_ERROR_WANT_READ             # <<<<<<<<<<<<<<
 * cdef int ssl_SSL_ERROR_WANT_WRITE = ssl.SSL_ERROR_WANT_WRITE
 * cdef int ssl_SSL_ERROR_SYSCALL = ssl.SSL_ERROR_SYSCALL
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SSL_ERROR_WANT_READ); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_READ = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":125
 * cdef ssl_CertificateError = ssl.CertificateError
 * cdef int ssl_SSL_ERROR_WANT_READ = ssl.SSL_ERROR_WANT_READ
 * cdef int ssl_SSL_ERROR_WANT_WRITE = ssl.SSL_ERROR_WANT_WRITE             # <<<<<<<<<<<<<<
 * cdef int ssl_SSL_ERROR_SYSCALL = ssl.SSL_ERROR_SYSCALL
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_SSL_ERROR_WANT_WRITE); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_WANT_WRITE = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":126
 * cdef int ssl_SSL_ERROR_WANT_READ = ssl.SSL_ERROR_WANT_READ
 * cdef int ssl_SSL_ERROR_WANT_WRITE = ssl.SSL_ERROR_WANT_WRITE
 * cdef int ssl_SSL_ERROR_SYSCALL = ssl.SSL_ERROR_SYSCALL             # <<<<<<<<<<<<<<
 * 
 * cdef uint64_t MAIN_THREAD_ID = <uint64_t><int64_t>threading.main_thread().ident
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_ssl); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_SSL_ERROR_SYSCALL); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_ssl_SSL_ERROR_SYSCALL = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":128
 * cdef int ssl_SSL_ERROR_SYSCALL = ssl.SSL_ERROR_SYSCALL
 * 
 * cdef uint64_t MAIN_THREAD_ID = <uint64_t><int64_t>threading.main_thread().ident             # <<<<<<<<<<<<<<
 * 
 * cdef int subprocess_PIPE = subprocess.PIPE
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_threading); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_main_thread); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_ident); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __Pyx_PyInt_As_int64_t(__pyx_t_1); if (unlikely((__pyx_t_5 == ((int64_t)-1)) && PyErr_Occurred())) __PYX_ERR(27, 128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_MAIN_THREAD_ID = ((uint64_t)((int64_t)__pyx_t_5));

  /* "uvloop/includes/stdlib.pxi":130
 * cdef uint64_t MAIN_THREAD_ID = <uint64_t><int64_t>threading.main_thread().ident
 * 
 * cdef int subprocess_PIPE = subprocess.PIPE             # <<<<<<<<<<<<<<
 * cdef int subprocess_STDOUT = subprocess.STDOUT
 * cdef int subprocess_DEVNULL = subprocess.DEVNULL
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_subprocess); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_PIPE); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 130, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_subprocess_PIPE = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":131
 * 
 * cdef int subprocess_PIPE = subprocess.PIPE
 * cdef int subprocess_STDOUT = subprocess.STDOUT             # <<<<<<<<<<<<<<
 * cdef int subprocess_DEVNULL = subprocess.DEVNULL
 * cdef subprocess_SubprocessError = subprocess.SubprocessError
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_subprocess); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_STDOUT); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_6uvloop_4loop_subprocess_STDOUT = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":132
 * cdef int subprocess_PIPE = subprocess.PIPE
 * cdef int subprocess_STDOUT = subprocess.STDOUT
 * cdef int subprocess_DEVNULL = subprocess.DEVNULL             # <<<<<<<<<<<<<<
 * cdef subprocess_SubprocessError = subprocess.SubprocessError
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_subprocess); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEVNULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_subprocess_DEVNULL = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":133
 * cdef int subprocess_STDOUT = subprocess.STDOUT
 * cdef int subprocess_DEVNULL = subprocess.DEVNULL
 * cdef subprocess_SubprocessError = subprocess.SubprocessError             # <<<<<<<<<<<<<<
 * 
 * cdef int signal_NSIG = signal.NSIG
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_subprocess); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_SubprocessError); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_subprocess_SubprocessError);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_subprocess_SubprocessError, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":135
 * cdef subprocess_SubprocessError = subprocess.SubprocessError
 * 
 * cdef int signal_NSIG = signal.NSIG             # <<<<<<<<<<<<<<
 * cdef signal_signal = signal.signal
 * cdef signal_siginterrupt = signal.siginterrupt
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_signal); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NSIG); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(27, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_6uvloop_4loop_signal_NSIG = __pyx_t_4;

  /* "uvloop/includes/stdlib.pxi":136
 * 
 * cdef int signal_NSIG = signal.NSIG
 * cdef signal_signal = signal.signal             # <<<<<<<<<<<<<<
 * cdef signal_siginterrupt = signal.siginterrupt
 * cdef signal_set_wakeup_fd = signal.set_wakeup_fd
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_signal); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_signal); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_signal_signal);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_signal_signal, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":137
 * cdef int signal_NSIG = signal.NSIG
 * cdef signal_signal = signal.signal
 * cdef signal_siginterrupt = signal.siginterrupt             # <<<<<<<<<<<<<<
 * cdef signal_set_wakeup_fd = signal.set_wakeup_fd
 * cdef signal_default_int_handler = signal.default_int_handler
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_signal); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_siginterrupt); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_signal_siginterrupt);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_signal_siginterrupt, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":138
 * cdef signal_signal = signal.signal
 * cdef signal_siginterrupt = signal.siginterrupt
 * cdef signal_set_wakeup_fd = signal.set_wakeup_fd             # <<<<<<<<<<<<<<
 * cdef signal_default_int_handler = signal.default_int_handler
 * cdef signal_SIG_DFL = signal.SIG_DFL
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_signal); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_wakeup_fd); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_signal_set_wakeup_fd);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_signal_set_wakeup_fd, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":139
 * cdef signal_siginterrupt = signal.siginterrupt
 * cdef signal_set_wakeup_fd = signal.set_wakeup_fd
 * cdef signal_default_int_handler = signal.default_int_handler             # <<<<<<<<<<<<<<
 * cdef signal_SIG_DFL = signal.SIG_DFL
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_signal); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_default_int_handler); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_signal_default_int_handler);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_signal_default_int_handler, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":140
 * cdef signal_set_wakeup_fd = signal.set_wakeup_fd
 * cdef signal_default_int_handler = signal.default_int_handler
 * cdef signal_SIG_DFL = signal.SIG_DFL             # <<<<<<<<<<<<<<
 * 
 * cdef time_sleep = time.sleep
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_signal); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_SIG_DFL); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_signal_SIG_DFL);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_signal_SIG_DFL, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":142
 * cdef signal_SIG_DFL = signal.SIG_DFL
 * 
 * cdef time_sleep = time.sleep             # <<<<<<<<<<<<<<
 * cdef time_monotonic = time.monotonic
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_sleep); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_time_sleep);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_time_sleep, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":143
 * 
 * cdef time_sleep = time.sleep
 * cdef time_monotonic = time.monotonic             # <<<<<<<<<<<<<<
 * 
 * cdef tb_StackSummary = traceback.StackSummary
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_time); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_monotonic); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_time_monotonic);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_time_monotonic, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":145
 * cdef time_monotonic = time.monotonic
 * 
 * cdef tb_StackSummary = traceback.StackSummary             # <<<<<<<<<<<<<<
 * cdef tb_walk_stack = traceback.walk_stack
 * cdef tb_format_list = traceback.format_list
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_traceback_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_StackSummary); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_tb_StackSummary);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_tb_StackSummary, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":146
 * 
 * cdef tb_StackSummary = traceback.StackSummary
 * cdef tb_walk_stack = traceback.walk_stack             # <<<<<<<<<<<<<<
 * cdef tb_format_list = traceback.format_list
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_traceback_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_walk_stack); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_tb_walk_stack);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_tb_walk_stack, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":147
 * cdef tb_StackSummary = traceback.StackSummary
 * cdef tb_walk_stack = traceback.walk_stack
 * cdef tb_format_list = traceback.format_list             # <<<<<<<<<<<<<<
 * 
 * cdef warnings_warn = warnings.warn
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_traceback_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_format_list); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_tb_format_list);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_tb_format_list, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":149
 * cdef tb_format_list = traceback.format_list
 * 
 * cdef warnings_warn = warnings.warn             # <<<<<<<<<<<<<<
 * 
 * cdef weakref_WeakValueDictionary = weakref.WeakValueDictionary
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_warnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_warnings_warn);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_warnings_warn, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":151
 * cdef warnings_warn = warnings.warn
 * 
 * cdef weakref_WeakValueDictionary = weakref.WeakValueDictionary             # <<<<<<<<<<<<<<
 * cdef weakref_WeakSet = weakref.WeakSet
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_weakref); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_WeakValueDictionary); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 151, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_weakref_WeakValueDictionary);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_weakref_WeakValueDictionary, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "uvloop/includes/stdlib.pxi":152
 * 
 * cdef weakref_WeakValueDictionary = weakref.WeakValueDictionary
 * cdef weakref_WeakSet = weakref.WeakSet             # <<<<<<<<<<<<<<
 * 
 * cdef py_inf = float('inf')
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_weakref); if (unlikely(!__pyx_t_2)) __PYX_ERR(27, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_WeakSet); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_weakref_WeakSet);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_weakref_WeakSet, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":154
 * cdef weakref_WeakSet = weakref.WeakSet
 * 
 * cdef py_inf = float('inf')             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyNumber_Float(__pyx_n_u_inf); if (unlikely(!__pyx_t_1)) __PYX_ERR(27, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop_py_inf);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop_py_inf, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/includes/stdlib.pxi":159
 * # Cython doesn't clean-up imported objects properly in Py3 mode,
 * # so we delete refs to all modules manually (except sys)
 * del asyncio, concurrent, collections, errno             # <<<<<<<<<<<<<<
 * del functools, inspect, itertools, socket, os, threading
 * del signal, subprocess, ssl
 */
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_asyncio) < 0) __PYX_ERR(27, 159, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_concurrent) < 0) __PYX_ERR(27, 159, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_collections) < 0) __PYX_ERR(27, 159, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_errno) < 0) __PYX_ERR(27, 159, __pyx_L1_error)

  /* "uvloop/includes/stdlib.pxi":160
 * # so we delete refs to all modules manually (except sys)
 * del asyncio, concurrent, collections, errno
 * del functools, inspect, itertools, socket, os, threading             # <<<<<<<<<<<<<<
 * del signal, subprocess, ssl
 * del time, traceback, warnings, weakref
 */
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_functools) < 0) __PYX_ERR(27, 160, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_inspect) < 0) __PYX_ERR(27, 160, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_itertools) < 0) __PYX_ERR(27, 160, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_socket_2) < 0) __PYX_ERR(27, 160, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_os) < 0) __PYX_ERR(27, 160, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_threading) < 0) __PYX_ERR(27, 160, __pyx_L1_error)

  /* "uvloop/includes/stdlib.pxi":161
 * del asyncio, concurrent, collections, errno
 * del functools, inspect, itertools, socket, os, threading
 * del signal, subprocess, ssl             # <<<<<<<<<<<<<<
 * del time, traceback, warnings, weakref
 */
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_signal) < 0) __PYX_ERR(27, 161, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_subprocess) < 0) __PYX_ERR(27, 161, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_ssl) < 0) __PYX_ERR(27, 161, __pyx_L1_error)

  /* "uvloop/includes/stdlib.pxi":162
 * del functools, inspect, itertools, socket, os, threading
 * del signal, subprocess, ssl
 * del time, traceback, warnings, weakref             # <<<<<<<<<<<<<<
 */
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_time) < 0) __PYX_ERR(27, 162, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_traceback_2) < 0) __PYX_ERR(27, 162, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_warnings) < 0) __PYX_ERR(27, 162, __pyx_L1_error)
  if (__Pyx_PyObject_DelAttrStr(__pyx_m, __pyx_n_s_weakref) < 0) __PYX_ERR(27, 162, __pyx_L1_error)

  /* "uvloop/loop.pyx":44
 * 
 * cdef:
 *     int PY37 = PY_VERSION_HEX >= 0x03070000             # <<<<<<<<<<<<<<
 *     int PY36 = PY_VERSION_HEX >= 0x03060000
 * 
 */
  __pyx_v_6uvloop_4loop_PY37 = (PY_VERSION_HEX >= 0x03070000);

  /* "uvloop/loop.pyx":45
 * cdef:
 *     int PY37 = PY_VERSION_HEX >= 0x03070000
 *     int PY36 = PY_VERSION_HEX >= 0x03060000             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_6uvloop_4loop_PY36 = (PY_VERSION_HEX >= 0x03060000);

  /* "uvloop/loop.pyx":1569
 *     async def create_server(self, protocol_factory, host=None, port=None,
 *                             *,
 *                             int family=uv.AF_UNSPEC,             # <<<<<<<<<<<<<<
 *                             int flags=uv.AI_PASSIVE,
 *                             sock=None,
 */
  __pyx_k__53 = AF_UNSPEC;

  /* "uvloop/loop.pyx":1570
 *                             *,
 *                             int family=uv.AF_UNSPEC,
 *                             int flags=uv.AI_PASSIVE,             # <<<<<<<<<<<<<<
 *                             sock=None,
 *                             backlog=100,
 */
  __pyx_k__54 = AI_PASSIVE;

  /* "uvloop/loop.pyx":2519
 *     @cython.iterable_coroutine
 *     async def __subprocess_run(self, protocol_factory, args,
 *                                stdin=subprocess_PIPE,             # <<<<<<<<<<<<<<
 *                                stdout=subprocess_PIPE,
 *                                stderr=subprocess_PIPE,
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_PIPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_k__101 = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2520
 *     async def __subprocess_run(self, protocol_factory, args,
 *                                stdin=subprocess_PIPE,
 *                                stdout=subprocess_PIPE,             # <<<<<<<<<<<<<<
 *                                stderr=subprocess_PIPE,
 *                                universal_newlines=False,
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_PIPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_k__102 = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2521
 *                                stdin=subprocess_PIPE,
 *                                stdout=subprocess_PIPE,
 *                                stderr=subprocess_PIPE,             # <<<<<<<<<<<<<<
 *                                universal_newlines=False,
 *                                shell=True,
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_6uvloop_4loop_subprocess_PIPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_k__103 = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2981
 * 
 * 
 * class _SyncSocketReaderFuture(aio_Future):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, sock, loop):
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_Future);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_aio_Future);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_6uvloop_4loop_aio_Future);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_1, __pyx_n_s_SyncSocketReaderFuture, __pyx_n_s_SyncSocketReaderFuture, (PyObject *) NULL, __pyx_n_s_uvloop_loop, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/loop.pyx":2983
 * class _SyncSocketReaderFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_23_SyncSocketReaderFuture_1__init__, 0, __pyx_n_s_SyncSocketReaderFuture___init, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__274)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(2, 2983, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":2988
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_reader(self.__sock)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_23_SyncSocketReaderFuture_3cancel, 0, __pyx_n_s_SyncSocketReaderFuture_cancel, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__276)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_cancel, __pyx_t_7) < 0) __PYX_ERR(2, 2988, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":2981
 * 
 * 
 * class _SyncSocketReaderFuture(aio_Future):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, sock, loop):
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_SyncSocketReaderFuture, __pyx_t_1, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SyncSocketReaderFuture, __pyx_t_7) < 0) __PYX_ERR(2, 2981, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/loop.pyx":2996
 * 
 * 
 * class _SyncSocketWriterFuture(aio_Future):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, sock, loop):
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_Future);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_aio_Future);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_6uvloop_4loop_aio_Future);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_1, __pyx_n_s_SyncSocketWriterFuture, __pyx_n_s_SyncSocketWriterFuture, (PyObject *) NULL, __pyx_n_s_uvloop_loop, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/loop.pyx":2998
 * class _SyncSocketWriterFuture(aio_Future):
 * 
 *     def __init__(self, sock, loop):             # <<<<<<<<<<<<<<
 *         aio_Future.__init__(self, loop=loop)
 *         self.__sock = sock
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_23_SyncSocketWriterFuture_1__init__, 0, __pyx_n_s_SyncSocketWriterFuture___init, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__278)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2998, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(2, 2998, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":3003
 *         self.__loop = loop
 * 
 *     def cancel(self):             # <<<<<<<<<<<<<<
 *         if self.__sock is not None and self.__sock.fileno() != -1:
 *             self.__loop.remove_writer(self.__sock)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_23_SyncSocketWriterFuture_3cancel, 0, __pyx_n_s_SyncSocketWriterFuture_cancel, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__280)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_cancel, __pyx_t_7) < 0) __PYX_ERR(2, 3003, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/loop.pyx":2996
 * 
 * 
 * class _SyncSocketWriterFuture(aio_Future):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, sock, loop):
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_SyncSocketWriterFuture, __pyx_t_1, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2996, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SyncSocketWriterFuture, __pyx_t_7) < 0) __PYX_ERR(2, 2996, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":672
 * 
 * 
 * class WriteSubprocessPipeProto(aio_BaseProtocol):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, proc, fd):
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_BaseProtocol);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_aio_BaseProtocol);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_6uvloop_4loop_aio_BaseProtocol);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_1, __pyx_n_s_WriteSubprocessPipeProto, __pyx_n_s_WriteSubprocessPipeProto, (PyObject *) NULL, __pyx_n_s_uvloop_loop, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/handles/process.pyx":674
 * class WriteSubprocessPipeProto(aio_BaseProtocol):
 * 
 *     def __init__(self, proc, fd):             # <<<<<<<<<<<<<<
 *         if UVLOOP_DEBUG:
 *             if type(proc) is not UVProcessTransport:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_1__init__, 0, __pyx_n_s_WriteSubprocessPipeProto___init, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(6, 674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/handles/process.pyx":685
 *         self.disconnected = False
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         self.pipe = transport
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_3connection_made, 0, __pyx_n_s_WriteSubprocessPipeProto_connect, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__284)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_connection_made, __pyx_t_7) < 0) __PYX_ERR(6, 685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/handles/process.pyx":688
 *         self.pipe = transport
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return ('<%s fd=%s pipe=%r>'
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_5__repr__, 0, __pyx_n_s_WriteSubprocessPipeProto___repr, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__286)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_repr, __pyx_t_7) < 0) __PYX_ERR(6, 688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/handles/process.pyx":692
 *                 % (self.__class__.__name__, self.fd, self.pipe))
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         self.disconnected = True
 *         (<UVProcessTransport>self.proc)._pipe_connection_lost(self.fd, exc)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_7connection_lost, 0, __pyx_n_s_WriteSubprocessPipeProto_connect_2, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__288)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_connection_lost, __pyx_t_7) < 0) __PYX_ERR(6, 692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/handles/process.pyx":697
 *         self.proc = None
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_9pause_writing, 0, __pyx_n_s_WriteSubprocessPipeProto_pause_w, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__290)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_pause_writing, __pyx_t_7) < 0) __PYX_ERR(6, 697, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/handles/process.pyx":700
 *         (<UVProcessTransport>self.proc)._protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._protocol.resume_writing()
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_24WriteSubprocessPipeProto_11resume_writing, 0, __pyx_n_s_WriteSubprocessPipeProto_resume, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__292)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_resume_writing, __pyx_t_7) < 0) __PYX_ERR(6, 700, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/handles/process.pyx":672
 * 
 * 
 * class WriteSubprocessPipeProto(aio_BaseProtocol):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, proc, fd):
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_WriteSubprocessPipeProto, __pyx_t_1, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_WriteSubprocessPipeProto, __pyx_t_7) < 0) __PYX_ERR(6, 672, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":704
 * 
 * 
 * class ReadSubprocessPipeProto(WriteSubprocessPipeProto,             # <<<<<<<<<<<<<<
 *                               aio_Protocol):
 * 
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_WriteSubprocessPipeProto); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/handles/process.pyx":705
 * 
 * class ReadSubprocessPipeProto(WriteSubprocessPipeProto,
 *                               aio_Protocol):             # <<<<<<<<<<<<<<
 * 
 *     def data_received(self, data):
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_Protocol);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_aio_Protocol);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_6uvloop_4loop_aio_Protocol);
  __pyx_t_1 = 0;

  /* "uvloop/handles/process.pyx":704
 * 
 * 
 * class ReadSubprocessPipeProto(WriteSubprocessPipeProto,             # <<<<<<<<<<<<<<
 *                               aio_Protocol):
 * 
 */
  __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_2, __pyx_n_s_ReadSubprocessPipeProto, __pyx_n_s_ReadSubprocessPipeProto, (PyObject *) NULL, __pyx_n_s_uvloop_loop, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/handles/process.pyx":707
 *                               aio_Protocol):
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         (<UVProcessTransport>self.proc)._pipe_data_received(self.fd, data)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_23ReadSubprocessPipeProto_1data_received, 0, __pyx_n_s_ReadSubprocessPipeProto_data_rec, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__294)); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_data_received, __pyx_t_7) < 0) __PYX_ERR(6, 707, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/handles/process.pyx":704
 * 
 * 
 * class ReadSubprocessPipeProto(WriteSubprocessPipeProto,             # <<<<<<<<<<<<<<
 *                               aio_Protocol):
 * 
 */
  __pyx_t_7 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_ReadSubprocessPipeProto, __pyx_t_2, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(6, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ReadSubprocessPipeProto, __pyx_t_7) < 0) __PYX_ERR(6, 704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/sslproto.pyx":20
 * # States of an _SSLPipe.
 * cdef:
 *     str _UNWRAPPED = "UNWRAPPED"             # <<<<<<<<<<<<<<
 *     str _DO_HANDSHAKE = "DO_HANDSHAKE"
 *     str _WRAPPED = "WRAPPED"
 */
  __Pyx_INCREF(__pyx_n_u_UNWRAPPED);
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop__UNWRAPPED);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop__UNWRAPPED, __pyx_n_u_UNWRAPPED);
  __Pyx_GIVEREF(__pyx_n_u_UNWRAPPED);

  /* "uvloop/sslproto.pyx":21
 * cdef:
 *     str _UNWRAPPED = "UNWRAPPED"
 *     str _DO_HANDSHAKE = "DO_HANDSHAKE"             # <<<<<<<<<<<<<<
 *     str _WRAPPED = "WRAPPED"
 *     str _SHUTDOWN = "SHUTDOWN"
 */
  __Pyx_INCREF(__pyx_n_u_DO_HANDSHAKE);
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop__DO_HANDSHAKE);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop__DO_HANDSHAKE, __pyx_n_u_DO_HANDSHAKE);
  __Pyx_GIVEREF(__pyx_n_u_DO_HANDSHAKE);

  /* "uvloop/sslproto.pyx":22
 *     str _UNWRAPPED = "UNWRAPPED"
 *     str _DO_HANDSHAKE = "DO_HANDSHAKE"
 *     str _WRAPPED = "WRAPPED"             # <<<<<<<<<<<<<<
 *     str _SHUTDOWN = "SHUTDOWN"
 * 
 */
  __Pyx_INCREF(__pyx_n_u_WRAPPED);
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop__WRAPPED);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop__WRAPPED, __pyx_n_u_WRAPPED);
  __Pyx_GIVEREF(__pyx_n_u_WRAPPED);

  /* "uvloop/sslproto.pyx":23
 *     str _DO_HANDSHAKE = "DO_HANDSHAKE"
 *     str _WRAPPED = "WRAPPED"
 *     str _SHUTDOWN = "SHUTDOWN"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF(__pyx_n_u_SHUTDOWN);
  __Pyx_XGOTREF(__pyx_v_6uvloop_4loop__SHUTDOWN);
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop__SHUTDOWN, __pyx_n_u_SHUTDOWN);
  __Pyx_GIVEREF(__pyx_n_u_SHUTDOWN);

  /* "uvloop/sslproto.pyx":26
 * 
 * 
 * cdef ssize_t READ_MAX_SIZE = 256 * 1024             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_6uvloop_4loop_READ_MAX_SIZE = 0x40000;

  /* "uvloop/sslproto.pyx":267
 * 
 * 
 * class _SSLProtocolTransport(aio_FlowControlMixin, aio_Transport):             # <<<<<<<<<<<<<<
 * 
 *     # TODO:
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_FlowControlMixin);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_aio_FlowControlMixin);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_6uvloop_4loop_aio_FlowControlMixin);
  __Pyx_INCREF(__pyx_v_6uvloop_4loop_aio_Transport);
  __Pyx_GIVEREF(__pyx_v_6uvloop_4loop_aio_Transport);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_6uvloop_4loop_aio_Transport);
  __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_2, __pyx_n_s_SSLProtocolTransport, __pyx_n_s_SSLProtocolTransport, (PyObject *) NULL, __pyx_n_s_uvloop_loop, (PyObject *) NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);

  /* "uvloop/sslproto.pyx":272
 *     # _sendfile_compatible = constants._SendfileMode.FALLBACK
 * 
 *     def __init__(self, loop, ssl_protocol):             # <<<<<<<<<<<<<<
 *         self._loop = loop
 *         # SSLProtocol instance
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_1__init__, 0, __pyx_n_s_SSLProtocolTransport___init, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__296)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_init, __pyx_t_7) < 0) __PYX_ERR(0, 272, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":278
 *         self._closed = False
 * 
 *     def get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         """Get optional transport information."""
 *         return self._ssl_protocol._get_extra_info(name, default)
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_3get_extra_info, 0, __pyx_n_s_SSLProtocolTransport_get_extra, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__298)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__299);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_get_extra_info, __pyx_t_7) < 0) __PYX_ERR(0, 278, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":282
 *         return self._ssl_protocol._get_extra_info(name, default)
 * 
 *     def set_protocol(self, protocol):             # <<<<<<<<<<<<<<
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_5set_protocol, 0, __pyx_n_s_SSLProtocolTransport_set_protoc, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__301)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_set_protocol, __pyx_t_7) < 0) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":285
 *         self._ssl_protocol._set_app_protocol(protocol)
 * 
 *     def get_protocol(self):             # <<<<<<<<<<<<<<
 *         return self._ssl_protocol._app_protocol
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_7get_protocol, 0, __pyx_n_s_SSLProtocolTransport_get_protoc, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__303)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_get_protocol, __pyx_t_7) < 0) __PYX_ERR(0, 285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":288
 *         return self._ssl_protocol._app_protocol
 * 
 *     def is_closing(self):             # <<<<<<<<<<<<<<
 *         return self._closed
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_9is_closing, 0, __pyx_n_s_SSLProtocolTransport_is_closing, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__305)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_is_closing, __pyx_t_7) < 0) __PYX_ERR(0, 288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":291
 *         return self._closed
 * 
 *     def close(self):             # <<<<<<<<<<<<<<
 *         """Close the transport.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_11close, 0, __pyx_n_s_SSLProtocolTransport_close, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__307)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_close, __pyx_t_7) < 0) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":302
 *         self._ssl_protocol._start_shutdown()
 * 
 *     def __del__(self):             # <<<<<<<<<<<<<<
 *         if not self._closed:
 *             _warn_with_source(
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_13__del__, 0, __pyx_n_s_SSLProtocolTransport___del, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__309)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_del, __pyx_t_7) < 0) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":309
 *             self.close()
 * 
 *     def is_reading(self):             # <<<<<<<<<<<<<<
 *         tr = self._ssl_protocol._transport
 *         if tr is None:
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_15is_reading, 0, __pyx_n_s_SSLProtocolTransport_is_reading, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__311)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_is_reading, __pyx_t_7) < 0) __PYX_ERR(0, 309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":315
 *         return tr.is_reading()
 * 
 *     def pause_reading(self):             # <<<<<<<<<<<<<<
 *         """Pause the receiving end.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_17pause_reading, 0, __pyx_n_s_SSLProtocolTransport_pause_read, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__313)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_pause_reading, __pyx_t_7) < 0) __PYX_ERR(0, 315, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":323
 *         self._ssl_protocol._transport.pause_reading()
 * 
 *     def resume_reading(self):             # <<<<<<<<<<<<<<
 *         """Resume the receiving end.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_19resume_reading, 0, __pyx_n_s_SSLProtocolTransport_resume_rea, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__315)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 323, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_resume_reading, __pyx_t_7) < 0) __PYX_ERR(0, 323, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":331
 *         self._ssl_protocol._transport.resume_reading()
 * 
 *     def set_write_buffer_limits(self, high=None, low=None):             # <<<<<<<<<<<<<<
 *         """Set the high- and low-water limits for write flow control.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_21set_write_buffer_limits, 0, __pyx_n_s_SSLProtocolTransport_set_write, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__317)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__318);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_set_write_buffer_limits, __pyx_t_7) < 0) __PYX_ERR(0, 331, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":352
 *         self._ssl_protocol._transport.set_write_buffer_limits(high, low)
 * 
 *     def get_write_buffer_size(self):             # <<<<<<<<<<<<<<
 *         """Return the current size of the write buffer."""
 *         return self._ssl_protocol._transport.get_write_buffer_size()
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_23get_write_buffer_size, 0, __pyx_n_s_SSLProtocolTransport_get_write, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__320)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_get_write_buffer_size, __pyx_t_7) < 0) __PYX_ERR(0, 352, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "uvloop/sslproto.pyx":357
 * 
 *     @property
 *     def _protocol_paused(self):             # <<<<<<<<<<<<<<
 *         # Required for sendfile fallback pause_writing/resume_writing logic
 *         return self._ssl_protocol._transport._protocol_paused
 */
  __pyx_t_7 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_25_protocol_paused, 0, __pyx_n_s_SSLProtocolTransport__protocol, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__322)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);

  /* "uvloop/sslproto.pyx":356
 *         return self._ssl_protocol._transport.get_write_buffer_size()
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def _protocol_paused(self):
 *         # Required for sendfile fallback pause_writing/resume_writing logic
 */
  __pyx_t_8 = __Pyx_PyObject_CallOneArg(__pyx_builtin_property, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_protocol_paused, __pyx_t_8) < 0) __PYX_ERR(0, 357, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "uvloop/sslproto.pyx":361
 *         return self._ssl_protocol._transport._protocol_paused
 * 
 *     def write(self, data):             # <<<<<<<<<<<<<<
 *         """Write some data bytes to the transport.
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_27write, 0, __pyx_n_s_SSLProtocolTransport_write, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__324)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_write, __pyx_t_8) < 0) __PYX_ERR(0, 361, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "uvloop/sslproto.pyx":374
 *         self._ssl_protocol._write_appdata(data)
 * 
 *     def can_write_eof(self):             # <<<<<<<<<<<<<<
 *         """Return True if this transport supports write_eof(), False if not."""
 *         return False
 */
  __pyx_t_8 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_29can_write_eof, 0, __pyx_n_s_SSLProtocolTransport_can_write, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__326)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_can_write_eof, __pyx_t_8) < 0) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "uvloop/sslproto.pyx":378
 *         return False
 * 
 *     def abort(self):             # <<<<<<<<<<<<<<
 *         """Close the transport immediately.
 * 
 */
  __pyx_t_8 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_21_SSLProtocolTransport_31abort, 0, __pyx_n_s_SSLProtocolTransport_abort, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__328)); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (__Pyx_SetNameInClass(__pyx_t_6, __pyx_n_s_abort_2, __pyx_t_8) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "uvloop/sslproto.pyx":267
 * 
 * 
 * class _SSLProtocolTransport(aio_FlowControlMixin, aio_Transport):             # <<<<<<<<<<<<<<
 * 
 *     # TODO:
 */
  __pyx_t_8 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_SSLProtocolTransport, __pyx_t_2, __pyx_t_6, NULL, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SSLProtocolTransport, __pyx_t_8) < 0) __PYX_ERR(0, 267, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/sslproto.pyx":389
 * 
 * 
 * class SSLProtocol(object):             # <<<<<<<<<<<<<<
 *     """SSL protocol.
 * 
 */
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_tuple__329); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_tuple__329, __pyx_n_s_SSLProtocol, __pyx_n_s_SSLProtocol, (PyObject *) NULL, __pyx_n_s_uvloop_loop, __pyx_kp_s_SSL_protocol_Implementation_of_S); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "uvloop/sslproto.pyx":396
 *     """
 * 
 *     def __init__(self, loop, app_protocol, sslcontext, waiter,             # <<<<<<<<<<<<<<
 *                  server_side=False, server_hostname=None,
 *                  call_connection_made=True,
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_1__init__, 0, __pyx_n_s_SSLProtocol___init, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__331)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__332);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_init, __pyx_t_6) < 0) __PYX_ERR(0, 396, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":439
 *         self._ssl_handshake_timeout = ssl_handshake_timeout
 * 
 *     def _set_app_protocol(self, app_protocol):             # <<<<<<<<<<<<<<
 *         self._app_protocol = app_protocol
 *         self._app_protocol_is_buffer = (
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_3_set_app_protocol, 0, __pyx_n_s_SSLProtocol__set_app_protocol, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__334)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_set_app_protocol, __pyx_t_6) < 0) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":446
 *         )
 * 
 *     def _wakeup_waiter(self, exc=None):             # <<<<<<<<<<<<<<
 *         if self._waiter is None:
 *             return
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_5_wakeup_waiter, 0, __pyx_n_s_SSLProtocol__wakeup_waiter, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__336)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__337);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_wakeup_waiter, __pyx_t_6) < 0) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":456
 *         self._waiter = None
 * 
 *     def connection_made(self, transport):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is made.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_7connection_made, 0, __pyx_n_s_SSLProtocol_connection_made, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__339)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_connection_made, __pyx_t_6) < 0) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":467
 *         self._start_handshake()
 * 
 *     def connection_lost(self, exc):             # <<<<<<<<<<<<<<
 *         """Called when the low-level connection is lost or closed.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_9connection_lost, 0, __pyx_n_s_SSLProtocol_connection_lost, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__341)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_connection_lost, __pyx_t_6) < 0) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":482
 *         self._wakeup_waiter(exc)
 * 
 *     def pause_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer goes over
 *         the high-water mark.
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_11pause_writing, 0, __pyx_n_s_SSLProtocol_pause_writing, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__343)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_pause_writing, __pyx_t_6) < 0) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":488
 *         self._app_protocol.pause_writing()
 * 
 *     def resume_writing(self):             # <<<<<<<<<<<<<<
 *         """Called when the low-level transport's buffer drains below
 *         the low-water mark.
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_13resume_writing, 0, __pyx_n_s_SSLProtocol_resume_writing, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__345)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_resume_writing, __pyx_t_6) < 0) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":494
 *         self._app_protocol.resume_writing()
 * 
 *     def data_received(self, data):             # <<<<<<<<<<<<<<
 *         """Called when some SSL data is received.
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_15data_received, 0, __pyx_n_s_SSLProtocol_data_received, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__347)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_data_received, __pyx_t_6) < 0) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":531
 *                 break
 * 
 *     def eof_received(self):             # <<<<<<<<<<<<<<
 *         """Called when the other end of the low-level stream
 *         is half-closed.
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_17eof_received, 0, __pyx_n_s_SSLProtocol_eof_received, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__349)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_eof_received, __pyx_t_6) < 0) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":553
 *             self._transport.close()
 * 
 *     def _get_extra_info(self, name, default=None):             # <<<<<<<<<<<<<<
 *         if name in self._extra:
 *             return self._extra[name]
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_19_get_extra_info, 0, __pyx_n_s_SSLProtocol__get_extra_info, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__351)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__352);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_get_extra_info_2, __pyx_t_6) < 0) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":561
 *             return default
 * 
 *     def _mark_closed(self):             # <<<<<<<<<<<<<<
 *         self._closed = True
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_21_mark_closed, 0, __pyx_n_s_SSLProtocol__mark_closed, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__354)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_mark_closed, __pyx_t_6) < 0) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":564
 *         self._closed = True
 * 
 *     def _start_shutdown(self):             # <<<<<<<<<<<<<<
 *         if self._in_shutdown:
 *             return
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_23_start_shutdown, 0, __pyx_n_s_SSLProtocol__start_shutdown, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__356)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_start_shutdown, __pyx_t_6) < 0) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":573
 *             self._write_appdata(b'')
 * 
 *     def _write_appdata(self, data):             # <<<<<<<<<<<<<<
 *         self._write_backlog.append((data, 0))
 *         self._write_buffer_size += len(data)
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_25_write_appdata, 0, __pyx_n_s_SSLProtocol__write_appdata, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__358)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_write_appdata, __pyx_t_6) < 0) __PYX_ERR(0, 573, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":578
 *         self._process_write_backlog()
 * 
 *     def _start_handshake(self):             # <<<<<<<<<<<<<<
 *         if self._loop.get_debug():
 *             aio_logger.debug("%r starts SSL handshake", self)
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_27_start_handshake, 0, __pyx_n_s_SSLProtocol__start_handshake, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__360)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 578, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_start_handshake, __pyx_t_6) < 0) __PYX_ERR(0, 578, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":593
 *         self._process_write_backlog()
 * 
 *     def _check_handshake_timeout(self):             # <<<<<<<<<<<<<<
 *         if self._in_handshake is True:
 *             msg = (
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_29_check_handshake_timeout, 0, __pyx_n_s_SSLProtocol__check_handshake_tim, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__362)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_check_handshake_timeout, __pyx_t_6) < 0) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":602
 *             self._fatal_error(ConnectionAbortedError(msg))
 * 
 *     def _on_handshake_complete(self, handshake_exc):             # <<<<<<<<<<<<<<
 *         self._in_handshake = False
 *         self._handshake_timeout_handle.cancel()
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_31_on_handshake_complete, 0, __pyx_n_s_SSLProtocol__on_handshake_comple, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__364)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_on_handshake_complete, __pyx_t_6) < 0) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":643
 *         self._loop.call_soon(self._process_write_backlog)
 * 
 *     def _process_write_backlog(self):             # <<<<<<<<<<<<<<
 *         # Try to make progress on the write backlog.
 *         if self._transport is None or self._sslpipe is None:
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_33_process_write_backlog, 0, __pyx_n_s_SSLProtocol__process_write_backl, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__366)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_process_write_backlog, __pyx_t_6) < 0) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":685
 *                 self._fatal_error(exc, 'Fatal error on SSL transport')
 * 
 *     def _fatal_error(self, exc, message='Fatal error on transport'):             # <<<<<<<<<<<<<<
 *         if self._transport:
 *             self._transport._force_close(exc)
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_35_fatal_error, 0, __pyx_n_s_SSLProtocol__fatal_error, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__368)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_6, __pyx_tuple__369);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_fatal_error, __pyx_t_6) < 0) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":702
 *             })
 * 
 *     def _finalize(self):             # <<<<<<<<<<<<<<
 *         self._sslpipe = None
 * 
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_37_finalize, 0, __pyx_n_s_SSLProtocol__finalize, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__371)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_finalize, __pyx_t_6) < 0) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":708
 *             self._transport.close()
 * 
 *     def _abort(self):             # <<<<<<<<<<<<<<
 *         try:
 *             if self._transport is not None:
 */
  __pyx_t_6 = __Pyx_CyFunction_NewEx(&__pyx_mdef_6uvloop_4loop_11SSLProtocol_39_abort, 0, __pyx_n_s_SSLProtocol__abort, NULL, __pyx_n_s_uvloop_loop, __pyx_d, ((PyObject *)__pyx_codeobj__373)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_abort, __pyx_t_6) < 0) __PYX_ERR(0, 708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "uvloop/sslproto.pyx":389
 * 
 * 
 * class SSLProtocol(object):             # <<<<<<<<<<<<<<
 *     """SSL protocol.
 * 
 */
  __pyx_t_6 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_SSLProtocol, __pyx_tuple__329, __pyx_t_1, NULL, 0, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SSLProtocol, __pyx_t_6) < 0) __PYX_ERR(0, 389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":3037
 * 
 * # Used in UVProcess
 * cdef vint __atfork_installed = 0             # <<<<<<<<<<<<<<
 * cdef vint __forking = 0
 * cdef Loop __forking_loop = None
 */
  __pyx_v_6uvloop_4loop___atfork_installed = 0;

  /* "uvloop/loop.pyx":3038
 * # Used in UVProcess
 * cdef vint __atfork_installed = 0
 * cdef vint __forking = 0             # <<<<<<<<<<<<<<
 * cdef Loop __forking_loop = None
 * 
 */
  __pyx_v_6uvloop_4loop___forking = 0;

  /* "uvloop/loop.pyx":3039
 * cdef vint __atfork_installed = 0
 * cdef vint __forking = 0
 * cdef Loop __forking_loop = None             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_XGOTREF(((PyObject *)__pyx_v_6uvloop_4loop___forking_loop));
  __Pyx_DECREF_SET(__pyx_v_6uvloop_4loop___forking_loop, ((struct __pyx_obj_6uvloop_4loop_Loop *)Py_None));
  __Pyx_GIVEREF(Py_None);

  /* "uvloop/loop.pyx":3069
 * 
 * # Install PyMem* memory allocators
 * cdef vint __mem_installed = 0             # <<<<<<<<<<<<<<
 * cdef __install_pymem():
 *     global __mem_installed
 */
  __pyx_v_6uvloop_4loop___mem_installed = 0;

  /* "uvloop/loop.pyx":3103
 * 
 * @cython.iterable_coroutine
 * async def _test_coroutine_1():             # <<<<<<<<<<<<<<
 *     return 42
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_6uvloop_4loop_1_test_coroutine_1, NULL, __pyx_n_s_uvloop_loop); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test_coroutine_1, __pyx_t_2) < 0) __PYX_ERR(2, 3103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_PseudoSocket(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     if __pyx_checksum != 0x88c0b03:
 *         from pickle import PickleError as __pyx_PickleError
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_6uvloop_4loop_4__pyx_unpickle_PseudoSocket, NULL, __pyx_n_s_uvloop_loop); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_PseudoSocket, __pyx_t_2) < 0) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":9
 *         __pyx_unpickle_PseudoSocket__set_state(<PseudoSocket> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_PseudoSocket__set_state(PseudoSocket __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result._family = __pyx_state[0]; __pyx_result._fd = __pyx_state[1]; __pyx_result._peername = __pyx_state[2]; __pyx_result._proto = __pyx_state[3]; __pyx_result._sockname = __pyx_state[4]; __pyx_result._type = __pyx_state[5]
 *     if len(__pyx_state) > 6 and hasattr(__pyx_result, '__dict__'):
 */
  __pyx_t_2 = PyCFunction_NewEx(&__pyx_mdef_6uvloop_4loop_6__pyx_unpickle__SSLPipe, NULL, __pyx_n_s_uvloop_loop); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle__SSLPipe, __pyx_t_2) < 0) __PYX_ERR(9, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "uvloop/loop.pyx":1
 * # cython: language_level=3, embedsignature=True             # <<<<<<<<<<<<<<
 * 
 * import asyncio
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_object____Loop____bint___to_py")
 * cdef object __Pyx_CFunc_object____Loop____bint___to_py(object (*f)(Loop, bint) ):             # <<<<<<<<<<<<<<
 *     def wrap(Loop self, bint enabled):
 *         """wrap(self: 'Loop', enabled: bool)"""
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init uvloop.loop", 0, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init uvloop.loop");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* decode_c_string */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        size_t slen = strlen(cstring);
        if (unlikely(slen > (size_t) PY_SSIZE_T_MAX)) {
            PyErr_SetString(PyExc_OverflowError,
                            "c-string too long to convert to Python");
            return NULL;
        }
        length = (Py_ssize_t) slen;
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    length = stop - start;
    if (unlikely(length <= 0))
        return PyUnicode_FromUnicode(NULL, 0);
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* GetModuleGlobalName */
static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    if (likely(result)) {
        Py_INCREF(result);
    } else if (unlikely(PyErr_Occurred())) {
        result = NULL;
    } else {
#else
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

/* PyFunctionFastCall */
    #if CYTHON_FAST_PYCALL
#include "frameobject.h"
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = f->f_localsplus;
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyCFunctionFastCall */
    #if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCall */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCallNoArg */
    #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyIntBinop */
      #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AndObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
            return PyInt_FromLong(a & b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_and(op1, op2);
            }
        }
                x = a & b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla & llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    return (inplace ? PyNumber_InPlaceAnd : PyNumber_And)(op1, op2);
}
#endif

/* PyIntBinop */
      #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyObjectSetAttrStr */
      #if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* RaiseArgTupleInvalid */
      static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* KeywordStringCheck */
      static int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* PyErrFetchRestore */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
      #if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* ExtTypeTest */
      static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* GetAttr */
      static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
      static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* WriteUnraisableException */
      static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* RaiseTooManyValuesToUnpack */
      static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
      static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
      static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
      static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* SaveResetException */
      #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if PY_VERSION_HEX >= 0x030700A2
    *type = tstate->exc_state.exc_type;
    *value = tstate->exc_state.exc_value;
    *tb = tstate->exc_state.exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if PY_VERSION_HEX >= 0x030700A2
    tmp_type = tstate->exc_state.exc_type;
    tmp_value = tstate->exc_state.exc_value;
    tmp_tb = tstate->exc_state.exc_traceback;
    tstate->exc_state.exc_type = type;
    tstate->exc_state.exc_value = value;
    tstate->exc_state.exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
      #if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
      #if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
#endif
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if PY_VERSION_HEX >= 0x030700A2
    tmp_type = tstate->exc_state.exc_type;
    tmp_value = tstate->exc_state.exc_value;
    tmp_tb = tstate->exc_state.exc_traceback;
    tstate->exc_state.exc_type = local_type;
    tstate->exc_state.exc_value = local_value;
    tstate->exc_state.exc_traceback = local_tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* SwapException */
        #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if PY_VERSION_HEX >= 0x030700A2
    tmp_type = tstate->exc_state.exc_type;
    tmp_value = tstate->exc_state.exc_value;
    tmp_tb = tstate->exc_state.exc_traceback;
    tstate->exc_state.exc_type = *type;
    tstate->exc_state.exc_value = *value;
    tstate->exc_state.exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* RaiseDoubleKeywords */
        static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
        static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* FastTypeChecks */
        #if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* pyfrozenset_new */
        static CYTHON_INLINE PyObject* __Pyx_PyFrozenSet_New(PyObject* it) {
    if (it) {
        PyObject* result;
#if CYTHON_COMPILING_IN_PYPY
        PyObject* args;
        args = PyTuple_Pack(1, it);
        if (unlikely(!args))
            return NULL;
        result = PyObject_Call((PyObject*)&PyFrozenSet_Type, args, NULL);
        Py_DECREF(args);
        return result;
#else
        if (PyFrozenSet_CheckExact(it)) {
            Py_INCREF(it);
            return it;
        }
        result = PyFrozenSet_New(it);
        if (unlikely(!result))
            return NULL;
        if (likely(PySet_GET_SIZE(result)))
            return result;
        Py_DECREF(result);
#endif
    }
#if CYTHON_USE_TYPE_SLOTS
    return PyFrozenSet_Type.tp_new(&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#else
    return PyObject_Call((PyObject*)&PyFrozenSet_Type, __pyx_empty_tuple, NULL);
#endif
}

/* py_set_discard_unhashable */
        static int __Pyx_PySet_DiscardUnhashable(PyObject *set, PyObject *key) {
    PyObject *tmpkey;
    int rv;
    if (likely(!PySet_Check(key) || !PyErr_ExceptionMatches(PyExc_TypeError)))
        return -1;
    PyErr_Clear();
    tmpkey = __Pyx_PyFrozenSet_New(key);
    if (tmpkey == NULL)
        return -1;
    rv = PySet_Discard(set, tmpkey);
    Py_DECREF(tmpkey);
    return rv;
}

/* py_set_discard */
        static CYTHON_INLINE int __Pyx_PySet_Discard(PyObject *set, PyObject *key) {
    int found = PySet_Discard(set, key);
    if (unlikely(found < 0)) {
        found = __Pyx_PySet_DiscardUnhashable(set, key);
    }
    return found;
}

/* set_iter */
        static CYTHON_INLINE PyObject* __Pyx_set_iterator(PyObject* iterable, int is_set,
                                                  Py_ssize_t* p_orig_length, int* p_source_is_set) {
#if CYTHON_COMPILING_IN_CPYTHON
    is_set = is_set || likely(PySet_CheckExact(iterable) || PyFrozenSet_CheckExact(iterable));
    *p_source_is_set = is_set;
    if (likely(is_set)) {
        *p_orig_length = PySet_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
    }
#else
    (void)is_set;
    *p_source_is_set = 0;
#endif
    *p_orig_length = 0;
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_set_iter_next(
        PyObject* iter_obj, Py_ssize_t orig_length,
        Py_ssize_t* ppos, PyObject **value,
        int source_is_set) {
    if (!CYTHON_COMPILING_IN_CPYTHON || unlikely(!source_is_set)) {
        *value = PyIter_Next(iter_obj);
        if (unlikely(!*value)) {
            return __Pyx_IterFinish();
        }
        (void)orig_length;
        (void)ppos;
        return 1;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(PySet_GET_SIZE(iter_obj) != orig_length)) {
        PyErr_SetString(
            PyExc_RuntimeError,
            "set changed size during iteration");
        return -1;
    }
    {
        Py_hash_t hash;
        int ret = _PySet_NextEntry(iter_obj, ppos, value, &hash);
        assert (ret != -1);
        if (likely(ret)) {
            Py_INCREF(*value);
            return 1;
        }
    }
#endif
    return 0;
}

/* DictGetItem */
        #if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* PyObjectCallMethod0 */
        static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method, *result = NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
#if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *function = PyMethod_GET_FUNCTION(method);
            result = __Pyx_PyObject_CallOneArg(function, self);
            Py_DECREF(method);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNoneIterError */
        static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
        static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
        static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = Py_TYPE(iter)->tp_iternext;
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
        static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* PyObjectCallMethod1 */
        static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = NULL;
#if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(method))) {
        PyObject *self = PyMethod_GET_SELF(method);
        if (likely(self)) {
            PyObject *args;
            PyObject *function = PyMethod_GET_FUNCTION(method);
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(function)) {
                PyObject *args[2] = {self, arg};
                result = __Pyx_PyFunction_FastCall(function, args, 2);
                goto done;
            }
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(function)) {
                PyObject *args[2] = {self, arg};
                result = __Pyx_PyCFunction_FastCall(function, args, 2);
                goto done;
            }
            #endif
            args = PyTuple_New(2);
            if (unlikely(!args)) goto done;
            Py_INCREF(self);
            PyTuple_SET_ITEM(args, 0, self);
            Py_INCREF(arg);
            PyTuple_SET_ITEM(args, 1, arg);
            Py_INCREF(function);
            result = __Pyx_PyObject_Call(function, args, NULL);
            Py_DECREF(args);
            Py_DECREF(function);
            return result;
        }
    }
#endif
    result = __Pyx_PyObject_CallOneArg(method, arg);
    goto done;
done:
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method, *result;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) return NULL;
    result = __Pyx__PyObject_CallMethod1(method, arg);
    Py_DECREF(method);
    return result;
}

/* append */
        static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* GetItemInt */
        static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely((0 <= wrapped_i) & (wrapped_i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely((0 <= wrapped_i) & (wrapped_i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* ObjectGetItem */
        #if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* UnpackUnboundCMethod */
        static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST);
    }
#endif
    return 0;
}

/* CallUnboundCMethod2 */
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* CallUnboundCMethod1 */
        #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if (PY_VERSION_HEX >= 0x030600B1 && flag == METH_FASTCALL) {
            if (PY_VERSION_HEX >= 0x030700A0) {
                return (*(__Pyx_PyCFunctionFast)cfunc->func)(self, &arg, 1);
            } else {
                return (*(__Pyx_PyCFunctionFastWithKeywords)cfunc->func)(self, &arg, 1, NULL);
            }
        } else if (PY_VERSION_HEX >= 0x030700A0 && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* py_dict_pop */
        static CYTHON_INLINE PyObject *__Pyx_PyDict_Pop(PyObject *d, PyObject *key, PyObject *default_value) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B3
    if ((1)) {
        return _PyDict_Pop(d, key, default_value);
    } else
#endif
    if (default_value) {
        return __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_pop, d, key, default_value);
    } else {
        return __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_pop, d, key);
    }
}

/* None */
        static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* FetchCommonType */
        static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunction */
        #include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* PyObjectFormatAndDecref */
            static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyString_CheckExact(s))) {
        PyObject *result = PyUnicode_FromEncodedObject(s, NULL, "strict");
        Py_DECREF(s);
        return result;
    }
    #endif
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* JoinPyUnicode */
            static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely(char_pos + ulength < 0))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + char_pos * result_ukind, udata, (size_t) (ulength * result_ukind));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* SliceObject */
            static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* None */
            static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* CoroutineBase */
            #include <structmember.h>
#include <frameobject.h>
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__pyx_CoroutineObject *self) {
    PyObject *exc_type = self->exc_type;
    PyObject *exc_value = self->exc_value;
    PyObject *exc_traceback = self->exc_traceback;
    self->exc_type = NULL;
    self->exc_value = NULL;
    self->exc_traceback = NULL;
    Py_XDECREF(exc_type);
    Py_XDECREF(exc_value);
    Py_XDECREF(exc_traceback);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if (0) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if (0) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    if (self->exc_type) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        if (self->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
#endif
        __Pyx_ExceptionSwap(&self->exc_type, &self->exc_value,
                            &self->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(self);
        __Pyx_ExceptionSave(&self->exc_type, &self->exc_value, &self->exc_traceback);
    }
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__pyx_CoroutineObject *self) {
    if (likely(self->exc_traceback)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    Py_VISIT(gen->exc_type);
    Py_VISIT(gen->exc_value);
    Py_VISIT(gen->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    Py_CLEAR(gen->exc_type);
    Py_CLEAR(gen->exc_value);
    Py_CLEAR(gen->exc_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    self->ob_refcnt = 1;
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        self->ob_refcnt = refcnt;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->exc_type = NULL;
    gen->exc_value = NULL;
    gen->exc_traceback = NULL;
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    PyObject_GC_Track(gen);
    return gen;
}

/* PyObject_GenericGetAttrNoDict */
                #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PatchModuleWithCoroutine */
                static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
                #ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Coroutine */
                static void __Pyx_CoroutineAwait_dealloc(PyObject *self) {
    PyObject_GC_UnTrack(self);
    Py_CLEAR(((__pyx_CoroutineAwaitObject*)self)->coroutine);
    PyObject_GC_Del(self);
}
static int __Pyx_CoroutineAwait_traverse(__pyx_CoroutineAwaitObject *self, visitproc visit, void *arg) {
    Py_VISIT(self->coroutine);
    return 0;
}
static int __Pyx_CoroutineAwait_clear(__pyx_CoroutineAwaitObject *self) {
    Py_CLEAR(self->coroutine);
    return 0;
}
static PyObject *__Pyx_CoroutineAwait_Next(__pyx_CoroutineAwaitObject *self) {
    return __Pyx_Generator_Next(self->coroutine);
}
static PyObject *__Pyx_CoroutineAwait_Send(__pyx_CoroutineAwaitObject *self, PyObject *value) {
    return __Pyx_Coroutine_Send(self->coroutine, value);
}
static PyObject *__Pyx_CoroutineAwait_Throw(__pyx_CoroutineAwaitObject *self, PyObject *args) {
    return __Pyx_Coroutine_Throw(self->coroutine, args);
}
static PyObject *__Pyx_CoroutineAwait_Close(__pyx_CoroutineAwaitObject *self) {
    return __Pyx_Coroutine_Close(self->coroutine);
}
static PyObject *__Pyx_CoroutineAwait_self(PyObject *self) {
    Py_INCREF(self);
    return self;
}
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_CoroutineAwait_no_new(CYTHON_UNUSED PyTypeObject *type, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwargs) {
    PyErr_SetString(PyExc_TypeError, "cannot instantiate type, use 'await coroutine' instead");
    return NULL;
}
#endif
static PyMethodDef __pyx_CoroutineAwait_methods[] = {
    {"send", (PyCFunction) __Pyx_CoroutineAwait_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into coroutine,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_CoroutineAwait_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in coroutine,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_CoroutineAwait_Close, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside coroutine.")},
    {0, 0, 0, 0}
};
static PyTypeObject __pyx_CoroutineAwaitType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "coroutine_wrapper",
    sizeof(__pyx_CoroutineAwaitObject),
    0,
    (destructor) __Pyx_CoroutineAwait_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    PyDoc_STR("A wrapper object implementing __await__ for coroutines."),
    (traverseproc) __Pyx_CoroutineAwait_traverse,
    (inquiry) __Pyx_CoroutineAwait_clear,
    0,
    0,
    __Pyx_CoroutineAwait_self,
    (iternextfunc) __Pyx_CoroutineAwait_Next,
    __pyx_CoroutineAwait_methods,
    0                         ,
    0                      ,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if !CYTHON_COMPILING_IN_PYPY
    __Pyx_CoroutineAwait_no_new,
#else
    0,
#endif
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static CYTHON_INLINE PyObject *__Pyx__Coroutine_await(PyObject *coroutine) {
    __pyx_CoroutineAwaitObject *await = PyObject_GC_New(__pyx_CoroutineAwaitObject, __pyx_CoroutineAwaitType);
    if (unlikely(!await)) return NULL;
    Py_INCREF(coroutine);
    await->coroutine = coroutine;
    PyObject_GC_Track(await);
    return (PyObject*)await;
}
static PyObject *__Pyx_Coroutine_await(PyObject *coroutine) {
    if (unlikely(!coroutine || !__Pyx_Coroutine_Check(coroutine))) {
        PyErr_SetString(PyExc_TypeError, "invalid input, expected coroutine");
        return NULL;
    }
    return __Pyx__Coroutine_await(coroutine);
}
static PyObject *
__Pyx_Coroutine_get_frame(CYTHON_UNUSED __pyx_CoroutineObject *self)
{
    Py_RETURN_NONE;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3 && PY_VERSION_HEX < 0x030500B1
static PyObject *__Pyx_Coroutine_compare(PyObject *obj, PyObject *other, int op) {
    PyObject* result;
    switch (op) {
        case Py_EQ: result = (other == obj) ? Py_True : Py_False; break;
        case Py_NE: result = (other != obj) ? Py_True : Py_False; break;
        default:
            result = Py_NotImplemented;
    }
    Py_INCREF(result);
    return result;
}
#endif
static PyMethodDef __pyx_Coroutine_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into coroutine,\nreturn next iterated value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in coroutine,\nreturn next iterated value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside coroutine.")},
#if PY_VERSION_HEX < 0x030500B1
    {"__await__", (PyCFunction) __Pyx_Coroutine_await, METH_NOARGS,
     (char*) PyDoc_STR("__await__() -> return an iterator to be used in await expression.")},
#endif
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Coroutine_memberlist[] = {
    {(char *) "cr_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "cr_await", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being awaited, or None")},
    {(char*) "cr_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Coroutine_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the coroutine"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the coroutine"), 0},
    {(char *) "cr_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the coroutine"), 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_ASYNC_SLOTS
static __Pyx_PyAsyncMethodsStruct __pyx_Coroutine_as_async = {
    __Pyx_Coroutine_await,
    0,
    0,
};
#endif
static PyTypeObject __pyx_CoroutineType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "coroutine",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
#if CYTHON_USE_ASYNC_SLOTS
    &__pyx_Coroutine_as_async,
#else
    0,
#endif
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
#if CYTHON_USE_ASYNC_SLOTS && CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3 && PY_VERSION_HEX < 0x030500B1
    __Pyx_Coroutine_compare,
#else
    0,
#endif
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    0,
    __pyx_Coroutine_methods,
    __pyx_Coroutine_memberlist,
    __pyx_Coroutine_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_Coroutine_init(void) {
    __pyx_CoroutineType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_CoroutineType = __Pyx_FetchCommonType(&__pyx_CoroutineType_type);
    if (unlikely(!__pyx_CoroutineType))
        return -1;
#ifdef __Pyx_IterableCoroutine_USED
    if (unlikely(__pyx_IterableCoroutine_init() == -1))
        return -1;
#endif
    __pyx_CoroutineAwaitType = __Pyx_FetchCommonType(&__pyx_CoroutineAwaitType_type);
    if (unlikely(!__pyx_CoroutineAwaitType))
        return -1;
    return 0;
}

/* GetAwaitIter */
                static CYTHON_INLINE PyObject *__Pyx_Coroutine_GetAwaitableIter(PyObject *o) {
#ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(o)) {
        return __Pyx_NewRef(o);
    }
#endif
    return __Pyx__Coroutine_GetAwaitableIter(o);
}
static void __Pyx_Coroutine_AwaitableIterError(PyObject *source) {
#if PY_VERSION_HEX >= 0x030600B3 || defined(_PyErr_FormatFromCause)
    _PyErr_FormatFromCause(
        PyExc_TypeError,
        "'async for' received an invalid object "
        "from __anext__: %.100s",
        Py_TYPE(source)->tp_name);
#elif PY_MAJOR_VERSION >= 3
    PyObject *exc, *val, *val2, *tb;
    assert(PyErr_Occurred());
    PyErr_Fetch(&exc, &val, &tb);
    PyErr_NormalizeException(&exc, &val, &tb);
    if (tb != NULL) {
        PyException_SetTraceback(val, tb);
        Py_DECREF(tb);
    }
    Py_DECREF(exc);
    assert(!PyErr_Occurred());
    PyErr_Format(
        PyExc_TypeError,
        "'async for' received an invalid object "
        "from __anext__: %.100s",
        Py_TYPE(source)->tp_name);
    PyErr_Fetch(&exc, &val2, &tb);
    PyErr_NormalizeException(&exc, &val2, &tb);
    Py_INCREF(val);
    PyException_SetCause(val2, val);
    PyException_SetContext(val2, val);
    PyErr_Restore(exc, val2, tb);
#else
    source++;
#endif
}
static PyObject *__Pyx__Coroutine_GetAwaitableIter(PyObject *obj) {
    PyObject *res;
#if CYTHON_USE_ASYNC_SLOTS
    __Pyx_PyAsyncMethodsStruct* am = __Pyx_PyType_AsAsync(obj);
    if (likely(am && am->am_await)) {
        res = (*am->am_await)(obj);
    } else
#endif
#if PY_VERSION_HEX >= 0x030500B2 || defined(PyCoro_CheckExact)
    if (PyCoro_CheckExact(obj)) {
        return __Pyx_NewRef(obj);
    } else
#endif
#if CYTHON_COMPILING_IN_CPYTHON && defined(CO_ITERABLE_COROUTINE)
    if (PyGen_CheckExact(obj) && ((PyGenObject*)obj)->gi_code && ((PyCodeObject *)((PyGenObject*)obj)->gi_code)->co_flags & CO_ITERABLE_COROUTINE) {
        return __Pyx_NewRef(obj);
    } else
#endif
    {
        PyObject *method = __Pyx_PyObject_GetAttrStr(obj, __pyx_n_s_await);
        if (unlikely(!method)) goto slot_error;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(method))) {
            PyObject *self = PyMethod_GET_SELF(method);
            if (likely(self)) {
                PyObject *function = PyMethod_GET_FUNCTION(method);
                res = __Pyx_PyObject_CallOneArg(function, self);
            } else
                res = __Pyx_PyObject_CallNoArg(method);
        } else
        #endif
            res = __Pyx_PyObject_CallNoArg(method);
        Py_DECREF(method);
    }
    if (unlikely(!res)) {
        __Pyx_Coroutine_AwaitableIterError(obj);
        goto bad;
    }
    if (unlikely(!PyIter_Check(res))) {
        PyErr_Format(PyExc_TypeError,
                     "__await__() returned non-iterator of type '%.100s'",
                     Py_TYPE(res)->tp_name);
        Py_CLEAR(res);
    } else {
        int is_coroutine = 0;
        #ifdef __Pyx_Coroutine_USED
        is_coroutine |= __Pyx_Coroutine_Check(res);
        #endif
        #if PY_VERSION_HEX >= 0x030500B2 || defined(PyCoro_CheckExact)
        is_coroutine |= PyCoro_CheckExact(res);
        #endif
        if (unlikely(is_coroutine)) {
            /* __await__ must return an *iterator*, not
               a coroutine or another awaitable (see PEP 492) */
            PyErr_SetString(PyExc_TypeError,
                            "__await__() returned a coroutine");
            Py_CLEAR(res);
        }
    }
    return res;
slot_error:
    PyErr_Format(PyExc_TypeError,
                 "object %.100s can't be used in 'await' expression",
                 Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* CoroutineYieldFrom */
                static PyObject* __Pyx__Coroutine_Yield_From_Generic(__pyx_CoroutineObject *gen, PyObject *source) {
    PyObject *retval;
    PyObject *source_gen = __Pyx__Coroutine_GetAwaitableIter(source);
    if (unlikely(!source_gen)) {
        return NULL;
    }
    if (__Pyx_Coroutine_Check(source_gen)) {
        retval = __Pyx_Generator_Next(source_gen);
    } else {
#if CYTHON_USE_TYPE_SLOTS
        retval = Py_TYPE(source_gen)->tp_iternext(source_gen);
#else
        retval = PyIter_Next(source_gen);
#endif
    }
    if (retval) {
        gen->yieldfrom = source_gen;
        return retval;
    }
    Py_DECREF(source_gen);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_Coroutine_Yield_From(__pyx_CoroutineObject *gen, PyObject *source) {
    PyObject *retval;
    if (__Pyx_Coroutine_Check(source)) {
        if (unlikely(((__pyx_CoroutineObject*)source)->yieldfrom)) {
            PyErr_SetString(
                PyExc_RuntimeError,
                "coroutine is being awaited already");
            return NULL;
        }
        retval = __Pyx_Generator_Next(source);
#ifdef __Pyx_AsyncGen_USED
    } else if (__pyx_PyAsyncGenASend_CheckExact(source)) {
        retval = __Pyx_async_gen_asend_iternext(source);
#endif
    } else {
        return __Pyx__Coroutine_Yield_From_Generic(gen, source);
    }
    if (retval) {
        Py_INCREF(source);
        gen->yieldfrom = source;
    }
    return retval;
}

/* ReturnWithStopIteration */
                static void __Pyx__ReturnWithStopIteration(PyObject* value) {
    PyObject *exc, *args;
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_PYSTON
    __Pyx_PyThreadState_declare
    if ((PY_VERSION_HEX >= 0x03030000 && PY_VERSION_HEX < 0x030500B1)
            || unlikely(PyTuple_Check(value) || PyExceptionInstance_Check(value))) {
        args = PyTuple_New(1);
        if (unlikely(!args)) return;
        Py_INCREF(value);
        PyTuple_SET_ITEM(args, 0, value);
        exc = PyType_Type.tp_call(PyExc_StopIteration, args, NULL);
        Py_DECREF(args);
        if (!exc) return;
    } else {
        Py_INCREF(value);
        exc = value;
    }
    #if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    #if PY_VERSION_HEX >= 0x030700A2
    if (!__pyx_tstate->exc_state.exc_type)
    #else
    if (!__pyx_tstate->exc_type)
    #endif
    {
        Py_INCREF(PyExc_StopIteration);
        __Pyx_ErrRestore(PyExc_StopIteration, exc, NULL);
        return;
    }
    #endif
#else
    args = PyTuple_Pack(1, value);
    if (unlikely(!args)) return;
    exc = PyObject_Call(PyExc_StopIteration, args, NULL);
    Py_DECREF(args);
    if (unlikely(!exc)) return;
#endif
    PyErr_SetObject(PyExc_StopIteration, exc);
    Py_DECREF(exc);
}

/* BytesEquals */
                static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
                static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* CallUnboundCMethod0 */
                static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* SetItemInt */
                static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely((n >= 0) & (n < PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o))) {
#else
    if (is_list || PySequence_Check(o)) {
#endif
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* MergeKeywords */
                  static int __Pyx_MergeKeywords(PyObject *kwdict, PyObject *source_mapping) {
    PyObject *iter, *key = NULL, *value = NULL;
    int source_is_dict, result;
    Py_ssize_t orig_length, ppos = 0;
    iter = __Pyx_dict_iterator(source_mapping, 0, __pyx_n_s_items, &orig_length, &source_is_dict);
    if (unlikely(!iter)) {
        PyObject *args;
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        args = PyTuple_Pack(1, source_mapping);
        if (likely(args)) {
            PyObject *fallback = PyObject_Call((PyObject*)&PyDict_Type, args, NULL);
            Py_DECREF(args);
            if (likely(fallback)) {
                iter = __Pyx_dict_iterator(fallback, 1, __pyx_n_s_items, &orig_length, &source_is_dict);
                Py_DECREF(fallback);
            }
        }
        if (unlikely(!iter)) goto bad;
    }
    while (1) {
        result = __Pyx_dict_iter_next(iter, orig_length, &ppos, &key, &value, NULL, source_is_dict);
        if (unlikely(result < 0)) goto bad;
        if (!result) break;
        if (unlikely(PyDict_Contains(kwdict, key))) {
            __Pyx_RaiseDoubleKeywordsError("function", key);
            result = -1;
        } else {
            result = PyDict_SetItem(kwdict, key, value);
        }
        Py_DECREF(key);
        Py_DECREF(value);
        if (unlikely(result < 0)) goto bad;
    }
    Py_XDECREF(iter);
    return 0;
bad:
    Py_XDECREF(iter);
    return -1;
}

/* PyIntBinop */
                  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) {
            Py_RETURN_TRUE;
        } else {
            Py_RETURN_FALSE;
        }
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a;
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                    CYTHON_FALLTHROUGH;
                #if PyLong_SHIFT < 30 && PyLong_SHIFT != 15
                default: return PyLong_Type.tp_richcompare(op1, op2, Py_EQ);
                #else
                default: Py_RETURN_FALSE;
                #endif
            }
        }
            if (a == b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            if ((double)a == (double)b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    return PyObject_RichCompare(op1, op2, Py_EQ);
}
#endif

/* GetAttr3 */
                  static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* ArgTypeTest */
                  static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* py_set_remove */
                  static int __Pyx_PySet_RemoveNotFound(PyObject *set, PyObject *key, int found) {
    if (unlikely(found < 0)) {
        found = __Pyx_PySet_DiscardUnhashable(set, key);
    }
    if (likely(found == 0)) {
        PyObject *tup;
        tup = PyTuple_Pack(1, key);
        if (!tup)
            return -1;
        PyErr_SetObject(PyExc_KeyError, tup);
        Py_DECREF(tup);
        return -1;
    }
    return found;
}
static CYTHON_INLINE int __Pyx_PySet_Remove(PyObject *set, PyObject *key) {
    int found = PySet_Discard(set, key);
    if (unlikely(found != 1)) {
        return __Pyx_PySet_RemoveNotFound(set, key, found);
    }
    return 0;
}

/* None */
                  static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* CIntToDigits */
                  static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
                  static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        uval = NULL;
        PyObject *sign = NULL, *padding = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
                  #ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned short    uint16_t;
        #else
           typedef unsigned __int16  uint16_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            *(uint16_t*)dpos = ((uint16_t*)DIGIT_PAIRS_8)[digit_pos];
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            *(uint16_t*)dpos = ((uint16_t*)DIGIT_PAIRS_10)[digit_pos];
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    if (last_one_off) {
        assert(*dpos == '0');
        dpos++;
    }
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* CIntToPyUnicode */
                  #ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned short    uint16_t;
        #else
           typedef unsigned __int16  uint16_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(Py_ssize_t)*3+2];
    char *dpos, *end = digits + sizeof(Py_ssize_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    Py_ssize_t remaining;
    const Py_ssize_t neg_one = (Py_ssize_t) -1, const_zero = (Py_ssize_t) 0;
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (Py_ssize_t) (remaining / (8*8));
            dpos -= 2;
            *(uint16_t*)dpos = ((uint16_t*)DIGIT_PAIRS_8)[digit_pos];
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (Py_ssize_t) (remaining / (10*10));
            dpos -= 2;
            *(uint16_t*)dpos = ((uint16_t*)DIGIT_PAIRS_10)[digit_pos];
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (Py_ssize_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    if (last_one_off) {
        assert(*dpos == '0');
        dpos++;
    }
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* decode_c_bytes */
                  static CYTHON_INLINE PyObject* __Pyx_decode_c_bytes(
         const char* cstring, Py_ssize_t length, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    if (unlikely((start < 0) | (stop < 0))) {
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    if (stop > length)
        stop = length;
    length = stop - start;
    if (unlikely(length <= 0))
        return PyUnicode_FromUnicode(NULL, 0);
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* DelItemInt */
                  static int __Pyx_DelItem_Generic(PyObject *o, PyObject *j) {
    int r;
    if (!j) return -1;
    r = PyObject_DelItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_DelItemInt_Fast(PyObject *o, Py_ssize_t i,
                                               CYTHON_UNUSED int is_list, CYTHON_NCP_UNUSED int wraparound) {
#if !CYTHON_USE_TYPE_SLOTS
    if (is_list || PySequence_Check(o)) {
        return PySequence_DelItem(o, i);
    }
#else
    PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
    if (likely(m && m->sq_ass_item)) {
        if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
            Py_ssize_t l = m->sq_length(o);
            if (likely(l >= 0)) {
                i += l;
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    return -1;
                PyErr_Clear();
            }
        }
        return m->sq_ass_item(o, i, (PyObject *)NULL);
    }
#endif
    return __Pyx_DelItem_Generic(o, PyInt_FromSsize_t(i));
}

/* SliceObject */
                  static CYTHON_INLINE int __Pyx_PyObject_SetSlice(PyObject* obj, PyObject* value,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_ass_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_ass_slice(obj, cstart, cstop, value);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_ass_subscript))
#endif
    {
        int result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_ass_subscript(obj, py_slice, value);
#else
        result = value ? PyObject_SetItem(obj, py_slice, value) : PyObject_DelItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object does not support slice %.10s",
        Py_TYPE(obj)->tp_name, value ? "assignment" : "deletion");
bad:
    return -1;
}

/* Import */
                  static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
                  static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* PyObject_GenericGetAttr */
                  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
                  static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* SetupReduce */
                  static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_cython); if (unlikely(!reduce_cython)) goto BAD;
            ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto BAD;
            ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto BAD;
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate_cython); if (unlikely(!setstate_cython)) goto BAD;
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto BAD;
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto GOOD;
BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* PatchInspect */
                  static PyObject* __Pyx_patch_inspect(PyObject* module) {
#if defined(__Pyx_Generator_USED) && (!defined(CYTHON_PATCH_INSPECT) || CYTHON_PATCH_INSPECT)
    static int inspect_patched = 0;
    if (unlikely((!inspect_patched) && module)) {
        module = __Pyx_Coroutine_patch_module(
            module, ""
"old_types = getattr(_module.isgenerator, '_cython_generator_types', None)\n"
"if old_types is None or not isinstance(old_types, set):\n"
"    old_types = set()\n"
"    def cy_wrap(orig_func, type=type, cython_generator_types=old_types):\n"
"        def cy_isgenerator(obj): return type(obj) in cython_generator_types or orig_func(obj)\n"
"        cy_isgenerator._cython_generator_types = cython_generator_types\n"
"        return cy_isgenerator\n"
"    _module.isgenerator = cy_wrap(_module.isgenerator)\n"
"old_types.add(_cython_generator_type)\n"
        );
        inspect_patched = 1;
    }
#else
    if ((0)) return __Pyx_Coroutine_patch_module(module, NULL);
#endif
    return module;
}

/* PatchAsyncIO */
                  static PyObject* __Pyx_patch_asyncio(PyObject* module) {
#if PY_VERSION_HEX < 0x030500B2 &&\
        (defined(__Pyx_Coroutine_USED) || defined(__Pyx_Generator_USED)) &&\
        (!defined(CYTHON_PATCH_ASYNCIO) || CYTHON_PATCH_ASYNCIO)
    PyObject *patch_module = NULL;
    static int asyncio_patched = 0;
    if (unlikely((!asyncio_patched) && module)) {
        PyObject *package;
        package = __Pyx_Import(__pyx_n_s_asyncio_coroutines, NULL, 0);
        if (package) {
            patch_module = __Pyx_Coroutine_patch_module(
                PyObject_GetAttrString(package, "coroutines"), ""
"try:\n"
"    coro_types = _module._COROUTINE_TYPES\n"
"except AttributeError: pass\n"
"else:\n"
"    if _cython_coroutine_type is not None and _cython_coroutine_type not in coro_types:\n"
"        coro_types = tuple(coro_types) + (_cython_coroutine_type,)\n"
"    if _cython_generator_type is not None and _cython_generator_type not in coro_types:\n"
"        coro_types = tuple(coro_types) + (_cython_generator_type,)\n"
"_module._COROUTINE_TYPES = coro_types\n"
            );
        } else {
            PyErr_Clear();
            package = __Pyx_Import(__pyx_n_s_asyncio_tasks, NULL, 0);
            if (unlikely(!package)) goto asyncio_done;
            patch_module = __Pyx_Coroutine_patch_module(
                PyObject_GetAttrString(package, "tasks"), ""
"if hasattr(_module, 'iscoroutine'):\n"
"    old_types = getattr(_module.iscoroutine, '_cython_coroutine_types', None)\n"
"    if old_types is None or not isinstance(old_types, set):\n"
"        old_types = set()\n"
"        def cy_wrap(orig_func, type=type, cython_coroutine_types=old_types):\n"
"            def cy_iscoroutine(obj): return type(obj) in cython_coroutine_types or orig_func(obj)\n"
"            cy_iscoroutine._cython_coroutine_types = cython_coroutine_types\n"
"            return cy_iscoroutine\n"
"        _module.iscoroutine = cy_wrap(_module.iscoroutine)\n"
"    if _cython_coroutine_type is not None:\n"
"        old_types.add(_cython_coroutine_type)\n"
"    if _cython_generator_type is not None:\n"
"        old_types.add(_cython_generator_type)\n"
            );
        }
        Py_DECREF(package);
        if (unlikely(!patch_module)) goto ignore;
asyncio_done:
        PyErr_Clear();
        asyncio_patched = 1;
#ifdef __Pyx_Generator_USED
        {
            PyObject *inspect_module;
            if (patch_module) {
                inspect_module = PyObject_GetAttr(patch_module, __pyx_n_s_inspect);
                Py_DECREF(patch_module);
            } else {
                inspect_module = __Pyx_Import(__pyx_n_s_inspect, NULL, 0);
            }
            if (unlikely(!inspect_module)) goto ignore;
            inspect_module = __Pyx_patch_inspect(inspect_module);
            if (unlikely(!inspect_module)) {
                Py_DECREF(module);
                module = NULL;
            }
            Py_XDECREF(inspect_module);
        }
#else
        if ((0)) return __Pyx_patch_inspect(module);
#endif
    }
    return module;
ignore:
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch asyncio package with custom generator type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    if ((0)) return __Pyx_patch_inspect(__Pyx_Coroutine_patch_module(module, NULL));
#endif
    return module;
}

/* CalculateMetaclass */
                  static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
                  static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CLineInTraceback */
                  #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
      use_cline = __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback);
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (PyObject_Not(use_cline) != 0) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
                  static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
                  #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
                  #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint64_t(uint64_t value) {
    const uint64_t neg_one = (uint64_t) -1, const_zero = (uint64_t) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint64_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(uint64_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint64_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint64_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint64_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(uint64_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_uint32_t(uint32_t value) {
    const uint32_t neg_one = (uint32_t) -1, const_zero = (uint32_t) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint32_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(uint32_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint32_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint32_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(uint32_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(uint32_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_short(unsigned short value) {
    const unsigned short neg_one = (unsigned short) -1, const_zero = (unsigned short) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned short) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned short) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned short) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(unsigned short) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned short) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned short),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_volatile__int(volatile int value) {
    const volatile int neg_one = (volatile int) -1, const_zero = (volatile int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(volatile int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(volatile int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(volatile int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(volatile int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(volatile int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(volatile int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int64_t(int64_t value) {
    const int64_t neg_one = (int64_t) -1, const_zero = (int64_t) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int64_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int64_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int64_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int64_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int64_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int64_t),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
                  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_long(unsigned long value) {
    const unsigned long neg_one = (unsigned long) -1, const_zero = (unsigned long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(unsigned long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(unsigned long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
                  static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
                  static CYTHON_INLINE int64_t __Pyx_PyInt_As_int64_t(PyObject *x) {
    const int64_t neg_one = (int64_t) -1, const_zero = (int64_t) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int64_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int64_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int64_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int64_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int64_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(int64_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) >= 2 * PyLong_SHIFT) {
                            return (int64_t) (((((int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int64_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) >= 3 * PyLong_SHIFT) {
                            return (int64_t) (((((((int64_t)digits[2]) << PyLong_SHIFT) | (int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int64_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) >= 4 * PyLong_SHIFT) {
                            return (int64_t) (((((((((int64_t)digits[3]) << PyLong_SHIFT) | (int64_t)digits[2]) << PyLong_SHIFT) | (int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int64_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int64_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int64_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int64_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int64_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int64_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int64_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int64_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int64_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) - 1 > 2 * PyLong_SHIFT) {
                            return (int64_t) (((int64_t)-1)*(((((int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int64_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) - 1 > 2 * PyLong_SHIFT) {
                            return (int64_t) ((((((int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int64_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) - 1 > 3 * PyLong_SHIFT) {
                            return (int64_t) (((int64_t)-1)*(((((((int64_t)digits[2]) << PyLong_SHIFT) | (int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int64_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) - 1 > 3 * PyLong_SHIFT) {
                            return (int64_t) ((((((((int64_t)digits[2]) << PyLong_SHIFT) | (int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int64_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) - 1 > 4 * PyLong_SHIFT) {
                            return (int64_t) (((int64_t)-1)*(((((((((int64_t)digits[3]) << PyLong_SHIFT) | (int64_t)digits[2]) << PyLong_SHIFT) | (int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int64_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int64_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int64_t) - 1 > 4 * PyLong_SHIFT) {
                            return (int64_t) ((((((((((int64_t)digits[3]) << PyLong_SHIFT) | (int64_t)digits[2]) << PyLong_SHIFT) | (int64_t)digits[1]) << PyLong_SHIFT) | (int64_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int64_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int64_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int64_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int64_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int64_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int64_t) -1;
        }
    } else {
        int64_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int64_t) -1;
        val = __Pyx_PyInt_As_int64_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int64_t");
    return (int64_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int64_t");
    return (int64_t) -1;
}

/* CIntFromPy */
                  static CYTHON_INLINE uint64_t __Pyx_PyInt_As_uint64_t(PyObject *x) {
    const uint64_t neg_one = (uint64_t) -1, const_zero = (uint64_t) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(uint64_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(uint64_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (uint64_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (uint64_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(uint64_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(uint64_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) >= 2 * PyLong_SHIFT) {
                            return (uint64_t) (((((uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(uint64_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) >= 3 * PyLong_SHIFT) {
                            return (uint64_t) (((((((uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(uint64_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) >= 4 * PyLong_SHIFT) {
                            return (uint64_t) (((((((((uint64_t)digits[3]) << PyLong_SHIFT) | (uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (uint64_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(uint64_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(uint64_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(uint64_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(uint64_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (uint64_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(uint64_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(uint64_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(uint64_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) - 1 > 2 * PyLong_SHIFT) {
                            return (uint64_t) (((uint64_t)-1)*(((((uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(uint64_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) - 1 > 2 * PyLong_SHIFT) {
                            return (uint64_t) ((((((uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(uint64_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) - 1 > 3 * PyLong_SHIFT) {
                            return (uint64_t) (((uint64_t)-1)*(((((((uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(uint64_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) - 1 > 3 * PyLong_SHIFT) {
                            return (uint64_t) ((((((((uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(uint64_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) - 1 > 4 * PyLong_SHIFT) {
                            return (uint64_t) (((uint64_t)-1)*(((((((((uint64_t)digits[3]) << PyLong_SHIFT) | (uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(uint64_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(uint64_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(uint64_t) - 1 > 4 * PyLong_SHIFT) {
                            return (uint64_t) ((((((((((uint64_t)digits[3]) << PyLong_SHIFT) | (uint64_t)digits[2]) << PyLong_SHIFT) | (uint64_t)digits[1]) << PyLong_SHIFT) | (uint64_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(uint64_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(uint64_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(uint64_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(uint64_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            uint64_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (uint64_t) -1;
        }
    } else {
        uint64_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (uint64_t) -1;
        val = __Pyx_PyInt_As_uint64_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to uint64_t");
    return (uint64_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to uint64_t");
    return (uint64_t) -1;
}

/* CIntFromPy */
                  static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
                  static CYTHON_INLINE unsigned long __Pyx_PyInt_As_unsigned_long(PyObject *x) {
    const unsigned long neg_one = (unsigned long) -1, const_zero = (unsigned long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(unsigned long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(unsigned long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (unsigned long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (unsigned long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(unsigned long, digit, digits[0])
                case 2:
                    if (8 * sizeof(unsigned long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) >= 2 * PyLong_SHIFT) {
                            return (unsigned long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) >= 3 * PyLong_SHIFT) {
                            return (unsigned long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) >= 4 * PyLong_SHIFT) {
                            return (unsigned long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (unsigned long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(unsigned long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(unsigned long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (unsigned long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(unsigned long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(unsigned long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(unsigned long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) - 1 > 2 * PyLong_SHIFT) {
                            return (unsigned long) (((unsigned long)-1)*(((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(unsigned long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) - 1 > 2 * PyLong_SHIFT) {
                            return (unsigned long) ((((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(unsigned long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) - 1 > 3 * PyLong_SHIFT) {
                            return (unsigned long) (((unsigned long)-1)*(((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) - 1 > 3 * PyLong_SHIFT) {
                            return (unsigned long) ((((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(unsigned long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) - 1 > 4 * PyLong_SHIFT) {
                            return (unsigned long) (((unsigned long)-1)*(((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned long) - 1 > 4 * PyLong_SHIFT) {
                            return (unsigned long) ((((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(unsigned long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(unsigned long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            unsigned long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (unsigned long) -1;
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (unsigned long) -1;
        val = __Pyx_PyInt_As_unsigned_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to unsigned long");
    return (unsigned long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to unsigned long");
    return (unsigned long) -1;
}

/* CIntFromPy */
                  static CYTHON_INLINE size_t __Pyx_PyInt_As_size_t(PyObject *x) {
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(size_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(size_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (size_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(size_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 2 * PyLong_SHIFT) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 3 * PyLong_SHIFT) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) >= 4 * PyLong_SHIFT) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (size_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(size_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (size_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(size_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(size_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(size_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(size_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(size_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(size_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(size_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            size_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (size_t) -1;
        }
    } else {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyInt_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* IterableCoroutine */
                  static PyTypeObject __pyx_IterableCoroutineType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "iterable_coroutine",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
#if CYTHON_USE_ASYNC_SLOTS
    &__pyx_Coroutine_as_async,
#else
    0,
#endif
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
#if CYTHON_USE_ASYNC_SLOTS && CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3 && PY_VERSION_HEX < 0x030500B1
    __Pyx_Coroutine_compare,
#else
    0,
#endif
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    __Pyx_Coroutine_await,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Coroutine_methods,
    __pyx_Coroutine_memberlist,
    __pyx_Coroutine_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if PY_VERSION_HEX >= 0x030400a1
    __Pyx_Coroutine_del,
#endif
};
static int __pyx_IterableCoroutine_init(void) {
    __pyx_IterableCoroutineType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_IterableCoroutineType = __Pyx_FetchCommonType(&__pyx_IterableCoroutineType_type);
    if (unlikely(!__pyx_IterableCoroutineType))
        return -1;
    return 0;
}

/* Generator */
                  static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
                  static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* ModuleImport */
                  #ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

/* TypeImport */
                  #ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. Expected %zd, got %zd",
            module_name, class_name, basicsize, size);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s has the wrong size, try recompiling. Expected %zd, got %zd",
            module_name, class_name, basicsize, size);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

/* InitStrings */
                  static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
